core/modules/ffi/rlgl/abbr
library
Functions
-
rlActiveDrawBuffers(int count)
→ void
-
See RaylibRlgl.rlActiveDrawBuffers.
-
rlActiveTextureSlot(int slot)
→ void
-
See RaylibRlgl.rlActiveTextureSlot.
-
rlBegin(int mode)
→ void
-
See RaylibRlgl.rlBegin.
-
rlBindFramebuffer(int target, int framebuffer)
→ void
-
See RaylibRlgl.rlBindFramebuffer.
-
rlBindImageTexture(int id, int index, int format, bool readonly)
→ void
-
See RaylibRlgl.rlBindImageTexture.
-
rlBindShaderBuffer(int id, int index)
→ void
-
See RaylibRlgl.rlBindShaderBuffer.
-
rlBlitFramebuffer(int srcX, int srcY, int srcWidth, int srcHeight, int dstX, int dstY, int dstWidth, int dstHeight, int bufferMask)
→ void
-
See RaylibRlgl.rlBlitFramebuffer.
-
rlCheckErrors()
→ void
-
See RaylibRlgl.rlCheckErrors.
-
rlCheckRenderBatchLimit(int vCount)
→ bool
-
See RaylibRlgl.rlCheckRenderBatchLimit.
-
rlClearColor(int r, int g, int b, int a)
→ void
-
See RaylibRlgl.rlClearColor.
-
rlClearScreenBuffers()
→ void
-
See RaylibRlgl.rlClearScreenBuffers.
-
rlColor3f(double x, double y, double z)
→ void
-
See RaylibRlgl.rlColor3f.
-
rlColor4f(double x, double y, double z, double w)
→ void
-
See RaylibRlgl.rlColor4f.
-
rlColor4ub(int r, int g, int b, int a)
→ void
-
See RaylibRlgl.rlColor4ub.
-
rlColorMask(bool r, bool g, bool b, bool a)
→ void
-
See RaylibRlgl.rlColorMask.
-
rlComputeShaderDispatch(int groupX, int groupY, int groupZ)
→ void
-
See RaylibRlgl.rlComputeShaderDispatch.
-
rlCopyFramebuffer(int x, int y, int width, int height, int format, Pointer<Void> pixels)
→ void
-
See RaylibRlgl.rlCopyFramebuffer.
-
rlCopyShaderBuffer(int destId, int srcId, int destOffset, int srcOffset, int count)
→ void
-
See RaylibRlgl.rlCopyShaderBuffer.
-
rlCubemapParameters(int id, int param, int value)
→ void
-
See RaylibRlgl.rlCubemapParameters.
-
rlDisableBackfaceCulling()
→ void
-
See RaylibRlgl.rlDisableBackfaceCulling.
-
rlDisableColorBlend()
→ void
-
See RaylibRlgl.rlDisableColorBlend.
-
rlDisableDepthMask()
→ void
-
See RaylibRlgl.rlDisableDepthMask.
-
rlDisableDepthTest()
→ void
-
See RaylibRlgl.rlDisableDepthTest.
-
rlDisableFramebuffer()
→ void
-
See RaylibRlgl.rlDisableFramebuffer.
-
rlDisablePointMode()
→ void
-
See RaylibRlgl.rlDisablePointMode.
-
rlDisableScissorTest()
→ void
-
See RaylibRlgl.rlDisableScissorTest.
-
rlDisableShader()
→ void
-
See RaylibRlgl.rlDisableShader.
-
rlDisableSmoothLines()
→ void
-
See RaylibRlgl.rlDisableSmoothLines.
-
rlDisableStatePointer(int vertexAttribType)
→ void
-
See RaylibRlgl.rlDisableStatePointer.
-
rlDisableStereoRender()
→ void
-
See RaylibRlgl.rlDisableStereoRender.
-
rlDisableTexture()
→ void
-
See RaylibRlgl.rlDisableTexture.
-
rlDisableTextureCubemap()
→ void
-
See RaylibRlgl.rlDisableTextureCubemap.
-
rlDisableVertexArray()
→ void
-
See RaylibRlgl.rlDisableVertexArray.
-
rlDisableVertexAttribute(int index)
→ void
-
See RaylibRlgl.rlDisableVertexAttribute.
-
rlDisableVertexBuffer()
→ void
-
See RaylibRlgl.rlDisableVertexBuffer.
-
rlDisableVertexBufferElement()
→ void
-
See RaylibRlgl.rlDisableVertexBufferElement.
-
rlDisableWireMode()
→ void
-
See RaylibRlgl.rlDisableWireMode.
-
rlDrawRenderBatch(Pointer<RlRenderBatchC> batch)
→ void
-
See RaylibRlgl.rlDrawRenderBatch.
-
rlDrawRenderBatchActive()
→ void
-
See RaylibRlgl.rlDrawRenderBatchActive.
-
rlDrawVertexArray(int offset, int count)
→ void
-
See RaylibRlgl.rlDrawVertexArray.
-
rlDrawVertexArrayElements(int offset, int count, Pointer<Void> buffer)
→ void
-
See RaylibRlgl.rlDrawVertexArrayElements.
-
rlDrawVertexArrayElementsInstanced(int offset, int count, Pointer<Void> buffer, int instances)
→ void
-
See RaylibRlgl.rlDrawVertexArrayElementsInstanced.
-
rlDrawVertexArrayInstanced(int offset, int count, int instances)
→ void
-
See RaylibRlgl.rlDrawVertexArrayInstanced.
-
rlEnableBackfaceCulling()
→ void
-
See RaylibRlgl.rlEnableBackfaceCulling.
-
rlEnableColorBlend()
→ void
-
See RaylibRlgl.rlEnableColorBlend.
-
rlEnableDepthMask()
→ void
-
See RaylibRlgl.rlEnableDepthMask.
-
rlEnableDepthTest()
→ void
-
See RaylibRlgl.rlEnableDepthTest.
-
rlEnableFramebuffer(int id)
→ void
-
See RaylibRlgl.rlEnableFramebuffer.
-
rlEnablePointMode()
→ void
-
See RaylibRlgl.rlEnablePointMode.
-
rlEnableScissorTest()
→ void
-
See RaylibRlgl.rlEnableScissorTest.
-
rlEnableShader(int id)
→ void
-
See RaylibRlgl.rlEnableShader.
-
rlEnableSmoothLines()
→ void
-
See RaylibRlgl.rlEnableSmoothLines.
-
rlEnableStatePointer(int vertexAttribType, Pointer<Void> buffer)
→ void
-
See RaylibRlgl.rlEnableStatePointer.
-
rlEnableStereoRender()
→ void
-
See RaylibRlgl.rlEnableStereoRender.
-
rlEnableTexture(int id)
→ void
-
See RaylibRlgl.rlEnableTexture.
-
rlEnableTextureCubemap(int id)
→ void
-
See RaylibRlgl.rlEnableTextureCubemap.
-
rlEnableVertexArray(int vaoId)
→ bool
-
See RaylibRlgl.rlEnableVertexArray.
-
rlEnableVertexAttribute(int index)
→ void
-
See RaylibRlgl.rlEnableVertexAttribute.
-
rlEnableVertexBuffer(int id)
→ void
-
See RaylibRlgl.rlEnableVertexBuffer.
-
rlEnableVertexBufferElement(int id)
→ void
-
See RaylibRlgl.rlEnableVertexBufferElement.
-
rlEnableWireMode()
→ void
-
See RaylibRlgl.rlEnableWireMode.
-
rlEnd()
→ void
-
See RaylibRlgl.rlEnd.
-
rlFramebufferAttach(int fboId, int texId, int attachType, int texType, int mipLevel)
→ void
-
See RaylibRlgl.rlFramebufferAttach.
-
rlFramebufferComplete(int id)
→ bool
-
See RaylibRlgl.rlFramebufferComplete.
-
rlFrustum(double left, double right, double bottom, double top, double znear, double zfar)
→ void
-
See RaylibRlgl.rlFrustum.
-
rlGenTextureMipmaps(int id, int width, int height, int format, Pointer<Int> mipmaps)
→ void
-
See RaylibRlgl.rlGenTextureMipmaps.
-
rlGetActiveFramebuffer()
→ int
-
See RaylibRlgl.rlGetActiveFramebuffer.
-
rlGetCullDistanceFar()
→ double
-
See RaylibRlgl.rlGetCullDistanceFar.
-
rlGetCullDistanceNear()
→ double
-
See RaylibRlgl.rlGetCullDistanceNear.
-
rlGetFramebufferHeight()
→ int
-
See RaylibRlgl.rlGetFramebufferHeight.
-
rlGetFramebufferWidth()
→ int
-
See RaylibRlgl.rlGetFramebufferWidth.
-
rlGetGlTextureFormats(int format, Pointer<UnsignedInt> glInternalFormat, Pointer<UnsignedInt> glFormat, Pointer<UnsignedInt> glType)
→ void
-
See RaylibRlgl.rlGetGlTextureFormats.
-
rlGetLineWidth()
→ double
-
See RaylibRlgl.rlGetLineWidth.
-
rlGetLocationAttrib(int shaderId, Pointer<Char> attribName)
→ int
-
See RaylibRlgl.rlGetLocationAttrib.
-
rlGetLocationUniform(int shaderId, Pointer<Char> uniformName)
→ int
-
See RaylibRlgl.rlGetLocationUniform.
-
rlGetMatrixModelview()
→ MatrixC
-
See RaylibRlgl.rlGetMatrixModelview.
-
rlGetMatrixProjection()
→ MatrixC
-
See RaylibRlgl.rlGetMatrixProjection.
-
rlGetMatrixProjectionStereo(int eye)
→ MatrixC
-
See RaylibRlgl.rlGetMatrixProjectionStereo.
-
rlGetMatrixTransform()
→ MatrixC
-
See RaylibRlgl.rlGetMatrixTransform.
-
rlGetMatrixViewOffsetStereo(int eye)
→ MatrixC
-
See RaylibRlgl.rlGetMatrixViewOffsetStereo.
-
rlGetPixelFormatName(int format)
→ Pointer<Char>
-
See RaylibRlgl.rlGetPixelFormatName.
-
rlGetPointSize()
→ double
-
See RaylibRlgl.rlGetPointSize.
-
rlGetProcAddress(Pointer<Char> procName)
→ Pointer<Void>
-
See RaylibRlgl.rlGetProcAddress.
-
rlGetShaderBufferSize(int id)
→ int
-
See RaylibRlgl.rlGetShaderBufferSize.
-
rlGetShaderIdDefault()
→ int
-
See RaylibRlgl.rlGetShaderIdDefault.
-
rlGetShaderLocsDefault()
→ Pointer<Int>
-
See RaylibRlgl.rlGetShaderLocsDefault.
-
rlGetTextureIdDefault()
→ int
-
See RaylibRlgl.rlGetTextureIdDefault.
-
rlGetVersion()
→ int
-
See RaylibRlgl.rlGetVersion.
-
rlglClose()
→ void
-
See RaylibRlgl.rlglClose.
-
rlglInit(int width, int height)
→ void
-
See RaylibRlgl.rlglInit.
-
rlIsStereoRenderEnabled()
→ bool
-
See RaylibRlgl.rlIsStereoRenderEnabled.
-
rlLoadDrawCube()
→ void
-
See RaylibRlgl.rlLoadDrawCube.
-
rlLoadDrawQuad()
→ void
-
See RaylibRlgl.rlLoadDrawQuad.
-
rlLoadExtensions(Pointer<Void> loader)
→ void
-
See RaylibRlgl.rlLoadExtensions.
-
rlLoadFramebuffer()
→ int
-
See RaylibRlgl.rlLoadFramebuffer.
-
rlLoadIdentity()
→ void
-
See RaylibRlgl.rlLoadIdentity.
-
rlLoadRenderBatch(int numBuffers, int bufferElements)
→ RlRenderBatchC
-
See RaylibRlgl.rlLoadRenderBatch.
-
rlLoadShader(Pointer<Char> code, int type)
→ int
-
See RaylibRlgl.rlLoadShader.
-
rlLoadShaderBuffer(int size, Pointer<Void> data, int usageHint)
→ int
-
See RaylibRlgl.rlLoadShaderBuffer.
-
rlLoadShaderProgram(Pointer<Char> vsCode, Pointer<Char> fsCode)
→ int
-
See RaylibRlgl.rlLoadShaderProgram.
-
rlLoadShaderProgramCompute(int csId)
→ int
-
See RaylibRlgl.rlLoadShaderProgramCompute.
-
rlLoadShaderProgramEx(int vsId, int fsId)
→ int
-
See RaylibRlgl.rlLoadShaderProgramEx.
-
rlLoadTexture(Pointer<Void> data, int width, int height, int format, int mipmapCount)
→ int
-
See RaylibRlgl.rlLoadTexture.
-
rlLoadTextureCubemap(Pointer<Void> data, int size, int format, int mipmapCount)
→ int
-
See RaylibRlgl.rlLoadTextureCubemap.
-
rlLoadTextureDepth(int width, int height, bool useRenderBuffer)
→ int
-
See RaylibRlgl.rlLoadTextureDepth.
-
rlLoadVertexArray()
→ int
-
See RaylibRlgl.rlLoadVertexArray.
-
rlLoadVertexBuffer(Pointer<Void> buffer, int size, bool dynamic)
→ int
-
See RaylibRlgl.rlLoadVertexBuffer.
-
rlLoadVertexBufferElement(Pointer<Void> buffer, int size, bool dynamic)
→ int
-
See RaylibRlgl.rlLoadVertexBufferElement.
-
rlMatrixMode(int mode)
→ void
-
See RaylibRlgl.rlMatrixMode.
-
rlMultMatrixf(Pointer<Float> matf)
→ void
-
See RaylibRlgl.rlMultMatrixf.
-
rlNormal3f(double x, double y, double z)
→ void
-
See RaylibRlgl.rlNormal3f.
-
rlOrtho(double left, double right, double bottom, double top, double znear, double zfar)
→ void
-
See RaylibRlgl.rlOrtho.
-
rlPopMatrix()
→ void
-
See RaylibRlgl.rlPopMatrix.
-
rlPushMatrix()
→ void
-
See RaylibRlgl.rlPushMatrix.
-
rlReadScreenPixels(int width, int height)
→ Pointer<UnsignedChar>
-
See RaylibRlgl.rlReadScreenPixels.
-
rlReadShaderBuffer(int id, Pointer<Void> dest, int count, int offset)
→ void
-
See RaylibRlgl.rlReadShaderBuffer.
-
rlReadTexturePixels(int id, int width, int height, int format)
→ Pointer<Void>
-
See RaylibRlgl.rlReadTexturePixels.
-
rlResizeFramebuffer(int width, int height)
→ void
-
See RaylibRlgl.rlResizeFramebuffer.
-
rlRotatef(double angle, double x, double y, double z)
→ void
-
See RaylibRlgl.rlRotatef.
-
rlScalef(double x, double y, double z)
→ void
-
See RaylibRlgl.rlScalef.
-
rlScissor(int x, int y, int width, int height)
→ void
-
See RaylibRlgl.rlScissor.
-
rlSetBlendFactors(int glSrcFactor, int glDstFactor, int glEquation)
→ void
-
See RaylibRlgl.rlSetBlendFactors.
-
See RaylibRlgl.rlSetBlendFactorsSeparate.
-
rlSetBlendMode(int mode)
→ void
-
See RaylibRlgl.rlSetBlendMode.
-
rlSetClipPlanes(double nearPlane, double farPlane)
→ void
-
See RaylibRlgl.rlSetClipPlanes.
-
rlSetCullFace(int mode)
→ void
-
See RaylibRlgl.rlSetCullFace.
-
rlSetFramebufferHeight(int height)
→ void
-
See RaylibRlgl.rlSetFramebufferHeight.
-
rlSetFramebufferWidth(int width)
→ void
-
See RaylibRlgl.rlSetFramebufferWidth.
-
rlSetLineWidth(double width)
→ void
-
See RaylibRlgl.rlSetLineWidth.
-
rlSetMatrixModelview(MatrixC view)
→ void
-
See RaylibRlgl.rlSetMatrixModelview.
-
rlSetMatrixProjection(MatrixC proj)
→ void
-
See RaylibRlgl.rlSetMatrixProjection.
-
rlSetMatrixProjectionStereo(MatrixC right, MatrixC left)
→ void
-
See RaylibRlgl.rlSetMatrixProjectionStereo.
-
rlSetMatrixViewOffsetStereo(MatrixC right, MatrixC left)
→ void
-
See RaylibRlgl.rlSetMatrixViewOffsetStereo.
-
rlSetPointSize(double size)
→ void
-
See RaylibRlgl.rlSetPointSize.
-
rlSetRenderBatchActive(Pointer<RlRenderBatchC> batch)
→ void
-
See RaylibRlgl.rlSetRenderBatchActive.
-
rlSetShader(int id, Pointer<Int> locs)
→ void
-
See RaylibRlgl.rlSetShader.
-
rlSetTexture(int id)
→ void
-
See RaylibRlgl.rlSetTexture.
-
rlSetUniform(int locIndex, Pointer<Void> value, int uniformType, int count)
→ void
-
See RaylibRlgl.rlSetUniform.
-
rlSetUniformMatrices(int locIndex, Pointer<MatrixC> mat, int count)
→ void
-
See RaylibRlgl.rlSetUniformMatrices.
-
rlSetUniformMatrix(int locIndex, MatrixC mat)
→ void
-
See RaylibRlgl.rlSetUniformMatrix.
-
rlSetUniformSampler(int locIndex, int textureId)
→ void
-
See RaylibRlgl.rlSetUniformSampler.
-
rlSetVertexAttribute(int index, int compSize, int type, bool normalized, int stride, int offset)
→ void
-
See RaylibRlgl.rlSetVertexAttribute.
-
rlSetVertexAttributeDefault(int locIndex, Pointer<Void> value, int attribType, int count)
→ void
-
See RaylibRlgl.rlSetVertexAttributeDefault.
-
rlSetVertexAttributeDivisor(int index, int divisor)
→ void
-
See RaylibRlgl.rlSetVertexAttributeDivisor.
-
rlTexCoord2f(double x, double y)
→ void
-
See RaylibRlgl.rlTexCoord2f.
-
rlTextureParameters(int id, int param, int value)
→ void
-
See RaylibRlgl.rlTextureParameters.
-
rlTranslatef(double x, double y, double z)
→ void
-
See RaylibRlgl.rlTranslatef.
-
rlUnloadFramebuffer(int id)
→ void
-
See RaylibRlgl.rlUnloadFramebuffer.
-
rlUnloadRenderBatch(RlRenderBatchC batch)
→ void
-
See RaylibRlgl.rlUnloadRenderBatch.
-
rlUnloadShader(int id)
→ void
-
See RaylibRlgl.rlUnloadShader.
-
rlUnloadShaderBuffer(int ssboId)
→ void
-
See RaylibRlgl.rlUnloadShaderBuffer.
-
rlUnloadShaderProgram(int id)
→ void
-
See RaylibRlgl.rlUnloadShaderProgram.
-
rlUnloadTexture(int id)
→ void
-
See RaylibRlgl.rlUnloadTexture.
-
rlUnloadVertexArray(int vaoId)
→ void
-
See RaylibRlgl.rlUnloadVertexArray.
-
rlUnloadVertexBuffer(int vboId)
→ void
-
See RaylibRlgl.rlUnloadVertexBuffer.
-
rlUpdateShaderBuffer(int id, Pointer<Void> data, int dataSize, int offset)
→ void
-
See RaylibRlgl.rlUpdateShaderBuffer.
-
rlUpdateTexture(int id, int offsetX, int offsetY, int width, int height, int format, Pointer<Void> data)
→ void
-
See RaylibRlgl.rlUpdateTexture.
-
rlUpdateVertexBuffer(int bufferId, Pointer<Void> data, int dataSize, int offset)
→ void
-
See RaylibRlgl.rlUpdateVertexBuffer.
-
rlUpdateVertexBufferElements(int id, Pointer<Void> data, int dataSize, int offset)
→ void
-
See RaylibRlgl.rlUpdateVertexBufferElements.
-
rlVertex2f(double x, double y)
→ void
-
See RaylibRlgl.rlVertex2f.
-
rlVertex2i(int x, int y)
→ void
-
See RaylibRlgl.rlVertex2i.
-
rlVertex3f(double x, double y, double z)
→ void
-
See RaylibRlgl.rlVertex3f.
-
rlViewport(int x, int y, int width, int height)
→ void
-
See RaylibRlgl.rlViewport.