registry property
The registry of live callbacks for this callback type.
Each concrete subclass owns a static List<CallbackD> and returns it
here. The registry is used to track active callbacks and support bulk
disposal via disposeRegistry.
Implementation
@override
@nonVirtual
get registry => _registry;