AutomationEventD class

Inheritance
Available extensions

Constructors

AutomationEventD({Pointer<AutomationEventC>? originalPointer, int frame = 0, int type = 0, List<int>? params})
AutomationEventD.zero()
factory

Properties

allocKey String
no setterinherited
cStructName String
no setterinherited
frame int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
internalId int
no setterinherited
isDisposed bool
no setterinherited
originalPointer Pointer<AutomationEventC>?
getter/setter pairinherited
paramCount int

Available on AutomationEventD, provided by the AutomationEventDLike extension

no setter
params List<int>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structName String
no setterinherited
tag String
no setterinherited
type int
getter/setter pair

Methods

allocateInto(RaylibTemp temp, Pointer<AutomationEventC> p, String key) → void
override
allocatePointer(RaylibTemp temp, String key, [int count = 1]) Pointer<AutomationEventC>
override
clone() AutomationEventD
override
copy() AutomationEventD
inherited
getOriginalPointer() Pointer<AutomationEventC>
inherited
getOriginalPointerAndDispose() Pointer<AutomationEventC>
inherited
markDisposed() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onOriginalPointer(void callback(Pointer<AutomationEventC> p)) → void
inherited
setC(AutomationEventC o) AutomationEventD
override
setD(AutomationEventD o) AutomationEventD
override
setTag(String newTag) AutomationEventD
inherited
signature() String
override
syncInto(RaylibTemp temp, Pointer<AutomationEventC> p, String key) → void
override
toC(RaylibTemp temp, String key) Pointer<AutomationEventC>
inherited
toString() String
A string representation of this object.
inherited
writeInto(AutomationEventC p) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited