BaseRaylibModule class abstract

Implementers

Constructors

BaseRaylibModule(Raylib rl)

Properties

hashCode int
The hash code for this object.
no setterinherited
logger → Logger
no setter
rl Raylib
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

debug(bool v) → void
debugFilter(bool filter(String)) → void
debugInfo(String message) → void
debugTime(bool v) → void
debugWarn(String message) → void
disableSync<T>(T f()) → T
dispose() → void
load() → void
logInfo(String message) → void
logWarn(String message) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose(void fn()) → void
run<T>(String name(), T f()) → T
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited