BoneInfoD class

Inheritance
Available extensions

Constructors

BoneInfoD({Pointer<BoneInfoC>? originalPointer, String name = '', int parent = 0})
BoneInfoD.zero()
factory

Properties

allocKey String
no setterinherited
cStructName String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
internalId int
no setterinherited
isDisposed bool
no setterinherited
name String
getter/setter pair
nameLength int

Available on BoneInfoD, provided by the BoneInfoDLike extension

no setter
originalPointer Pointer<BoneInfoC>?
getter/setter pairinherited
parent int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structName String
no setterinherited
tag String
no setterinherited

Methods

allocateInto(RaylibTemp temp, Pointer<BoneInfoC> p, String key) → void
override
allocatePointer(RaylibTemp temp, String key, [int count = 1]) Pointer<BoneInfoC>
override
clone() BoneInfoD
override
copy() BoneInfoD
inherited
getOriginalPointer() Pointer<BoneInfoC>
inherited
getOriginalPointerAndDispose() Pointer<BoneInfoC>
inherited
markDisposed() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onOriginalPointer(void callback(Pointer<BoneInfoC> p)) → void
inherited
setC(BoneInfoC o) BoneInfoD
override
setD(BoneInfoD o) BoneInfoD
override
setTag(String newTag) BoneInfoD
inherited
signature() String
override
syncInto(RaylibTemp temp, Pointer<BoneInfoC> p, String key) → void
inherited
toC(RaylibTemp temp, String key) Pointer<BoneInfoC>
inherited
toString() String
A string representation of this object.
inherited
writeInto(BoneInfoC p) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited