setC method
Copies the fields of the native struct o into this instance.
Implementation
@override
BoundingBoxD setC(BoundingBoxC o) {
min.setC(o.min);
max.setC(o.max);
return this;
}
Copies the fields of the native struct o into this instance.
@override
BoundingBoxD setC(BoundingBoxC o) {
min.setC(o.min);
max.setC(o.max);
return this;
}