setD method
Copies the fields of the Dart struct o into this instance.
Implementation
@override
BoundingBoxD setD(BoundingBoxD o) {
originalPointer ??= o.originalPointer;
min.setD(o.min);
max.setD(o.max);
return this;
}
Copies the fields of the Dart struct o into this instance.
@override
BoundingBoxD setD(BoundingBoxD o) {
originalPointer ??= o.originalPointer;
min.setD(o.min);
max.setD(o.max);
return this;
}