writeInto method
Writes all fields directly into the native struct reference p.
For nested structs, use writeInto as well.
Implementation
@override
void writeInto(BoundingBoxC p) {
min.writeInto(p.min);
max.writeInto(p.max);
}
Writes all fields directly into the native struct reference p.
For nested structs, use writeInto as well.
@override
void writeInto(BoundingBoxC p) {
min.writeInto(p.min);
max.writeInto(p.max);
}