allocateInto method
Writes all fields into the native struct at p, allocating nested pointers
into temp under key as needed.
Called after allocatePointer to populate the zeroed memory (or reuse). For structs
with no nested pointers this is typically equivalent to writeInto(p.ref).
Implementation
@override
void allocateInto(RaylibTemp temp, Pointer<Camera2DC> p, String key)
=> writeInto(p.ref);