Camera3DD class

Inheritance

Constructors

Camera3DD({Pointer<Camera3DC>? originalPointer, Vector3D? position, Vector3D? target, Vector3D? up, double fovy = 45, CameraProjection projection = .CAMERA_PERSPECTIVE})
Camera3DD.zero()
factory

Properties

allocKey String
no setterinherited
cStructName String
no setterinherited
fovy double
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
internalId int
no setterinherited
isDisposed bool
no setterinherited
originalPointer Pointer<Camera3DC>?
getter/setter pairinherited
position Vector3D
getter/setter pair
projection CameraProjection
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structName String
no setterinherited
tag String
no setterinherited
target Vector3D
getter/setter pair
up Vector3D
getter/setter pair

Methods

allocateInto(RaylibTemp temp, Pointer<Camera3DC> p, String key) → void
override
allocatePointer(RaylibTemp temp, String key, [int count = 1]) Pointer<Camera3DC>
override
clone() Camera3DD
override
copy() Camera3DD
inherited
getOriginalPointer() Pointer<Camera3DC>
inherited
getOriginalPointerAndDispose() Pointer<Camera3DC>
inherited
markDisposed() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onOriginalPointer(void callback(Pointer<Camera3DC> p)) → void
inherited
setC(Camera3DC o) Camera3DD
override
setD(Camera3DD o) Camera3DD
override
setTag(String newTag) Camera3DD
inherited
signature() String
override
syncInto(RaylibTemp temp, Pointer<Camera3DC> p, String key) → void
inherited
toC(RaylibTemp temp, String key) Pointer<Camera3DC>
inherited
toString() String
A string representation of this object.
inherited
writeInto(Camera3DC p) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited