ConfigFlags enum
Values
- FLAG_VSYNC_HINT → const ConfigFlags
-
const ConfigFlags(64) - FLAG_FULLSCREEN_MODE → const ConfigFlags
-
const ConfigFlags(2) - FLAG_WINDOW_RESIZABLE → const ConfigFlags
-
const ConfigFlags(4) - FLAG_WINDOW_UNDECORATED → const ConfigFlags
-
const ConfigFlags(8) - FLAG_WINDOW_HIDDEN → const ConfigFlags
-
const ConfigFlags(128) - FLAG_WINDOW_MINIMIZED → const ConfigFlags
-
const ConfigFlags(512) - FLAG_WINDOW_MAXIMIZED → const ConfigFlags
-
const ConfigFlags(1024) - FLAG_WINDOW_UNFOCUSED → const ConfigFlags
-
const ConfigFlags(2048) - FLAG_WINDOW_TOPMOST → const ConfigFlags
-
const ConfigFlags(4096) - FLAG_WINDOW_ALWAYS_RUN → const ConfigFlags
-
const ConfigFlags(256) - FLAG_WINDOW_TRANSPARENT → const ConfigFlags
-
const ConfigFlags(16) - FLAG_WINDOW_HIGHDPI → const ConfigFlags
-
const ConfigFlags(8192) - FLAG_WINDOW_MOUSE_PASSTHROUGH → const ConfigFlags
-
const ConfigFlags(16384) - FLAG_BORDERLESS_WINDOWED_MODE → const ConfigFlags
-
const ConfigFlags(32768) - FLAG_MSAA_4X_HINT → const ConfigFlags
-
const ConfigFlags(32) - FLAG_INTERLACED_HINT → const ConfigFlags
-
const ConfigFlags(65536)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
eq(
FEnum o) → bool -
inherited
-
gt(
FEnum o) → bool -
inherited
-
gte(
FEnum o) → bool -
inherited
-
lt(
FEnum o) → bool -
inherited
-
lte(
FEnum o) → bool -
inherited
-
neq(
FEnum o) → bool -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → ConfigFlags
Constants
-
values
→ const List<
ConfigFlags> - A constant List of the values in this enum, in order of their declaration.