FMouseInfoD class final

Constructors

FMouseInfoD({Vector2D? position, Vector2D? delta, Vector2D? wheel, FMouseButtonInfoD? left, FMouseButtonInfoD? middle, FMouseButtonInfoD? right, FMouseButtonInfoD? side, FMouseButtonInfoD? extra, FMouseButtonInfoD? forward, FMouseButtonInfoD? back})

Properties

back FMouseButtonInfoD
final
delta Vector2D
final
extra FMouseButtonInfoD
final
forward FMouseButtonInfoD
final
hashCode int
The hash code for this object.
no setterinherited
left FMouseButtonInfoD
final
middle FMouseButtonInfoD
final
position Vector2D
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
side FMouseButtonInfoD
final
wheel Vector2D
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited