FontC class final

Inheritance
Implemented types
Available extensions

Constructors

FontC()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
baseSize int
getter/setter pair
glyphCount int
getter/setter pair
glyphPadding int
getter/setter pair
glyphs Pointer<GlyphInfoC>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
recs Pointer<RectangleC>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
texture Texture2DC
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setC(FontC o) FontC

Available on FontC, provided by the FontCEx extension

setD(FontD o) FontC

Available on FontC, provided by the FontCEx extension

toD([Pointer<FontC>? ptr]) FontD

Available on FontC, provided by the FontCEx extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited