FontD class

Inheritance

Constructors

FontD({Pointer<FontC>? originalPointer, int baseSize = 0, int glyphCount = 0, int glyphPadding = 0, TextureD? texture, List<RectangleD>? recs, List<GlyphInfoD>? glyphs})
FontD.zero()
factory

Properties

allocKey String
no setterinherited
baseSize int
getter/setter pair
cStructName String
no setterinherited
glyphCount int
getter/setter pair
glyphPadding int
getter/setter pair
glyphs List<GlyphInfoD>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
internalId int
no setterinherited
isDisposed bool
no setterinherited
originalPointer Pointer<FontC>?
getter/setter pairinherited
recs List<RectangleD>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structName String
no setterinherited
tag String
no setterinherited
texture TextureD
getter/setter pair

Methods

allocateInto(RaylibTemp temp, Pointer<FontC> p, String key) → void
override
allocatePointer(RaylibTemp temp, String key, [int count = 1]) Pointer<FontC>
override
clone() FontD
override
copy() FontD
inherited
getOriginalPointer() Pointer<FontC>
inherited
getOriginalPointerAndDispose() Pointer<FontC>
inherited
markDisposed() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onOriginalPointer(void callback(Pointer<FontC> p)) → void
inherited
setC(FontC o) FontD
override
setD(FontD o) FontD
override
setTag(String newTag) FontD
inherited
signature() String
override
syncInto(RaylibTemp temp, Pointer<FontC> p, String key) → void
override
toC(RaylibTemp temp, String key) Pointer<FontC>
inherited
toString() String
A string representation of this object.
inherited
writeInto(FontC p) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited