GamepadButton enum

Inheritance
Available extensions

Values

GAMEPAD_BUTTON_UNKNOWN → const GamepadButton
const GamepadButton(0)
GAMEPAD_BUTTON_LEFT_FACE_UP → const GamepadButton
const GamepadButton(1)
GAMEPAD_BUTTON_LEFT_FACE_RIGHT → const GamepadButton
const GamepadButton(2)
GAMEPAD_BUTTON_LEFT_FACE_DOWN → const GamepadButton
const GamepadButton(3)
GAMEPAD_BUTTON_LEFT_FACE_LEFT → const GamepadButton
const GamepadButton(4)
GAMEPAD_BUTTON_RIGHT_FACE_UP → const GamepadButton
const GamepadButton(5)
GAMEPAD_BUTTON_RIGHT_FACE_RIGHT → const GamepadButton
const GamepadButton(6)
GAMEPAD_BUTTON_RIGHT_FACE_DOWN → const GamepadButton
const GamepadButton(7)
GAMEPAD_BUTTON_RIGHT_FACE_LEFT → const GamepadButton
const GamepadButton(8)
GAMEPAD_BUTTON_LEFT_TRIGGER_1 → const GamepadButton
const GamepadButton(9)
GAMEPAD_BUTTON_LEFT_TRIGGER_2 → const GamepadButton
const GamepadButton(10)
GAMEPAD_BUTTON_RIGHT_TRIGGER_1 → const GamepadButton
const GamepadButton(11)
GAMEPAD_BUTTON_RIGHT_TRIGGER_2 → const GamepadButton
const GamepadButton(12)
GAMEPAD_BUTTON_MIDDLE_LEFT → const GamepadButton
const GamepadButton(13)
GAMEPAD_BUTTON_MIDDLE → const GamepadButton
const GamepadButton(14)
GAMEPAD_BUTTON_MIDDLE_RIGHT → const GamepadButton
const GamepadButton(15)
GAMEPAD_BUTTON_LEFT_THUMB → const GamepadButton
const GamepadButton(16)
GAMEPAD_BUTTON_RIGHT_THUMB → const GamepadButton
const GamepadButton(17)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GamepadButton

Constants

values → const List<GamepadButton>
A constant List of the values in this enum, in order of their declaration.