Gesture enum
Values
- GESTURE_NONE → const Gesture
-
const Gesture(0) - GESTURE_TAP → const Gesture
-
const Gesture(1) - GESTURE_DOUBLETAP → const Gesture
-
const Gesture(2) - GESTURE_HOLD → const Gesture
-
const Gesture(4) - GESTURE_DRAG → const Gesture
-
const Gesture(8) - GESTURE_SWIPE_RIGHT → const Gesture
-
const Gesture(16) - GESTURE_SWIPE_LEFT → const Gesture
-
const Gesture(32) - GESTURE_SWIPE_UP → const Gesture
-
const Gesture(64) - GESTURE_SWIPE_DOWN → const Gesture
-
const Gesture(128) - GESTURE_PINCH_IN → const Gesture
-
const Gesture(256) - GESTURE_PINCH_OUT → const Gesture
-
const Gesture(512)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
eq(
FEnum o) → bool -
inherited
-
gt(
FEnum o) → bool -
inherited
-
gte(
FEnum o) → bool -
inherited
-
lt(
FEnum o) → bool -
inherited
-
lte(
FEnum o) → bool -
inherited
-
neq(
FEnum o) → bool -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited