GlyphInfoC class final

Inheritance
Implemented types
Available extensions

Constructors

GlyphInfoC()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
advanceX int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
image ImageC
getter/setter pair
offsetX int
getter/setter pair
offsetY int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setC(GlyphInfoC o) GlyphInfoC

Available on GlyphInfoC, provided by the GlyphInfoCEx extension

setD(GlyphInfoD o) GlyphInfoC

Available on GlyphInfoC, provided by the GlyphInfoCEx extension

toD([Pointer<GlyphInfoC>? ptr]) GlyphInfoD

Available on GlyphInfoC, provided by the GlyphInfoCEx extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited