GlyphInfoD class

Inheritance

Constructors

GlyphInfoD({Pointer<GlyphInfoC>? originalPointer, int value = 0, int offsetX = 0, int offsetY = 0, int advanceX = 0, ImageD? image})
GlyphInfoD.zero()
factory

Properties

advanceX int
getter/setter pair
allocKey String
no setterinherited
cStructName String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
image ImageD
getter/setter pair
internalId int
no setterinherited
isDisposed bool
no setterinherited
offsetX int
getter/setter pair
offsetY int
getter/setter pair
originalPointer Pointer<GlyphInfoC>?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structName String
no setterinherited
tag String
no setterinherited
value int
getter/setter pair

Methods

allocateInto(RaylibTemp temp, Pointer<GlyphInfoC> p, String key) → void
override
allocatePointer(RaylibTemp temp, String key, [int count = 1]) Pointer<GlyphInfoC>
override
clone() GlyphInfoD
override
copy() GlyphInfoD
inherited
getOriginalPointer() Pointer<GlyphInfoC>
inherited
getOriginalPointerAndDispose() Pointer<GlyphInfoC>
inherited
markDisposed() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onOriginalPointer(void callback(Pointer<GlyphInfoC> p)) → void
inherited
setC(GlyphInfoC o) GlyphInfoD
override
setD(GlyphInfoD o) GlyphInfoD
override
setTag(String newTag) GlyphInfoD
inherited
signature() String
override
syncInto(RaylibTemp temp, Pointer<GlyphInfoC> p, String key) → void
inherited
toC(RaylibTemp temp, String key) Pointer<GlyphInfoC>
inherited
toString() String
A string representation of this object.
inherited
writeInto(GlyphInfoC p) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited