GuiIconName enum

Inheritance
Available extensions

Values

ICON_NONE → const GuiIconName
const GuiIconName(0)
ICON_FOLDER_FILE_OPEN → const GuiIconName
const GuiIconName(1)
ICON_FILE_SAVE_CLASSIC → const GuiIconName
const GuiIconName(2)
ICON_FOLDER_OPEN → const GuiIconName
const GuiIconName(3)
ICON_FOLDER_SAVE → const GuiIconName
const GuiIconName(4)
ICON_FILE_OPEN → const GuiIconName
const GuiIconName(5)
ICON_FILE_SAVE → const GuiIconName
const GuiIconName(6)
ICON_FILE_EXPORT → const GuiIconName
const GuiIconName(7)
ICON_FILE_ADD → const GuiIconName
const GuiIconName(8)
ICON_FILE_DELETE → const GuiIconName
const GuiIconName(9)
ICON_FILETYPE_TEXT → const GuiIconName
const GuiIconName(10)
ICON_FILETYPE_AUDIO → const GuiIconName
const GuiIconName(11)
ICON_FILETYPE_IMAGE → const GuiIconName
const GuiIconName(12)
ICON_FILETYPE_PLAY → const GuiIconName
const GuiIconName(13)
ICON_FILETYPE_VIDEO → const GuiIconName
const GuiIconName(14)
ICON_FILETYPE_INFO → const GuiIconName
const GuiIconName(15)
ICON_FILE_COPY → const GuiIconName
const GuiIconName(16)
ICON_FILE_CUT → const GuiIconName
const GuiIconName(17)
ICON_FILE_PASTE → const GuiIconName
const GuiIconName(18)
ICON_CURSOR_HAND → const GuiIconName
const GuiIconName(19)
ICON_CURSOR_POINTER → const GuiIconName
const GuiIconName(20)
ICON_CURSOR_CLASSIC → const GuiIconName
const GuiIconName(21)
ICON_PENCIL → const GuiIconName
const GuiIconName(22)
ICON_PENCIL_BIG → const GuiIconName
const GuiIconName(23)
ICON_BRUSH_CLASSIC → const GuiIconName
const GuiIconName(24)
ICON_BRUSH_PAINTER → const GuiIconName
const GuiIconName(25)
ICON_WATER_DROP → const GuiIconName
const GuiIconName(26)
ICON_COLOR_PICKER → const GuiIconName
const GuiIconName(27)
ICON_RUBBER → const GuiIconName
const GuiIconName(28)
ICON_COLOR_BUCKET → const GuiIconName
const GuiIconName(29)
ICON_TEXT_T → const GuiIconName
const GuiIconName(30)
ICON_TEXT_A → const GuiIconName
const GuiIconName(31)
ICON_SCALE → const GuiIconName
const GuiIconName(32)
ICON_RESIZE → const GuiIconName
const GuiIconName(33)
ICON_FILTER_POINT → const GuiIconName
const GuiIconName(34)
ICON_FILTER_BILINEAR → const GuiIconName
const GuiIconName(35)
ICON_CROP → const GuiIconName
const GuiIconName(36)
ICON_CROP_ALPHA → const GuiIconName
const GuiIconName(37)
ICON_SQUARE_TOGGLE → const GuiIconName
const GuiIconName(38)
ICON_SYMMETRY → const GuiIconName
const GuiIconName(39)
ICON_SYMMETRY_HORIZONTAL → const GuiIconName
const GuiIconName(40)
ICON_SYMMETRY_VERTICAL → const GuiIconName
const GuiIconName(41)
ICON_LENS → const GuiIconName
const GuiIconName(42)
ICON_LENS_BIG → const GuiIconName
const GuiIconName(43)
ICON_EYE_ON → const GuiIconName
const GuiIconName(44)
ICON_EYE_OFF → const GuiIconName
const GuiIconName(45)
ICON_FILTER_TOP → const GuiIconName
const GuiIconName(46)
ICON_FILTER → const GuiIconName
const GuiIconName(47)
ICON_TARGET_POINT → const GuiIconName
const GuiIconName(48)
ICON_TARGET_SMALL → const GuiIconName
const GuiIconName(49)
ICON_TARGET_BIG → const GuiIconName
const GuiIconName(50)
ICON_TARGET_MOVE → const GuiIconName
const GuiIconName(51)
ICON_CURSOR_MOVE → const GuiIconName
const GuiIconName(52)
ICON_CURSOR_SCALE → const GuiIconName
const GuiIconName(53)
ICON_CURSOR_SCALE_RIGHT → const GuiIconName
const GuiIconName(54)
ICON_CURSOR_SCALE_LEFT → const GuiIconName
const GuiIconName(55)
ICON_UNDO → const GuiIconName
const GuiIconName(56)
ICON_REDO → const GuiIconName
const GuiIconName(57)
ICON_REREDO → const GuiIconName
const GuiIconName(58)
ICON_MUTATE → const GuiIconName
const GuiIconName(59)
ICON_ROTATE → const GuiIconName
const GuiIconName(60)
ICON_REPEAT → const GuiIconName
const GuiIconName(61)
ICON_SHUFFLE → const GuiIconName
const GuiIconName(62)
ICON_EMPTYBOX → const GuiIconName
const GuiIconName(63)
ICON_TARGET → const GuiIconName
const GuiIconName(64)
ICON_TARGET_SMALL_FILL → const GuiIconName
const GuiIconName(65)
ICON_TARGET_BIG_FILL → const GuiIconName
const GuiIconName(66)
ICON_TARGET_MOVE_FILL → const GuiIconName
const GuiIconName(67)
ICON_CURSOR_MOVE_FILL → const GuiIconName
const GuiIconName(68)
ICON_CURSOR_SCALE_FILL → const GuiIconName
const GuiIconName(69)
ICON_CURSOR_SCALE_RIGHT_FILL → const GuiIconName
const GuiIconName(70)
ICON_CURSOR_SCALE_LEFT_FILL → const GuiIconName
const GuiIconName(71)
ICON_UNDO_FILL → const GuiIconName
const GuiIconName(72)
ICON_REDO_FILL → const GuiIconName
const GuiIconName(73)
ICON_REREDO_FILL → const GuiIconName
const GuiIconName(74)
ICON_MUTATE_FILL → const GuiIconName
const GuiIconName(75)
ICON_ROTATE_FILL → const GuiIconName
const GuiIconName(76)
ICON_REPEAT_FILL → const GuiIconName
const GuiIconName(77)
ICON_SHUFFLE_FILL → const GuiIconName
const GuiIconName(78)
ICON_EMPTYBOX_SMALL → const GuiIconName
const GuiIconName(79)
ICON_BOX → const GuiIconName
const GuiIconName(80)
ICON_BOX_TOP → const GuiIconName
const GuiIconName(81)
ICON_BOX_TOP_RIGHT → const GuiIconName
const GuiIconName(82)
ICON_BOX_RIGHT → const GuiIconName
const GuiIconName(83)
ICON_BOX_BOTTOM_RIGHT → const GuiIconName
const GuiIconName(84)
ICON_BOX_BOTTOM → const GuiIconName
const GuiIconName(85)
ICON_BOX_BOTTOM_LEFT → const GuiIconName
const GuiIconName(86)
ICON_BOX_LEFT → const GuiIconName
const GuiIconName(87)
ICON_BOX_TOP_LEFT → const GuiIconName
const GuiIconName(88)
ICON_BOX_CENTER → const GuiIconName
const GuiIconName(89)
ICON_BOX_CIRCLE_MASK → const GuiIconName
const GuiIconName(90)
ICON_POT → const GuiIconName
const GuiIconName(91)
ICON_ALPHA_MULTIPLY → const GuiIconName
const GuiIconName(92)
ICON_ALPHA_CLEAR → const GuiIconName
const GuiIconName(93)
ICON_DITHERING → const GuiIconName
const GuiIconName(94)
ICON_MIPMAPS → const GuiIconName
const GuiIconName(95)
ICON_BOX_GRID → const GuiIconName
const GuiIconName(96)
ICON_GRID → const GuiIconName
const GuiIconName(97)
ICON_BOX_CORNERS_SMALL → const GuiIconName
const GuiIconName(98)
ICON_BOX_CORNERS_BIG → const GuiIconName
const GuiIconName(99)
ICON_FOUR_BOXES → const GuiIconName
const GuiIconName(100)
ICON_GRID_FILL → const GuiIconName
const GuiIconName(101)
ICON_BOX_MULTISIZE → const GuiIconName
const GuiIconName(102)
ICON_ZOOM_SMALL → const GuiIconName
const GuiIconName(103)
ICON_ZOOM_MEDIUM → const GuiIconName
const GuiIconName(104)
ICON_ZOOM_BIG → const GuiIconName
const GuiIconName(105)
ICON_ZOOM_ALL → const GuiIconName
const GuiIconName(106)
ICON_ZOOM_CENTER → const GuiIconName
const GuiIconName(107)
ICON_BOX_DOTS_SMALL → const GuiIconName
const GuiIconName(108)
ICON_BOX_DOTS_BIG → const GuiIconName
const GuiIconName(109)
ICON_BOX_CONCENTRIC → const GuiIconName
const GuiIconName(110)
ICON_BOX_GRID_BIG → const GuiIconName
const GuiIconName(111)
ICON_OK_TICK → const GuiIconName
const GuiIconName(112)
ICON_CROSS → const GuiIconName
const GuiIconName(113)
ICON_ARROW_LEFT → const GuiIconName
const GuiIconName(114)
ICON_ARROW_RIGHT → const GuiIconName
const GuiIconName(115)
ICON_ARROW_DOWN → const GuiIconName
const GuiIconName(116)
ICON_ARROW_UP → const GuiIconName
const GuiIconName(117)
ICON_ARROW_LEFT_FILL → const GuiIconName
const GuiIconName(118)
ICON_ARROW_RIGHT_FILL → const GuiIconName
const GuiIconName(119)
ICON_ARROW_DOWN_FILL → const GuiIconName
const GuiIconName(120)
ICON_ARROW_UP_FILL → const GuiIconName
const GuiIconName(121)
ICON_AUDIO → const GuiIconName
const GuiIconName(122)
ICON_FX → const GuiIconName
const GuiIconName(123)
ICON_WAVE → const GuiIconName
const GuiIconName(124)
ICON_WAVE_SINUS → const GuiIconName
const GuiIconName(125)
ICON_WAVE_SQUARE → const GuiIconName
const GuiIconName(126)
ICON_WAVE_TRIANGULAR → const GuiIconName
const GuiIconName(127)
ICON_CROSS_SMALL → const GuiIconName
const GuiIconName(128)
ICON_PLAYER_PREVIOUS → const GuiIconName
const GuiIconName(129)
ICON_PLAYER_PLAY_BACK → const GuiIconName
const GuiIconName(130)
ICON_PLAYER_PLAY → const GuiIconName
const GuiIconName(131)
ICON_PLAYER_PAUSE → const GuiIconName
const GuiIconName(132)
ICON_PLAYER_STOP → const GuiIconName
const GuiIconName(133)
ICON_PLAYER_NEXT → const GuiIconName
const GuiIconName(134)
ICON_PLAYER_RECORD → const GuiIconName
const GuiIconName(135)
ICON_MAGNET → const GuiIconName
const GuiIconName(136)
ICON_LOCK_CLOSE → const GuiIconName
const GuiIconName(137)
ICON_LOCK_OPEN → const GuiIconName
const GuiIconName(138)
ICON_CLOCK → const GuiIconName
const GuiIconName(139)
ICON_TOOLS → const GuiIconName
const GuiIconName(140)
ICON_GEAR → const GuiIconName
const GuiIconName(141)
ICON_GEAR_BIG → const GuiIconName
const GuiIconName(142)
ICON_BIN → const GuiIconName
const GuiIconName(143)
ICON_HAND_POINTER → const GuiIconName
const GuiIconName(144)
ICON_LASER → const GuiIconName
const GuiIconName(145)
ICON_COIN → const GuiIconName
const GuiIconName(146)
ICON_EXPLOSION → const GuiIconName
const GuiIconName(147)
ICON_1UP → const GuiIconName
const GuiIconName(148)
ICON_PLAYER → const GuiIconName
const GuiIconName(149)
ICON_PLAYER_JUMP → const GuiIconName
const GuiIconName(150)
ICON_KEY → const GuiIconName
const GuiIconName(151)
ICON_DEMON → const GuiIconName
const GuiIconName(152)
ICON_TEXT_POPUP → const GuiIconName
const GuiIconName(153)
ICON_GEAR_EX → const GuiIconName
const GuiIconName(154)
ICON_CRACK → const GuiIconName
const GuiIconName(155)
ICON_CRACK_POINTS → const GuiIconName
const GuiIconName(156)
ICON_STAR → const GuiIconName
const GuiIconName(157)
ICON_DOOR → const GuiIconName
const GuiIconName(158)
ICON_EXIT → const GuiIconName
const GuiIconName(159)
ICON_MODE_2D → const GuiIconName
const GuiIconName(160)
ICON_MODE_3D → const GuiIconName
const GuiIconName(161)
ICON_CUBE → const GuiIconName
const GuiIconName(162)
ICON_CUBE_FACE_TOP → const GuiIconName
const GuiIconName(163)
ICON_CUBE_FACE_LEFT → const GuiIconName
const GuiIconName(164)
ICON_CUBE_FACE_FRONT → const GuiIconName
const GuiIconName(165)
ICON_CUBE_FACE_BOTTOM → const GuiIconName
const GuiIconName(166)
ICON_CUBE_FACE_RIGHT → const GuiIconName
const GuiIconName(167)
ICON_CUBE_FACE_BACK → const GuiIconName
const GuiIconName(168)
ICON_CAMERA → const GuiIconName
const GuiIconName(169)
ICON_SPECIAL → const GuiIconName
const GuiIconName(170)
const GuiIconName(171)
const GuiIconName(172)
const GuiIconName(173)
const GuiIconName(174)
const GuiIconName(175)
ICON_TEXT_NOTES → const GuiIconName
const GuiIconName(176)
ICON_NOTEBOOK → const GuiIconName
const GuiIconName(177)
ICON_SUITCASE → const GuiIconName
const GuiIconName(178)
ICON_SUITCASE_ZIP → const GuiIconName
const GuiIconName(179)
ICON_MAILBOX → const GuiIconName
const GuiIconName(180)
ICON_MONITOR → const GuiIconName
const GuiIconName(181)
ICON_PRINTER → const GuiIconName
const GuiIconName(182)
ICON_PHOTO_CAMERA → const GuiIconName
const GuiIconName(183)
ICON_PHOTO_CAMERA_FLASH → const GuiIconName
const GuiIconName(184)
ICON_HOUSE → const GuiIconName
const GuiIconName(185)
ICON_HEART → const GuiIconName
const GuiIconName(186)
ICON_CORNER → const GuiIconName
const GuiIconName(187)
ICON_VERTICAL_BARS → const GuiIconName
const GuiIconName(188)
ICON_VERTICAL_BARS_FILL → const GuiIconName
const GuiIconName(189)
ICON_LIFE_BARS → const GuiIconName
const GuiIconName(190)
ICON_INFO → const GuiIconName
const GuiIconName(191)
ICON_CROSSLINE → const GuiIconName
const GuiIconName(192)
ICON_HELP → const GuiIconName
const GuiIconName(193)
ICON_FILETYPE_ALPHA → const GuiIconName
const GuiIconName(194)
ICON_FILETYPE_HOME → const GuiIconName
const GuiIconName(195)
ICON_LAYERS_VISIBLE → const GuiIconName
const GuiIconName(196)
ICON_LAYERS → const GuiIconName
const GuiIconName(197)
ICON_WINDOW → const GuiIconName
const GuiIconName(198)
ICON_HIDPI → const GuiIconName
const GuiIconName(199)
ICON_FILETYPE_BINARY → const GuiIconName
const GuiIconName(200)
ICON_HEX → const GuiIconName
const GuiIconName(201)
ICON_SHIELD → const GuiIconName
const GuiIconName(202)
ICON_FILE_NEW → const GuiIconName
const GuiIconName(203)
ICON_FOLDER_ADD → const GuiIconName
const GuiIconName(204)
ICON_ALARM → const GuiIconName
const GuiIconName(205)
ICON_CPU → const GuiIconName
const GuiIconName(206)
ICON_ROM → const GuiIconName
const GuiIconName(207)
ICON_STEP_OVER → const GuiIconName
const GuiIconName(208)
ICON_STEP_INTO → const GuiIconName
const GuiIconName(209)
ICON_STEP_OUT → const GuiIconName
const GuiIconName(210)
ICON_RESTART → const GuiIconName
const GuiIconName(211)
ICON_BREAKPOINT_ON → const GuiIconName
const GuiIconName(212)
ICON_BREAKPOINT_OFF → const GuiIconName
const GuiIconName(213)
ICON_BURGER_MENU → const GuiIconName
const GuiIconName(214)
ICON_CASE_SENSITIVE → const GuiIconName
const GuiIconName(215)
ICON_REG_EXP → const GuiIconName
const GuiIconName(216)
ICON_FOLDER → const GuiIconName
const GuiIconName(217)
ICON_FILE → const GuiIconName
const GuiIconName(218)
ICON_SAND_TIMER → const GuiIconName
const GuiIconName(219)
ICON_WARNING → const GuiIconName
const GuiIconName(220)
ICON_HELP_BOX → const GuiIconName
const GuiIconName(221)
ICON_INFO_BOX → const GuiIconName
const GuiIconName(222)
ICON_PRIORITY → const GuiIconName
const GuiIconName(223)
ICON_LAYERS_ISO → const GuiIconName
const GuiIconName(224)
ICON_LAYERS2 → const GuiIconName
const GuiIconName(225)
ICON_MLAYERS → const GuiIconName
const GuiIconName(226)
ICON_MAPS → const GuiIconName
const GuiIconName(227)
ICON_HOT → const GuiIconName
const GuiIconName(228)
ICON_LABEL → const GuiIconName
const GuiIconName(229)
ICON_NAME_ID → const GuiIconName
const GuiIconName(230)
ICON_SLICING → const GuiIconName
const GuiIconName(231)
ICON_MANUAL_CONTROL → const GuiIconName
const GuiIconName(232)
ICON_COLLISION → const GuiIconName
const GuiIconName(233)
ICON_CIRCLE_ADD → const GuiIconName
const GuiIconName(234)
ICON_CIRCLE_ADD_FILL → const GuiIconName
const GuiIconName(235)
ICON_CIRCLE_WARNING → const GuiIconName
const GuiIconName(236)
ICON_CIRCLE_WARNING_FILL → const GuiIconName
const GuiIconName(237)
ICON_BOX_MORE → const GuiIconName
const GuiIconName(238)
ICON_BOX_MORE_FILL → const GuiIconName
const GuiIconName(239)
ICON_BOX_MINUS → const GuiIconName
const GuiIconName(240)
ICON_BOX_MINUS_FILL → const GuiIconName
const GuiIconName(241)
ICON_UNION → const GuiIconName
const GuiIconName(242)
ICON_INTERSECTION → const GuiIconName
const GuiIconName(243)
ICON_DIFFERENCE → const GuiIconName
const GuiIconName(244)
ICON_SPHERE → const GuiIconName
const GuiIconName(245)
ICON_CYLINDER → const GuiIconName
const GuiIconName(246)
ICON_CONE → const GuiIconName
const GuiIconName(247)
ICON_ELLIPSOID → const GuiIconName
const GuiIconName(248)
ICON_CAPSULE → const GuiIconName
const GuiIconName(249)
ICON_250 → const GuiIconName
const GuiIconName(250)
ICON_251 → const GuiIconName
const GuiIconName(251)
ICON_252 → const GuiIconName
const GuiIconName(252)
ICON_253 → const GuiIconName
const GuiIconName(253)
ICON_254 → const GuiIconName
const GuiIconName(254)
ICON_255 → const GuiIconName
const GuiIconName(255)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GuiIconName

Constants

values → const List<GuiIconName>
A constant List of the values in this enum, in order of their declaration.