GuiScrollBarProperty enum

Inheritance
Mixed-in types
Available extensions

Values

ARROWS_SIZE → const GuiScrollBarProperty
const GuiScrollBarProperty(16)
ARROWS_VISIBLE → const GuiScrollBarProperty
const GuiScrollBarProperty(17)
SCROLL_SLIDER_PADDING → const GuiScrollBarProperty
const GuiScrollBarProperty(18)
SCROLL_SLIDER_SIZE → const GuiScrollBarProperty
const GuiScrollBarProperty(19)
SCROLL_PADDING → const GuiScrollBarProperty
const GuiScrollBarProperty(20)
SCROLL_SPEED → const GuiScrollBarProperty
const GuiScrollBarProperty(21)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GuiScrollBarProperty

Constants

values → const List<GuiScrollBarProperty>
A constant List of the values in this enum, in order of their declaration.