GuiState enum

Inheritance
Available extensions

Values

STATE_NORMAL → const GuiState
const GuiState(0)
STATE_FOCUSED → const GuiState
const GuiState(1)
STATE_PRESSED → const GuiState
const GuiState(2)
STATE_DISABLED → const GuiState
const GuiState(3)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GuiState

Constants

values → const List<GuiState>
A constant List of the values in this enum, in order of their declaration.