HasTempRefs mixin

Superclass constraints
Mixin applications

Properties

hashCode int
The hash code for this object.
no setterinherited
rl Raylib
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refBool1([bool? y, String? x]) Pointer<Bool>
refBool1OrNull([bool? y]) Pointer<Bool>
refBool2([bool? y, String? x]) Pointer<Bool>
refBool2OrNull([bool? y]) Pointer<Bool>
refBool3([bool? y, String? x]) Pointer<Bool>
refBool3OrNull([bool? y]) Pointer<Bool>
refBool4([bool? y, String? x]) Pointer<Bool>
refBool4OrNull([bool? y]) Pointer<Bool>
refChar1([int? y]) Pointer<Char>
refChar1OrNull([int? y]) Pointer<Char>
refChar2([int? y]) Pointer<Char>
refChar2OrNull([int? y]) Pointer<Char>
refChar3([int? y]) Pointer<Char>
refChar3OrNull([int? y]) Pointer<Char>
refChar4([int? y]) Pointer<Char>
refChar4OrNull([int? y]) Pointer<Char>
refFloat1([double? y, String? x]) Pointer<Float>
refFloat1OrNull([double? y]) Pointer<Float>
refFloat2([double? y, String? x]) Pointer<Float>
refFloat2OrNull([double? y]) Pointer<Float>
refFloat3([double? y, String? x]) Pointer<Float>
refFloat3OrNull([double? y]) Pointer<Float>
refFloat4([double? y, String? x]) Pointer<Float>
refFloat4OrNull([double? y]) Pointer<Float>
refId(String x) String
inherited
refInt1([int? y]) Pointer<Int>
refInt1OrNull([int? y]) Pointer<Int>
refInt2([int? y]) Pointer<Int>
refInt2OrNull([int? y]) Pointer<Int>
refInt3([int? y]) Pointer<Int>
refInt3OrNull([int? y]) Pointer<Int>
refInt4([int? y]) Pointer<Int>
refInt4OrNull([int? y]) Pointer<Int>
refListBool(List<bool> y, [String? x]) Pointer<Bool>
refListChar(List<num> y, [String? x]) Pointer<Char>
refListFloat(List<num> y, [String? x]) Pointer<Float>
refListInt(List<num> y, [String? x]) Pointer<Int>
refListShort(List<num> y, [String? x]) Pointer<Short>
refListString(List<String> y, [String? x]) Pointer<Pointer<Char>>
refListUChars(List<num> y, [String? x]) Pointer<UnsignedChar>
refListUInt(List<num> y, [String? x]) Pointer<UnsignedInt>
refListUInt8(List<num> y, [String? x]) Pointer<Uint8>
refLitSized<U extends NativeType, D>(int count, String? key, Pointer<U> alloc(String, [int])) Pointer<U>
inherited
refPtrLitOrNull<U extends NativeType, D>(D? x, String key, Pointer<U> alloc([D, String])) Pointer<U>
inherited
refPtrStructOrNull<U extends Struct, D extends StructD<D, U>>(D? x, String key, Pointer<U> alloc([D, String])) Pointer<U>
inherited
refShort1([int? y]) Pointer<Short>
refShort1OrNull([int? y]) Pointer<Short>
refShort2([int? y]) Pointer<Short>
refShort2OrNull([int? y]) Pointer<Short>
refShort3([int? y]) Pointer<Short>
refShort3OrNull([int? y]) Pointer<Short>
refShort4([int? y]) Pointer<Short>
refShort4OrNull([int? y]) Pointer<Short>
refSizedUInt8(int count, [String? x]) Pointer<Uint8>
refStr(String? s) Pointer<Char>
refString1([String? y]) Pointer<Char>
refString2([String? y]) Pointer<Char>
refString3([String? y]) Pointer<Char>
refString4([String? y]) Pointer<Char>
refTypedDataUInt8(TypedData y, [String? x]) Pointer<Uint8>
refTypedListFloat(Float32List y, [String? x]) Pointer<Float>
refTypedListInt32(Int32List y, [String? x]) Pointer<Int32>
refTypedListUInt16(Uint16List y, [String? x]) Pointer<Uint16>
refTypedListUInt32(Uint32List y, [String? x]) Pointer<Uint32>
refTypedListUInt8(Uint8List y, [String? x]) Pointer<Uint8>
refUInt1([int? y]) Pointer<UnsignedInt>
refUInt1OrNull([int? y]) Pointer<UnsignedInt>
refUInt2([int? y]) Pointer<UnsignedInt>
refUInt2OrNull([int? y]) Pointer<UnsignedInt>
refUInt3([int? y]) Pointer<UnsignedInt>
refUInt3OrNull([int? y]) Pointer<UnsignedInt>
refUInt4([int? y]) Pointer<UnsignedInt>
refUInt4OrNull([int? y]) Pointer<UnsignedInt>
refUpdateNullable$<T, C extends Struct, D extends StructD<D, C>>(D? o, T callback(Pointer<C> p), Pointer<C> alloc(D), void update(Pointer<C> p, D o)) → T
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited