ImageC class final

Inheritance
Implemented types
Available extensions

Constructors

ImageC()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
bytesPerPixel int

Available on ImageC, provided by the ImageCLike extension

no setter
data Pointer<Void>
getter/setter pair
dataLength int

Available on ImageC, provided by the ImageCLike extension

no setter
format int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height int
getter/setter pair
mipmaps int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setC(ImageC o) ImageC

Available on ImageC, provided by the ImageCEx extension

setD(ImageD o) ImageC

Available on ImageC, provided by the ImageCEx extension

toD([Pointer<ImageC>? ptr]) ImageD

Available on ImageC, provided by the ImageCEx extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited