KeyboardKey enum
Values
- KEY_NULL → const KeyboardKey
-
const KeyboardKey(0) - KEY_APOSTROPHE → const KeyboardKey
-
const KeyboardKey(39) - KEY_COMMA → const KeyboardKey
-
const KeyboardKey(44) - KEY_MINUS → const KeyboardKey
-
const KeyboardKey(45) - KEY_PERIOD → const KeyboardKey
-
const KeyboardKey(46) - KEY_SLASH → const KeyboardKey
-
const KeyboardKey(47) - KEY_ZERO → const KeyboardKey
-
const KeyboardKey(48) - KEY_ONE → const KeyboardKey
-
const KeyboardKey(49) - KEY_TWO → const KeyboardKey
-
const KeyboardKey(50) - KEY_THREE → const KeyboardKey
-
const KeyboardKey(51) - KEY_FOUR → const KeyboardKey
-
const KeyboardKey(52) - KEY_FIVE → const KeyboardKey
-
const KeyboardKey(53) - KEY_SIX → const KeyboardKey
-
const KeyboardKey(54) - KEY_SEVEN → const KeyboardKey
-
const KeyboardKey(55) - KEY_EIGHT → const KeyboardKey
-
const KeyboardKey(56) - KEY_NINE → const KeyboardKey
-
const KeyboardKey(57) - KEY_SEMICOLON → const KeyboardKey
-
const KeyboardKey(59) - KEY_EQUAL → const KeyboardKey
-
const KeyboardKey(61) - KEY_A → const KeyboardKey
-
const KeyboardKey(65) - KEY_B → const KeyboardKey
-
const KeyboardKey(66) - KEY_C → const KeyboardKey
-
const KeyboardKey(67) - KEY_D → const KeyboardKey
-
const KeyboardKey(68) - KEY_E → const KeyboardKey
-
const KeyboardKey(69) - KEY_F → const KeyboardKey
-
const KeyboardKey(70) - KEY_G → const KeyboardKey
-
const KeyboardKey(71) - KEY_H → const KeyboardKey
-
const KeyboardKey(72) - KEY_I → const KeyboardKey
-
const KeyboardKey(73) - KEY_J → const KeyboardKey
-
const KeyboardKey(74) - KEY_K → const KeyboardKey
-
const KeyboardKey(75) - KEY_L → const KeyboardKey
-
const KeyboardKey(76) - KEY_M → const KeyboardKey
-
const KeyboardKey(77) - KEY_N → const KeyboardKey
-
const KeyboardKey(78) - KEY_O → const KeyboardKey
-
const KeyboardKey(79) - KEY_P → const KeyboardKey
-
const KeyboardKey(80) - KEY_Q → const KeyboardKey
-
const KeyboardKey(81) - KEY_R → const KeyboardKey
-
const KeyboardKey(82) - KEY_S → const KeyboardKey
-
const KeyboardKey(83) - KEY_T → const KeyboardKey
-
const KeyboardKey(84) - KEY_U → const KeyboardKey
-
const KeyboardKey(85) - KEY_V → const KeyboardKey
-
const KeyboardKey(86) - KEY_W → const KeyboardKey
-
const KeyboardKey(87) - KEY_X → const KeyboardKey
-
const KeyboardKey(88) - KEY_Y → const KeyboardKey
-
const KeyboardKey(89) - KEY_Z → const KeyboardKey
-
const KeyboardKey(90) - KEY_LEFT_BRACKET → const KeyboardKey
-
const KeyboardKey(91) - KEY_BACKSLASH → const KeyboardKey
-
const KeyboardKey(92) - KEY_RIGHT_BRACKET → const KeyboardKey
-
const KeyboardKey(93) - KEY_GRAVE → const KeyboardKey
-
const KeyboardKey(96) - KEY_SPACE → const KeyboardKey
-
const KeyboardKey(32) - KEY_ESCAPE → const KeyboardKey
-
const KeyboardKey(256) - KEY_ENTER → const KeyboardKey
-
const KeyboardKey(257) - KEY_TAB → const KeyboardKey
-
const KeyboardKey(258) - KEY_BACKSPACE → const KeyboardKey
-
const KeyboardKey(259) - KEY_INSERT → const KeyboardKey
-
const KeyboardKey(260) - KEY_DELETE → const KeyboardKey
-
const KeyboardKey(261) - KEY_RIGHT → const KeyboardKey
-
const KeyboardKey(262) - KEY_LEFT → const KeyboardKey
-
const KeyboardKey(263) - KEY_DOWN → const KeyboardKey
-
const KeyboardKey(264) - KEY_UP → const KeyboardKey
-
const KeyboardKey(265) - KEY_PAGE_UP → const KeyboardKey
-
const KeyboardKey(266) - KEY_PAGE_DOWN → const KeyboardKey
-
const KeyboardKey(267) - KEY_HOME → const KeyboardKey
-
const KeyboardKey(268) - KEY_END → const KeyboardKey
-
const KeyboardKey(269) - KEY_CAPS_LOCK → const KeyboardKey
-
const KeyboardKey(280) - KEY_SCROLL_LOCK → const KeyboardKey
-
const KeyboardKey(281) - KEY_NUM_LOCK → const KeyboardKey
-
const KeyboardKey(282) - KEY_PRINT_SCREEN → const KeyboardKey
-
const KeyboardKey(283) - KEY_PAUSE → const KeyboardKey
-
const KeyboardKey(284) - KEY_F1 → const KeyboardKey
-
const KeyboardKey(290) - KEY_F2 → const KeyboardKey
-
const KeyboardKey(291) - KEY_F3 → const KeyboardKey
-
const KeyboardKey(292) - KEY_F4 → const KeyboardKey
-
const KeyboardKey(293) - KEY_F5 → const KeyboardKey
-
const KeyboardKey(294) - KEY_F6 → const KeyboardKey
-
const KeyboardKey(295) - KEY_F7 → const KeyboardKey
-
const KeyboardKey(296) - KEY_F8 → const KeyboardKey
-
const KeyboardKey(297) - KEY_F9 → const KeyboardKey
-
const KeyboardKey(298) - KEY_F10 → const KeyboardKey
-
const KeyboardKey(299) - KEY_F11 → const KeyboardKey
-
const KeyboardKey(300) - KEY_F12 → const KeyboardKey
-
const KeyboardKey(301) - KEY_LEFT_SHIFT → const KeyboardKey
-
const KeyboardKey(340) - KEY_LEFT_CONTROL → const KeyboardKey
-
const KeyboardKey(341) - KEY_LEFT_ALT → const KeyboardKey
-
const KeyboardKey(342) - KEY_LEFT_SUPER → const KeyboardKey
-
const KeyboardKey(343) - KEY_RIGHT_SHIFT → const KeyboardKey
-
const KeyboardKey(344) - KEY_RIGHT_CONTROL → const KeyboardKey
-
const KeyboardKey(345) - KEY_RIGHT_ALT → const KeyboardKey
-
const KeyboardKey(346) - KEY_RIGHT_SUPER → const KeyboardKey
-
const KeyboardKey(347) - KEY_KB_MENU → const KeyboardKey
-
const KeyboardKey(348) - KEY_KP_0 → const KeyboardKey
-
const KeyboardKey(320) - KEY_KP_1 → const KeyboardKey
-
const KeyboardKey(321) - KEY_KP_2 → const KeyboardKey
-
const KeyboardKey(322) - KEY_KP_3 → const KeyboardKey
-
const KeyboardKey(323) - KEY_KP_4 → const KeyboardKey
-
const KeyboardKey(324) - KEY_KP_5 → const KeyboardKey
-
const KeyboardKey(325) - KEY_KP_6 → const KeyboardKey
-
const KeyboardKey(326) - KEY_KP_7 → const KeyboardKey
-
const KeyboardKey(327) - KEY_KP_8 → const KeyboardKey
-
const KeyboardKey(328) - KEY_KP_9 → const KeyboardKey
-
const KeyboardKey(329) - KEY_KP_DECIMAL → const KeyboardKey
-
const KeyboardKey(330) - KEY_KP_DIVIDE → const KeyboardKey
-
const KeyboardKey(331) - KEY_KP_MULTIPLY → const KeyboardKey
-
const KeyboardKey(332) - KEY_KP_SUBTRACT → const KeyboardKey
-
const KeyboardKey(333) - KEY_KP_ADD → const KeyboardKey
-
const KeyboardKey(334) - KEY_KP_ENTER → const KeyboardKey
-
const KeyboardKey(335) - KEY_KP_EQUAL → const KeyboardKey
-
const KeyboardKey(336) - KEY_BACK → const KeyboardKey
-
const KeyboardKey(4) - KEY_MENU → const KeyboardKey
-
const KeyboardKey(5) - KEY_VOLUME_UP → const KeyboardKey
-
const KeyboardKey(24) - KEY_VOLUME_DOWN → const KeyboardKey
-
const KeyboardKey(25)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → KeyboardKey
Constants
-
values
→ const List<
KeyboardKey> - A constant List of the values in this enum, in order of their declaration.