LightC class final

Inheritance
Implemented types
Available extensions

Constructors

LightC()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
attenuation double
getter/setter pair
attenuationLoc int
getter/setter pair
color ColorC
getter/setter pair
colorLoc int
getter/setter pair
enabled bool
getter/setter pair
enabledLoc int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
position Vector3C
getter/setter pair
positionLoc int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target Vector3C
getter/setter pair
targetLoc int
getter/setter pair
type int
getter/setter pair
typeLoc int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setC(LightC o) LightC

Available on LightC, provided by the LightCEx extension

setD(LightD o) LightC

Available on LightC, provided by the LightCEx extension

toD([Pointer<LightC>? ptr]) LightD

Available on LightC, provided by the LightCEx extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited