MaterialC class final

Inheritance
Implemented types
Available extensions

Constructors

MaterialC()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
mapCount int

Available on MaterialC, provided by the MaterialCLike extension

no setter
maps Pointer<MaterialMapC>
getter/setter pair
paramCount int

Available on MaterialC, provided by the MaterialCLike extension

no setter
params Array<Float>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shader ShaderC
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setC(MaterialC o) MaterialC

Available on MaterialC, provided by the MaterialCEx extension

setD(MaterialD o) MaterialC

Available on MaterialC, provided by the MaterialCEx extension

toD([Pointer<MaterialC>? ptr]) MaterialD

Available on MaterialC, provided by the MaterialCEx extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited