setC method
Copies the fields of the native struct o into this instance.
Implementation
@override
MaterialMapD setC(MaterialMapC o) {
texture.setC(o.texture);
color.setC(o.color);
value = o.value;
return this;
}
Copies the fields of the native struct o into this instance.
@override
MaterialMapD setC(MaterialMapC o) {
texture.setC(o.texture);
color.setC(o.color);
value = o.value;
return this;
}