MaterialMapIndex enum

Inheritance
Available extensions

Values

MATERIAL_MAP_ALBEDO → const MaterialMapIndex
const MaterialMapIndex(0)
MATERIAL_MAP_METALNESS → const MaterialMapIndex
const MaterialMapIndex(1)
MATERIAL_MAP_NORMAL → const MaterialMapIndex
const MaterialMapIndex(2)
MATERIAL_MAP_ROUGHNESS → const MaterialMapIndex
const MaterialMapIndex(3)
MATERIAL_MAP_OCCLUSION → const MaterialMapIndex
const MaterialMapIndex(4)
MATERIAL_MAP_EMISSION → const MaterialMapIndex
const MaterialMapIndex(5)
MATERIAL_MAP_HEIGHT → const MaterialMapIndex
const MaterialMapIndex(6)
MATERIAL_MAP_CUBEMAP → const MaterialMapIndex
const MaterialMapIndex(7)
MATERIAL_MAP_IRRADIANCE → const MaterialMapIndex
const MaterialMapIndex(8)
MATERIAL_MAP_PREFILTER → const MaterialMapIndex
const MaterialMapIndex(9)
MATERIAL_MAP_BRDF → const MaterialMapIndex
const MaterialMapIndex(10)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) MaterialMapIndex

Constants

values → const List<MaterialMapIndex>
A constant List of the values in this enum, in order of their declaration.