ModelAnimationD class

Inheritance
Available extensions

Constructors

ModelAnimationD({Pointer<ModelAnimationC>? originalPointer, List<BoneInfoD>? bones, List<List<TransformD>>? framePoses, String name = ''})
ModelAnimationD.zero()
factory

Properties

allocKey String
no setterinherited
bones List<BoneInfoD>
getter/setter pair
cStructName String
no setterinherited
frameCount int
no setter
framePoses List<List<TransformD>>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
internalId int
no setterinherited
isDisposed bool
no setterinherited
name String
getter/setter pair
nameLength int

Available on ModelAnimationD, provided by the ModelAnimationDLike extension

no setter
originalPointer Pointer<ModelAnimationC>?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structName String
no setterinherited
tag String
no setterinherited

Methods

allocateInto(RaylibTemp temp, Pointer<ModelAnimationC> p, String key) → void
override
allocatePointer(RaylibTemp temp, String key, [int count = 1]) Pointer<ModelAnimationC>
override
clone() ModelAnimationD
override
copy() ModelAnimationD
inherited
getOriginalPointer() Pointer<ModelAnimationC>
inherited
getOriginalPointerAndDispose() Pointer<ModelAnimationC>
inherited
markDisposed() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onOriginalPointer(void callback(Pointer<ModelAnimationC> p)) → void
inherited
setC(ModelAnimationC o) ModelAnimationD
override
setD(ModelAnimationD o) ModelAnimationD
override
setTag(String newTag) ModelAnimationD
inherited
signature() String
override
syncInto(RaylibTemp temp, Pointer<ModelAnimationC> p, String key) → void
override
toC(RaylibTemp temp, String key) Pointer<ModelAnimationC>
inherited
toString() String
A string representation of this object.
inherited
writeInto(ModelAnimationC p) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited