MouseButtonInfoD class final

Constructors

MouseButtonInfoD({bool up = false, bool down = false, bool pressed = false, bool released = false})
const

Properties

down bool
final
hashCode int
The hash code for this object.
no setterinherited
pressed bool
final
released bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
up bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited