MouseInfoD class final
Constructors
- MouseInfoD({Vector2D? position, Vector2D? delta, Vector2D? wheel, MouseButtonInfoD? left, MouseButtonInfoD? middle, MouseButtonInfoD? right, MouseButtonInfoD? side, MouseButtonInfoD? extra, MouseButtonInfoD? forward, MouseButtonInfoD? back})
Properties
- back → MouseButtonInfoD
-
final
- delta → Vector2D
-
final
- extra → MouseButtonInfoD
-
final
- forward → MouseButtonInfoD
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- left → MouseButtonInfoD
-
final
- middle → MouseButtonInfoD
-
final
- position → Vector2D
-
final
- right → MouseButtonInfoD
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- side → MouseButtonInfoD
-
final
- wheel → Vector2D
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited