MusicC class final

Inheritance
Implemented types
Available extensions

Constructors

MusicC()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
ctxData Pointer<Void>
getter/setter pair
ctxType int
getter/setter pair
frameCount int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
looping bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream AudioStreamC
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setC(MusicC o) MusicC

Available on MusicC, provided by the MusicCEx extension

setD(MusicD o) MusicC

Available on MusicC, provided by the MusicCEx extension

toD([Pointer<MusicC>? ptr]) MusicD

Available on MusicC, provided by the MusicCEx extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited