MusicD class

Inheritance

Constructors

MusicD({Pointer<MusicC>? originalPointer, required AudioStreamD stream, required int frameCount, required bool looping, required MusicContextType ctxType})

Properties

allocKey String
no setterinherited
cStructName String
no setterinherited
ctxType MusicContextType
getter/setter pair
frameCount int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
internalId int
no setterinherited
isDisposed bool
no setterinherited
looping bool
getter/setter pair
originalPointer Pointer<MusicC>?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream AudioStreamD
getter/setter pair
structName String
no setterinherited
tag String
no setterinherited

Methods

allocateInto(RaylibTemp temp, Pointer<MusicC> p, String key) → void
override
allocatePointer(RaylibTemp temp, String key, [int count = 1]) Pointer<MusicC>
override
clone() MusicD
override
copy() MusicD
inherited
getOriginalPointer() Pointer<MusicC>
inherited
getOriginalPointerAndDispose() Pointer<MusicC>
inherited
markDisposed() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onOriginalPointer(void callback(Pointer<MusicC> p)) → void
inherited
setC(MusicC o) MusicD
override
setD(MusicD o) MusicD
override
setTag(String newTag) MusicD
inherited
signature() String
override
syncInto(RaylibTemp temp, Pointer<MusicC> p, String key) → void
override
toC(RaylibTemp temp, String key) Pointer<MusicC>
inherited
toString() String
A string representation of this object.
inherited
writeInto(MusicC p) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited