NPatchInfoC class final

Inheritance
Implemented types
Available extensions

Constructors

NPatchInfoC()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
bottom int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
layout int
getter/setter pair
left int
getter/setter pair
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source RectangleC
getter/setter pair
top int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(num x, num y, num width, num height, num left, num top, num right, num bottom, int layout) NPatchInfoC

Available on NPatchInfoC, provided by the NPatchInfoCEx extension

setC(NPatchInfoC o) NPatchInfoC

Available on NPatchInfoC, provided by the NPatchInfoCEx extension

setD(NPatchInfoD o) NPatchInfoC

Available on NPatchInfoC, provided by the NPatchInfoCEx extension

toD([Pointer<NPatchInfoC>? ptr]) NPatchInfoD

Available on NPatchInfoC, provided by the NPatchInfoCEx extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited