NPatchInfoCPEx extension
- on
Methods
-
set(
num x, num y, num width, num height, num left, num top, num right, num bottom, int layout) → Pointer< NPatchInfoC> -
Available on Pointer<
NPatchInfoC> , provided by the NPatchInfoCPEx extension -
setC(
NPatchInfoC o) → Pointer< NPatchInfoC> -
Available on Pointer<
NPatchInfoC> , provided by the NPatchInfoCPEx extension -
setD(
NPatchInfoD o) → Pointer< NPatchInfoC> -
Available on Pointer<
NPatchInfoC> , provided by the NPatchInfoCPEx extension -
toD(
) → NPatchInfoD -
Available on Pointer<
NPatchInfoC> , provided by the NPatchInfoCPEx extension