PixelFormat enum
Values
- PIXELFORMAT_NONE → const PixelFormat
-
const PixelFormat(0) - PIXELFORMAT_UNCOMPRESSED_GRAYSCALE → const PixelFormat
-
const PixelFormat(1) - PIXELFORMAT_UNCOMPRESSED_GRAY_ALPHA → const PixelFormat
-
const PixelFormat(2) - PIXELFORMAT_UNCOMPRESSED_R5G6B5 → const PixelFormat
-
const PixelFormat(3) - PIXELFORMAT_UNCOMPRESSED_R8G8B8 → const PixelFormat
-
const PixelFormat(4) - PIXELFORMAT_UNCOMPRESSED_R5G5B5A1 → const PixelFormat
-
const PixelFormat(5) - PIXELFORMAT_UNCOMPRESSED_R4G4B4A4 → const PixelFormat
-
const PixelFormat(6) - PIXELFORMAT_UNCOMPRESSED_R8G8B8A8 → const PixelFormat
-
const PixelFormat(7) - PIXELFORMAT_UNCOMPRESSED_R32 → const PixelFormat
-
const PixelFormat(8) - PIXELFORMAT_UNCOMPRESSED_R32G32B32 → const PixelFormat
-
const PixelFormat(9) - PIXELFORMAT_UNCOMPRESSED_R32G32B32A32 → const PixelFormat
-
const PixelFormat(10) - PIXELFORMAT_UNCOMPRESSED_R16 → const PixelFormat
-
const PixelFormat(11) - PIXELFORMAT_UNCOMPRESSED_R16G16B16 → const PixelFormat
-
const PixelFormat(12) - PIXELFORMAT_UNCOMPRESSED_R16G16B16A16 → const PixelFormat
-
const PixelFormat(13) - PIXELFORMAT_COMPRESSED_DXT1_RGB → const PixelFormat
-
const PixelFormat(14) - PIXELFORMAT_COMPRESSED_DXT1_RGBA → const PixelFormat
-
const PixelFormat(15) - PIXELFORMAT_COMPRESSED_DXT3_RGBA → const PixelFormat
-
const PixelFormat(16) - PIXELFORMAT_COMPRESSED_DXT5_RGBA → const PixelFormat
-
const PixelFormat(17) - PIXELFORMAT_COMPRESSED_ETC1_RGB → const PixelFormat
-
const PixelFormat(18) - PIXELFORMAT_COMPRESSED_ETC2_RGB → const PixelFormat
-
const PixelFormat(19) - PIXELFORMAT_COMPRESSED_ETC2_EAC_RGBA → const PixelFormat
-
const PixelFormat(20) - PIXELFORMAT_COMPRESSED_PVRT_RGB → const PixelFormat
-
const PixelFormat(21) - PIXELFORMAT_COMPRESSED_PVRT_RGBA → const PixelFormat
-
const PixelFormat(22) - PIXELFORMAT_COMPRESSED_ASTC_4x4_RGBA → const PixelFormat
-
const PixelFormat(23) - PIXELFORMAT_COMPRESSED_ASTC_8x8_RGBA → const PixelFormat
-
const PixelFormat(24)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → PixelFormat
Constants
-
values
→ const List<
PixelFormat> - A constant List of the values in this enum, in order of their declaration.