Array method

Pointer<T> Array(
  1. List<X> array, {
  2. String? key,
})

Writes array into a slot of sufficient capacity and returns the pointer.

key defaults to 'default'. The slot is grown automatically if the current capacity is smaller than array.length.

Implementation

Pointer<T> Array(List<X> array, {String? key}) {
  final p = At(_slotKey(key), array.length);
  for (int i = 0; i < array.length; i++) indexSetterFunc(p, i, array[i]);
  return p;
}