RawArray method
Allocates an unslotted array and populates it from array.
The caller is responsible for freeing the returned pointer.
Implementation
Pointer<T> RawArray(List<X> array) {
final p = Raw(array.length);
for (int i = 0; i < array.length; i++) indexSetterFunc(p, i, array[i]);
return p;
}