Raw method

Pointer<Pointer<Char>> Raw([
  1. int count = 1
])

Allocates and returns an unslotted array of count Pointer<Char> pointers.

The caller is responsible for freeing the returned pointer.

Implementation

Pointer<Pointer<Char>> Raw([int count = 1]) => allocatorFunc(count);