RawArray method
Allocates an unslotted array and writes each X value from array into it.
The caller is responsible for freeing the returned pointer.
Implementation
Pointer<T> RawArray(List<X> array) {
final p = Raw(array.length);
for (int i = 0; i < array.length; i++) writeIntoIndexedFunc(p, i, array[i]);
return p;
}