setRefFunc property

Pointer<T> Function(Pointer<T> ptr, T value) setRefFunc
getter/setter pair

Assigns value to the struct referenced by ptr.

Equivalent to ptr.ref = value, provided as a function for the same reason as refFunc: Dart's type system does not permit assignment through .ref on a generic Pointer<T>.

Implementation

Pointer<T> Function(Pointer<T> ptr, T value) setRefFunc;