writeIntoFunc property
Writes the Dart value value into the struct at ptr.
Implementation
void Function(Pointer<T> ptr, X value) writeIntoFunc;
Writes the Dart value value into the struct at ptr.
void Function(Pointer<T> ptr, X value) writeIntoFunc;