RayC class final

Inheritance
Implemented types
Available extensions

Constructors

RayC()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
direction Vector3C
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
position Vector3C
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setC(RayC o) RayC

Available on RayC, provided by the RayCEx extension

setD(RayD o) RayC

Available on RayC, provided by the RayCEx extension

toD([Pointer<RayC>? ptr]) RayD

Available on RayC, provided by the RayCEx extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited