RayCollisionC class final

Inheritance
Implemented types
Available extensions

Constructors

RayCollisionC()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
distance double
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hit bool
getter/setter pair
normal Vector3C
getter/setter pair
point Vector3C
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setC(RayCollisionC o) RayCollisionC

Available on RayCollisionC, provided by the RayCollisionCEx extension

setD(RayCollisionD o) RayCollisionC

Available on RayCollisionC, provided by the RayCollisionCEx extension

toD([Pointer<RayCollisionC>? ptr]) RayCollisionD

Available on RayCollisionC, provided by the RayCollisionCEx extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited