RayCollisionD class
- Inheritance
-
- Object
- StructD<
RayCollisionD, RayCollisionC> - StructDLiteral<
RayCollisionD, RayCollisionC> - RayCollisionD
Constructors
-
RayCollisionD({Pointer<
RayCollisionC> ? originalPointer, bool hit = false, double distance = 0, Vector3D? point, Vector3D? normal}) - RayCollisionD.zero()
-
factory
Properties
- allocKey → String
-
no setterinherited
- cStructName → String
-
no setterinherited
- distance ↔ double
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hit ↔ bool
-
getter/setter pair
- internalId → int
-
no setterinherited
- isDisposed → bool
-
no setterinherited
- normal ↔ Vector3D
-
getter/setter pair
-
originalPointer
↔ Pointer<
RayCollisionC> ? -
getter/setter pairinherited
- point ↔ Vector3D
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- structName → String
-
no setterinherited
- tag → String
-
no setterinherited
Methods
-
allocateInto(
RaylibTemp temp, Pointer< RayCollisionC> p, String key) → void -
override
-
allocatePointer(
RaylibTemp temp, String key, [int count = 1]) → Pointer< RayCollisionC> -
override
-
clone(
) → RayCollisionD -
override
-
copy(
) → RayCollisionD -
inherited
-
getOriginalPointer(
) → Pointer< RayCollisionC> -
inherited
-
getOriginalPointerAndDispose(
) → Pointer< RayCollisionC> -
inherited
-
markDisposed(
) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onOriginalPointer(
void callback(Pointer< RayCollisionC> p)) → void -
inherited
-
setC(
RayCollisionC o) → RayCollisionD -
override
-
setD(
RayCollisionD o) → RayCollisionD -
override
-
setTag(
String newTag) → RayCollisionD -
inherited
-
signature(
) → String -
override
-
syncInto(
RaylibTemp temp, Pointer< RayCollisionC> p, String key) → void -
inherited
-
toC(
RaylibTemp temp, String key) → Pointer< RayCollisionC> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
writeInto(
RayCollisionC p) → void -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited