RayD class

Inheritance

Constructors

RayD({Pointer<RayC>? originalPointer, Vector3D? position, Vector3D? direction})
RayD.zero()
factory

Properties

allocKey String
no setterinherited
cStructName String
no setterinherited
direction Vector3D
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
internalId int
no setterinherited
isDisposed bool
no setterinherited
originalPointer Pointer<RayC>?
getter/setter pairinherited
position Vector3D
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structName String
no setterinherited
tag String
no setterinherited

Methods

allocateInto(RaylibTemp temp, Pointer<RayC> p, String key) → void
override
allocatePointer(RaylibTemp temp, String key, [int count = 1]) Pointer<RayC>
override
clone() RayD
override
copy() RayD
inherited
getOriginalPointer() Pointer<RayC>
inherited
getOriginalPointerAndDispose() Pointer<RayC>
inherited
markDisposed() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onOriginalPointer(void callback(Pointer<RayC> p)) → void
inherited
setC(RayC o) RayD
override
setD(RayD o) RayD
override
setTag(String newTag) RayD
inherited
signature() String
override
syncInto(RaylibTemp temp, Pointer<RayC> p, String key) → void
inherited
toC(RaylibTemp temp, String key) Pointer<RayC>
inherited
toString() String
A string representation of this object.
inherited
writeInto(RayC p) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited