Raylib class

Constructors

Raylib({required String core, String? gui, RaylibTempOptions? tempOptions, Random? random})

Properties

Audio RaylibAudio
getter/setter pair
AudioD RaylibAudioD
getter/setter pair
C RaylibColors
getter/setter pair
Cam RaylibCamera
getter/setter pair
CamD RaylibCameraD
getter/setter pair
Core RaylibCore
getter/setter pair
CoreD RaylibCoreD
getter/setter pair
coreLookup RaylibLookup
no setter
DEG2RAD double
final
Ease RaylibEasings
getter/setter pair
EPSILON double
final
Gui RaylibGui
getter/setter pair
GuiD RaylibGuiD
getter/setter pair
guiLookup RaylibLookup
no setter
hashCode int
The hash code for this object.
no setterinherited
Light RaylibLight
getter/setter pair
LightD RaylibLightD
getter/setter pair
logger ↔ Logger
getter/setter pair
M_1_PI double
final
M_2_PI double
final
M_2_SQRTPI double
final
M_E double
final
M_LN10 double
final
M_LN2 double
final
M_LOG10E double
final
M_LOG2E double
final
M_PI double
final
M_PI_2 double
final
M_PI_4 double
final
M_SQRT1_2 double
final
M_SQRT2 double
final
MATERIAL_MAP_DIFFUSE MaterialMapIndex
final
MATERIAL_MAP_SPECULAR MaterialMapIndex
final
Matrix RaylibMatrices
getter/setter pair
MAX_MATERIAL_MAPS int
final
PI double
final
Q RaylibQuaternions
getter/setter pair
RAD2DEG double
final
RAND_MAX int
final
random Random
getter/setter pair
RAYLIB_VERSION String
final
RAYLIB_VERSION_MAJOR int
final
RAYLIB_VERSION_MINOR int
final
RAYLIB_VERSION_PATCH int
final
Rlgl RaylibRlgl
getter/setter pair
RlglD RaylibRlglD
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
SHADER_LOC_MAP_DIFFUSE int
final
SHADER_LOC_MAP_SPECULAR int
final
Temp RaylibTemp
getter/setter pair
tempOptions RaylibTempOptions
latefinal
Vec RaylibVectors
getter/setter pair

Methods

Clamp(num value, num min, num max) double
CloseWindowAndDispose() → void
debugEverything(bool debug) → void
dispose() → void
dynLib<T extends RaylibModule>() DynamicLibrary
FloatEquals(double x, double y) bool
Lerp(num start, num end, num amount) double
logInfo(String message) → void
module<T extends BaseRaylibModule>() → T
Normalize(num value, num start, num end) double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rand() double
randC() double
registerDynLib<T extends RaylibModule>(T module, DynamicLibrary dynLib) → (T, DynamicLibrary)
registerModule<T extends BaseRaylibModule>(T module) → T
Remap(num value, num inputStart, num inputEnd, num outputStart, num outputEnd) double
timeIt<T>(String label, T fn()) → T
toString() String
A string representation of this object.
inherited
Wrap(num value, num min, num max) double

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance Raylib
no setter