RaylibAudio class

Inheritance

Constructors

RaylibAudio(Raylib lib)

Properties

hashCode int
The hash code for this object.
no setterinherited
logger → Logger
no setterinherited
rl Raylib
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

AttachAudioMixedProcessor(AudioCallbackC processor) → void
AttachAudioStreamProcessor(AudioStreamC stream, AudioCallbackC processor) → void
CloseAudioDevice() → void
debug(bool v) → void
inherited
debugFilter(bool filter(String)) → void
inherited
debugInfo(String message) → void
inherited
debugTime(bool v) → void
inherited
debugWarn(String message) → void
inherited
DetachAudioMixedProcessor(AudioCallbackC processor) → void
DetachAudioStreamProcessor(AudioStreamC stream, AudioCallbackC processor) → void
disableSync<T>(T f()) → T
inherited
dispose() → void
inherited
ExportWave(WaveC wave, Pointer<Char> fileName) bool
ExportWaveAsCode(WaveC wave, Pointer<Char> fileName) bool
GetMasterVolume() double
GetMusicTimeLength(MusicC music) double
GetMusicTimePlayed(MusicC music) double
InitAudioDevice() → void
IsAudioDeviceReady() bool
IsAudioStreamPlaying(AudioStreamC stream) bool
IsAudioStreamProcessed(AudioStreamC stream) bool
IsAudioStreamValid(AudioStreamC stream) bool
IsMusicStreamPlaying(MusicC music) bool
IsMusicValid(MusicC music) bool
IsSoundPlaying(SoundC sound) bool
IsSoundValid(SoundC sound) bool
IsWaveValid(WaveC wave) bool
load() → void
inherited
LoadAudioStream(int sampleRate, int sampleSize, int channels) AudioStreamC
LoadMusicStream(Pointer<Char> fileName) MusicC
LoadMusicStreamFromMemory(Pointer<Char> fileType, Pointer<UnsignedChar> data, int dataSize) MusicC
LoadSound(Pointer<Char> fileName) SoundC
LoadSoundAlias(SoundC source) SoundC
LoadSoundFromWave(WaveC wave) SoundC
LoadWave(Pointer<Char> fileName) WaveC
LoadWaveFromMemory(Pointer<Char> fileType, Pointer<UnsignedChar> fileData, int dataSize) WaveC
LoadWaveSamples(WaveC wave) Pointer<Float>
logInfo(String message) → void
inherited
logWarn(String message) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose(void fn()) → void
inherited
PauseAudioStream(AudioStreamC stream) → void
PauseMusicStream(MusicC music) → void
PauseSound(SoundC sound) → void
PlayAudioStream(AudioStreamC stream) → void
PlayMusicStream(MusicC music) → void
PlaySound(SoundC sound) → void
ResumeAudioStream(AudioStreamC stream) → void
ResumeMusicStream(MusicC music) → void
ResumeSound(SoundC sound) → void
run<T>(String name(), T f()) → T
inherited
SeekMusicStream(MusicC music, double position) → void
SetAudioStreamBufferSizeDefault(int size) → void
SetAudioStreamCallback(AudioStreamC stream, AudioCallbackC callback) → void
SetAudioStreamPan(AudioStreamC stream, double pan) → void
SetAudioStreamPitch(AudioStreamC stream, double pitch) → void
SetAudioStreamVolume(AudioStreamC stream, double volume) → void
SetMasterVolume(double volume) → void
SetMusicPan(MusicC music, double pan) → void
SetMusicPitch(MusicC music, double pitch) → void
SetMusicVolume(MusicC music, double volume) → void
SetSoundPan(SoundC sound, double pan) → void
SetSoundPitch(SoundC sound, double pitch) → void
SetSoundVolume(SoundC sound, double volume) → void
StopAudioStream(AudioStreamC stream) → void
StopMusicStream(MusicC music) → void
StopSound(SoundC sound) → void
toString() String
A string representation of this object.
inherited
UnloadAudioStream(AudioStreamC stream) → void
UnloadMusicStream(MusicC music) → void
UnloadSound(SoundC sound) → void
UnloadSoundAlias(SoundC alias) → void
UnloadWave(WaveC wave) → void
UnloadWaveSamples(Pointer<Float> samples) → void
UpdateAudioStream(AudioStreamC stream, Pointer<Void> data, int frameCount) → void
UpdateMusicStream(MusicC music) → void
UpdateSound(SoundC sound, Pointer<Void> data, int sampleCount) → void
WaveCopy(WaveC wave) WaveC
WaveCrop(Pointer<WaveC> wave, int initFrame, int finalFrame) → void
WaveFormat(Pointer<WaveC> wave, int sampleRate, int sampleSize, int channels) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited