RaylibCamera class

Inheritance

Constructors

RaylibCamera(Raylib lib)

Properties

hashCode int
The hash code for this object.
no setterinherited
logger → Logger
no setterinherited
rl Raylib
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

CameraMoveForward(Pointer<CameraC> camera, double distance, bool moveInWorldPlane) → void
CameraMoveRight(Pointer<CameraC> camera, double distance, bool moveInWorldPlane) → void
CameraMoveToTarget(Pointer<CameraC> camera, double delta) → void
CameraMoveUp(Pointer<CameraC> camera, double distance) → void
CameraPitch(Pointer<CameraC> camera, double angle, bool lockView, bool rotateAroundTarget, bool rotateUp) → void
CameraRoll(Pointer<CameraC> camera, double angle) → void
CameraYaw(Pointer<CameraC> camera, double angle, bool rotateAroundTarget) → void
debug(bool v) → void
inherited
debugFilter(bool filter(String)) → void
inherited
debugInfo(String message) → void
inherited
debugTime(bool v) → void
inherited
debugWarn(String message) → void
inherited
disableSync<T>(T f()) → T
inherited
dispose() → void
inherited
GetCameraForward(Pointer<CameraC> camera) Vector3C
GetCameraProjectionMatrix(Pointer<CameraC> camera, double aspect) MatrixC
GetCameraRight(Pointer<CameraC> camera) Vector3C
GetCameraUp(Pointer<CameraC> camera) Vector3C
GetCameraViewMatrix(Pointer<CameraC> camera) MatrixC
load() → void
inherited
logInfo(String message) → void
inherited
logWarn(String message) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose(void fn()) → void
inherited
run<T>(String name(), T f()) → T
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited