RaylibCameraD class

Inheritance

Constructors

RaylibCameraD(Raylib lib)

Properties

hashCode int
The hash code for this object.
no setterinherited
logger → Logger
no setterinherited
rl Raylib
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

CameraMoveForward(CameraD camera, num distance, bool moveInWorldPlane) → void
CameraMoveRight(CameraD camera, num distance, bool moveInWorldPlane) → void
CameraMoveToTarget(CameraD camera, num delta) → void
CameraMoveUp(CameraD camera, num distance) → void
CameraPitch(CameraD camera, num angle, bool lockView, bool rotateAroundTarget, bool rotateUp) → void
CameraRoll(CameraD camera, num angle) → void
CameraYaw(CameraD camera, num angle, bool rotateAroundTarget) → void
debug(bool v) → void
inherited
debugFilter(bool filter(String)) → void
inherited
debugInfo(String message) → void
inherited
debugTime(bool v) → void
inherited
debugWarn(String message) → void
inherited
disableSync<T>(T f()) → T
inherited
dispose() → void
inherited
GetCameraForward(CameraD camera) Vector3D
GetCameraProjectionMatrix(CameraD camera, num aspect) MatrixD
GetCameraRight(CameraD camera) Vector3D
GetCameraUp(CameraD camera) Vector3D
GetCameraViewMatrix(CameraD camera) MatrixD
load() → void
inherited
logInfo(String message) → void
inherited
logWarn(String message) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose(void fn()) → void
inherited
refBool1([bool? y, String? x]) Pointer<Bool>
inherited
refBool1OrNull([bool? y]) Pointer<Bool>
inherited
refBool2([bool? y, String? x]) Pointer<Bool>
inherited
refBool2OrNull([bool? y]) Pointer<Bool>
inherited
refBool3([bool? y, String? x]) Pointer<Bool>
inherited
refBool3OrNull([bool? y]) Pointer<Bool>
inherited
refBool4([bool? y, String? x]) Pointer<Bool>
inherited
refBool4OrNull([bool? y]) Pointer<Bool>
inherited
refChar1([int? y]) Pointer<Char>
inherited
refChar1OrNull([int? y]) Pointer<Char>
inherited
refChar2([int? y]) Pointer<Char>
inherited
refChar2OrNull([int? y]) Pointer<Char>
inherited
refChar3([int? y]) Pointer<Char>
inherited
refChar3OrNull([int? y]) Pointer<Char>
inherited
refChar4([int? y]) Pointer<Char>
inherited
refChar4OrNull([int? y]) Pointer<Char>
inherited
refFloat1([double? y, String? x]) Pointer<Float>
inherited
refFloat1OrNull([double? y]) Pointer<Float>
inherited
refFloat2([double? y, String? x]) Pointer<Float>
inherited
refFloat2OrNull([double? y]) Pointer<Float>
inherited
refFloat3([double? y, String? x]) Pointer<Float>
inherited
refFloat3OrNull([double? y]) Pointer<Float>
inherited
refFloat4([double? y, String? x]) Pointer<Float>
inherited
refFloat4OrNull([double? y]) Pointer<Float>
inherited
refId(String x) String
inherited
refInt1([int? y]) Pointer<Int>
inherited
refInt1OrNull([int? y]) Pointer<Int>
inherited
refInt2([int? y]) Pointer<Int>
inherited
refInt2OrNull([int? y]) Pointer<Int>
inherited
refInt3([int? y]) Pointer<Int>
inherited
refInt3OrNull([int? y]) Pointer<Int>
inherited
refInt4([int? y]) Pointer<Int>
inherited
refInt4OrNull([int? y]) Pointer<Int>
inherited
refListBool(List<bool> y, [String? x]) Pointer<Bool>
inherited
refListChar(List<num> y, [String? x]) Pointer<Char>
inherited
refListFloat(List<num> y, [String? x]) Pointer<Float>
inherited
refListInt(List<num> y, [String? x]) Pointer<Int>
inherited
refListShort(List<num> y, [String? x]) Pointer<Short>
inherited
refListString(List<String> y, [String? x]) Pointer<Pointer<Char>>
inherited
refListUChars(List<num> y, [String? x]) Pointer<UnsignedChar>
inherited
refListUInt(List<num> y, [String? x]) Pointer<UnsignedInt>
inherited
refListUInt8(List<num> y, [String? x]) Pointer<Uint8>
inherited
refLitSized<U extends NativeType, D>(int count, String? key, Pointer<U> alloc(String, [int])) Pointer<U>
inherited
refPtrLitOrNull<U extends NativeType, D>(D? x, String key, Pointer<U> alloc([D, String])) Pointer<U>
inherited
refPtrStructOrNull<U extends Struct, D extends StructD<D, U>>(D? x, String key, Pointer<U> alloc([D, String])) Pointer<U>
inherited
refShort1([int? y]) Pointer<Short>
inherited
refShort1OrNull([int? y]) Pointer<Short>
inherited
refShort2([int? y]) Pointer<Short>
inherited
refShort2OrNull([int? y]) Pointer<Short>
inherited
refShort3([int? y]) Pointer<Short>
inherited
refShort3OrNull([int? y]) Pointer<Short>
inherited
refShort4([int? y]) Pointer<Short>
inherited
refShort4OrNull([int? y]) Pointer<Short>
inherited
refSizedUInt8(int count, [String? x]) Pointer<Uint8>
inherited
refStr(String? s) Pointer<Char>
inherited
refString1([String? y]) Pointer<Char>
inherited
refString2([String? y]) Pointer<Char>
inherited
refString3([String? y]) Pointer<Char>
inherited
refString4([String? y]) Pointer<Char>
inherited
refTypedDataUInt8(TypedData y, [String? x]) Pointer<Uint8>
inherited
refTypedListFloat(Float32List y, [String? x]) Pointer<Float>
inherited
refTypedListInt32(Int32List y, [String? x]) Pointer<Int32>
inherited
refTypedListUInt16(Uint16List y, [String? x]) Pointer<Uint16>
inherited
refTypedListUInt32(Uint32List y, [String? x]) Pointer<Uint32>
inherited
refTypedListUInt8(Uint8List y, [String? x]) Pointer<Uint8>
inherited
refUInt1([int? y]) Pointer<UnsignedInt>
inherited
refUInt1OrNull([int? y]) Pointer<UnsignedInt>
inherited
refUInt2([int? y]) Pointer<UnsignedInt>
inherited
refUInt2OrNull([int? y]) Pointer<UnsignedInt>
inherited
refUInt3([int? y]) Pointer<UnsignedInt>
inherited
refUInt3OrNull([int? y]) Pointer<UnsignedInt>
inherited
refUInt4([int? y]) Pointer<UnsignedInt>
inherited
refUInt4OrNull([int? y]) Pointer<UnsignedInt>
inherited
refUpdateNullable$<T, C extends Struct, D extends StructD<D, C>>(D? o, T callback(Pointer<C> p), Pointer<C> alloc(D), void update(Pointer<C> p, D o)) → T
inherited
run<T>(String name(), T f()) → T
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited