RaylibGui class

Inheritance
Mixed-in types

Constructors

RaylibGui(Raylib lib)

Properties

guiIcons List<int>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
ICON_TEXT_PADDING int
no setterinherited
logger → Logger
no setterinherited
MAX_LINE_BUFFER_SIZE int
no setterinherited
RAYGUI_COLORBARALPHA_CHECKED_SIZE int
no setterinherited
RAYGUI_GRID_ALPHA double
no setterinherited
RAYGUI_GROUPBOX_LINE_THICK int
no setterinherited
RAYGUI_ICON_DATA_ELEMENTS int
no setterinherited
RAYGUI_ICON_MAX_ICONS int
no setterinherited
RAYGUI_ICON_MAX_NAME_LENGTH int
no setterinherited
RAYGUI_ICON_SIZE int
no setterinherited
RAYGUI_LINE_MARGIN_TEXT int
no setterinherited
RAYGUI_LINE_TEXT_PADDING int
no setterinherited
RAYGUI_MAX_CONTROLS int
no setterinherited
RAYGUI_MAX_PROPS_BASE int
no setterinherited
RAYGUI_MAX_PROPS_EXTENDED int
no setterinherited
RAYGUI_MAX_TEXT_LINES int
no setterinherited
RAYGUI_MESSAGEBOX_BUTTON_HEIGHT int
no setterinherited
RAYGUI_MESSAGEBOX_BUTTON_PADDING int
no setterinherited
RAYGUI_MIN_MOUSE_WHEEL_SPEED int
no setterinherited
RAYGUI_MIN_SCROLLBAR_HEIGHT int
no setterinherited
RAYGUI_MIN_SCROLLBAR_WIDTH int
no setterinherited
RAYGUI_PANEL_BORDER_WIDTH int
no setterinherited
RAYGUI_TABBAR_ITEM_WIDTH int
no setterinherited
RAYGUI_TEXTBOX_AUTO_CURSOR_COOLDOWN int
no setterinherited
RAYGUI_TEXTBOX_AUTO_CURSOR_DELAY int
no setterinherited
RAYGUI_TEXTFORMAT_MAX_SIZE int
no setterinherited
RAYGUI_TEXTINPUTBOX_BUTTON_HEIGHT int
no setterinherited
RAYGUI_TEXTINPUTBOX_BUTTON_PADDING int
no setterinherited
RAYGUI_TEXTINPUTBOX_HEIGHT int
no setterinherited
RAYGUI_TEXTSPLIT_MAX_ITEMS int
no setterinherited
RAYGUI_TEXTSPLIT_MAX_TEXT_SIZE int
no setterinherited
RAYGUI_TOGGLEGROUP_MAX_ITEMS int
no setterinherited
RAYGUI_VALUEBOX_MAX_CHARS int
no setterinherited
RAYGUI_VERSION String
no setterinherited
RAYGUI_VERSION_MAJOR int
no setterinherited
RAYGUI_VERSION_MINOR int
no setterinherited
RAYGUI_VERSION_PATCH int
no setterinherited
RAYGUI_WINDOWBOX_STATUSBAR_HEIGHT int
no setterinherited
rl Raylib
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
SCROLLBAR_LEFT_SIDE int
no setterinherited
SCROLLBAR_RIGHT_SIDE int
no setterinherited

Methods

debug(bool v) → void
inherited
debugFilter(bool filter(String)) → void
inherited
debugInfo(String message) → void
inherited
debugTime(bool v) → void
inherited
debugWarn(String message) → void
inherited
disableSync<T>(T f()) → T
inherited
dispose() → void
inherited
GuiButton(RectangleC bounds, Pointer<Char> text) int
GuiCheckBox(RectangleC bounds, Pointer<Char> text, Pointer<Bool> checked) int
GuiColorBarAlpha(RectangleC bounds, Pointer<Char> text, Pointer<Float> alpha) int
GuiColorBarHue(RectangleC bounds, Pointer<Char> text, Pointer<Float> value) int
GuiColorPanel(RectangleC bounds, Pointer<Char> text, Pointer<ColorC> color) int
GuiColorPanelHSV(RectangleC bounds, Pointer<Char> text, Pointer<Vector3C> colorHsv) int
GuiColorPicker(RectangleC bounds, Pointer<Char> text, Pointer<ColorC> color) int
GuiColorPickerHSV(RectangleC bounds, Pointer<Char> text, Pointer<Vector3C> colorHsv) int
GuiComboBox(RectangleC bounds, Pointer<Char> text, Pointer<Int> active) int
GuiDisable() → void
GuiDisableTooltip() → void
GuiDrawIcon(int iconId, int posX, int posY, int pixelSize, ColorC color) → void
GuiDropdownBox(RectangleC bounds, Pointer<Char> text, Pointer<Int> active, bool editMode) int
GuiDummyRec(RectangleC bounds, Pointer<Char> text) int
GuiEnable() → void
GuiEnableTooltip() → void
GuiGetFont() FontC
GuiGetIcons() Pointer<UnsignedInt>
GuiGetState() int
GuiGetStyle(int control, int property) int
GuiGetTextWidth(Pointer<Char> text) int
GuiGrid(RectangleC bounds, Pointer<Char> text, double spacing, int subdivs, Pointer<Vector2C> mouseCell) int
GuiGroupBox(RectangleC bounds, Pointer<Char> text) int
GuiIconText(int iconId, Pointer<Char> text) Pointer<Char>
GuiIsLocked() bool
GuiLabel(RectangleC bounds, Pointer<Char> text) int
GuiLabelButton(RectangleC bounds, Pointer<Char> text) int
GuiLine(RectangleC bounds, Pointer<Char> text) int
GuiListView(RectangleC bounds, Pointer<Char> text, Pointer<Int> scrollIndex, Pointer<Int> active) int
GuiListViewEx(RectangleC bounds, Pointer<Pointer<Char>> text, int count, Pointer<Int> scrollIndex, Pointer<Int> active, Pointer<Int> focus) int
GuiLoadIcons(Pointer<Char> fileName, bool loadIconsName) Pointer<Pointer<Char>>
GuiLoadStyle(Pointer<Char> fileName) → void
GuiLoadStyleDefault() → void
GuiLock() → void
GuiMessageBox(RectangleC bounds, Pointer<Char> title, Pointer<Char> message, Pointer<Char> buttons) int
GuiPanel(RectangleC bounds, Pointer<Char> text) int
GuiProgressBar(RectangleC bounds, Pointer<Char> textLeft, Pointer<Char> textRight, Pointer<Float> value, double minValue, double maxValue) int
GuiScrollPanel(RectangleC bounds, Pointer<Char> text, RectangleC content, Pointer<Vector2C> scroll, Pointer<RectangleC> view) int
GuiSetAlpha(double alpha) → void
GuiSetFont(FontC font) → void
GuiSetIconScale(int scale) → void
GuiSetState(int state) → void
GuiSetStyle(int control, int property, int value) → void
GuiSetTooltip(Pointer<Char> tooltip) → void
GuiSlider(RectangleC bounds, Pointer<Char> textLeft, Pointer<Char> textRight, Pointer<Float> value, double minValue, double maxValue) int
GuiSliderBar(RectangleC bounds, Pointer<Char> textLeft, Pointer<Char> textRight, Pointer<Float> value, double minValue, double maxValue) int
GuiSpinner(RectangleC bounds, Pointer<Char> text, Pointer<Int> value, int minValue, int maxValue, bool editMode) int
GuiStatusBar(RectangleC bounds, Pointer<Char> text) int
GuiTabBar(RectangleC bounds, Pointer<Pointer<Char>> text, int count, Pointer<Int> active) int
GuiTextBox(RectangleC bounds, Pointer<Char> text, int textSize, bool editMode) int
GuiTextInputBox(RectangleC bounds, Pointer<Char> title, Pointer<Char> message, Pointer<Char> buttons, Pointer<Char> text, int textMaxSize, Pointer<Bool> secretViewActive) int
GuiToggle(RectangleC bounds, Pointer<Char> text, Pointer<Bool> active) int
GuiToggleGroup(RectangleC bounds, Pointer<Char> text, Pointer<Int> active) int
GuiToggleSlider(RectangleC bounds, Pointer<Char> text, Pointer<Int> active) int
GuiUnlock() → void
GuiValueBox(RectangleC bounds, Pointer<Char> text, Pointer<Int> value, int minValue, int maxValue, bool editMode) int
GuiValueBoxFloat(RectangleC bounds, Pointer<Char> text, Pointer<Char> textValue, Pointer<Float> value, bool editMode) int
GuiWindowBox(RectangleC bounds, Pointer<Char> title) int
load() → void
inherited
logInfo(String message) → void
inherited
logWarn(String message) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose(void fn()) → void
inherited
run<T>(String name(), T f()) → T
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited