RaylibGuiD class

Inheritance
Mixed-in types

Constructors

RaylibGuiD(Raylib lib)

Properties

guiIcons List<int>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
ICON_TEXT_PADDING int
no setterinherited
logger → Logger
no setterinherited
MAX_LINE_BUFFER_SIZE int
no setterinherited
RAYGUI_COLORBARALPHA_CHECKED_SIZE int
no setterinherited
RAYGUI_GRID_ALPHA double
no setterinherited
RAYGUI_GROUPBOX_LINE_THICK int
no setterinherited
RAYGUI_ICON_DATA_ELEMENTS int
no setterinherited
RAYGUI_ICON_MAX_ICONS int
no setterinherited
RAYGUI_ICON_MAX_NAME_LENGTH int
no setterinherited
RAYGUI_ICON_SIZE int
no setterinherited
RAYGUI_LINE_MARGIN_TEXT int
no setterinherited
RAYGUI_LINE_TEXT_PADDING int
no setterinherited
RAYGUI_MAX_CONTROLS int
no setterinherited
RAYGUI_MAX_PROPS_BASE int
no setterinherited
RAYGUI_MAX_PROPS_EXTENDED int
no setterinherited
RAYGUI_MAX_TEXT_LINES int
no setterinherited
RAYGUI_MESSAGEBOX_BUTTON_HEIGHT int
no setterinherited
RAYGUI_MESSAGEBOX_BUTTON_PADDING int
no setterinherited
RAYGUI_MIN_MOUSE_WHEEL_SPEED int
no setterinherited
RAYGUI_MIN_SCROLLBAR_HEIGHT int
no setterinherited
RAYGUI_MIN_SCROLLBAR_WIDTH int
no setterinherited
RAYGUI_PANEL_BORDER_WIDTH int
no setterinherited
RAYGUI_TABBAR_ITEM_WIDTH int
no setterinherited
RAYGUI_TEXTBOX_AUTO_CURSOR_COOLDOWN int
no setterinherited
RAYGUI_TEXTBOX_AUTO_CURSOR_DELAY int
no setterinherited
RAYGUI_TEXTFORMAT_MAX_SIZE int
no setterinherited
RAYGUI_TEXTINPUTBOX_BUTTON_HEIGHT int
no setterinherited
RAYGUI_TEXTINPUTBOX_BUTTON_PADDING int
no setterinherited
RAYGUI_TEXTINPUTBOX_HEIGHT int
no setterinherited
RAYGUI_TEXTSPLIT_MAX_ITEMS int
no setterinherited
RAYGUI_TEXTSPLIT_MAX_TEXT_SIZE int
no setterinherited
RAYGUI_TOGGLEGROUP_MAX_ITEMS int
no setterinherited
RAYGUI_VALUEBOX_MAX_CHARS int
no setterinherited
RAYGUI_VERSION String
no setterinherited
RAYGUI_VERSION_MAJOR int
no setterinherited
RAYGUI_VERSION_MINOR int
no setterinherited
RAYGUI_VERSION_PATCH int
no setterinherited
RAYGUI_WINDOWBOX_STATUSBAR_HEIGHT int
no setterinherited
rl Raylib
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
SCROLLBAR_LEFT_SIDE int
no setterinherited
SCROLLBAR_RIGHT_SIDE int
no setterinherited

Methods

debug(bool v) → void
inherited
debugFilter(bool filter(String)) → void
inherited
debugInfo(String message) → void
inherited
debugTime(bool v) → void
inherited
debugWarn(String message) → void
inherited
disableSync<T>(T f()) → T
inherited
dispose() → void
inherited
GuiButton(RectangleD bounds, String? text) int
GuiCheckBox(RectangleD bounds, String? text, bool checked) → (int, bool)
GuiColorBarAlpha(RectangleD bounds, num alpha) → (int, double)
GuiColorBarHue(RectangleD bounds, num value) → (int, double)
GuiColorPanel(RectangleD bounds, ColorD color) → (int, ColorD)
GuiColorPanelHSV(RectangleD bounds, [Vector3D? colorHsv]) → (int, Vector3D)
GuiColorPicker(RectangleD bounds, ColorD? color) → (int, ColorD)
GuiColorPickerHSV(RectangleD bounds, [Vector3D? colorHsv]) → (int, Vector3D)
GuiComboBox(RectangleD bounds, String? text, num active) → (int, int)
GuiDisable() → void
GuiDisableTooltip() → void
GuiDrawIcon(GuiIconName iconId, num posX, num posY, num pixelSize, ColorD color) → void
GuiDropdownBox(RectangleD bounds, String? text, num active, bool editMode) → (int, int)
GuiDummyRec(RectangleD bounds, String? text) int
GuiEnable() → void
GuiEnableTooltip() → void
GuiGetFont() FontD
GuiGetIcons() List<int>
GuiGetState() int
GuiGetStyle(GuiControl control, GuiProperty property) int
GuiGetTextWidth(String? text) int
GuiGrid(RectangleD bounds, num spacing, num subdivs, [Vector2D? mouseCell]) int
GuiGroupBox(RectangleD bounds, String? text) int
GuiIconText(GuiIconName iconId, String? text) String
GuiIsLocked() bool
GuiLabel(RectangleD bounds, String? text) int
GuiLabelButton(RectangleD bounds, String? text) int
GuiLine(RectangleD bounds, String? text) int
GuiListView(RectangleD bounds, String? text, {int? scrollIndex, int? active}) → (int, int, int)
GuiListViewEx(RectangleD bounds, List<String> text, {int? scrollIndex, int? active, int? focus}) → (int, int, int, int)
GuiLoadIcons(String fileName, bool loadIconsName) List<String>
GuiLoadStyle(String fileName) → void
GuiLoadStyleDefault() → void
GuiLock() → void
GuiMessageBox(RectangleD bounds, String? title, String message, String buttons) int
GuiPanel(RectangleD bounds, String? text) int
GuiProgressBar(RectangleD bounds, String? textLeft, String? textRight, num value, num minValue, num maxValue) → (int, double)
GuiScrollPanel(RectangleD bounds, String? text, RectangleD content, Vector2D scroll, [RectangleD? view]) int
GuiSetAlpha(num alpha) → void
GuiSetFont(FontD font) → void
GuiSetIconScale(num scale) → void
GuiSetState(GuiState state) → void
GuiSetStyle(GuiControl control, GuiProperty property, num value) → void
GuiSetTooltip(String? tooltip) → void
GuiSlider(RectangleD bounds, String? textLeft, String? textRight, num value, num minValue, num maxValue) → (int, double)
GuiSliderBar(RectangleD bounds, String? textLeft, String? textRight, num value, num minValue, num maxValue) → (int, double)
GuiSpinner(RectangleD bounds, String? text, num value, num minValue, num maxValue, bool editMode) → (int, int)
GuiStatusBar(RectangleD bounds, String? text) int
GuiTabBar(RectangleD bounds, List<String> text) → (int, int)
GuiTextBox(RectangleD bounds, String? text, num textSize, bool editMode) → (int, String)
GuiTextInputBox(RectangleD bounds, String? title, String? message, String buttons, String? text, num textMaxSize, bool? secretViewActive) → (int, String)
GuiToggle(RectangleD bounds, String? text, bool active) → (int, bool)
GuiToggleGroup(RectangleD bounds, String? text, num active) → (int, int)
GuiToggleSlider(RectangleD bounds, String? text, num active) → (int, int)
GuiUnlock() → void
GuiValueBox(RectangleD bounds, String? text, num value, num minValue, num maxValue, bool editMode) → (int, int)
GuiValueBoxFloat(RectangleD bounds, String? text, String textValue, num value, bool editMode) → (int, double)
GuiWindowBox(RectangleD bounds, String? title) int
load() → void
inherited
logInfo(String message) → void
inherited
logWarn(String message) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose(void fn()) → void
inherited
run<T>(String name(), T f()) → T
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited