RaylibGuiExtras mixin

Superclass constraints
Mixin applications

Properties

guiIcons List<int>
no setter
hashCode int
The hash code for this object.
no setterinherited
ICON_TEXT_PADDING int
no setter
logger → Logger
no setterinherited
MAX_LINE_BUFFER_SIZE int
no setter
RAYGUI_COLORBARALPHA_CHECKED_SIZE int
no setter
RAYGUI_GRID_ALPHA double
no setter
RAYGUI_GROUPBOX_LINE_THICK int
no setter
RAYGUI_ICON_DATA_ELEMENTS int
no setter
RAYGUI_ICON_MAX_ICONS int
no setter
RAYGUI_ICON_MAX_NAME_LENGTH int
no setter
RAYGUI_ICON_SIZE int
no setter
RAYGUI_LINE_MARGIN_TEXT int
no setter
RAYGUI_LINE_TEXT_PADDING int
no setter
RAYGUI_MAX_CONTROLS int
no setter
RAYGUI_MAX_PROPS_BASE int
no setter
RAYGUI_MAX_PROPS_EXTENDED int
no setter
RAYGUI_MAX_TEXT_LINES int
no setter
RAYGUI_MESSAGEBOX_BUTTON_HEIGHT int
no setter
RAYGUI_MESSAGEBOX_BUTTON_PADDING int
no setter
RAYGUI_MIN_MOUSE_WHEEL_SPEED int
no setter
RAYGUI_MIN_SCROLLBAR_HEIGHT int
no setter
RAYGUI_MIN_SCROLLBAR_WIDTH int
no setter
RAYGUI_PANEL_BORDER_WIDTH int
no setter
RAYGUI_TABBAR_ITEM_WIDTH int
no setter
RAYGUI_TEXTBOX_AUTO_CURSOR_COOLDOWN int
no setter
RAYGUI_TEXTBOX_AUTO_CURSOR_DELAY int
no setter
RAYGUI_TEXTFORMAT_MAX_SIZE int
no setter
RAYGUI_TEXTINPUTBOX_BUTTON_HEIGHT int
no setter
RAYGUI_TEXTINPUTBOX_BUTTON_PADDING int
no setter
RAYGUI_TEXTINPUTBOX_HEIGHT int
no setter
RAYGUI_TEXTSPLIT_MAX_ITEMS int
no setter
RAYGUI_TEXTSPLIT_MAX_TEXT_SIZE int
no setter
RAYGUI_TOGGLEGROUP_MAX_ITEMS int
no setter
RAYGUI_VALUEBOX_MAX_CHARS int
no setter
RAYGUI_VERSION String
no setter
RAYGUI_VERSION_MAJOR int
no setter
RAYGUI_VERSION_MINOR int
no setter
RAYGUI_VERSION_PATCH int
no setter
RAYGUI_WINDOWBOX_STATUSBAR_HEIGHT int
no setter
rl Raylib
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
SCROLLBAR_LEFT_SIDE int
no setter
SCROLLBAR_RIGHT_SIDE int
no setter

Methods

debug(bool v) → void
inherited
debugFilter(bool filter(String)) → void
inherited
debugInfo(String message) → void
inherited
debugTime(bool v) → void
inherited
debugWarn(String message) → void
inherited
disableSync<T>(T f()) → T
inherited
dispose() → void
inherited
load() → void
inherited
logInfo(String message) → void
inherited
logWarn(String message) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose(void fn()) → void
inherited
run<T>(String name(), T f()) → T
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited