RaylibLightD class

Inheritance

Constructors

RaylibLightD(Raylib lib)

Properties

hashCode int
The hash code for this object.
no setterinherited
logger → Logger
no setterinherited
rl Raylib
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

CreateLight(LightType type, Vector3D position, Vector3D target, ColorD color, ShaderD shader) LightD
debug(bool v) → void
inherited
debugFilter(bool filter(String)) → void
inherited
debugInfo(String message) → void
inherited
debugTime(bool v) → void
inherited
debugWarn(String message) → void
inherited
disableSync<T>(T f()) → T
inherited
dispose() → void
inherited
load() → void
inherited
logInfo(String message) → void
inherited
logWarn(String message) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose(void fn()) → void
inherited
run<T>(String name(), T f()) → T
inherited
toString() String
A string representation of this object.
inherited
UpdateLightValues(ShaderD shader, LightD light) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited