RaylibRlgl class
- Inheritance
-
- Mixed-in types
-
Methods
-
debug(bool v)
→ void
-
inherited
-
debugFilter(bool filter(String))
→ void
-
inherited
-
debugInfo(String message)
→ void
-
inherited
-
debugTime(bool v)
→ void
-
inherited
-
debugWarn(String message)
→ void
-
inherited
-
disableSync<T>(T f())
→ T
-
inherited
-
dispose()
→ void
-
inherited
-
load()
→ void
-
inherited
-
logInfo(String message)
→ void
-
inherited
-
logWarn(String message)
→ void
-
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
onDispose(void fn())
→ void
-
inherited
-
rlActiveDrawBuffers(int count)
→ void
-
-
rlActiveTextureSlot(int slot)
→ void
-
-
rlBegin(int mode)
→ void
-
-
rlBindFramebuffer(int target, int framebuffer)
→ void
-
-
rlBindImageTexture(int id, int index, int format, bool readonly)
→ void
-
-
rlBindShaderBuffer(int id, int index)
→ void
-
-
rlBlitFramebuffer(int srcX, int srcY, int srcWidth, int srcHeight, int dstX, int dstY, int dstWidth, int dstHeight, int bufferMask)
→ void
-
-
rlCheckErrors()
→ void
-
-
rlCheckRenderBatchLimit(int vCount)
→ bool
-
-
rlClearColor(int r, int g, int b, int a)
→ void
-
-
rlClearScreenBuffers()
→ void
-
-
rlColor3f(double x, double y, double z)
→ void
-
-
rlColor4f(double x, double y, double z, double w)
→ void
-
-
rlColor4ub(int r, int g, int b, int a)
→ void
-
-
rlColorMask(bool r, bool g, bool b, bool a)
→ void
-
-
rlCompileShader(Pointer<Char> shaderCode, int type)
→ int
-
-
rlComputeShaderDispatch(int groupX, int groupY, int groupZ)
→ void
-
-
rlCopyShaderBuffer(int destId, int srcId, int destOffset, int srcOffset, int count)
→ void
-
-
rlCubemapParameters(int id, int param, int value)
→ void
-
-
rlDisableBackfaceCulling()
→ void
-
-
rlDisableColorBlend()
→ void
-
-
rlDisableDepthMask()
→ void
-
-
rlDisableDepthTest()
→ void
-
-
rlDisableFramebuffer()
→ void
-
-
rlDisableScissorTest()
→ void
-
-
rlDisableShader()
→ void
-
-
rlDisableSmoothLines()
→ void
-
-
rlDisableStereoRender()
→ void
-
-
rlDisableTexture()
→ void
-
-
rlDisableTextureCubemap()
→ void
-
-
rlDisableVertexArray()
→ void
-
-
rlDisableVertexAttribute(int index)
→ void
-
-
rlDisableVertexBuffer()
→ void
-
-
rlDisableVertexBufferElement()
→ void
-
-
rlDisableWireMode()
→ void
-
-
rlDrawRenderBatch(Pointer<RlRenderBatchC> batch)
→ void
-
-
rlDrawRenderBatchActive()
→ void
-
-
rlDrawVertexArray(int offset, int count)
→ void
-
-
rlDrawVertexArrayElements(int offset, int count, Pointer<Void> buffer)
→ void
-
-
rlDrawVertexArrayElementsInstanced(int offset, int count, Pointer<Void> buffer, int instances)
→ void
-
-
rlDrawVertexArrayInstanced(int offset, int count, int instances)
→ void
-
-
rlEnableBackfaceCulling()
→ void
-
-
rlEnableColorBlend()
→ void
-
-
rlEnableDepthMask()
→ void
-
-
rlEnableDepthTest()
→ void
-
-
rlEnableFramebuffer(int id)
→ void
-
-
rlEnablePointMode()
→ void
-
-
rlEnableScissorTest()
→ void
-
-
rlEnableShader(int id)
→ void
-
-
rlEnableSmoothLines()
→ void
-
-
rlEnableStereoRender()
→ void
-
-
rlEnableTexture(int id)
→ void
-
-
rlEnableTextureCubemap(int id)
→ void
-
-
rlEnableVertexArray(int vaoId)
→ bool
-
-
rlEnableVertexAttribute(int index)
→ void
-
-
rlEnableVertexBuffer(int id)
→ void
-
-
rlEnableVertexBufferElement(int id)
→ void
-
-
rlEnableWireMode()
→ void
-
-
rlEnd()
→ void
-
-
rlFramebufferAttach(int fboId, int texId, int attachType, int texType, int mipLevel)
→ void
-
-
rlFramebufferComplete(int id)
→ bool
-
-
rlFrustum(double left, double right, double bottom, double top, double znear, double zfar)
→ void
-
-
rlGenTextureMipmaps(int id, int width, int height, int format, Pointer<Int> mipmaps)
→ void
-
-
rlGetActiveFramebuffer()
→ int
-
-
rlGetCullDistanceFar()
→ double
-
-
rlGetCullDistanceNear()
→ double
-
-
rlGetFramebufferHeight()
→ int
-
-
rlGetFramebufferWidth()
→ int
-
-
rlGetGlTextureFormats(int format, Pointer<UnsignedInt> glInternalFormat, Pointer<UnsignedInt> glFormat, Pointer<UnsignedInt> glType)
→ void
-
-
rlGetLineWidth()
→ double
-
-
rlGetLocationAttrib(int shaderId, Pointer<Char> attribName)
→ int
-
-
rlGetLocationUniform(int shaderId, Pointer<Char> uniformName)
→ int
-
-
rlGetMatrixModelview()
→ MatrixC
-
-
rlGetMatrixProjection()
→ MatrixC
-
-
rlGetMatrixProjectionStereo(int eye)
→ MatrixC
-
-
rlGetMatrixTransform()
→ MatrixC
-
-
rlGetMatrixViewOffsetStereo(int eye)
→ MatrixC
-
-
rlGetPixelFormatName(int format)
→ Pointer<Char>
-
-
rlGetShaderBufferSize(int id)
→ int
-
-
rlGetShaderIdDefault()
→ int
-
-
rlGetShaderLocsDefault()
→ Pointer<Int>
-
-
rlGetTextureIdDefault()
→ int
-
-
rlGetVersion()
→ int
-
-
rlglClose()
→ void
-
-
rlglInit(int width, int height)
→ void
-
-
rlIsStereoRenderEnabled()
→ bool
-
-
rlLoadComputeShaderProgram(int shaderId)
→ int
-
-
rlLoadDrawCube()
→ void
-
-
rlLoadDrawQuad()
→ void
-
-
rlLoadExtensions(Pointer<Void> loader)
→ void
-
-
rlLoadFramebuffer()
→ int
-
-
rlLoadIdentity()
→ void
-
-
rlLoadRenderBatch(int numBuffers, int bufferElements)
→ RlRenderBatchC
-
-
rlLoadShaderBuffer(int size, Pointer<Void> data, int usageHint)
→ int
-
-
rlLoadShaderCode(Pointer<Char> vsCode, Pointer<Char> fsCode)
→ int
-
-
rlLoadShaderProgram(int vShaderId, int fShaderId)
→ int
-
-
rlLoadTexture(Pointer<Void> data, int width, int height, int format, int mipmapCount)
→ int
-
-
rlLoadTextureCubemap(Pointer<Void> data, int size, int format, int mipmapCount)
→ int
-
-
rlLoadTextureDepth(int width, int height, bool useRenderBuffer)
→ int
-
-
rlLoadVertexArray()
→ int
-
-
rlLoadVertexBuffer(Pointer<Void> buffer, int size, bool dynamic)
→ int
-
-
rlLoadVertexBufferElement(Pointer<Void> buffer, int size, bool dynamic)
→ int
-
-
rlMatrixMode(int mode)
→ void
-
-
rlMultMatrixf(Pointer<Float> matf)
→ void
-
-
rlNormal3f(double x, double y, double z)
→ void
-
-
rlOrtho(double left, double right, double bottom, double top, double znear, double zfar)
→ void
-
-
rlPopMatrix()
→ void
-
-
rlPushMatrix()
→ void
-
-
rlReadScreenPixels(int width, int height)
→ Pointer<UnsignedChar>
-
-
rlReadShaderBuffer(int id, Pointer<Void> dest, int count, int offset)
→ void
-
-
rlReadTexturePixels(int id, int width, int height, int format)
→ Pointer<Void>
-
-
rlRotatef(double angle, double x, double y, double z)
→ void
-
-
rlScalef(double x, double y, double z)
→ void
-
-
rlScissor(int x, int y, int width, int height)
→ void
-
-
rlSetBlendFactors(int glSrcFactor, int glDstFactor, int glEquation)
→ void
-
-
-
rlSetBlendMode(int mode)
→ void
-
-
rlSetClipPlanes(double nearPlane, double farPlane)
→ void
-
-
rlSetCullFace(int mode)
→ void
-
-
rlSetFramebufferHeight(int height)
→ void
-
-
rlSetFramebufferWidth(int width)
→ void
-
-
rlSetLineWidth(double width)
→ void
-
-
rlSetMatrixModelview(MatrixC view)
→ void
-
-
rlSetMatrixProjection(MatrixC proj)
→ void
-
-
rlSetMatrixProjectionStereo(MatrixC right, MatrixC left)
→ void
-
-
rlSetMatrixViewOffsetStereo(MatrixC right, MatrixC left)
→ void
-
-
rlSetRenderBatchActive(Pointer<RlRenderBatchC> batch)
→ void
-
-
rlSetShader(int id, Pointer<Int> locs)
→ void
-
-
rlSetTexture(int id)
→ void
-
-
rlSetUniform(int locIndex, Pointer<Void> value, int uniformType, int count)
→ void
-
-
rlSetUniformMatrices(int locIndex, Pointer<MatrixC> mat, int count)
→ void
-
-
rlSetUniformMatrix(int locIndex, MatrixC mat)
→ void
-
-
rlSetUniformSampler(int locIndex, int textureId)
→ void
-
-
rlSetVertexAttribute(int index, int compSize, int type, bool normalized, int stride, int offset)
→ void
-
-
rlSetVertexAttributeDefault(int locIndex, Pointer<Void> value, int attribType, int count)
→ void
-
-
rlSetVertexAttributeDivisor(int index, int divisor)
→ void
-
-
rlTexCoord2f(double x, double y)
→ void
-
-
rlTextureParameters(int id, int param, int value)
→ void
-
-
rlTranslatef(double x, double y, double z)
→ void
-
-
rlUnloadFramebuffer(int id)
→ void
-
-
rlUnloadRenderBatch(RlRenderBatchC batch)
→ void
-
-
rlUnloadShaderBuffer(int ssboId)
→ void
-
-
rlUnloadShaderProgram(int id)
→ void
-
-
rlUnloadTexture(int id)
→ void
-
-
rlUnloadVertexArray(int vaoId)
→ void
-
-
rlUnloadVertexBuffer(int vboId)
→ void
-
-
rlUpdateShaderBuffer(int id, Pointer<Void> data, int dataSize, int offset)
→ void
-
-
rlUpdateTexture(int id, int offsetX, int offsetY, int width, int height, int format, Pointer<Void> data)
→ void
-
-
rlUpdateVertexBuffer(int bufferId, Pointer<Void> data, int dataSize, int offset)
→ void
-
-
rlUpdateVertexBufferElements(int id, Pointer<Void> data, int dataSize, int offset)
→ void
-
-
rlVertex2f(double x, double y)
→ void
-
-
rlVertex2i(int x, int y)
→ void
-
-
rlVertex3f(double x, double y, double z)
→ void
-
-
rlViewport(int x, int y, int width, int height)
→ void
-
-
run<T>(String name(), T f())
→ T
-
inherited
-
toString()
→ String
-
A string representation of this object.
inherited