RaylibVectors class

Inheritance
Available extensions

Constructors

RaylibVectors(Raylib lib)

Properties

hashCode int
The hash code for this object.
no setterinherited
logger → Logger
no setterinherited
rl Raylib
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

debug(bool v) → void
inherited
debugFilter(bool filter(String)) → void
inherited
debugInfo(String message) → void
inherited
debugTime(bool v) → void
inherited
debugWarn(String message) → void
inherited
disableSync<T>(T f()) → T
inherited
dispose() → void
inherited
load() → void
inherited
logInfo(String message) → void
inherited
logWarn(String message) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose(void fn()) → void
inherited
run<T>(String name(), T f()) → T
inherited
toString() String
A string representation of this object.
inherited
Vector2Add(Vector2D v1, Vector2D v2) Vector2D

Available on RaylibVectors, provided by the RaylibVector2 extension

Vector2AddValue(Vector2D v, double add) Vector2D

Available on RaylibVectors, provided by the RaylibVector2 extension

Vector2Angle(Vector2D v1, Vector2D v2) double

Available on RaylibVectors, provided by the RaylibVector2 extension

Vector2Clamp(Vector2D v, Vector2D min, Vector2D max) Vector2D

Available on RaylibVectors, provided by the RaylibVector2 extension

Vector2ClampValue(Vector2D v, double min, double max) Vector2D

Available on RaylibVectors, provided by the RaylibVector2 extension

Vector2Distance(Vector2D v1, Vector2D v2) double

Available on RaylibVectors, provided by the RaylibVector2 extension

Vector2DistanceSqr(Vector2D v1, Vector2D v2) double

Available on RaylibVectors, provided by the RaylibVector2 extension

Vector2Divide(Vector2D v1, Vector2D v2) Vector2D

Available on RaylibVectors, provided by the RaylibVector2 extension

Vector2DotProduct(Vector2D v1, Vector2D v2) double

Available on RaylibVectors, provided by the RaylibVector2 extension

Vector2Equals(Vector2D p, Vector2D q) bool

Available on RaylibVectors, provided by the RaylibVector2 extension

Vector2Invert(Vector2D v) Vector2D

Available on RaylibVectors, provided by the RaylibVector2 extension

Vector2Length(Vector2D v) double

Available on RaylibVectors, provided by the RaylibVector2 extension

Vector2LengthSqr(Vector2D v) double

Available on RaylibVectors, provided by the RaylibVector2 extension

Vector2Lerp(Vector2D v1, Vector2D v2, double amount) Vector2D

Available on RaylibVectors, provided by the RaylibVector2 extension

Vector2LineAngle(Vector2D start, Vector2D end) double

Available on RaylibVectors, provided by the RaylibVector2 extension

Vector2Max(Vector2D v1, Vector2D v2) Vector2D

Available on RaylibVectors, provided by the RaylibVector2 extension

Vector2Min(Vector2D v1, Vector2D v2) Vector2D

Available on RaylibVectors, provided by the RaylibVector2 extension

Vector2MoveTowards(Vector2D v, Vector2D target, double maxDistance) Vector2D

Available on RaylibVectors, provided by the RaylibVector2 extension

Vector2Multiply(Vector2D v1, Vector2D v2) Vector2D

Available on RaylibVectors, provided by the RaylibVector2 extension

Vector2Negate(Vector2D v) Vector2D

Available on RaylibVectors, provided by the RaylibVector2 extension

Vector2Normalize(Vector2D v) Vector2D

Available on RaylibVectors, provided by the RaylibVector2 extension

Vector2Reflect(Vector2D v, Vector2D normal) Vector2D

Available on RaylibVectors, provided by the RaylibVector2 extension

Vector2Refract(Vector2D v, Vector2D n, double r) Vector2D

Available on RaylibVectors, provided by the RaylibVector2 extension

Vector2Rotate(Vector2D v, double angle) Vector2D

Available on RaylibVectors, provided by the RaylibVector2 extension

Vector2Scale(Vector2D v, double scale) Vector2D

Available on RaylibVectors, provided by the RaylibVector2 extension

Vector2Subtract(Vector2D v1, Vector2D v2) Vector2D

Available on RaylibVectors, provided by the RaylibVector2 extension

Vector2SubtractValue(Vector2D v, double sub) Vector2D

Available on RaylibVectors, provided by the RaylibVector2 extension

Vector2Transform(Vector2D v, MatrixD mat) Vector2D

Available on RaylibVectors, provided by the RaylibVector2 extension

Vector3Add(Vector3D v1, Vector3D v2) Vector3D

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3AddValue(Vector3D v, double add) Vector3D

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3Angle(Vector3D v1, Vector3D v2) double

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3Barycenter(Vector3D p, Vector3D a, Vector3D b, Vector3D c) Vector3D

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3Clamp(Vector3D v, Vector3D min, Vector3D max) Vector3D

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3ClampValue(Vector3D v, double min, double max) Vector3D

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3CrossProduct(Vector3D v1, Vector3D v2) Vector3D

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3CubicHermite(Vector3D v1, Vector3D tangent1, Vector3D v2, Vector3D tangent2, double amount) Vector3D

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3Distance(Vector3D v1, Vector3D v2) double

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3DistanceSqr(Vector3D v1, Vector3D v2) double

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3Divide(Vector3D v1, Vector3D v2) Vector3D

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3DotProduct(Vector3D v1, Vector3D v2) double

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3DSubtract(Vector3D v1, Vector3D v2) Vector3D

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3Equals(Vector3D p, Vector3D q) bool

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3Invert(Vector3D v) Vector3D

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3Length(Vector3D v) double

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3LengthSqr(Vector3D v) double

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3Lerp(Vector3D v1, Vector3D v2, double amount) Vector3D

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3Max(Vector3D v1, Vector3D v2) Vector3D

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3Min(Vector3D v1, Vector3D v2) Vector3D

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3MoveTowards(Vector3D v, Vector3D target, double maxDistance) Vector3D

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3Multiply(Vector3D v1, Vector3D v2) Vector3D

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3Negate(Vector3D v) Vector3D

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3Normalize(Vector3D v) Vector3D

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3OrthoNormalize(Vector3D v1, Vector3D v2) → void

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3Perpendicular(Vector3D v) Vector3D

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3Project(Vector3D v1, Vector3D v2) Vector3D

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3Reflect(Vector3D v, Vector3D normal) Vector3D

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3Refract(Vector3D v, Vector3D n, double r) Vector3D

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3Reject(Vector3D v1, Vector3D v2) Vector3D

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3RotateByAxisAngle(Vector3D v, Vector3D axis, double angle) Vector3D

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3RotateByQuaternion(Vector3D v, QuaternionD q) Vector3D

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3Scale(Vector3D v, double scalar) Vector3D

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3SubtractValue(Vector3D v, double sub) Vector3D

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3Transform(Vector3D v, MatrixD mat) Vector3D

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector3Unproject(Vector3D source, MatrixD projection, MatrixD view) Vector3D

Available on RaylibVectors, provided by the RaylibVector3 extension

Vector4Add(Vector4D v1, Vector4D v2) Vector4D

Available on RaylibVectors, provided by the RaylibVector4 extension

Vector4AddValue(Vector4D v, double add) Vector4D

Available on RaylibVectors, provided by the RaylibVector4 extension

Vector4Distance(Vector4D v1, Vector4D v2) double

Available on RaylibVectors, provided by the RaylibVector4 extension

Vector4DistanceSqr(Vector4D v1, Vector4D v2) double

Available on RaylibVectors, provided by the RaylibVector4 extension

Vector4Divide(Vector4D v1, Vector4D v2) Vector4D

Available on RaylibVectors, provided by the RaylibVector4 extension

Vector4DotProduct(Vector4D v1, Vector4D v2) double

Available on RaylibVectors, provided by the RaylibVector4 extension

Vector4Equals(Vector4D p, Vector4D q) bool

Available on RaylibVectors, provided by the RaylibVector4 extension

Vector4Invert(Vector4D v) Vector4D

Available on RaylibVectors, provided by the RaylibVector4 extension

Vector4Length(Vector4D v) double

Available on RaylibVectors, provided by the RaylibVector4 extension

Vector4LengthSqr(Vector4D v) double

Available on RaylibVectors, provided by the RaylibVector4 extension

Vector4Lerp(Vector4D v1, Vector4D v2, double amount) Vector4D

Available on RaylibVectors, provided by the RaylibVector4 extension

Vector4Max(Vector4D v1, Vector4D v2) Vector4D

Available on RaylibVectors, provided by the RaylibVector4 extension

Vector4Min(Vector4D v1, Vector4D v2) Vector4D

Available on RaylibVectors, provided by the RaylibVector4 extension

Vector4MoveTowards(Vector4D v, Vector4D target, double maxDistance) Vector4D

Available on RaylibVectors, provided by the RaylibVector4 extension

Vector4Multiply(Vector4D v1, Vector4D v2) Vector4D

Available on RaylibVectors, provided by the RaylibVector4 extension

Vector4Negate(Vector4D v) Vector4D

Available on RaylibVectors, provided by the RaylibVector4 extension

Vector4Normalize(Vector4D v) Vector4D

Available on RaylibVectors, provided by the RaylibVector4 extension

Vector4Scale(Vector4D v, double scale) Vector4D

Available on RaylibVectors, provided by the RaylibVector4 extension

Vector4Subtract(Vector4D v1, Vector4D v2) Vector4D

Available on RaylibVectors, provided by the RaylibVector4 extension

Vector4SubtractValue(Vector4D v, double sub) Vector4D

Available on RaylibVectors, provided by the RaylibVector4 extension

Operators

operator ==(Object other) bool
The equality operator.
inherited