RectangleC class final

Inheritance
Implemented types
Available extensions

Constructors

RectangleC()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
height double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double
getter/setter pair
x double
getter/setter pair
y double
getter/setter pair

Methods

format([int x0 = 0, int? y0, int? w0, int? h0]) String

Available on RectangleC, provided by the RectangleCLike extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(num x, num y, num width, num height) RectangleC

Available on RectangleC, provided by the RectangleCEx extension

setC(RectangleC o) RectangleC

Available on RectangleC, provided by the RectangleCEx extension

setD(RectangleD o) RectangleC

Available on RectangleC, provided by the RectangleCEx extension

toD([Pointer<RectangleC>? ptr]) RectangleD

Available on RectangleC, provided by the RectangleCEx extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited