clone method
Returns a deep copy of this instance, preserving originalPointer.
Implementation
@override
RectangleD clone() => .new(
originalPointer: originalPointer,
x: x,
y: y,
width: width,
height: height,
);
Returns a deep copy of this instance, preserving originalPointer.
@override
RectangleD clone() => .new(
originalPointer: originalPointer,
x: x,
y: y,
width: width,
height: height,
);