setC method
Copies the fields of the native struct o into this instance.
Implementation
@override
RectangleD setC(RectangleC o) => set(o.x, o.y, o.width, o.height);
Copies the fields of the native struct o into this instance.
@override
RectangleD setC(RectangleC o) => set(o.x, o.y, o.width, o.height);