setD method
Copies the fields of the Dart struct o into this instance.
Implementation
@override
RectangleD setD(RectangleD o) {
originalPointer ??= o.originalPointer;
return set(o.x, o.y, o.width, o.height);
}
Copies the fields of the Dart struct o into this instance.
@override
RectangleD setD(RectangleD o) {
originalPointer ??= o.originalPointer;
return set(o.x, o.y, o.width, o.height);
}