writeInto method
Writes all fields directly into the native struct reference p.
For nested structs, use writeInto as well.
Implementation
@override
void writeInto(RectangleC p) {
p.x = x;
p.y = y;
p.width = width;
p.height = height;
}
Writes all fields directly into the native struct reference p.
For nested structs, use writeInto as well.
@override
void writeInto(RectangleC p) {
p.x = x;
p.y = y;
p.width = width;
p.height = height;
}