RenderTextureC class final

Inheritance
Implemented types
Available extensions

Constructors

RenderTextureC()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
depth TextureC
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
texture TextureC
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setC(RenderTextureC o) RenderTextureC

Available on RenderTextureC, provided by the RenderTextureCEx extension

setD(RenderTextureD o) RenderTextureC

Available on RenderTextureC, provided by the RenderTextureCEx extension

toD([Pointer<RenderTextureC>? ptr]) RenderTextureD

Available on RenderTextureC, provided by the RenderTextureCEx extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited