setC method
Copies the fields of the native struct o into this instance.
Implementation
@override
RenderTextureD setC(RenderTextureC o) {
id = o.id;
texture.setC(o.texture);
depth.setC(o.depth);
return this;
}
Copies the fields of the native struct o into this instance.
@override
RenderTextureD setC(RenderTextureC o) {
id = o.id;
texture.setC(o.texture);
depth.setC(o.depth);
return this;
}