RlBlendMode enum
Values
- RL_BLEND_ALPHA → const RlBlendMode
-
const RlBlendMode(0) - RL_BLEND_ADDITIVE → const RlBlendMode
-
const RlBlendMode(1) - RL_BLEND_MULTIPLIED → const RlBlendMode
-
const RlBlendMode(2) - RL_BLEND_ADD_COLORS → const RlBlendMode
-
const RlBlendMode(3) - RL_BLEND_SUBTRACT_COLORS → const RlBlendMode
-
const RlBlendMode(4) - RL_BLEND_ALPHA_PREMULTIPLY → const RlBlendMode
-
const RlBlendMode(5) - RL_BLEND_CUSTOM → const RlBlendMode
-
const RlBlendMode(6) - RL_BLEND_CUSTOM_SEPARATE → const RlBlendMode
-
const RlBlendMode(7)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → RlBlendMode
Constants
-
values
→ const List<
RlBlendMode> - A constant List of the values in this enum, in order of their declaration.