RlDrawCallC class final

Inheritance
Implemented types
Available extensions

Constructors

RlDrawCallC()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
mode int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textureId int
getter/setter pair
vertexAlignment int
getter/setter pair
vertexCount int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setC(RlDrawCallC o) RlDrawCallC

Available on RlDrawCallC, provided by the RlDrawCallCEx extension

setD(RlDrawCallD o) RlDrawCallC

Available on RlDrawCallC, provided by the RlDrawCallCEx extension

toD([Pointer<RlDrawCallC>? ptr]) RlDrawCallD

Available on RlDrawCallC, provided by the RlDrawCallCEx extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited