RlDrawCallD class

Inheritance

Constructors

RlDrawCallD({Pointer<RlDrawCallC>? originalPointer, int mode = 0, int vertexCount = 0, int vertexAlignment = 0, int textureId = 0})
RlDrawCallD.zero()
factory

Properties

allocKey String
no setterinherited
cStructName String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
internalId int
no setterinherited
isDisposed bool
no setterinherited
mode int
getter/setter pair
originalPointer Pointer<RlDrawCallC>?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structName String
no setterinherited
tag String
no setterinherited
textureId int
getter/setter pair
vertexAlignment int
getter/setter pair
vertexCount int
getter/setter pair

Methods

allocateInto(RaylibTemp temp, Pointer<RlDrawCallC> p, String key) → void
override
allocatePointer(RaylibTemp temp, String key, [int count = 1]) Pointer<RlDrawCallC>
override
clone() RlDrawCallD
override
copy() RlDrawCallD
inherited
getOriginalPointer() Pointer<RlDrawCallC>
inherited
getOriginalPointerAndDispose() Pointer<RlDrawCallC>
inherited
markDisposed() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onOriginalPointer(void callback(Pointer<RlDrawCallC> p)) → void
inherited
setC(RlDrawCallC o) RlDrawCallD
override
setD(RlDrawCallD o) RlDrawCallD
override
setTag(String newTag) RlDrawCallD
inherited
signature() String
override
syncInto(RaylibTemp temp, Pointer<RlDrawCallC> p, String key) → void
override
toC(RaylibTemp temp, String key) Pointer<RlDrawCallC>
inherited
toString() String
A string representation of this object.
inherited
writeInto(RlDrawCallC p) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited