RlGlVersion enum
Values
- RL_OPENGL_11 → const RlGlVersion
-
const RlGlVersion(1) - RL_OPENGL_21 → const RlGlVersion
-
const RlGlVersion(2) - RL_OPENGL_33 → const RlGlVersion
-
const RlGlVersion(3) - RL_OPENGL_43 → const RlGlVersion
-
const RlGlVersion(4) - RL_OPENGL_ES_20 → const RlGlVersion
-
const RlGlVersion(5) - RL_OPENGL_ES_30 → const RlGlVersion
-
const RlGlVersion(6)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → RlGlVersion
Constants
-
values
→ const List<
RlGlVersion> - A constant List of the values in this enum, in order of their declaration.