RlPixelFormat enum

Inheritance
Mixed-in types
Available extensions

Values

RL_PIXELFORMAT_UNCOMPRESSED_GRAYSCALE → const RlPixelFormat
const RlPixelFormat(1)
RL_PIXELFORMAT_UNCOMPRESSED_GRAY_ALPHA → const RlPixelFormat
const RlPixelFormat(2)
RL_PIXELFORMAT_UNCOMPRESSED_R5G6B5 → const RlPixelFormat
const RlPixelFormat(3)
RL_PIXELFORMAT_UNCOMPRESSED_R8G8B8 → const RlPixelFormat
const RlPixelFormat(4)
RL_PIXELFORMAT_UNCOMPRESSED_R5G5B5A1 → const RlPixelFormat
const RlPixelFormat(5)
RL_PIXELFORMAT_UNCOMPRESSED_R4G4B4A4 → const RlPixelFormat
const RlPixelFormat(6)
RL_PIXELFORMAT_UNCOMPRESSED_R8G8B8A8 → const RlPixelFormat
const RlPixelFormat(7)
RL_PIXELFORMAT_UNCOMPRESSED_R32 → const RlPixelFormat
const RlPixelFormat(8)
RL_PIXELFORMAT_UNCOMPRESSED_R32G32B32 → const RlPixelFormat
const RlPixelFormat(9)
RL_PIXELFORMAT_UNCOMPRESSED_R32G32B32A32 → const RlPixelFormat
const RlPixelFormat(10)
RL_PIXELFORMAT_UNCOMPRESSED_R16 → const RlPixelFormat
const RlPixelFormat(11)
RL_PIXELFORMAT_UNCOMPRESSED_R16G16B16 → const RlPixelFormat
const RlPixelFormat(12)
RL_PIXELFORMAT_UNCOMPRESSED_R16G16B16A16 → const RlPixelFormat
const RlPixelFormat(13)
RL_PIXELFORMAT_COMPRESSED_DXT1_RGB → const RlPixelFormat
const RlPixelFormat(14)
RL_PIXELFORMAT_COMPRESSED_DXT1_RGBA → const RlPixelFormat
const RlPixelFormat(15)
RL_PIXELFORMAT_COMPRESSED_DXT3_RGBA → const RlPixelFormat
const RlPixelFormat(16)
RL_PIXELFORMAT_COMPRESSED_DXT5_RGBA → const RlPixelFormat
const RlPixelFormat(17)
RL_PIXELFORMAT_COMPRESSED_ETC1_RGB → const RlPixelFormat
const RlPixelFormat(18)
RL_PIXELFORMAT_COMPRESSED_ETC2_RGB → const RlPixelFormat
const RlPixelFormat(19)
RL_PIXELFORMAT_COMPRESSED_ETC2_EAC_RGBA → const RlPixelFormat
const RlPixelFormat(20)
RL_PIXELFORMAT_COMPRESSED_PVRT_RGB → const RlPixelFormat
const RlPixelFormat(21)
RL_PIXELFORMAT_COMPRESSED_PVRT_RGBA → const RlPixelFormat
const RlPixelFormat(22)
RL_PIXELFORMAT_COMPRESSED_ASTC_4x4_RGBA → const RlPixelFormat
const RlPixelFormat(23)
RL_PIXELFORMAT_COMPRESSED_ASTC_8x8_RGBA → const RlPixelFormat
const RlPixelFormat(24)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

eq(FEnum o) bool
inherited
gt(FEnum o) bool
inherited
gte(FEnum o) bool
inherited
lt(FEnum o) bool
inherited
lte(FEnum o) bool
inherited
neq(FEnum o) bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) RlPixelFormat

Constants

values → const List<RlPixelFormat>
A constant List of the values in this enum, in order of their declaration.