RlRenderBatchC class final

Inheritance
Implemented types
Available extensions

Constructors

RlRenderBatchC()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
bufferCount int
getter/setter pair
currentBuffer int
getter/setter pair
currentDepth double
getter/setter pair
drawCounter int
getter/setter pair
draws Pointer<RlDrawCallC>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vertexBuffer Pointer<RlVertexBufferC>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setC(RlRenderBatchC o) RlRenderBatchC

Available on RlRenderBatchC, provided by the RlRenderBatchCEx extension

setD(RlRenderBatchD o) RlRenderBatchC

Available on RlRenderBatchC, provided by the RlRenderBatchCEx extension

toD([Pointer<RlRenderBatchC>? ptr]) RlRenderBatchD

Available on RlRenderBatchC, provided by the RlRenderBatchCEx extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited