RlTraceLogLevel enum
Values
- RL_LOG_ALL → const RlTraceLogLevel
-
const RlTraceLogLevel(0) - RL_LOG_TRACE → const RlTraceLogLevel
-
const RlTraceLogLevel(1) - RL_LOG_DEBUG → const RlTraceLogLevel
-
const RlTraceLogLevel(2) - RL_LOG_INFO → const RlTraceLogLevel
-
const RlTraceLogLevel(3) - RL_LOG_WARNING → const RlTraceLogLevel
-
const RlTraceLogLevel(4) - RL_LOG_ERROR → const RlTraceLogLevel
-
const RlTraceLogLevel(5) - RL_LOG_FATAL → const RlTraceLogLevel
-
const RlTraceLogLevel(6) - RL_LOG_NONE → const RlTraceLogLevel
-
const RlTraceLogLevel(7)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → RlTraceLogLevel
Constants
-
values
→ const List<
RlTraceLogLevel> - A constant List of the values in this enum, in order of their declaration.