SaveFileDataCallbackD class abstract
- Inheritance
-
- Object
- CallbackD<
SaveFileDataCallbackFunctionC, SaveFileDataCallbackFunctionD> - SaveFileDataCallbackD
Constructors
- SaveFileDataCallbackD([String? name])
- SaveFileDataCallbackD.function(SaveFileDataCallbackFunctionD f, {String? name})
-
factory
Properties
- function → SaveFileDataCallbackFunctionD
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String
-
getter/setter pairinherited
-
nativeFunction
→ Pointer<
NativeFunction< SaveFileDataCallbackFunctionC> > -
no setterinherited
-
registry
→ List<
CallbackD< Function, Function> > -
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
attach(
) → Pointer< NativeFunction< SaveFileDataCallbackFunctionC> > -
inherited
-
detach(
[bool keepAlive = false]) → void -
inherited
-
dispose(
) → void -
inherited
-
initializer(
) → NativeCallable< SaveFileDataCallbackFunctionC> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
disposeRegistry(
) → void -
override