ShaderC class final

Inheritance
Implemented types
Available extensions

Constructors

ShaderC()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
id int
getter/setter pair
locs Pointer<Int>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setC(ShaderC o) ShaderC

Available on ShaderC, provided by the ShaderCEx extension

setD(ShaderD o) ShaderC

Available on ShaderC, provided by the ShaderCEx extension

toD([Pointer<ShaderC>? ptr]) ShaderD

Available on ShaderC, provided by the ShaderCEx extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited