SoundC class final

Inheritance
Implemented types
Available extensions

Constructors

SoundC()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
frameCount int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream AudioStreamC
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setC(SoundC o) SoundC

Available on SoundC, provided by the SoundCEx extension

setD(SoundD o) SoundC

Available on SoundC, provided by the SoundCEx extension

toD([Pointer<SoundC>? ptr]) SoundD

Available on SoundC, provided by the SoundCEx extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited