SoundD class

Inheritance

Constructors

SoundD({Pointer<SoundC>? originalPointer, required AudioStreamD stream, required int frameCount})

Properties

allocKey String
no setterinherited
cStructName String
no setterinherited
frameCount int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
internalId int
no setterinherited
isDisposed bool
no setterinherited
originalPointer Pointer<SoundC>?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream AudioStreamD
getter/setter pair
structName String
no setterinherited
tag String
no setterinherited

Methods

allocateInto(RaylibTemp temp, Pointer<SoundC> p, String key) → void
override
allocatePointer(RaylibTemp temp, String key, [int count = 1]) Pointer<SoundC>
override
clone() SoundD
override
copy() SoundD
inherited
getOriginalPointer() Pointer<SoundC>
inherited
getOriginalPointerAndDispose() Pointer<SoundC>
inherited
markDisposed() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onOriginalPointer(void callback(Pointer<SoundC> p)) → void
inherited
setC(SoundC o) SoundD
override
setD(SoundD o) SoundD
override
setTag(String newTag) SoundD
inherited
signature() String
override
syncInto(RaylibTemp temp, Pointer<SoundC> p, String key) → void
override
toC(RaylibTemp temp, String key) Pointer<SoundC>
inherited
toString() String
A string representation of this object.
inherited
writeInto(SoundC p) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited