allocKey property
String?
get
allocKey
The RaylibTemp slot key used during the most recent toC allocation.
Implementation
String? get allocKey => _allocKey;
The RaylibTemp slot key used during the most recent toC allocation.
String? get allocKey => _allocKey;