allocateInto abstract method

void allocateInto(
  1. RaylibTemp temp,
  2. Pointer<C> p,
  3. String key
)

Writes all fields into the native struct at p, allocating nested pointers into temp under key as needed.

Called after allocatePointer to populate the zeroed memory (or reuse). For structs with no nested pointers this is typically equivalent to writeInto(p.ref).

Implementation

void allocateInto(RaylibTemp temp, Pointer<C> p, String key);