writeInto abstract method
void
writeInto(
- C p
Writes all fields directly into the native struct reference p.
For nested structs, use writeInto as well.
Implementation
void writeInto(C p);
Writes all fields directly into the native struct reference p.
For nested structs, use writeInto as well.
void writeInto(C p);