setC method
Copies the fields of the native struct o into this instance.
Implementation
@override
@nonVirtual
D setC(C o) => throw UnsupportedError('$runtimeType: is just a view; cannot write to it.');
Copies the fields of the native struct o into this instance.
@override
@nonVirtual
D setC(C o) => throw UnsupportedError('$runtimeType: is just a view; cannot write to it.');