TextureC class final
- Inheritance
- Implemented types
- Available extensions
Constructors
- TextureC()
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - format ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- height ↔ int
-
getter/setter pair
- id ↔ int
-
getter/setter pair
- mipmaps ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setC(
TextureC o) → TextureC -
Available on TextureC, provided by the TextureCEx extension
-
setD(
TextureD o) → TextureC -
Available on TextureC, provided by the TextureCEx extension
-
toD(
[Pointer< TextureC> ? ptr]) → TextureD -
Available on TextureC, provided by the TextureCEx extension
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited