TextureD class

Inheritance

Constructors

TextureD({Pointer<TextureC>? originalPointer, int id = 0, int width = 0, int height = 0, int mipmaps = 0, PixelFormat format = .PIXELFORMAT_NONE})
TextureD.zero()
factory

Properties

allocKey String
no setterinherited
cStructName String
no setterinherited
format PixelFormat
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
height int
getter/setter pair
id int
getter/setter pair
internalId int
no setterinherited
isDisposed bool
no setterinherited
mipmaps int
getter/setter pair
originalPointer Pointer<TextureC>?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structName String
no setterinherited
tag String
no setterinherited
width int
getter/setter pair

Methods

allocateInto(RaylibTemp temp, Pointer<TextureC> p, String key) → void
override
allocatePointer(RaylibTemp temp, String key, [int count = 1]) Pointer<TextureC>
override
clone() TextureD
override
copy() TextureD
inherited
getOriginalPointer() Pointer<TextureC>
inherited
getOriginalPointerAndDispose() Pointer<TextureC>
inherited
markDisposed() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onOriginalPointer(void callback(Pointer<TextureC> p)) → void
inherited
setC(TextureC o) TextureD
override
setD(TextureD o) TextureD
override
setTag(String newTag) TextureD
inherited
signature() String
override
syncInto(RaylibTemp temp, Pointer<TextureC> p, String key) → void
inherited
toC(RaylibTemp temp, String key) Pointer<TextureC>
inherited
toString() String
A string representation of this object.
inherited
writeInto(TextureC p) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited