TraceLogLevel enum

Inheritance
Available extensions

Values

LOG_ALL → const TraceLogLevel
const TraceLogLevel(0)
LOG_TRACE → const TraceLogLevel
const TraceLogLevel(1)
LOG_DEBUG → const TraceLogLevel
const TraceLogLevel(2)
LOG_INFO → const TraceLogLevel
const TraceLogLevel(3)
LOG_WARNING → const TraceLogLevel
const TraceLogLevel(4)
LOG_ERROR → const TraceLogLevel
const TraceLogLevel(5)
LOG_FATAL → const TraceLogLevel
const TraceLogLevel(6)
LOG_NONE → const TraceLogLevel
const TraceLogLevel(7)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) TraceLogLevel

Constants

values → const List<TraceLogLevel>
A constant List of the values in this enum, in order of their declaration.