TransformC class final

Inheritance
Implemented types
Available extensions

Constructors

TransformC()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
rotation QuaternionC
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale Vector3C
getter/setter pair
translation Vector3C
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setC(TransformC o) TransformC

Available on TransformC, provided by the TransformCEx extension

setD(TransformD o) TransformC

Available on TransformC, provided by the TransformCEx extension

toD([Pointer<TransformC>? ptr]) TransformD

Available on TransformC, provided by the TransformCEx extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited