setC method
Copies the fields of the native struct o into this instance.
Implementation
@override
TransformD setC(TransformC o) {
translation.setC(o.translation);
rotation.setC(o.rotation);
scale.setC(o.scale);
return this;
}
Copies the fields of the native struct o into this instance.
@override
TransformD setC(TransformC o) {
translation.setC(o.translation);
rotation.setC(o.rotation);
scale.setC(o.scale);
return this;
}