Vector2C class final
- Inheritance
- Implemented types
- Available extensions
Constructors
- Vector2C()
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- length → double
-
Available on Vector2C, provided by the Vector2CLike extension
no setter - lengthSqr → double
-
Available on Vector2C, provided by the Vector2CLike extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- x ↔ double
-
getter/setter pair
- y ↔ double
-
getter/setter pair
Methods
-
add(
Vector2C o) → Vector2C -
Available on Vector2C, provided by the Vector2CEx extension
-
angle(
Vector2C o) → double -
Available on Vector2C, provided by the Vector2CLike extension
-
distance(
Vector2C o) → double -
Available on Vector2C, provided by the Vector2CLike extension
-
distanceSqr(
Vector2C o) → double -
Available on Vector2C, provided by the Vector2CLike extension
-
div(
Vector2C o) → Vector2C -
Available on Vector2C, provided by the Vector2CEx extension
-
divideBy(
num o) → Vector2C -
Available on Vector2C, provided by the Vector2CEx extension
-
dotProduct(
Vector2C o) → double -
Available on Vector2C, provided by the Vector2CLike extension
-
format(
[int x0 = 0, int? y0]) → String -
Available on Vector2C, provided by the Vector2CLike extension
-
lineAngle(
Vector2C o) → double -
Available on Vector2C, provided by the Vector2CLike extension
-
mul(
Vector2C o) → Vector2C -
Available on Vector2C, provided by the Vector2CEx extension
-
negate(
) → Vector2C -
Available on Vector2C, provided by the Vector2CEx extension
-
normalize(
) → Vector2C -
Available on Vector2C, provided by the Vector2CEx extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
scale(
num o) → Vector2C -
Available on Vector2C, provided by the Vector2CEx extension
-
set(
num x, num y) → Vector2C -
Available on Vector2C, provided by the Vector2CEx extension
-
setC(
Vector2C o) → Vector2C -
Available on Vector2C, provided by the Vector2CEx extension
-
setD(
Vector2D o) → Vector2C -
Available on Vector2C, provided by the Vector2CEx extension
-
sub(
Vector2C o) → Vector2C -
Available on Vector2C, provided by the Vector2CEx extension
-
toD(
[Pointer< Vector2C> ? ptr]) → Vector2D -
Available on Vector2C, provided by the Vector2CEx extension
-
toString(
) → String -
A string representation of this object.
inherited
-
transform(
MatrixC o) → Vector2C -
Available on Vector2C, provided by the Vector2CEx extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited