VrStereoConfigC class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
-
leftLensCenter
↔ Array<
Float> -
getter/setter pair
-
leftScreenCenter
↔ Array<
Float> -
getter/setter pair
- paramCount → int
-
Available on VrStereoConfigC, provided by the VrStereoConfigCLike extension
no setter -
projection
↔ Array<
MatrixC> -
getter/setter pair
-
rightLensCenter
↔ Array<
Float> -
getter/setter pair
-
rightScreenCenter
↔ Array<
Float> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scale
↔ Array<
Float> -
getter/setter pair
-
scaleIn
↔ Array<
Float> -
getter/setter pair
-
viewOffset
↔ Array<
MatrixC> -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setC(
VrStereoConfigC o) → VrStereoConfigC -
Available on VrStereoConfigC, provided by the VrStereoConfigCEx extension
-
setD(
VrStereoConfigD o) → VrStereoConfigC -
Available on VrStereoConfigC, provided by the VrStereoConfigCEx extension
-
toD(
[Pointer< VrStereoConfigC> ? ptr]) → VrStereoConfigD -
Available on VrStereoConfigC, provided by the VrStereoConfigCEx extension
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited