core/raylib_dartified library

Extensions

AudioStreamCEx on AudioStreamC
AudioStreamCPEx on Pointer<AudioStreamC>
AutomationEventCEx on AutomationEventC
AutomationEventCPEx on Pointer<AutomationEventC>
AutomationEventListCEx on AutomationEventListC
AutomationEventListCPEx on Pointer<AutomationEventListC>
BoneInfoCEx on BoneInfoC
BoneInfoCPEx on Pointer<BoneInfoC>
BoundingBoxCEx on BoundingBoxC
BoundingBoxCPEx on Pointer<BoundingBoxC>
Camera2DCEx on Camera2DC
Camera2DCPEx on Pointer<Camera2DC>
Camera3DCEx on Camera3DC
Camera3DCPEx on Pointer<Camera3DC>
CharPointerEx on Pointer<Char>
ColorCEx on ColorC
ColorCPEx on Pointer<ColorC>
FilePathListCEx on FilePathListC
FilePathListCPEx on Pointer<FilePathListC>
float16CEx on float16C
float16CPEx on Pointer<float16C>
float3CEx on float3C
float3CPEx on Pointer<float3C>
FontCEx on FontC
FontCPEx on Pointer<FontC>
GestureEventCEx on GestureEventC
GestureEventCPEx on Pointer<GestureEventC>
GetStringFromArrayChar on Array<Char>
GlyphInfoCEx on GlyphInfoC
GlyphInfoCPEx on Pointer<GlyphInfoC>
ImageCEx on ImageC
ImageCPEx on Pointer<ImageC>
LightCEx on LightC
LightCPEx on Pointer<LightC>
MaterialCEx on MaterialC
MaterialCPEx on Pointer<MaterialC>
MaterialMapCEx on MaterialMapC
MaterialMapCPEx on Pointer<MaterialMapC>
MatrixCEx on MatrixC
MatrixCPEx on Pointer<MatrixC>
MemoryPointerAsNativePointer on MemoryPointer<RType>
MeshCEx on MeshC
MeshCPEx on Pointer<MeshC>
ModelAnimationCEx on ModelAnimationC
ModelAnimationCPEx on Pointer<ModelAnimationC>
ModelCEx on ModelC
ModelCPEx on Pointer<ModelC>
ModelSkeletonCEx on ModelSkeletonC
ModelSkeletonCPEx on Pointer<ModelSkeletonC>
MsfGifBufferData on Pointer<MsfGifBufferC>
MsfGifResultCEx on MsfGifResultC
MsfGifResultCPEx on Pointer<MsfGifResultC>
MsfGifStateCEx on MsfGifStateC
MsfGifStateCPEx on Pointer<MsfGifStateC>
MusicCEx on MusicC
MusicCPEx on Pointer<MusicC>
NativePointerAsMemoryPointer on Pointer<NativeType>
NPatchInfoCEx on NPatchInfoC
NPatchInfoCPEx on Pointer<NPatchInfoC>
QuaternionCEx on QuaternionC
QuaternionCPEx on Pointer<QuaternionC>
RayCEx on RayC
RayCollisionCEx on RayCollisionC
RayCollisionCPEx on Pointer<RayCollisionC>
RayCPEx on Pointer<RayC>
RectangleCEx on RectangleC
RectangleCPEx on Pointer<RectangleC>
RenderTextureCEx on RenderTextureC
RenderTextureCPEx on Pointer<RenderTextureC>
RlDrawCallCEx on RlDrawCallC
RlDrawCallCPEx on Pointer<RlDrawCallC>
RlRenderBatchCEx on RlRenderBatchC
RlRenderBatchCPEx on Pointer<RlRenderBatchC>
RlVertexBufferCEx on RlVertexBufferC
RlVertexBufferCPEx on Pointer<RlVertexBufferC>
ShaderCEx on ShaderC
ShaderCPEx on Pointer<ShaderC>
SoundCEx on SoundC
SoundCPEx on Pointer<SoundC>
StructPointerAsNativePointer on StructPointer<RaylibStruct>
TextureCEx on TextureC
TextureCPEx on Pointer<TextureC>
TransformCEx on TransformC
TransformCPEx on Pointer<TransformC>
Vector2CEx on Vector2C
Vector2CPEx on Pointer<Vector2C>
Vector3CEx on Vector3C
Vector3CPEx on Pointer<Vector3C>
Vector4CEx on Vector4C
Vector4CPEx on Pointer<Vector4C>
VrDeviceInfoCEx on VrDeviceInfoC
VrDeviceInfoCPEx on Pointer<VrDeviceInfoC>
VrStereoConfigCEx on VrStereoConfigC
VrStereoConfigCPEx on Pointer<VrStereoConfigC>
WaveCEx on WaveC
WaveCPEx on Pointer<WaveC>

Functions

bootMemoryBackend() → void
findRaylib(String folder, {bool silent = false}) → Raylib
Locates the native raylib library by walking up from the current working directory until a directory named folder is found.
runRaylib(RaylibAppBase<Raylib> app, {String? nativeLibPath, bool silent = false}) → Future<void>
Runs app on the native raylib backend until it closes.