AutomationEventC class final

Inheritance
Implemented types
Available extensions

Constructors

AutomationEventC()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
frame ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
params ↔ Array<Int>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDart([Pointer<AutomationEventC>? ptr]) → AutomationEventD

Available on AutomationEventC, provided by the AutomationEventCEx extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited