setD method
Copies the fields of o into this instance and returns this.
Implementation
@override
BoundingBoxD setD(BoundingBoxD o) {
min.setD(o.min);
max.setD(o.max);
return this;
}
Copies the fields of o into this instance and returns this.
@override
BoundingBoxD setD(BoundingBoxD o) {
min.setD(o.min);
max.setD(o.max);
return this;
}