Camera3DC class final

Inheritance
Implemented types
Available extensions

Constructors

Camera3DC()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
fovy ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
position ↔ Vector3C
getter/setter pair
projection ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target ↔ Vector3C
getter/setter pair
up ↔ Vector3C
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDart([Pointer<Camera3DC>? ptr]) → Camera3DD

Available on Camera3DC, provided by the Camera3DCEx extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited