FilePathListC class final

Inheritance
Implemented types
Available extensions

Constructors

FilePathListC()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
count ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
paths ↔ Pointer<Pointer<Char>>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDart([Pointer<FilePathListC>? ptr]) → FilePathListD

Available on FilePathListC, provided by the FilePathListCEx extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited