format property
Pixel format of the image data.
Must be set to a value other than PixelFormat.PIXELFORMAT_NONE before accessing any data layout properties such as bytesPerPixel, frameSize, or dataLength.
Implementation
@override get format {
structOnOp((p) => _format = .fromValue(p.ref.format));
return _format;
}
Pixel format of the image data.
Must be set to a value other than PixelFormat.PIXELFORMAT_NONE before accessing any data layout properties such as bytesPerPixel, frameSize, or dataLength.
Implementation
@override set format(PixelFormat value) {
_format = value;
structOnOp((p) => p.ref.format = value.value);
}