setD method
Copies the fields of o into this instance and returns this.
Implementation
@override
MaterialMapD setD(MaterialMapD o) {
texture.setD(o.texture);
color.setD(o.color);
value = o.value;
return this;
}
Copies the fields of o into this instance and returns this.
@override
MaterialMapD setD(MaterialMapD o) {
texture.setD(o.texture);
color.setD(o.color);
value = o.value;
return this;
}