ModelSkeletonC class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter -
bindPose
↔ Pointer<
TransformC> -
getter/setter pair
- boneCount ↔ int
-
getter/setter pair
-
bones
↔ Pointer<
BoneInfoC> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDart(
[Pointer< ModelSkeletonC> ? ptr]) → ModelSkeletonD -
Available on ModelSkeletonC, provided by the ModelSkeletonCEx extension
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited