QuaternionC class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- w ↔ double
-
getter/setter pair
- x ↔ double
-
getter/setter pair
- y ↔ double
-
getter/setter pair
- z ↔ double
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
set(
num x, num y, num z, num w) → QuaternionC -
Available on QuaternionC, provided by the QuaternionCEx extension
-
setC(
QuaternionC o) → QuaternionC -
Available on QuaternionC, provided by the QuaternionCEx extension
-
setD(
QuaternionD o) → QuaternionC -
Available on QuaternionC, provided by the QuaternionCEx extension
-
toD(
[Pointer< QuaternionC> ? ptr]) → QuaternionD -
Available on QuaternionC, provided by the QuaternionCEx extension
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited