nativeWriteInto method
Writes all fields directly into the native struct reference p.
For nested structs, use writeInto as well.
Implementation
@override
void nativeWriteInto(QuaternionC p) {
p.x = x;
p.y = y;
p.z = z;
p.w = w;
}
Writes all fields directly into the native struct reference p.
For nested structs, use writeInto as well.
@override
void nativeWriteInto(QuaternionC p) {
p.x = x;
p.y = y;
p.z = z;
p.w = w;
}