AttachAudioMixedProcessor method
Attach audio stream processor to the entire audio pipeline, receives the samples as 'float'
Implementation
void AttachAudioMixedProcessor(AudioCallbackC processor)
=> _AttachAudioMixedProcessor(processor);
Attach audio stream processor to the entire audio pipeline, receives the samples as 'float'
void AttachAudioMixedProcessor(AudioCallbackC processor)
=> _AttachAudioMixedProcessor(processor);