LoadSoundAlias method

SoundC LoadSoundAlias(
  1. SoundC source
)

Create a new sound that shares the same sample data as the source sound, does not own the sound data

Implementation

SoundC LoadSoundAlias(SoundC source)
  => _LoadSoundAlias(source);