RaylibAudioFlatNative class

Inheritance

Constructors

RaylibAudioFlatNative(Raylib rl)

Properties

$ → RaylibTemp<RaylibBase>
See RaylibTemp.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
RaylibCaptureIds → _RaylibAudioDartCaptureIds
Capture ID generator for pointer slots allocated by this module.
finalinherited
rl → Raylib
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

AttachAudioMixedProcessor(MemoryPointer<RFunction> processor) → void
Attach audio stream processor to the entire audio pipeline, receives the samples as 'float'
override
AttachAudioStreamProcessor(AudioStreamD stream, MemoryPointer<RFunction> processor) → void
Attach audio stream processor to stream, receives the samples as 'float'
override
CloseAudioDevice() → void
Close the audio device and context
override
debug(bool v) → void
Enables or disables debug logging for this module.
inherited
debugError(String message) → void
Logs message at error level if debug is enabled and message passes all filters.
inherited
debugFilter(bool filter(String)) → void
Adds a predicate that gates debug output. Only messages satisfying at least one filter are logged.
inherited
debugInfo(String message) → void
Logs message at info level if debug is enabled and message passes all filters.
inherited
debugTime(bool v) → void
Enables or disables per-call timing output alongside debug logs.
inherited
debugWarn(String message) → void
Logs message at warn level if debug is enabled and message passes all filters.
inherited
DetachAudioMixedProcessor(MemoryPointer<RFunction> processor) → void
Detach audio stream processor from the entire audio pipeline
override
DetachAudioStreamProcessor(AudioStreamD stream, MemoryPointer<RFunction> processor) → void
Detach audio stream processor from stream
override
disableSync<T>(T f()) → T
Executes f with RaylibTemp syncing temporarily disabled, restoring the previous sync state afterward.
inherited
dispose() → void
Calls all registered onDispose callbacks and clears them.
inherited
disposeStructWithOpFreed<D extends RaylibStruct<D>>(D struct, void fn(StructPointer<D> ptr)) → void
Disposes struct, invokes fn with its underlying pointer, and then frees the temporary allocation backing the pointer, if any.
inherited
disposeStructWithOpUnslotted<D extends RaylibStruct<D>>(D struct, void fn(StructPointer<D> ptr)) → void
Disposes struct, invokes fn with its underlying pointer, and then unslots the temporary allocation backing the pointer, if any.
inherited
ExportWave(WaveD wave, MemoryPointer<RChar> fileName) → bool
Export wave data to file, returns true on success
override
ExportWaveAsCode(WaveD wave, MemoryPointer<RChar> fileName) → bool
Export wave sample data to code (.h), returns true on success
override
GetMasterVolume() → double
Get master volume (listener)
override
GetMusicTimeLength(MusicD music) → double
Get music time length (in seconds)
override
GetMusicTimePlayed(MusicD music) → double
Get current music time played (in seconds)
override
InitAudioDevice() → void
Initialize audio device and context
override
IsAudioDeviceReady() → bool
Check if audio device has been initialized successfully
override
IsAudioStreamPlaying(AudioStreamD stream) → bool
Check if audio stream is playing
override
IsAudioStreamProcessed(AudioStreamD stream) → bool
Check if any audio stream buffers requires refill
override
IsAudioStreamValid(AudioStreamD stream) → bool
Checks if an audio stream is valid (buffers initialized)
override
IsMusicStreamPlaying(MusicD music) → bool
Check if music is playing
override
IsMusicValid(MusicD music) → bool
Checks if a music stream is valid (context and buffers initialized)
override
IsSoundPlaying(SoundD sound) → bool
Check if a sound is currently playing
override
IsSoundValid(SoundD sound) → bool
Checks if a sound is valid (data loaded and buffers initialized)
override
IsWaveValid(WaveD wave) → bool
Checks if wave data is valid (data loaded and parameters)
override
load() → void
Override to perform one-time module initialization.
inherited
LoadAudioStream(int sampleRate, int sampleSize, int channels) → AudioStreamD
Load audio stream (to stream raw audio pcm data)
override
LoadMusicStream(MemoryPointer<RChar> fileName) → MusicD
Load music stream from file
override
LoadMusicStreamFromMemory(MemoryPointer<RChar> fileType, MemoryPointer<RUnsignedChar> data, int dataSize) → MusicD
Load music stream from data
override
LoadSound(MemoryPointer<RChar> fileName) → SoundD
Load sound from file
override
LoadSoundAlias(SoundD source) → SoundD
Create a new sound that shares the same sample data as the source sound, does not own the sound data
override
LoadSoundFromWave(WaveD wave) → SoundD
Load sound from wave data
override
LoadWave(MemoryPointer<RChar> fileName) → WaveD
Load wave data from file
override
LoadWaveFromMemory(MemoryPointer<RChar> fileType, MemoryPointer<RUnsignedChar> fileData, int dataSize) → WaveD
Load wave from memory buffer, fileType refers to extension: i.e. '.wav'
override
LoadWaveSamples(WaveD wave) → NativeMemoryPointer<RFloat32>
Load samples data from wave as a 32bit float data array
override
logError(Object? message) → void
inherited
logInfo(Object? message) → void
inherited
logWarn(Object? message) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose(void fn()) → void
Registers fn to be called when this module is disposed.
inherited
PauseAudioStream(AudioStreamD stream) → void
Pause audio stream
override
PauseMusicStream(MusicD music) → void
Pause music playing
override
PauseSound(SoundD sound) → void
Pause a sound
override
PlayAudioStream(AudioStreamD stream) → void
Play audio stream
override
PlayMusicStream(MusicD music) → void
Start music playing
override
PlaySound(SoundD sound) → void
Play a sound
override
ResumeAudioStream(AudioStreamD stream) → void
Resume audio stream
override
ResumeMusicStream(MusicD music) → void
Resume playing paused music
override
ResumeSound(SoundD sound) → void
Resume a paused sound
override
run<T>(String name(), T f()) → T
Executes f, logging its label (and optionally timing it) when debug is enabled and the label passes all filters.
inherited
SeekMusicStream(MusicD music, double position) → void
Seek music to a position (in seconds)
override
SetAudioStreamBufferSizeDefault(int size) → void
Default size for new audio streams
override
SetAudioStreamCallback(AudioStreamD stream, MemoryPointer<RFunction> callback) → void
Audio thread callback to request new data
override
SetAudioStreamPan(AudioStreamD stream, double pan) → void
Set pan for a sound (-1.0 left, 0.0 center, 1.0 right)
override
SetAudioStreamPitch(AudioStreamD stream, double pitch) → void
Set pitch for audio stream (1.0 is base level)
override
SetAudioStreamVolume(AudioStreamD stream, double volume) → void
Set volume for audio stream (1.0 is max level)
override
SetMasterVolume(double volume) → void
Set master volume (listener)
override
SetMusicPan(MusicD music, double pan) → void
Set pan for a music (0.5 is center)
override
SetMusicPitch(MusicD music, double pitch) → void
Set pitch for a music (1.0 is base level)
override
SetMusicVolume(MusicD music, double volume) → void
Set volume for music (1.0 is max level)
override
SetSoundPan(SoundD sound, double pan) → void
Set pan for a sound (0.5 is center)
override
SetSoundPitch(SoundD sound, double pitch) → void
Set pitch for a sound (1.0 is base level)
override
SetSoundVolume(SoundD sound, double volume) → void
Set volume for a sound (1.0 is max level)
override
StopAudioStream(AudioStreamD stream) → void
Stop audio stream
override
StopMusicStream(MusicD music) → void
Stop music playing
override
StopSound(SoundD sound) → void
Stop playing a sound
override
toString() → String
A string representation of this object.
inherited
UnloadAudioStream(AudioStreamD stream) → void
Unload audio stream and free memory
override
UnloadMusicStream(MusicD music) → void
Unload music stream
override
UnloadSound(SoundD sound) → void
Unload sound
override
UnloadSoundAlias(SoundD alias) → void
Unload a sound alias (does not deallocate sample data)
override
UnloadWave(WaveD wave) → void
Unload wave data
override
UnloadWaveSamples(MemoryPointer<RFloat> samples) → void
Unload samples data loaded with LoadWaveSamples()
override
UpdateAudioStream(AudioStreamD stream, MemoryPointer<RVoid> data, int frameCount) → void
Update audio stream buffers with data
override
UpdateMusicStream(MusicD music) → void
Updates buffers for music streaming
override
UpdateSound(SoundD sound, MemoryPointer<RVoid> data, int sampleCount) → void
Update sound buffer with new data
override
WaveCopy(WaveD wave) → WaveD
Copy a wave to a new wave
override
WaveCrop(StructPointer<WaveD> wave, int initFrame, int finalFrame) → void
Crop a wave to defined frames range
override
WaveFormat(StructPointer<WaveD> wave, int sampleRate, int sampleSize, int channels) → void
Convert wave data to desired format
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited