LoadSoundAlias method
Create a new sound that shares the same sample data as the source sound, does not own the sound data
Implementation
@override
SoundD LoadSoundAlias(
SoundD source,
) => $.Sound$.RefCapture(
RaylibCaptureIds.LoadSoundAlias,
(p) => _ffi.LoadSoundAlias(
$.Sound$.Ref1(source).asNativePointer<SoundC>().ref,
).toDart(p.asNativePointer()),
);