CameraMoveRight method

void CameraMoveRight(
  1. Pointer<Camera3DC> camera,
  2. double distance,
  3. bool moveInWorldPlane
)

Moves the camera target in its current right direction by distance.

If moveInWorldPlane is true, movement is constrained to the XZ plane regardless of the camera's pitch.

Implementation

void CameraMoveRight(Pointer<Camera3DC> camera, double distance, bool moveInWorldPlane)
  => _CameraMoveRight(camera, distance, moveInWorldPlane);