GetCameraProjectionMatrix method
Returns the projection matrix for camera with the given aspect ratio.
Implementation
MatrixC GetCameraProjectionMatrix(Pointer<Camera3DC> camera, double aspect)
=> _GetCameraProjectionMatrix(camera, aspect);
Returns the projection matrix for camera with the given aspect ratio.
MatrixC GetCameraProjectionMatrix(Pointer<Camera3DC> camera, double aspect)
=> _GetCameraProjectionMatrix(camera, aspect);