RaylibCameraFlat class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
CameraMoveForward(StructPointer<Camera3DD> camera, double distance, bool moveInWorldPlane)
→ void
-
-
CameraMoveRight(StructPointer<Camera3DD> camera, double distance, bool moveInWorldPlane)
→ void
-
-
CameraMoveToTarget(StructPointer<Camera3DD> camera, double delta)
→ void
-
-
CameraMoveUp(StructPointer<Camera3DD> camera, double distance)
→ void
-
-
CameraPitch(StructPointer<Camera3DD> camera, double angle, bool lockView, bool rotateAroundTarget, bool rotateUp)
→ void
-
-
CameraRoll(StructPointer<Camera3DD> camera, double angle)
→ void
-
-
CameraYaw(StructPointer<Camera3DD> camera, double angle, bool rotateAroundTarget)
→ void
-
-
GetCameraForward(StructPointer<Camera3DD> camera)
→ Vector3D
-
-
GetCameraProjectionMatrix(StructPointer<Camera3DD> camera, double aspect)
→ MatrixD
-
-
GetCameraRight(StructPointer<Camera3DD> camera)
→ Vector3D
-
-
GetCameraUp(StructPointer<Camera3DD> camera)
→ Vector3D
-
-
GetCameraViewMatrix(StructPointer<Camera3DD> camera)
→ MatrixD
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited