CameraMoveRight method

  1. @override
void CameraMoveRight(
  1. StructPointer<Camera3DD> camera,
  2. double distance,
  3. bool moveInWorldPlane
)
override

Moves the camera target in its current right direction by distance.

If moveInWorldPlane is true, movement is constrained to the XZ plane regardless of the camera's pitch.

Implementation

@override
void CameraMoveRight(
  StructPointer<Camera3DD> camera,
  double distance,
  bool moveInWorldPlane,
) => _ffi.CameraMoveRight(
  camera.asNativePointer(),
  distance.toDouble(),
  moveInWorldPlane,
);