RaylibCore class

Inheritance

Constructors

RaylibCore(Raylib rl)

Properties

$ → RaylibTemp<RaylibBase>
See RaylibTemp.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
rl → Raylib
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

BeginBlendMode(int mode) → void
Begin blending mode (alpha, additive, multiplied, subtract, custom)
BeginDrawing() → void
Setup canvas (framebuffer) to start drawing
BeginMode2D(Camera2DC camera) → void
Begin 2D mode with custom camera (2D)
BeginMode3D(Camera3DC camera) → void
Begin 3D mode with custom camera (3D)
BeginScissorMode(int x, int y, int width, int height) → void
Begin scissor mode (define screen area for following drawing)
BeginShaderMode(ShaderC shader) → void
Begin custom shader drawing
BeginTextureMode(RenderTextureC target) → void
Begin drawing to render texture
BeginVrStereoMode(VrStereoConfigC config) → void
Begin stereo rendering (requires VR simulator)
ChangeDirectory(Pointer<Char> dir) → bool
Change working directory, return true on success
CheckCollisionBoxes(BoundingBoxC box1, BoundingBoxC box2) → bool
Check collision between two bounding boxes
CheckCollisionBoxSphere(BoundingBoxC box, Vector3C center, double radius) → bool
Check collision between box and sphere
CheckCollisionCircleLine(Vector2C center, double radius, Vector2C p1, Vector2C p2) → bool
Check if circle collides with a line created betweeen two points p1 and p2
CheckCollisionCircleRec(Vector2C center, double radius, RectangleC rec) → bool
Check collision between circle and rectangle
CheckCollisionCircles(Vector2C center1, double radius1, Vector2C center2, double radius2) → bool
Check collision between two circles
CheckCollisionLines(Vector2C startPos1, Vector2C endPos1, Vector2C startPos2, Vector2C endPos2, Pointer<Vector2C> collisionPoint) → bool
Check the collision between two lines defined by two points each, returns collision point by reference
CheckCollisionPointCircle(Vector2C point, Vector2C center, double radius) → bool
Check if point is inside circle
CheckCollisionPointLine(Vector2C point, Vector2C p1, Vector2C p2, int threshold) → bool
Check if point belongs to line created between two points p1 and p2 with defined margin in pixels threshold
CheckCollisionPointPoly(Vector2C point, Pointer<Vector2C> points, int pointCount) → bool
Check if point is within a polygon described by array of vertices
CheckCollisionPointRec(Vector2C point, RectangleC rec) → bool
Check if point is inside rectangle
CheckCollisionPointTriangle(Vector2C point, Vector2C p1, Vector2C p2, Vector2C p3) → bool
Check if point is inside a triangle
CheckCollisionRecs(RectangleC rec1, RectangleC rec2) → bool
Check collision between two rectangles
CheckCollisionSpheres(Vector3C center1, double radius1, Vector3C center2, double radius2) → bool
Check collision between two spheres
ClearBackground(ColorC color) → void
Set background color (framebuffer clear color)
ClearWindowState(int flags) → void
Clear window configuration state flags
CloseWindow() → void
Close window and unload OpenGL context
CodepointToUTF8(int codepoint, Pointer<Int> utf8Size) → Pointer<Char>
Encode one codepoint into UTF-8 byte array (array length returned as parameter)
ColorAlpha(ColorC color, double alpha) → ColorC
Get color with alpha applied, alpha goes from 0.0 to 1.0
ColorAlphaBlend(ColorC dst, ColorC src, ColorC tint) → ColorC
Get src alpha-blended into dst color with tint
ColorBrightness(ColorC color, double factor) → ColorC
Get color with brightness correction, brightness factor goes from -1.0 to 1.0
ColorContrast(ColorC color, double contrast) → ColorC
Get color with contrast correction, contrast values between -1.0 and 1.0
ColorFromHSV(double hue, double saturation, double value) → ColorC
Get a Color from HSV values, hue 0..360, saturation/value 0..1
ColorFromNormalized(Vector4C normalized) → ColorC
Get Color from normalized values 0..1
ColorIsEqual(ColorC col1, ColorC col2) → bool
Check if two colors are equal
ColorLerp(ColorC color1, ColorC color2, double factor) → ColorC
Get color lerp interpolation between two colors, factor 0.0..1.0
ColorNormalize(ColorC color) → Vector4C
Get Color normalized as float 0..1
ColorTint(ColorC color, ColorC tint) → ColorC
Get color multiplied with another color
ColorToHSV(ColorC color) → Vector3C
Get HSV values for a Color, hue 0..360, saturation/value 0..1
ColorToInt(ColorC color) → int
Get hexadecimal value for a Color (0xRRGGBBAA)
CompressData(Pointer<UnsignedChar> data, int dataSize, Pointer<Int> compDataSize) → Pointer<UnsignedChar>
Compress data (DEFLATE algorithm)
ComputeCRC32(Pointer<UnsignedChar> data, int dataSize) → int
Compute CRC32 hash code
ComputeMD5(Pointer<UnsignedChar> data, int dataSize) → Pointer<UnsignedInt>
Compute MD5 hash code
ComputeSHA1(Pointer<UnsignedChar> data, int dataSize) → Pointer<UnsignedInt>
Compute SHA1 hash code
ComputeSHA256(Pointer<UnsignedChar> data, int dataSize) → Pointer<UnsignedInt>
Compute SHA256 hash code
debug(bool v) → void
Enables or disables debug logging for this module.
inherited
debugError(String message) → void
Logs message at error level if debug is enabled and message passes all filters.
inherited
debugFilter(bool filter(String)) → void
Adds a predicate that gates debug output. Only messages satisfying at least one filter are logged.
inherited
debugInfo(String message) → void
Logs message at info level if debug is enabled and message passes all filters.
inherited
debugTime(bool v) → void
Enables or disables per-call timing output alongside debug logs.
inherited
debugWarn(String message) → void
Logs message at warn level if debug is enabled and message passes all filters.
inherited
DecodeDataBase64(Pointer<Char> data, Pointer<Int> outputSize) → Pointer<UnsignedChar>
Decode Base64 string data
DecompressData(Pointer<UnsignedChar> compData, int compDataSize, Pointer<Int> dataSize) → Pointer<UnsignedChar>
Decompress data (DEFLATE algorithm)
DirectoryExists(Pointer<Char> dirPath) → bool
Check if a directory path exists
DisableCursor() → void
Disables cursor (lock cursor)
DisableEventWaiting() → void
Disable waiting for events on EndDrawing(), automatic events polling
disableSync<T>(T f()) → T
Executes f with RaylibTemp syncing temporarily disabled, restoring the previous sync state afterward.
inherited
dispose() → void
Calls all registered onDispose callbacks and clears them.
inherited
disposeStructWithOpFreed<D extends RaylibStruct<D>>(D struct, void fn(StructPointer<D> ptr)) → void
Disposes struct, invokes fn with its underlying pointer, and then frees the temporary allocation backing the pointer, if any.
inherited
disposeStructWithOpUnslotted<D extends RaylibStruct<D>>(D struct, void fn(StructPointer<D> ptr)) → void
Disposes struct, invokes fn with its underlying pointer, and then unslots the temporary allocation backing the pointer, if any.
inherited
DrawBillboard(Camera3DC camera, TextureC texture, Vector3C position, double scale, ColorC tint) → void
Draw a billboard texture
DrawBillboardPro(Camera3DC camera, TextureC texture, RectangleC source, Vector3C position, Vector3C up, Vector2C size, Vector2C origin, double rotation, ColorC tint) → void
Draw a billboard texture defined by source and rotation
DrawBillboardRec(Camera3DC camera, TextureC texture, RectangleC source, Vector3C position, Vector2C size, ColorC tint) → void
Draw a billboard texture defined by source
DrawBoundingBox(BoundingBoxC box, ColorC color) → void
Draw bounding box (wires)
DrawCapsule(Vector3C startPos, Vector3C endPos, double radius, int slices, int rings, ColorC color) → void
Draw a capsule with the center of its sphere caps at startPos and endPos
DrawCapsuleWires(Vector3C startPos, Vector3C endPos, double radius, int slices, int rings, ColorC color) → void
Draw capsule wireframe with the center of its sphere caps at startPos and endPos
DrawCircle(int centerX, int centerY, double radius, ColorC color) → void
Draw a color-filled circle
DrawCircle3D(Vector3C center, double radius, Vector3C rotationAxis, double rotationAngle, ColorC color) → void
Draw a circle in 3D world space
DrawCircleGradient(Vector2C center, double radius, ColorC inner, ColorC outer) → void
Draw a gradient-filled circle
DrawCircleLines(int centerX, int centerY, double radius, ColorC color) → void
Draw circle outline
DrawCircleLinesV(Vector2C center, double radius, ColorC color) → void
Draw circle outline (Vector version)
DrawCircleSector(Vector2C center, double radius, double startAngle, double endAngle, int segments, ColorC color) → void
Draw a piece of a circle
DrawCircleSectorLines(Vector2C center, double radius, double startAngle, double endAngle, int segments, ColorC color) → void
Draw circle sector outline
DrawCircleV(Vector2C center, double radius, ColorC color) → void
Draw a color-filled circle (Vector version)
DrawCube(Vector3C position, double width, double height, double length, ColorC color) → void
Draw cube
DrawCubeV(Vector3C position, Vector3C size, ColorC color) → void
Draw cube (Vector version)
DrawCubeWires(Vector3C position, double width, double height, double length, ColorC color) → void
Draw cube wires
DrawCubeWiresV(Vector3C position, Vector3C size, ColorC color) → void
Draw cube wires (Vector version)
DrawCylinder(Vector3C position, double radiusTop, double radiusBottom, double height, int slices, ColorC color) → void
Draw a cylinder/cone
DrawCylinderEx(Vector3C startPos, Vector3C endPos, double startRadius, double endRadius, int sides, ColorC color) → void
Draw a cylinder with base at startPos and top at endPos
DrawCylinderWires(Vector3C position, double radiusTop, double radiusBottom, double height, int slices, ColorC color) → void
Draw a cylinder/cone wires
DrawCylinderWiresEx(Vector3C startPos, Vector3C endPos, double startRadius, double endRadius, int sides, ColorC color) → void
Draw a cylinder wires with base at startPos and top at endPos
DrawEllipse(int centerX, int centerY, double radiusH, double radiusV, ColorC color) → void
Draw ellipse
DrawEllipseLines(int centerX, int centerY, double radiusH, double radiusV, ColorC color) → void
Draw ellipse outline
DrawEllipseLinesV(Vector2C center, double radiusH, double radiusV, ColorC color) → void
Draw ellipse outline (Vector version)
DrawEllipseV(Vector2C center, double radiusH, double radiusV, ColorC color) → void
Draw ellipse (Vector version)
DrawFPS(int posX, int posY) → void
Draw current FPS
DrawGrid(int slices, double spacing) → void
Draw a grid (centered at (0, 0, 0))
DrawLine(int startPosX, int startPosY, int endPosX, int endPosY, ColorC color) → void
Draw a line
DrawLine3D(Vector3C startPos, Vector3C endPos, ColorC color) → void
Draw a line in 3D world space
DrawLineBezier(Vector2C startPos, Vector2C endPos, double thick, ColorC color) → void
Draw line segment cubic-bezier in-out interpolation
DrawLineDashed(Vector2C startPos, Vector2C endPos, int dashSize, int spaceSize, ColorC color) → void
Draw a dashed line
DrawLineEx(Vector2C startPos, Vector2C endPos, double thick, ColorC color) → void
Draw a line (using triangles/quads)
DrawLineStrip(Pointer<Vector2C> points, int pointCount, ColorC color) → void
Draw lines sequence (using gl lines)
DrawLineV(Vector2C startPos, Vector2C endPos, ColorC color) → void
Draw a line (using gl lines)
DrawMesh(MeshC mesh, MaterialC material, MatrixC transform) → void
Draw a 3d mesh with material and transform
DrawMeshInstanced(MeshC mesh, MaterialC material, Pointer<MatrixC> transforms, int instances) → void
Draw multiple mesh instances with material and different transforms
DrawModel(ModelC model, Vector3C position, double scale, ColorC tint) → void
Draw a model (with texture if set)
DrawModelEx(ModelC model, Vector3C position, Vector3C rotationAxis, double rotationAngle, Vector3C scale, ColorC tint) → void
Draw a model with extended parameters
DrawModelWires(ModelC model, Vector3C position, double scale, ColorC tint) → void
Draw a model wires (with texture if set)
DrawModelWiresEx(ModelC model, Vector3C position, Vector3C rotationAxis, double rotationAngle, Vector3C scale, ColorC tint) → void
Draw a model wires (with texture if set) with extended parameters
DrawPixel(int posX, int posY, ColorC color) → void
Draw a pixel using geometry Can be slow, use with care
DrawPixelV(Vector2C position, ColorC color) → void
Draw a pixel using geometry (Vector version) Can be slow, use with care
DrawPlane(Vector3C centerPos, Vector2C size, ColorC color) → void
Draw a plane XZ
DrawPoint3D(Vector3C position, ColorC color) → void
Draw a point in 3D space, actually a small line
DrawPoly(Vector2C center, int sides, double radius, double rotation, ColorC color) → void
Draw a regular polygon (Vector version)
DrawPolyLines(Vector2C center, int sides, double radius, double rotation, ColorC color) → void
Draw a polygon outline of n sides
DrawPolyLinesEx(Vector2C center, int sides, double radius, double rotation, double lineThick, ColorC color) → void
Draw a polygon outline of n sides with extended parameters
DrawRay(RayC ray, ColorC color) → void
Draw a ray line
DrawRectangle(int posX, int posY, int width, int height, ColorC color) → void
Draw a color-filled rectangle
DrawRectangleGradientEx(RectangleC rec, ColorC topLeft, ColorC bottomLeft, ColorC topRight, ColorC bottomRight) → void
Draw a gradient-filled rectangle with custom vertex colors
DrawRectangleGradientH(int posX, int posY, int width, int height, ColorC left, ColorC right) → void
Draw a horizontal-gradient-filled rectangle
DrawRectangleGradientV(int posX, int posY, int width, int height, ColorC top, ColorC bottom) → void
Draw a vertical-gradient-filled rectangle
DrawRectangleLines(int posX, int posY, int width, int height, ColorC color) → void
Draw rectangle outline
DrawRectangleLinesEx(RectangleC rec, double lineThick, ColorC color) → void
Draw rectangle outline with extended parameters
DrawRectanglePro(RectangleC rec, Vector2C origin, double rotation, ColorC color) → void
Draw a color-filled rectangle with pro parameters
DrawRectangleRec(RectangleC rec, ColorC color) → void
Draw a color-filled rectangle
DrawRectangleRounded(RectangleC rec, double roundness, int segments, ColorC color) → void
Draw rectangle with rounded edges
DrawRectangleRoundedLines(RectangleC rec, double roundness, int segments, ColorC color) → void
Draw rectangle lines with rounded edges
DrawRectangleRoundedLinesEx(RectangleC rec, double roundness, int segments, double lineThick, ColorC color) → void
Draw rectangle with rounded edges outline
DrawRectangleV(Vector2C position, Vector2C size, ColorC color) → void
Draw a color-filled rectangle (Vector version)
DrawRing(Vector2C center, double innerRadius, double outerRadius, double startAngle, double endAngle, int segments, ColorC color) → void
Draw ring
DrawRingLines(Vector2C center, double innerRadius, double outerRadius, double startAngle, double endAngle, int segments, ColorC color) → void
Draw ring outline
DrawSphere(Vector3C centerPos, double radius, ColorC color) → void
Draw sphere
DrawSphereEx(Vector3C centerPos, double radius, int rings, int slices, ColorC color) → void
Draw sphere with extended parameters
DrawSphereWires(Vector3C centerPos, double radius, int rings, int slices, ColorC color) → void
Draw sphere wires
DrawSplineBasis(Pointer<Vector2C> points, int pointCount, double thick, ColorC color) → void
Draw spline: B-Spline, minimum 4 points
DrawSplineBezierCubic(Pointer<Vector2C> points, int pointCount, double thick, ColorC color) → void
Draw spline: Cubic Bezier, minimum 4 points (2 control points): p1, c2, c3, p4, c5, c6...
DrawSplineBezierQuadratic(Pointer<Vector2C> points, int pointCount, double thick, ColorC color) → void
Draw spline: Quadratic Bezier, minimum 3 points (1 control point): p1, c2, p3, c4...
DrawSplineCatmullRom(Pointer<Vector2C> points, int pointCount, double thick, ColorC color) → void
Draw spline: Catmull-Rom, minimum 4 points
DrawSplineLinear(Pointer<Vector2C> points, int pointCount, double thick, ColorC color) → void
Draw spline: Linear, minimum 2 points
DrawSplineSegmentBasis(Vector2C p1, Vector2C p2, Vector2C p3, Vector2C p4, double thick, ColorC color) → void
Draw spline segment: B-Spline, 4 points
DrawSplineSegmentBezierCubic(Vector2C p1, Vector2C c2, Vector2C c3, Vector2C p4, double thick, ColorC color) → void
Draw spline segment: Cubic Bezier, 2 points, 2 control points
DrawSplineSegmentBezierQuadratic(Vector2C p1, Vector2C c2, Vector2C p3, double thick, ColorC color) → void
Draw spline segment: Quadratic Bezier, 2 points, 1 control point
DrawSplineSegmentCatmullRom(Vector2C p1, Vector2C p2, Vector2C p3, Vector2C p4, double thick, ColorC color) → void
Draw spline segment: Catmull-Rom, 4 points
DrawSplineSegmentLinear(Vector2C p1, Vector2C p2, double thick, ColorC color) → void
Draw spline segment: Linear, 2 points
DrawText(Pointer<Char> text, int posX, int posY, int fontSize, ColorC color) → void
Draw text (using default font)
DrawTextCodepoint(FontC font, int codepoint, Vector2C position, double fontSize, ColorC tint) → void
Draw one character (codepoint)
DrawTextCodepoints(FontC font, Pointer<Int> codepoints, int codepointCount, Vector2C position, double fontSize, double spacing, ColorC tint) → void
Draw multiple character (codepoint)
DrawTextEx(FontC font, Pointer<Char> text, Vector2C position, double fontSize, double spacing, ColorC tint) → void
Draw text using font and additional parameters
DrawTextPro(FontC font, Pointer<Char> text, Vector2C position, Vector2C origin, double rotation, double fontSize, double spacing, ColorC tint) → void
Draw text using Font and pro parameters (rotation)
DrawTexture(TextureC texture, int posX, int posY, ColorC tint) → void
Draw a Texture2D
DrawTextureEx(TextureC texture, Vector2C position, double rotation, double scale, ColorC tint) → void
Draw a Texture2D with extended parameters
DrawTextureNPatch(TextureC texture, NPatchInfoC nPatchInfo, RectangleC dest, Vector2C origin, double rotation, ColorC tint) → void
Draws a texture (or part of it) that stretches or shrinks nicely
DrawTexturePro(TextureC texture, RectangleC source, RectangleC dest, Vector2C origin, double rotation, ColorC tint) → void
Draw a part of a texture defined by a rectangle with 'pro' parameters
DrawTextureRec(TextureC texture, RectangleC source, Vector2C position, ColorC tint) → void
Draw a part of a texture defined by a rectangle
DrawTextureV(TextureC texture, Vector2C position, ColorC tint) → void
Draw a Texture2D with position defined as Vector2
DrawTriangle(Vector2C v1, Vector2C v2, Vector2C v3, ColorC color) → void
Draw a color-filled triangle (vertex in counter-clockwise order!)
DrawTriangle3D(Vector3C v1, Vector3C v2, Vector3C v3, ColorC color) → void
Draw a color-filled triangle (vertex in counter-clockwise order!)
DrawTriangleFan(Pointer<Vector2C> points, int pointCount, ColorC color) → void
Draw a triangle fan defined by points (first vertex is the center)
DrawTriangleLines(Vector2C v1, Vector2C v2, Vector2C v3, ColorC color) → void
Draw triangle outline (vertex in counter-clockwise order!)
DrawTriangleStrip(Pointer<Vector2C> points, int pointCount, ColorC color) → void
Draw a triangle strip defined by points
DrawTriangleStrip3D(Pointer<Vector3C> points, int pointCount, ColorC color) → void
Draw a triangle strip defined by points
EnableCursor() → void
Enables cursor (unlock cursor)
EnableEventWaiting() → void
Enable waiting for events on EndDrawing(), no automatic event polling
EncodeDataBase64(Pointer<UnsignedChar> data, int dataSize, Pointer<Int> outputSize) → Pointer<Char>
Encode data to Base64 string
EndBlendMode() → void
End blending mode (reset to default: alpha blending)
EndDrawing() → void
End canvas drawing and swap buffers (double buffering)
EndMode2D() → void
Ends 2D mode with custom camera
EndMode3D() → void
Ends 3D mode and returns to default 2D orthographic mode
EndScissorMode() → void
End scissor mode
EndShaderMode() → void
End custom shader drawing (use default shader)
EndTextureMode() → void
Ends drawing to render texture
EndVrStereoMode() → void
End stereo rendering (requires VR simulator)
ExportAutomationEventList(AutomationEventListC list, Pointer<Char> fileName) → bool
Export automation events list as text file
ExportDataAsCode(Pointer<UnsignedChar> data, int dataSize, Pointer<Char> fileName) → bool
Export data to code (.h), returns true on success
ExportFontAsCode(FontC font, Pointer<Char> fileName) → bool
Export font as code file, returns true on success
ExportImage(ImageC image, Pointer<Char> fileName) → bool
Export image data to file, returns true on success
ExportImageAsCode(ImageC image, Pointer<Char> fileName) → bool
Export image as code file defining an array of bytes, returns true on success
ExportImageToMemory(ImageC image, Pointer<Char> fileType, Pointer<Int> fileSize) → Pointer<UnsignedChar>
Export image to memory buffer
ExportMesh(MeshC mesh, Pointer<Char> fileName) → bool
Export mesh data to file, returns true on success
ExportMeshAsCode(MeshC mesh, Pointer<Char> fileName) → bool
Export mesh as code file (.h) defining multiple arrays of vertex attributes
Fade(ColorC color, double alpha) → ColorC
Get color with alpha applied, alpha goes from 0.0 to 1.0
FileCopy(Pointer<Char> srcPath, Pointer<Char> dstPath) → int
Copy file from one path to another, dstPath created if it doesn't exist
FileExists(Pointer<Char> fileName) → bool
Check if file exists
FileMove(Pointer<Char> srcPath, Pointer<Char> dstPath) → int
Move file from one directory to another, dstPath created if it doesn't exist
FileRemove(Pointer<Char> fileName) → int
Remove file (if exists)
FileRename(Pointer<Char> fileName, Pointer<Char> fileRename) → int
Rename file (if exists)
FileTextFindIndex(Pointer<Char> fileName, Pointer<Char> search) → int
Find text in existing file
FileTextReplace(Pointer<Char> fileName, Pointer<Char> search, Pointer<Char> replacement) → int
Replace text in an existing file
GenImageCellular(int width, int height, int tileSize) → ImageC
Generate image: cellular algorithm, bigger tileSize means bigger cells
GenImageChecked(int width, int height, int checksX, int checksY, ColorC col1, ColorC col2) → ImageC
Generate image: checked
GenImageColor(int width, int height, ColorC color) → ImageC
Generate image: plain color
GenImageFontAtlas(Pointer<GlyphInfoC> glyphs, Pointer<Pointer<RectangleC>> glyphRecs, int glyphCount, int fontSize, int padding, int packMethod) → ImageC
Generate image font atlas using chars info
GenImageGradientLinear(int width, int height, int direction, ColorC start, ColorC end) → ImageC
Generate image: linear gradient, direction in degrees 0..360, 0=Vertical gradient
GenImageGradientRadial(int width, int height, double density, ColorC inner, ColorC outer) → ImageC
Generate image: radial gradient
GenImageGradientSquare(int width, int height, double density, ColorC inner, ColorC outer) → ImageC
Generate image: square gradient
GenImagePerlinNoise(int width, int height, int offsetX, int offsetY, double scale) → ImageC
Generate image: perlin noise
GenImageText(int width, int height, Pointer<Char> text) → ImageC
Generate image: grayscale image from text data
GenImageWhiteNoise(int width, int height, double factor) → ImageC
Generate image: white noise
GenMeshCone(double radius, double height, int slices) → MeshC
Generate cone/pyramid mesh
GenMeshCube(double width, double height, double length) → MeshC
Generate cuboid mesh
GenMeshCubicmap(ImageC cubicmap, Vector3C cubeSize) → MeshC
Generate cubes-based map mesh from image data
GenMeshCylinder(double radius, double height, int slices) → MeshC
Generate cylinder mesh
GenMeshHeightmap(ImageC heightmap, Vector3C size) → MeshC
Generate heightmap mesh from image data
GenMeshHemiSphere(double radius, int rings, int slices) → MeshC
Generate half-sphere mesh (no bottom cap)
GenMeshKnot(double radius, double size, int radSeg, int sides) → MeshC
Generate trefoil knot mesh
GenMeshPlane(double width, double length, int resX, int resZ) → MeshC
Generate plane mesh (with subdivisions)
GenMeshPoly(int sides, double radius) → MeshC
Generate polygonal mesh
GenMeshSphere(double radius, int rings, int slices) → MeshC
Generate sphere mesh (standard sphere)
GenMeshTangents(Pointer<MeshC> mesh) → void
Compute mesh tangents
GenMeshTorus(double radius, double size, int radSeg, int sides) → MeshC
Generate torus mesh
GenTextureMipmaps(Pointer<TextureC> texture) → void
Generate GPU mipmaps for a texture
GetApplicationDirectory() → Pointer<Char>
Get the directory of the running application
GetCameraMatrix(Camera3DC camera) → MatrixC
Get camera transform matrix (view matrix)
GetCameraMatrix2D(Camera2DC camera) → MatrixC
Get camera 2d transform matrix
GetCharPressed() → int
Get char pressed (unicode), call it multiple times for chars queued, returns 0 when the queue is empty
GetClipboardImage() → ImageC
Get clipboard image content
GetClipboardText() → Pointer<Char>
Get clipboard text content
GetCodepoint(Pointer<Char> text, Pointer<Int> codepointSize) → int
Get next codepoint in a UTF-8 encoded string, 0x3f('?') is returned on failure
GetCodepointCount(Pointer<Char> text) → int
Get total number of codepoints in a UTF-8 encoded string
GetCodepointNext(Pointer<Char> text, Pointer<Int> codepointSize) → int
Get next codepoint in a UTF-8 encoded string, 0x3f('?') is returned on failure
GetCodepointPrevious(Pointer<Char> text, Pointer<Int> codepointSize) → int
Get previous codepoint in a UTF-8 encoded string, 0x3f('?') is returned on failure
GetCollisionRec(RectangleC rec1, RectangleC rec2) → RectangleC
Get collision rectangle for two rectangles collision
GetColor(int hexValue) → ColorC
Get Color structure from hexadecimal value
GetCurrentMonitor() → int
Get current monitor where window is placed
GetDirectoryFileCount(Pointer<Char> dirPath) → int
Get the file count in a directory
GetDirectoryFileCountEx(Pointer<Char> basePath, Pointer<Char> filter, bool scanSubdirs) → int
Get the file count in a directory with extension filtering and recursive directory scan.
GetDirectoryPath(Pointer<Char> filePath) → Pointer<Char>
Get full path for a given fileName with path
GetFileExtension(Pointer<Char> fileName) → Pointer<Char>
Get extension for a filename (includes dot: '.png')
GetFileLength(Pointer<Char> fileName) → int
Get file length in bytes
GetFileModTime(Pointer<Char> fileName) → int
Get file modification time (last write time)
GetFileName(Pointer<Char> filePath) → Pointer<Char>
Get filename for a path string
GetFileNameWithoutExt(Pointer<Char> filePath) → Pointer<Char>
Get filename without extension
GetFontDefault() → FontC
Get the default Font
GetFPS() → int
Get current FPS
GetFrameTime() → double
Get time in seconds for last frame drawn (delta time)
GetGamepadAxisCount(int gamepad) → int
Get gamepad axis count for a gamepad
GetGamepadAxisMovement(int gamepad, int axis) → double
Get axis movement value for a gamepad axis
GetGamepadButtonPressed() → int
Get the last gamepad button pressed
GetGamepadName(int gamepad) → Pointer<Char>
Get gamepad internal name id
GetGestureDetected() → int
Get latest detected gesture
GetGestureDragAngle() → double
Get gesture drag angle
GetGestureDragVector() → Vector2C
Get gesture drag vector
GetGestureHoldDuration() → double
Get gesture hold time in seconds
GetGesturePinchAngle() → double
Get gesture pinch angle
GetGesturePinchVector() → Vector2C
Get gesture pinch delta
GetGlyphAtlasRec(FontC font, int codepoint) → RectangleC
Get glyph rectangle in font atlas for a codepoint (unicode character), fallback to '?' if not found
GetGlyphIndex(FontC font, int codepoint) → int
Get glyph index position in font for a codepoint (unicode character), fallback to '?' if not found
GetGlyphInfo(FontC font, int codepoint) → GlyphInfoC
Get glyph font info data for a codepoint (unicode character), fallback to '?' if not found
GetImageAlphaBorder(ImageC image, double threshold) → RectangleC
Get image alpha border rectangle
GetImageColor(ImageC image, int x, int y) → ColorC
Get image pixel color at (x, y) position
GetKeyName(int key) → Pointer<Char>
Get name of a QWERTY key on the current keyboard layout (eg returns string 'q' for KEY_A on an AZERTY keyboard)
GetKeyPressed() → int
Get key pressed (keycode), call it multiple times for keys queued, returns 0 when the queue is empty
GetMeshBoundingBox(MeshC mesh) → BoundingBoxC
Compute mesh bounding box limits
GetModelBoundingBox(ModelC model) → BoundingBoxC
Compute model bounding box limits (considers all meshes)
GetMonitorCount() → int
Get number of connected monitors
GetMonitorHeight(int monitor) → int
Get specified monitor height (current video mode used by monitor)
GetMonitorName(int monitor) → Pointer<Char>
Get the human-readable, UTF-8 encoded name of the specified monitor
GetMonitorPhysicalHeight(int monitor) → int
Get specified monitor physical height in millimetres
GetMonitorPhysicalWidth(int monitor) → int
Get specified monitor physical width in millimetres
GetMonitorPosition(int monitor) → Vector2C
Get specified monitor position
GetMonitorRefreshRate(int monitor) → int
Get specified monitor refresh rate
GetMonitorWidth(int monitor) → int
Get specified monitor width (current video mode used by monitor)
GetMouseDelta() → Vector2C
Get mouse delta between frames
GetMousePosition() → Vector2C
Get mouse position XY
GetMouseWheelMove() → double
Get mouse wheel movement for X or Y, whichever is larger
GetMouseWheelMoveV() → Vector2C
Get mouse wheel movement for both X and Y
GetMouseX() → int
Get mouse position X
GetMouseY() → int
Get mouse position Y
GetPixelColor(Pointer<Void> srcPtr, int format) → ColorC
Get Color from a source pixel pointer of certain format
GetPixelDataSize(int width, int height, int format) → int
Get pixel data size in bytes for certain format
GetPrevDirectoryPath(Pointer<Char> dirPath) → Pointer<Char>
Get previous directory path for a given path
GetRandomValue(int min, int max) → int
Get a random value between min and max (both included)
GetRayCollisionBox(RayC ray, BoundingBoxC box) → RayCollisionC
Get collision info between ray and box
GetRayCollisionMesh(RayC ray, MeshC mesh, MatrixC transform) → RayCollisionC
Get collision info between ray and mesh
GetRayCollisionQuad(RayC ray, Vector3C p1, Vector3C p2, Vector3C p3, Vector3C p4) → RayCollisionC
Get collision info between ray and quad
GetRayCollisionSphere(RayC ray, Vector3C center, double radius) → RayCollisionC
Get collision info between ray and sphere
GetRayCollisionTriangle(RayC ray, Vector3C p1, Vector3C p2, Vector3C p3) → RayCollisionC
Get collision info between ray and triangle
GetRenderHeight() → int
Get current render height (it considers HiDPI)
GetRenderWidth() → int
Get current render width (it considers HiDPI)
GetScreenHeight() → int
Get current screen height
GetScreenToWorld2D(Vector2C position, Camera2DC camera) → Vector2C
Get the world space position for a 2d camera screen space position
GetScreenToWorldRay(Vector2C position, Camera3DC camera) → RayC
Get a ray trace from screen position (i.e mouse)
GetScreenToWorldRayEx(Vector2C position, Camera3DC camera, int width, int height) → RayC
Get a ray trace from screen position (i.e mouse) in a viewport
GetScreenWidth() → int
Get current screen width
GetShaderLocation(ShaderC shader, Pointer<Char> uniformName) → int
Get shader uniform location
GetShaderLocationAttrib(ShaderC shader, Pointer<Char> attribName) → int
Get shader attribute location
GetShapesTexture() → TextureC
Get texture that is used for shapes drawing
GetShapesTextureRectangle() → RectangleC
Get texture source rectangle that is used for shapes drawing
GetSplinePointBasis(Vector2C p1, Vector2C p2, Vector2C p3, Vector2C p4, double t) → Vector2C
Get (evaluate) spline point: B-Spline
GetSplinePointBezierCubic(Vector2C p1, Vector2C c2, Vector2C c3, Vector2C p4, double t) → Vector2C
Get (evaluate) spline point: Cubic Bezier
GetSplinePointBezierQuad(Vector2C p1, Vector2C c2, Vector2C p3, double t) → Vector2C
Get (evaluate) spline point: Quadratic Bezier
GetSplinePointCatmullRom(Vector2C p1, Vector2C p2, Vector2C p3, Vector2C p4, double t) → Vector2C
Get (evaluate) spline point: Catmull-Rom
GetSplinePointLinear(Vector2C startPos, Vector2C endPos, double t) → Vector2C
Get (evaluate) spline point: Linear
GetTextBetween(Pointer<Char> text, Pointer<Char> begin, Pointer<Char> end) → Pointer<Char>
Get text between two strings
GetTime() → double
Get elapsed time in seconds since InitWindow()
GetTouchPointCount() → int
Get number of touch points
GetTouchPointId(int index) → int
Get touch point identifier for given index
GetTouchPosition(int index) → Vector2C
Get touch position XY for a touch point index (relative to screen size)
GetTouchX() → int
Get touch position X for touch point 0 (relative to screen size)
GetTouchY() → int
Get touch position Y for touch point 0 (relative to screen size)
GetWindowHandle() → Pointer<Void>
Get native window handle
GetWindowPosition() → Vector2C
Get window position XY on monitor
GetWindowScaleDPI() → Vector2C
Get window scale DPI factor
GetWorkingDirectory() → Pointer<Char>
Get current working directory
GetWorldToScreen(Vector3C position, Camera3DC camera) → Vector2C
Get the screen space position for a 3d world space position
GetWorldToScreen2D(Vector2C position, Camera2DC camera) → Vector2C
Get the screen space position for a 2d camera world space position
GetWorldToScreenEx(Vector3C position, Camera3DC camera, int width, int height) → Vector2C
Get size position for a 3d world space position
HideCursor() → void
Hides cursor
ImageAlphaClear(Pointer<ImageC> image, ColorC color, double threshold) → void
Clear alpha channel to desired color
ImageAlphaCrop(Pointer<ImageC> image, double threshold) → void
Crop image depending on alpha value
ImageAlphaMask(Pointer<ImageC> image, ImageC alphaMask) → void
Apply alpha mask to image
ImageAlphaPremultiply(Pointer<ImageC> image) → void
Premultiply alpha channel
ImageBlurGaussian(Pointer<ImageC> image, int blurSize) → void
Apply Gaussian blur using a box blur approximation
ImageClearBackground(Pointer<ImageC> dst, ColorC color) → void
Clear image background with given color
ImageColorBrightness(Pointer<ImageC> image, int brightness) → void
Modify image color: brightness (-255 to 255)
ImageColorContrast(Pointer<ImageC> image, double contrast) → void
Modify image color: contrast (-100 to 100)
ImageColorGrayscale(Pointer<ImageC> image) → void
Modify image color: grayscale
ImageColorInvert(Pointer<ImageC> image) → void
Modify image color: invert
ImageColorReplace(Pointer<ImageC> image, ColorC color, ColorC replace) → void
Modify image color: replace color
ImageColorTint(Pointer<ImageC> image, ColorC color) → void
Modify image color: tint
ImageCopy(ImageC image) → ImageC
Create an image duplicate (useful for transformations)
ImageCrop(Pointer<ImageC> image, RectangleC crop) → void
Crop an image to a defined rectangle
ImageDither(Pointer<ImageC> image, int rBpp, int gBpp, int bBpp, int aBpp) → void
Dither image data to 16bpp or lower (Floyd-Steinberg dithering)
ImageDraw(Pointer<ImageC> dst, ImageC src, RectangleC srcRec, RectangleC dstRec, ColorC tint) → void
Draw a source image within a destination image (tint applied to source)
ImageDrawCircle(Pointer<ImageC> dst, int centerX, int centerY, int radius, ColorC color) → void
Draw a filled circle within an image
ImageDrawCircleLines(Pointer<ImageC> dst, int centerX, int centerY, int radius, ColorC color) → void
Draw circle outline within an image
ImageDrawCircleLinesV(Pointer<ImageC> dst, Vector2C center, int radius, ColorC color) → void
Draw circle outline within an image (Vector version)
ImageDrawCircleV(Pointer<ImageC> dst, Vector2C center, int radius, ColorC color) → void
Draw a filled circle within an image (Vector version)
ImageDrawLine(Pointer<ImageC> dst, int startPosX, int startPosY, int endPosX, int endPosY, ColorC color) → void
Draw line within an image
ImageDrawLineEx(Pointer<ImageC> dst, Vector2C start, Vector2C end, int thick, ColorC color) → void
Draw a line defining thickness within an image
ImageDrawLineV(Pointer<ImageC> dst, Vector2C start, Vector2C end, ColorC color) → void
Draw line within an image (Vector version)
ImageDrawPixel(Pointer<ImageC> dst, int posX, int posY, ColorC color) → void
Draw pixel within an image
ImageDrawPixelV(Pointer<ImageC> dst, Vector2C position, ColorC color) → void
Draw pixel within an image (Vector version)
ImageDrawRectangle(Pointer<ImageC> dst, int posX, int posY, int width, int height, ColorC color) → void
Draw rectangle within an image
ImageDrawRectangleLines(Pointer<ImageC> dst, RectangleC rec, int thick, ColorC color) → void
Draw rectangle lines within an image
ImageDrawRectangleRec(Pointer<ImageC> dst, RectangleC rec, ColorC color) → void
Draw rectangle within an image
ImageDrawRectangleV(Pointer<ImageC> dst, Vector2C position, Vector2C size, ColorC color) → void
Draw rectangle within an image (Vector version)
ImageDrawText(Pointer<ImageC> dst, Pointer<Char> text, int posX, int posY, int fontSize, ColorC color) → void
Draw text (using default font) within an image (destination)
ImageDrawTextEx(Pointer<ImageC> dst, FontC font, Pointer<Char> text, Vector2C position, double fontSize, double spacing, ColorC tint) → void
Draw text (custom sprite font) within an image (destination)
ImageDrawTriangle(Pointer<ImageC> dst, Vector2C v1, Vector2C v2, Vector2C v3, ColorC color) → void
Draw triangle within an image
ImageDrawTriangleEx(Pointer<ImageC> dst, Vector2C v1, Vector2C v2, Vector2C v3, ColorC c1, ColorC c2, ColorC c3) → void
Draw triangle with interpolated colors within an image
ImageDrawTriangleFan(Pointer<ImageC> dst, Pointer<Vector2C> points, int pointCount, ColorC color) → void
Draw a triangle fan defined by points within an image (first vertex is the center)
ImageDrawTriangleLines(Pointer<ImageC> dst, Vector2C v1, Vector2C v2, Vector2C v3, ColorC color) → void
Draw triangle outline within an image
ImageDrawTriangleStrip(Pointer<ImageC> dst, Pointer<Vector2C> points, int pointCount, ColorC color) → void
Draw a triangle strip defined by points within an image
ImageFlipHorizontal(Pointer<ImageC> image) → void
Flip image horizontally
ImageFlipVertical(Pointer<ImageC> image) → void
Flip image vertically
ImageFormat(Pointer<ImageC> image, int newFormat) → void
Convert image data to desired format
ImageFromChannel(ImageC image, int selectedChannel) → ImageC
Create an image from a selected channel of another image (GRAYSCALE)
ImageFromImage(ImageC image, RectangleC rec) → ImageC
Create an image from another image piece
ImageKernelConvolution(Pointer<ImageC> image, Pointer<Float> kernel, int kernelSize) → void
Apply custom square convolution kernel to image
ImageMipmaps(Pointer<ImageC> image) → void
Compute all mipmap levels for a provided image
ImageResize(Pointer<ImageC> image, int newWidth, int newHeight) → void
Resize image (Bicubic scaling algorithm)
ImageResizeCanvas(Pointer<ImageC> image, int newWidth, int newHeight, int offsetX, int offsetY, ColorC fill) → void
Resize canvas and fill with color
ImageResizeNN(Pointer<ImageC> image, int newWidth, int newHeight) → void
Resize image (Nearest-Neighbor scaling algorithm)
ImageRotate(Pointer<ImageC> image, int degrees) → void
Rotate image by input angle in degrees (-359 to 359)
ImageRotateCCW(Pointer<ImageC> image) → void
Rotate image counter-clockwise 90deg
ImageRotateCW(Pointer<ImageC> image) → void
Rotate image clockwise 90deg
ImageText(Pointer<Char> text, int fontSize, ColorC color) → ImageC
Create an image from text (default font)
ImageTextEx(FontC font, Pointer<Char> text, double fontSize, double spacing, ColorC tint) → ImageC
Create an image from text (custom sprite font)
ImageToPOT(Pointer<ImageC> image, ColorC fill) → void
Convert image to POT (power-of-two)
InitWindow(int width, int height, Pointer<Char> title) → void
Initialize window and OpenGL context
IsCursorHidden() → bool
Check if cursor is not visible
IsCursorOnScreen() → bool
Check if cursor is on the screen
IsFileDropped() → bool
Check if a file has been dropped into window
IsFileExtension(Pointer<Char> fileName, Pointer<Char> ext) → bool
Check file extension (including point: .png, .wav)
IsFileNameValid(Pointer<Char> fileName) → bool
Check if fileName is valid for the platform/OS
IsFontValid(FontC font) → bool
Check if a font is valid (font data loaded, WARNING: GPU texture not checked)
IsGamepadAvailable(int gamepad) → bool
Check if a gamepad is available
IsGamepadButtonDown(int gamepad, int button) → bool
Check if a gamepad button is being pressed
IsGamepadButtonPressed(int gamepad, int button) → bool
Check if a gamepad button has been pressed once
IsGamepadButtonReleased(int gamepad, int button) → bool
Check if a gamepad button has been released once
IsGamepadButtonUp(int gamepad, int button) → bool
Check if a gamepad button is NOT being pressed
IsGestureDetected(int gesture) → bool
Check if a gesture have been detected
IsImageValid(ImageC image) → bool
Check if an image is valid (data and parameters)
IsKeyDown(int key) → bool
Check if a key is being pressed
IsKeyPressed(int key) → bool
Check if a key has been pressed once
IsKeyPressedRepeat(int key) → bool
Check if a key has been pressed again
IsKeyReleased(int key) → bool
Check if a key has been released once
IsKeyUp(int key) → bool
Check if a key is NOT being pressed
IsMaterialValid(MaterialC material) → bool
Check if a material is valid (shader assigned, map textures loaded in GPU)
IsModelAnimationValid(ModelC model, ModelAnimationC anim) → bool
Check model animation skeleton match
IsModelValid(ModelC model) → bool
Check if a model is valid (loaded in GPU, VAO/VBOs)
IsMouseButtonDown(int button) → bool
Check if a mouse button is being pressed
IsMouseButtonPressed(int button) → bool
Check if a mouse button has been pressed once
IsMouseButtonReleased(int button) → bool
Check if a mouse button has been released once
IsMouseButtonUp(int button) → bool
Check if a mouse button is NOT being pressed
IsPathFile(Pointer<Char> path) → bool
Check if a given path is a file or a directory
IsRenderTextureValid(RenderTextureC target) → bool
Check if a render texture is valid (loaded in GPU)
IsShaderValid(ShaderC shader) → bool
Check if a shader is valid (loaded on GPU)
IsTextureValid(TextureC texture) → bool
Check if a texture is valid (loaded in GPU)
IsWindowFocused() → bool
Check if window is currently focused
IsWindowFullscreen() → bool
Check if window is currently fullscreen
IsWindowHidden() → bool
Check if window is currently hidden
IsWindowMaximized() → bool
Check if window is currently maximized
IsWindowMinimized() → bool
Check if window is currently minimized
IsWindowReady() → bool
Check if window has been initialized successfully
IsWindowResized() → bool
Check if window has been resized last frame
IsWindowState(int flag) → bool
Check if one specific window flag is enabled
load() → void
Override to perform one-time module initialization.
inherited
LoadAutomationEventList(Pointer<Char> fileName) → AutomationEventListC
Load automation events list from file, NULL for empty list
LoadCodepoints(Pointer<Char> text, Pointer<Int> count) → Pointer<Int>
Load all codepoints from a UTF-8 text string, codepoints count returned by parameter
LoadDirectoryFiles(Pointer<Char> dirPath) → FilePathListC
Load directory filepaths
LoadDirectoryFilesEx(Pointer<Char> basePath, Pointer<Char> filter, bool scanSubdirs) → FilePathListC
Load directory filepaths with extension filtering and recursive directory scan.
LoadDroppedFiles() → FilePathListC
Load dropped filepaths
LoadFileData(Pointer<Char> fileName, Pointer<Int> dataSize) → Pointer<UnsignedChar>
Load file data as byte array (read)
LoadFileText(Pointer<Char> fileName) → Pointer<Char>
Load text data from file (read)
LoadFont(Pointer<Char> fileName) → FontC
Load font from file into GPU memory (VRAM)
LoadFontData(Pointer<UnsignedChar> fileData, int dataSize, int fontSize, Pointer<Int> codepoints, int codepointCount, int type, Pointer<Int> glyphCount) → Pointer<GlyphInfoC>
Load font data for further use
LoadFontEx(Pointer<Char> fileName, int fontSize, Pointer<Int> codepoints, int codepointCount) → FontC
Load font from file with extended parameters, use NULL for codepoints and 0 for codepointCount to load the default character set, font size is provided in pixels height
LoadFontFromImage(ImageC image, ColorC key, int firstChar) → FontC
Load font from Image (XNA style)
LoadFontFromMemory(Pointer<Char> fileType, Pointer<UnsignedChar> fileData, int dataSize, int fontSize, Pointer<Int> codepoints, int codepointCount) → FontC
Load font from memory buffer, fileType refers to extension: i.e. '.ttf'
LoadImage(Pointer<Char> fileName) → ImageC
Load image from file into CPU memory (RAM)
LoadImageAnim(Pointer<Char> fileName, Pointer<Int> frames) → ImageC
Load image sequence from file (frames appended to image.data)
LoadImageAnimFromMemory(Pointer<Char> fileType, Pointer<UnsignedChar> fileData, int dataSize, Pointer<Int> frames) → ImageC
Load image sequence from memory buffer
LoadImageColors(ImageC image) → Pointer<ColorC>
Load color data from image as a Color array (RGBA - 32bit)
LoadImageFromMemory(Pointer<Char> fileType, Pointer<UnsignedChar> fileData, int dataSize) → ImageC
Load image from memory buffer, fileType refers to extension: i.e. '.png'
LoadImageFromScreen() → ImageC
Load image from screen buffer and (screenshot)
LoadImageFromTexture(TextureC texture) → ImageC
Load image from GPU texture data
LoadImagePalette(ImageC image, int maxPaletteSize, Pointer<Int> colorCount) → Pointer<ColorC>
Load colors palette from image as a Color array (RGBA - 32bit)
LoadImageRaw(Pointer<Char> fileName, int width, int height, int format, int headerSize) → ImageC
Load image from RAW file data
LoadMaterialDefault() → MaterialC
Load default material (Supports: DIFFUSE, SPECULAR, NORMAL maps)
LoadMaterials(Pointer<Char> fileName, Pointer<Int> materialCount) → Pointer<MaterialC>
Load materials from model file
LoadModel(Pointer<Char> fileName) → ModelC
Load model from files (meshes and materials)
LoadModelAnimations(Pointer<Char> fileName, Pointer<Int> animCount) → Pointer<ModelAnimationC>
Load model animations from file
LoadModelFromMesh(MeshC mesh) → ModelC
Load model from generated mesh (default material)
LoadRandomSequence(int count, int min, int max) → Pointer<Int>
Load random values sequence, no values repeated, min and max included
LoadRenderTexture(int width, int height) → RenderTextureC
Load texture for rendering (framebuffer)
LoadShader(Pointer<Char> vsFileName, Pointer<Char> fsFileName) → ShaderC
Load shader from files and bind default locations
LoadShaderFromMemory(Pointer<Char> vsCode, Pointer<Char> fsCode) → ShaderC
Load shader from code strings and bind default locations
LoadTextLines(Pointer<Char> text, Pointer<Int> count) → Pointer<Pointer<Char>>
Load text as separate lines ('\n')
LoadTexture(Pointer<Char> fileName) → TextureC
Load texture from file into GPU memory (VRAM)
LoadTextureCubemap(ImageC image, int layout) → TextureC
Load cubemap from image, multiple image cubemap layouts supported
LoadTextureFromImage(ImageC image) → TextureC
Load texture from image data
LoadUTF8(Pointer<Int> codepoints, int length) → Pointer<Char>
Load UTF-8 text encoded from codepoints array
LoadVrStereoConfig(VrDeviceInfoC device) → VrStereoConfigC
Load VR stereo config for VR simulator device parameters
logError(Object? message) → void
inherited
logInfo(Object? message) → void
inherited
logWarn(Object? message) → void
inherited
MakeDirectory(Pointer<Char> dirPath) → int
Create directories (including full path requested), returns 0 on success
MaximizeWindow() → void
Set window state: maximized, if ConfigFlags.FLAG_WINDOW_RESIZABLE
MeasureText(Pointer<Char> text, int fontSize) → int
Measure string width for default font
MeasureTextCodepoints(FontC font, Pointer<Int> codepoints, int length, double fontSize, double spacing) → Vector2C
Measure string size for an existing array of codepoints for Font
MeasureTextEx(FontC font, Pointer<Char> text, double fontSize, double spacing) → Vector2C
Measure string size for Font
MinimizeWindow() → void
Set window state: minimized, if ConfigFlags.FLAG_WINDOW_RESIZABLE
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose(void fn()) → void
Registers fn to be called when this module is disposed.
inherited
OpenURL(Pointer<Char> url) → void
Open URL with default system browser (if available)
PlayAutomationEvent(AutomationEventC event) → void
Play a recorded automation event
PollInputEvents() → void
Register all input events
ProcessGestureEvent(GestureEventC event) → void
Process gesture event and translate it into gestures
RestoreWindow() → void
Set window state: not minimized/maximized
run<T>(String name(), T f()) → T
Executes f, logging its label (and optionally timing it) when debug is enabled and the label passes all filters.
inherited
SaveFileData(Pointer<Char> fileName, Pointer<Void> data, int dataSize) → bool
Save data to file from byte array (write), returns true on success
SaveFileText(Pointer<Char> fileName, Pointer<Char> text) → bool
Save text data to file (write), returns true on success
SetAutomationEventBaseFrame(int frame) → void
Set automation event internal base frame to start recording
SetAutomationEventList(Pointer<AutomationEventListC> list) → void
Set automation event list to record to
SetClipboardText(Pointer<Char> text) → void
Set clipboard text content
SetConfigFlags(int flags) → void
Setup init configuration flags (view ConfigFlags)
SetExitKey(int key) → void
Set a custom key to exit program (default is ESC)
SetGamepadMappings(Pointer<Char> mappings) → int
Set internal gamepad mappings (SDL_GameControllerDB)
SetGamepadVibration(int gamepad, double leftMotor, double rightMotor, double duration) → void
Set gamepad vibration for both motors (duration in seconds)
SetGesturesEnabled(int flags) → void
Enable a set of gestures using flags Gesture
SetLoadFileDataCallback(LoadFileDataCallbackC callback) → void
Set custom file binary data loader
SetLoadFileTextCallback(LoadFileTextCallbackC callback) → void
Set custom file text data loader
SetMaterialTexture(Pointer<MaterialC> material, int mapType, TextureC texture) → void
Set texture for a material map type (MATERIAL_MAP_DIFFUSE, MATERIAL_MAP_SPECULAR...)
SetModelMeshMaterial(Pointer<ModelC> model, int meshId, int materialId) → void
Set material for a mesh
SetMouseCursor(int cursor) → void
Set mouse cursor
SetMouseOffset(int offsetX, int offsetY) → void
Set mouse offset
SetMousePosition(int x, int y) → void
Set mouse position XY
SetMouseScale(double scaleX, double scaleY) → void
Set mouse scaling
SetPixelColor(Pointer<Void> dstPtr, ColorC color, int format) → void
Set color formatted into destination pixel pointer
SetRandomSeed(int seed) → void
Set the seed for the random number generator
SetSaveFileDataCallback(SaveFileDataCallbackC callback) → void
Set custom file binary data saver
SetSaveFileTextCallback(SaveFileTextCallbackC callback) → void
Set custom file text data saver
SetShaderValue(ShaderC shader, int locIndex, Pointer<Void> value, int uniformType) → void
Set shader uniform value
SetShaderValueMatrix(ShaderC shader, int locIndex, MatrixC mat) → void
Set shader uniform value (matrix 4x4)
SetShaderValueTexture(ShaderC shader, int locIndex, TextureC texture) → void
Set shader uniform value for texture (sampler2d)
SetShaderValueV(ShaderC shader, int locIndex, Pointer<Void> value, int uniformType, int count) → void
Set shader uniform value vector
SetShapesTexture(TextureC texture, RectangleC source) → void
Set texture and rectangle to be used on shapes drawing
SetTargetFPS(int fps) → void
Set target FPS (maximum)
SetTextLineSpacing(int spacing) → void
Set vertical line spacing when drawing with line-breaks
SetTextureFilter(TextureC texture, int filter) → void
Set texture scaling filter mode
SetTextureWrap(TextureC texture, int wrap) → void
Set texture wrapping mode
SetTraceLogCallback(TraceLogCallbackC callback) → void
Set custom trace log
SetTraceLogLevel(int logLevel) → void
Set the current threshold (minimum) log level
SetWindowFocused() → void
Set window focused
SetWindowIcon(ImageC image) → void
Set icon for window (single image, RGBA 32bit)
SetWindowIcons(Pointer<ImageC> images, int count) → void
Set icon for window (multiple images, RGBA 32bit)
SetWindowMaxSize(int width, int height) → void
Set window maximum dimensions (for ConfigFlags.FLAG_WINDOW_RESIZABLE)
SetWindowMinSize(int width, int height) → void
Set window minimum dimensions (for ConfigFlags.FLAG_WINDOW_RESIZABLE)
SetWindowMonitor(int monitor) → void
Set monitor for the current window
SetWindowOpacity(double opacity) → void
Set window opacity 0.0..1.0
SetWindowPosition(int x, int y) → void
Set window position on screen
SetWindowSize(int width, int height) → void
Set window dimensions
SetWindowState(int flags) → void
Set window configuration state using flags
SetWindowTitle(Pointer<Char> title) → void
Set title for window
ShowCursor() → void
Shows cursor
StartAutomationEventRecording() → void
Start recording automation events (AutomationEventList must be set)
StopAutomationEventRecording() → void
Stop recording automation events
SwapScreenBuffer() → void
Swap back buffer with front buffer (screen drawing)
TakeScreenshot(Pointer<Char> fileName) → void
Takes a screenshot of current screen (filename extension defines format)
TextAppend(Pointer<Char> text, Pointer<Char> append, Pointer<Int> position) → void
Append text at specific position and move cursor
TextCopy(Pointer<Char> dst, Pointer<Char> src) → int
Copy one string to another, returns bytes copied
TextFindIndex(Pointer<Char> text, Pointer<Char> find) → int
Find first text occurrence within a string, -1 if not found
TextFormat(Pointer<Char> text) → Pointer<Char>
Text formatting with variables (sprintf() style)
TextInsert(Pointer<Char> text, Pointer<Char> insert, int position) → Pointer<Char>
Insert text in a defined byte position
TextInsertAlloc(Pointer<Char> text, Pointer<Char> insert, int position) → Pointer<Char>
Insert text in a defined byte position, memory must be freed
TextIsEqual(Pointer<Char> text1, Pointer<Char> text2) → bool
Check if two text string are equal
TextJoin(Pointer<Pointer<Char>> textList, int count, Pointer<Char> delimiter) → Pointer<Char>
Join text strings with delimiter (delimiter is expected to be length of 1)
TextLength(Pointer<Char> text) → int
Get text length
TextRemoveSpaces(Pointer<Char> text) → Pointer<Char>
Remove text spaces, concat words
TextReplace(Pointer<Char> text, Pointer<Char> replace, Pointer<Char> by) → Pointer<Char>
Replace text string with new string
TextReplaceAlloc(Pointer<Char> text, Pointer<Char> replace, Pointer<Char> by) → Pointer<Char>
Replace text string with new string, memory must be freed
TextReplaceBetween(Pointer<Char> text, Pointer<Char> begin, Pointer<Char> end, Pointer<Char> replacement) → Pointer<Char>
Replace text between two specific strings
TextReplaceBetweenAlloc(Pointer<Char> text, Pointer<Char> begin, Pointer<Char> end, Pointer<Char> replacement) → Pointer<Char>
Replace text between two specific strings, memory must be freed
TextSplit(Pointer<Char> text, int delimiter, Pointer<Int> count) → Pointer<Pointer<Char>>
Split text into multiple strings
TextSubtext(Pointer<Char> text, int position, int length) → Pointer<Char>
Get a piece of a text string
TextToCamel(Pointer<Char> text) → Pointer<Char>
Get Camel case notation version of provided string
TextToFloat(Pointer<Char> text) → double
Get float value from text
TextToInteger(Pointer<Char> text) → int
Get integer value from text
TextToLower(Pointer<Char> text) → Pointer<Char>
Get lower case version of provided string
TextToPascal(Pointer<Char> text) → Pointer<Char>
Get Pascal case notation version of provided string
TextToSnake(Pointer<Char> text) → Pointer<Char>
Get Snake case notation version of provided string
TextToUpper(Pointer<Char> text) → Pointer<Char>
Get upper case version of provided string
ToggleBorderlessWindowed() → void
Toggle window state: borderless windowed, resizes window to match monitor resolution
ToggleFullscreen() → void
Toggle window state: fullscreen/windowed, resizes monitor to match window resolution
toString() → String
A string representation of this object.
inherited
TraceLog(int logLevel, Pointer<Char> text) → void
Show trace log messages (LOG_DEBUG, LOG_INFO, LOG_WARNING, LOG_ERROR...)
UnloadAutomationEventList(AutomationEventListC list) → void
Unload automation events list from file
UnloadCodepoints(Pointer<Int> codepoints) → void
Unload codepoints data from memory
UnloadDirectoryFiles(FilePathListC files) → void
Unload filepaths
UnloadDroppedFiles(FilePathListC files) → void
Unload dropped filepaths
UnloadFileData(Pointer<UnsignedChar> data) → void
Unload file data allocated by LoadFileData()
UnloadFileText(Pointer<Char> text) → void
Unload file text data allocated by LoadFileText()
UnloadFont(FontC font) → void
Unload font from GPU memory (VRAM)
UnloadFontData(Pointer<GlyphInfoC> glyphs, int glyphCount) → void
Unload font chars info data (RAM)
UnloadImage(ImageC image) → void
Unload image from CPU memory (RAM)
UnloadImageColors(Pointer<ColorC> colors) → void
Unload color data loaded with LoadImageColors()
UnloadImagePalette(Pointer<ColorC> colors) → void
Unload colors palette loaded with LoadImagePalette()
UnloadMaterial(MaterialC material) → void
Unload material from GPU memory (VRAM)
UnloadMesh(MeshC mesh) → void
Unload mesh data from CPU and GPU
UnloadModel(ModelC model) → void
Unload model (including meshes) from memory (RAM and/or VRAM)
UnloadModelAnimations(Pointer<ModelAnimationC> animations, int animCount) → void
Unload animation array data
UnloadRandomSequence(Pointer<Int> sequence) → void
Unload random values sequence
UnloadRenderTexture(RenderTextureC target) → void
Unload render texture from GPU memory (VRAM)
UnloadShader(ShaderC shader) → void
Unload shader from GPU memory (VRAM)
UnloadTextLines(Pointer<Pointer<Char>> text, int lineCount) → void
Unload text lines
UnloadTexture(TextureC texture) → void
Unload texture from GPU memory (VRAM)
UnloadUTF8(Pointer<Char> text) → void
Unload UTF-8 text encoded from codepoints array
UnloadVrStereoConfig(VrStereoConfigC config) → void
Unload VR stereo config
UpdateCamera(Pointer<Camera3DC> camera, int mode) → void
Update camera position for selected mode
UpdateCameraPro(Pointer<Camera3DC> camera, Vector3C movement, Vector3C rotation, double zoom) → void
Update camera movement/rotation
UpdateGestures() → void
Update gestures detected (must be called every frame)
UpdateMeshBuffer(MeshC mesh, int index, Pointer<Void> data, int dataSize, int offset) → void
Update mesh vertex data in GPU for a specific buffer index
UpdateModelAnimation(ModelC model, ModelAnimationC anim, double frame) → void
Update model animation pose (CPU)
UpdateModelAnimationEx(ModelC model, ModelAnimationC animA, double frameA, ModelAnimationC animB, double frameB, double blend) → void
Update model animation data (vertex buffers / bone matrices) for a specific pose, defined by two different animations at specific frames blended together
UpdateTexture(TextureC texture, Pointer<Void> pixels) → void
Update GPU texture with new data
UpdateTextureRec(TextureC texture, RectangleC rec, Pointer<Void> pixels) → void
Update GPU texture rectangle with new data
UploadMesh(Pointer<MeshC> mesh, bool dynamic) → void
Upload mesh vertex data in GPU and provide VAO/VBO ids
WaitTime(double seconds) → void
Wait for some time (halt program execution)
WindowShouldClose() → bool
Check if application should close (KeyboardKey.KEY_ESCAPE pressed or windows close icon clicked)

Operators

operator ==(Object other) → bool
The equality operator.
inherited