DrawPolyLinesEx method
void
DrawPolyLinesEx()
Draw a polygon outline of n sides with extended parameters
Implementation
void DrawPolyLinesEx(Vector2C center, int sides, double radius, double rotation, double lineThick, ColorC color)
=> _DrawPolyLinesEx(center, sides, radius, rotation, lineThick, color);