GetGlyphAtlasRec method
Get glyph rectangle in font atlas for a codepoint (unicode character), fallback to '?' if not found
Implementation
RectangleC GetGlyphAtlasRec(FontC font, int codepoint)
=> _GetGlyphAtlasRec(font, codepoint);
Get glyph rectangle in font atlas for a codepoint (unicode character), fallback to '?' if not found
RectangleC GetGlyphAtlasRec(FontC font, int codepoint)
=> _GetGlyphAtlasRec(font, codepoint);