GetGlyphInfo method
Get glyph font info data for a codepoint (unicode character), fallback to '?' if not found
Implementation
GlyphInfoC GetGlyphInfo(FontC font, int codepoint)
=> _GetGlyphInfo(font, codepoint);
Get glyph font info data for a codepoint (unicode character), fallback to '?' if not found
GlyphInfoC GetGlyphInfo(FontC font, int codepoint)
=> _GetGlyphInfo(font, codepoint);