GetShapesTextureRectangle method
Get texture source rectangle that is used for shapes drawing
Implementation
RectangleC GetShapesTextureRectangle()
=> _GetShapesTextureRectangle();
Get texture source rectangle that is used for shapes drawing
RectangleC GetShapesTextureRectangle()
=> _GetShapesTextureRectangle();