LoadFontEx method

FontC LoadFontEx(
  1. Pointer<Char> fileName,
  2. int fontSize,
  3. Pointer<Int> codepoints,
  4. int codepointCount,
)

Load font from file with extended parameters, use NULL for codepoints and 0 for codepointCount to load the default character set, font size is provided in pixels height

Implementation

FontC LoadFontEx(Pointer<Char> fileName, int fontSize, Pointer<Int> codepoints, int codepointCount)
  => _LoadFontEx(fileName, fontSize, codepoints, codepointCount);