LoadImageRaw method
Load image from RAW file data
Implementation
ImageC LoadImageRaw(Pointer<Char> fileName, int width, int height, int format, int headerSize)
=> _LoadImageRaw(fileName, width, height, format, headerSize);
Load image from RAW file data
ImageC LoadImageRaw(Pointer<Char> fileName, int width, int height, int format, int headerSize)
=> _LoadImageRaw(fileName, width, height, format, headerSize);