SetAutomationEventBaseFrame method
Set automation event internal base frame to start recording
Implementation
void SetAutomationEventBaseFrame(int frame)
=> _SetAutomationEventBaseFrame(frame);
Set automation event internal base frame to start recording
void SetAutomationEventBaseFrame(int frame)
=> _SetAutomationEventBaseFrame(frame);