SetShapesTexture method
Set texture and rectangle to be used on shapes drawing
Implementation
void SetShapesTexture(TextureC texture, RectangleC source)
=> _SetShapesTexture(texture, source);
Set texture and rectangle to be used on shapes drawing
void SetShapesTexture(TextureC texture, RectangleC source)
=> _SetShapesTexture(texture, source);