TextInsertAlloc method
Insert text in a defined byte position, memory must be freed
Implementation
Pointer<Char> TextInsertAlloc(Pointer<Char> text, Pointer<Char> insert, int position)
=> _TextInsertAlloc(text, insert, position);
Insert text in a defined byte position, memory must be freed
Pointer<Char> TextInsertAlloc(Pointer<Char> text, Pointer<Char> insert, int position)
=> _TextInsertAlloc(text, insert, position);