TextReplaceAlloc method
Replace text string with new string, memory must be freed
Implementation
Pointer<Char> TextReplaceAlloc(Pointer<Char> text, Pointer<Char> replace, Pointer<Char> by)
=> _TextReplaceAlloc(text, replace, by);
Replace text string with new string, memory must be freed
Pointer<Char> TextReplaceAlloc(Pointer<Char> text, Pointer<Char> replace, Pointer<Char> by)
=> _TextReplaceAlloc(text, replace, by);