DrawPixel method
Draw a pixel using geometry Can be slow, use with care
Implementation
@override
void DrawPixel(
int posX,
int posY,
ColorD color,
) => _ffi.DrawPixel(
posX,
posY,
$.Color$.Ref1(color).asNativePointer<ColorC>().ref,
);
Draw a pixel using geometry Can be slow, use with care
@override
void DrawPixel(
int posX,
int posY,
ColorD color,
) => _ffi.DrawPixel(
posX,
posY,
$.Color$.Ref1(color).asNativePointer<ColorC>().ref,
);