IsPathFile method
Check if a given path is a file or a directory
Implementation
@override
bool IsPathFile(
MemoryPointer<RChar> path,
) => _ffi.IsPathFile(
path.asNativePointer(),
);
Check if a given path is a file or a directory
@override
bool IsPathFile(
MemoryPointer<RChar> path,
) => _ffi.IsPathFile(
path.asNativePointer(),
);