LoadFontEx method

  1. @override
FontD LoadFontEx(
  1. MemoryPointer<RChar> fileName,
  2. int fontSize,
  3. MemoryPointer<RInt> codepoints,
  4. int codepointCount,
)
override

Load font from file with extended parameters, use NULL for codepoints and 0 for codepointCount to load the default character set, font size is provided in pixels height

Implementation

@override
FontD LoadFontEx(
  MemoryPointer<RChar> fileName,
  int fontSize,
  MemoryPointer<RInt> codepoints,
  int codepointCount,
) => $.Font$.RefCapture(
  RaylibCaptureIds.LoadFontEx,
  (p) => _ffi.LoadFontEx(
    fileName.asNativePointer(),
    fontSize,
    codepoints.asNativePointer(),
    codepointCount,
  ).toDart(p.asNativePointer()),
);