RaylibGame class abstract

Inheritance

Constructors

RaylibGame()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close(Raylib rl) → void
inherited
dispose(Raylib rl) → void
inherited
init(Raylib rl) → void
inherited
loop(Raylib rl) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldClose(Raylib rl) bool
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited