RaylibGui class

Inheritance
Mixed-in types

Constructors

RaylibGui(Raylib rl)

Properties

$ → RaylibTemp<RaylibBase>
See RaylibTemp.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
RAYGUI_COLORBARALPHA_CHECKED_SIZE → int
See RaylibGuiConstants.RAYGUI_COLORBARALPHA_CHECKED_SIZE.
no setterinherited
RAYGUI_GRID_ALPHA → double
See RaylibGuiConstants.RAYGUI_GRID_ALPHA.
no setterinherited
RAYGUI_GROUPBOX_LINE_THICK → int
See RaylibGuiConstants.RAYGUI_GROUPBOX_LINE_THICK.
no setterinherited
RAYGUI_ICON_DATA_ELEMENTS → int
See RaylibGuiConstants.RAYGUI_ICON_DATA_ELEMENTS.
no setterinherited
RAYGUI_ICON_FONT_ATLAS_PADDING → int
See RaylibGuiConstants.RAYGUI_ICON_FONT_ATLAS_PADDING.
no setterinherited
RAYGUI_ICON_MAX_FONT_BACKED → int
See RaylibGuiConstants.RAYGUI_ICON_MAX_FONT_BACKED.
no setterinherited
RAYGUI_ICON_MAX_ICONS → int
See RaylibGuiConstants.RAYGUI_ICON_MAX_ICONS.
no setterinherited
RAYGUI_ICON_MAX_NAME_LENGTH → int
See RaylibGuiConstants.RAYGUI_ICON_MAX_NAME_LENGTH.
no setterinherited
RAYGUI_ICON_SIZE → int
See RaylibGuiConstants.RAYGUI_ICON_SIZE.
no setterinherited
RAYGUI_ICON_TEXT_PADDING → int
See RaylibGuiConstants.RAYGUI_ICON_TEXT_PADDING.
no setterinherited
RAYGUI_ICONS → List<int>
See RaylibGuiConstants.RAYGUI_ICONS.
no setterinherited
RAYGUI_LINE_MARGIN_TEXT → int
See RaylibGuiConstants.RAYGUI_LINE_MARGIN_TEXT.
no setterinherited
RAYGUI_LINE_TEXT_PADDING → int
See RaylibGuiConstants.RAYGUI_LINE_TEXT_PADDING.
no setterinherited
RAYGUI_MAX_CONTROLS → int
See RaylibGuiConstants.RAYGUI_MAX_CONTROLS.
no setterinherited
RAYGUI_MAX_PROPS_BASE → int
See RaylibGuiConstants.RAYGUI_MAX_PROPS_BASE.
no setterinherited
RAYGUI_MAX_PROPS_EXTENDED → int
See RaylibGuiConstants.RAYGUI_MAX_PROPS_EXTENDED.
no setterinherited
RAYGUI_MAX_TEXT_LINES → int
See RaylibGuiConstants.RAYGUI_MAX_TEXT_LINES.
no setterinherited
RAYGUI_MESSAGEBOX_BUTTON_HEIGHT → int
See RaylibGuiConstants.RAYGUI_MESSAGEBOX_BUTTON_HEIGHT.
no setterinherited
RAYGUI_MESSAGEBOX_BUTTON_PADDING → int
See RaylibGuiConstants.RAYGUI_MESSAGEBOX_BUTTON_PADDING.
no setterinherited
RAYGUI_MIN_MOUSE_WHEEL_SPEED → int
See RaylibGuiConstants.RAYGUI_MIN_MOUSE_WHEEL_SPEED.
no setterinherited
RAYGUI_MIN_SCROLLBAR_HEIGHT → int
See RaylibGuiConstants.RAYGUI_MIN_SCROLLBAR_HEIGHT.
no setterinherited
RAYGUI_MIN_SCROLLBAR_WIDTH → int
See RaylibGuiConstants.RAYGUI_MIN_SCROLLBAR_WIDTH.
no setterinherited
RAYGUI_PANEL_BORDER_WIDTH → int
See RaylibGuiConstants.RAYGUI_PANEL_BORDER_WIDTH.
no setterinherited
RAYGUI_SCROLLBAR_LEFT_SIDE → int
See RaylibGuiConstants.RAYGUI_SCROLLBAR_LEFT_SIDE.
no setterinherited
RAYGUI_SCROLLBAR_RIGHT_SIDE → int
See RaylibGuiConstants.RAYGUI_SCROLLBAR_RIGHT_SIDE.
no setterinherited
RAYGUI_TEXTBOX_AUTO_CURSOR_COOLDOWN → int
See RaylibGuiConstants.RAYGUI_TEXTBOX_AUTO_CURSOR_COOLDOWN.
no setterinherited
RAYGUI_TEXTBOX_AUTO_CURSOR_DELAY → int
See RaylibGuiConstants.RAYGUI_TEXTBOX_AUTO_CURSOR_DELAY.
no setterinherited
RAYGUI_TEXTINPUTBOX_BUTTON_HEIGHT → int
See RaylibGuiConstants.RAYGUI_TEXTINPUTBOX_BUTTON_HEIGHT.
no setterinherited
RAYGUI_TEXTINPUTBOX_BUTTON_PADDING → int
See RaylibGuiConstants.RAYGUI_TEXTINPUTBOX_BUTTON_PADDING.
no setterinherited
RAYGUI_TEXTINPUTBOX_HEIGHT → int
See RaylibGuiConstants.RAYGUI_TEXTINPUTBOX_HEIGHT.
no setterinherited
RAYGUI_TOGGLEGROUP_MAX_ITEM_TEXT_SIZE → int
See RaylibGuiConstants.RAYGUI_TOGGLEGROUP_MAX_ITEM_TEXT_SIZE.
no setterinherited
RAYGUI_VALUEBOX_MAX_CHARS → int
See RaylibGuiConstants.RAYGUI_VALUEBOX_MAX_CHARS.
no setterinherited
RAYGUI_VERSION → String
See RaylibGuiConstants.RAYGUI_VERSION.
no setterinherited
RAYGUI_VERSION_MAJOR → int
See RaylibGuiConstants.RAYGUI_VERSION_MAJOR.
no setterinherited
RAYGUI_VERSION_MINOR → int
See RaylibGuiConstants.RAYGUI_VERSION_MINOR.
no setterinherited
RAYGUI_VERSION_PATCH → int
See RaylibGuiConstants.RAYGUI_VERSION_PATCH.
no setterinherited
RAYGUI_WINDOWBOX_CLOSEBUTTON_HEIGHT → int
See RaylibGuiConstants.RAYGUI_WINDOWBOX_CLOSEBUTTON_HEIGHT.
no setterinherited
RAYGUI_WINDOWBOX_STATUSBAR_HEIGHT → int
See RaylibGuiConstants.RAYGUI_WINDOWBOX_STATUSBAR_HEIGHT.
no setterinherited
rl → Raylib
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

debug(bool v) → void
Enables or disables debug logging for this module.
inherited
debugError(String message) → void
Logs message at error level if debug is enabled and message passes all filters.
inherited
debugFilter(bool filter(String)) → void
Adds a predicate that gates debug output. Only messages satisfying at least one filter are logged.
inherited
debugInfo(String message) → void
Logs message at info level if debug is enabled and message passes all filters.
inherited
debugTime(bool v) → void
Enables or disables per-call timing output alongside debug logs.
inherited
debugWarn(String message) → void
Logs message at warn level if debug is enabled and message passes all filters.
inherited
disableSync<T>(T f()) → T
Executes f with RaylibTemp syncing temporarily disabled, restoring the previous sync state afterward.
inherited
dispose() → void
Calls all registered onDispose callbacks and clears them.
inherited
disposeStructWithOpFreed<D extends RaylibStruct<D>>(D struct, void fn(StructPointer<D> ptr)) → void
Disposes struct, invokes fn with its underlying pointer, and then frees the temporary allocation backing the pointer, if any.
inherited
disposeStructWithOpUnslotted<D extends RaylibStruct<D>>(D struct, void fn(StructPointer<D> ptr)) → void
Disposes struct, invokes fn with its underlying pointer, and then unslots the temporary allocation backing the pointer, if any.
inherited
GuiButton(RectangleC bounds, Pointer<Char> text) → int
Button control, returns true when clicked
GuiCheckBox(RectangleC bounds, Pointer<Char> text, Pointer<Bool> checked) → int
Check Box control, returns true when active
GuiColorBarAlpha(RectangleC bounds, Pointer<Char> text, Pointer<Float> alpha) → int
Color Bar Alpha control
GuiColorBarHue(RectangleC bounds, Pointer<Char> text, Pointer<Float> value) → int
Color Bar Hue control
GuiColorPanel(RectangleC bounds, Pointer<Char> text, Pointer<ColorC> color) → int
Color Panel control
GuiColorPanelHSV(RectangleC bounds, Pointer<Char> text, Pointer<Vector3C> colorHsv) → int
Color Panel control, using Hue-Saturation-Value color data
GuiColorPicker(RectangleC bounds, Pointer<Char> text, Pointer<ColorC> color) → int
Color Picker control, includes Color bar controls
GuiColorPickerHSV(RectangleC bounds, Pointer<Char> text, Pointer<Vector3C> colorHsv) → int
Color Picker control, using Hue-Saturation-Value color data, includes Color bar controls
GuiComboBox(RectangleC bounds, Pointer<Char> text, Pointer<Int> active) → int
Combo Box control
GuiDisable() → void
Disable gui controls (global state)
GuiDisableTooltip() → void
Disable gui tooltips (global state)
GuiDrawIcon(int iconId, int posX, int posY, int pixelSize, ColorC color) → void
Draw icon using pixel size at specified position
GuiDropdownBox(RectangleC bounds, Pointer<Char> text, Pointer<Int> active, bool editMode) → int
Dropdown Box control
GuiDummyRec(RectangleC bounds, Pointer<Char> text) → int
Dummy control for placeholders
GuiEnable() → void
Enable gui controls (global state)
GuiEnableTooltip() → void
Enable gui tooltips (global state)
GuiGetFont() → FontC
Get gui custom font (global state)
GuiGetIcons() → Pointer<UnsignedInt>
Get raygui icons data
GuiGetState() → int
Get gui state (global state)
GuiGetStyle(int control, int property) → int
Get one style property
GuiGetTextWidth(Pointer<Char> text) → int
Get text width considering gui style and icon size (if required)
GuiGrid(RectangleC bounds, Pointer<Char> text, double spacing, int subdivs, Pointer<Vector2C> mouseCell) → int
Grid control
GuiGroupBox(RectangleC bounds, Pointer<Char> text) → int
Group Box control with text name
GuiIconText(int iconId, Pointer<Char> text) → Pointer<Char>
Get text with icon id prepended (if supported)
GuiIsLocked() → bool
Check if gui is locked (global state)
GuiLabel(RectangleC bounds, Pointer<Char> text) → int
Label control
GuiLabelButton(RectangleC bounds, Pointer<Char> text) → int
Label button control, returns true when clicked
GuiLine(RectangleC bounds, Pointer<Char> text) → int
Line separator control, could contain text
GuiListView(RectangleC bounds, Pointer<Char> text, Pointer<Int> scrollIndex, Pointer<Int> active) → int
List View control
GuiListViewEx(RectangleC bounds, Pointer<Pointer<Char>> text, int count, Pointer<Int> scrollIndex, Pointer<Int> active, Pointer<Int> focus) → int
List View control, using text entries list and returning focus entry
GuiLoadIcons(Pointer<Char> fileName, bool loadIconsName) → Pointer<Pointer<Char>>
Load raygui icons file (.rgi) into internal icons data
GuiLoadIconsFromMemory(Pointer<UnsignedChar> fileData, int dataSize, bool loadIconsName) → Pointer<Pointer<Char>>
Load raygui icons file (.rgi) from memory into internal icons data
GuiLoadStyle(Pointer<Char> fileName) → void
Load style file over global style variable (.rgs)
GuiLoadStyleDefault() → void
Load style default over global style
GuiLoadStyleFromMemory(Pointer<UnsignedChar> fileData, int dataSize) → void
Load style from memory (binary only)
GuiLock() → void
Lock gui controls (global state)
GuiMessageBox(RectangleC bounds, Pointer<Char> title, Pointer<Char> message, Pointer<Char> btnText, Pointer<Int> btnActive) → int
Message Box control, displays a message
GuiPanel(RectangleC bounds, Pointer<Char> text) → int
Panel control, useful to group controls
GuiProgressBar(RectangleC bounds, Pointer<Char> textLeft, Pointer<Char> textRight, Pointer<Float> value, double minValue, double maxValue) → int
Progress Bar control
GuiScrollPanel(RectangleC bounds, Pointer<Char> text, RectangleC content, Pointer<Vector2C> scroll, Pointer<RectangleC> view) → int
Scroll Panel control
GuiSetAlpha(double alpha) → void
Set gui controls alpha (global state), alpha goes from 0.0 to 1.0
GuiSetFont(FontC font) → void
Set gui custom font (global state)
GuiSetIconScale(int scale) → void
Set default icon drawing size
GuiSetState(int state) → void
Set gui state (global state)
GuiSetStyle(int control, int property, int value) → void
Set one style property
GuiSetTooltip(Pointer<Char> tooltip) → void
Set tooltip string
GuiSlider(RectangleC bounds, Pointer<Char> textLeft, Pointer<Char> textRight, Pointer<Float> value, double minValue, double maxValue) → int
Slider control
GuiSliderBar(RectangleC bounds, Pointer<Char> textLeft, Pointer<Char> textRight, Pointer<Float> value, double minValue, double maxValue) → int
Slider Bar control
GuiSpinner(RectangleC bounds, Pointer<Char> text, Pointer<Int> value, int minValue, int maxValue, bool editMode) → int
Spinner control
GuiStatusBar(RectangleC bounds, Pointer<Char> text) → int
Status Bar control, shows info text
GuiTabBar(RectangleC bounds, Pointer<Char> text, Pointer<Int> hscroll, Pointer<Int> active) → int
Tab Bar control
GuiTabBarEx(RectangleC bounds, Pointer<Pointer<Char>> text, int count, Pointer<Int> hscroll, Pointer<Int> active, Pointer<Int> focus) → int
Tab Bar control, using text entries list and returning focus entry
GuiTextBox(RectangleC bounds, Pointer<Char> text, int textSize, bool editMode) → int
Text Box control, updates input text
GuiTextInputBox(RectangleC bounds, Pointer<Char> title, Pointer<Char> message, Pointer<Char> text, int textSize, Pointer<Char> btnText, Pointer<Int> btnActive, Pointer<Bool> secretViewActive) → int
Text Input Box control, ask for text, supports secret
GuiToggle(RectangleC bounds, Pointer<Char> text, Pointer<Bool> active) → int
Toggle Button control
GuiToggleGroup(RectangleC bounds, Pointer<Char> text, Pointer<Int> active) → int
Toggle Group control
GuiToggleSlider(RectangleC bounds, Pointer<Char> text, Pointer<Int> active) → int
Toggle Slider control
GuiUnlock() → void
Unlock gui controls (global state)
GuiValueBox(RectangleC bounds, Pointer<Char> text, Pointer<Int> value, int minValue, int maxValue, bool editMode) → int
Value Box control, updates input text with numbers
GuiValueBoxFloat(RectangleC bounds, Pointer<Char> text, Pointer<Char> textValue, Pointer<Float> value, bool editMode) → int
Value box control for float values
GuiWindowBox(RectangleC bounds, Pointer<Char> title) → int
Window Box control, shows a window that can be closed
load() → void
Override to perform one-time module initialization.
inherited
logError(Object? message) → void
inherited
logInfo(Object? message) → void
inherited
logWarn(Object? message) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose(void fn()) → void
Registers fn to be called when this module is disposed.
inherited
run<T>(String name(), T f()) → T
Executes f, logging its label (and optionally timing it) when debug is enabled and the label passes all filters.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited