GuiWindowBox method
Window Box control, shows a window that can be closed
Implementation
int GuiWindowBox(RectangleC bounds, Pointer<Char> title)
=> _GuiWindowBox(bounds, title);
Window Box control, shows a window that can be closed
int GuiWindowBox(RectangleC bounds, Pointer<Char> title)
=> _GuiWindowBox(bounds, title);