RaylibGuiFlat class

Constructors

RaylibGuiFlat(dynamic rl)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

GuiButton(RectangleD bounds, MemoryPointer<RChar> text) → int
GuiCheckBox(RectangleD bounds, MemoryPointer<RChar> text, MemoryPointer<RBool> checked) → int
GuiColorBarAlpha(RectangleD bounds, MemoryPointer<RChar> text, MemoryPointer<RFloat> alpha) → int
GuiColorBarHue(RectangleD bounds, MemoryPointer<RChar> text, MemoryPointer<RFloat> value) → int
GuiColorPanel(RectangleD bounds, MemoryPointer<RChar> text, StructPointer<ColorD> color) → int
GuiColorPanelHSV(RectangleD bounds, MemoryPointer<RChar> text, StructPointer<Vector3D> colorHsv) → int
GuiColorPicker(RectangleD bounds, MemoryPointer<RChar> text, StructPointer<ColorD> color) → int
GuiColorPickerHSV(RectangleD bounds, MemoryPointer<RChar> text, StructPointer<Vector3D> colorHsv) → int
GuiComboBox(RectangleD bounds, MemoryPointer<RChar> text, MemoryPointer<RInt> active) → int
GuiDisable() → void
GuiDisableTooltip() → void
GuiDrawIcon(int iconId, int posX, int posY, int pixelSize, ColorD color) → void
GuiDropdownBox(RectangleD bounds, MemoryPointer<RChar> text, MemoryPointer<RInt> active, bool editMode) → int
GuiDummyRec(RectangleD bounds, MemoryPointer<RChar> text) → int
GuiEnable() → void
GuiEnableTooltip() → void
GuiGetFont() → FontD
GuiGetIcons() → NativeMemoryPointer<RUnsignedInt>
GuiGetState() → int
GuiGetStyle(int control, int property) → int
GuiGetTextWidth(MemoryPointer<RChar> text) → int
GuiGrid(RectangleD bounds, MemoryPointer<RChar> text, double spacing, int subdivs, StructPointer<Vector2D> mouseCell) → int
GuiGroupBox(RectangleD bounds, MemoryPointer<RChar> text) → int
GuiIconText(int iconId, MemoryPointer<RChar> text) → NativeMemoryPointer<RChar>
GuiIsLocked() → bool
GuiLabel(RectangleD bounds, MemoryPointer<RChar> text) → int
GuiLabelButton(RectangleD bounds, MemoryPointer<RChar> text) → int
GuiLine(RectangleD bounds, MemoryPointer<RChar> text) → int
GuiListView(RectangleD bounds, MemoryPointer<RChar> text, MemoryPointer<RInt> scrollIndex, MemoryPointer<RInt> active) → int
GuiListViewEx(RectangleD bounds, MemoryPointer<RPointer<RChar>> text, int count, MemoryPointer<RInt> scrollIndex, MemoryPointer<RInt> active, MemoryPointer<RInt> focus) → int
GuiLoadIcons(MemoryPointer<RChar> fileName, bool loadIconsName) → NativeMemoryPointer<RPointer<RChar>>
GuiLoadIconsFromMemory(MemoryPointer<RUnsignedChar> fileData, int dataSize, bool loadIconsName) → NativeMemoryPointer<RPointer<RChar>>
GuiLoadStyle(MemoryPointer<RChar> fileName) → void
GuiLoadStyleDefault() → void
GuiLoadStyleFromMemory(MemoryPointer<RUnsignedChar> fileData, int dataSize) → void
GuiLock() → void
GuiMessageBox(RectangleD bounds, MemoryPointer<RChar> title, MemoryPointer<RChar> message, MemoryPointer<RChar> btnText, MemoryPointer<RInt> btnActive) → int
GuiPanel(RectangleD bounds, MemoryPointer<RChar> text) → int
GuiProgressBar(RectangleD bounds, MemoryPointer<RChar> textLeft, MemoryPointer<RChar> textRight, MemoryPointer<RFloat> value, double minValue, double maxValue) → int
GuiScrollPanel(RectangleD bounds, MemoryPointer<RChar> text, RectangleD content, StructPointer<Vector2D> scroll, StructPointer<RectangleD> view) → int
GuiSetAlpha(double alpha) → void
GuiSetFont(FontD font) → void
GuiSetIconScale(int scale) → void
GuiSetState(int state) → void
GuiSetStyle(int control, int property, int value) → void
GuiSetTooltip(MemoryPointer<RChar> tooltip) → void
GuiSlider(RectangleD bounds, MemoryPointer<RChar> textLeft, MemoryPointer<RChar> textRight, MemoryPointer<RFloat> value, double minValue, double maxValue) → int
GuiSliderBar(RectangleD bounds, MemoryPointer<RChar> textLeft, MemoryPointer<RChar> textRight, MemoryPointer<RFloat> value, double minValue, double maxValue) → int
GuiSpinner(RectangleD bounds, MemoryPointer<RChar> text, MemoryPointer<RInt> value, int minValue, int maxValue, bool editMode) → int
GuiStatusBar(RectangleD bounds, MemoryPointer<RChar> text) → int
GuiTabBar(RectangleD bounds, MemoryPointer<RChar> text, MemoryPointer<RInt> hscroll, MemoryPointer<RInt> active) → int
GuiTabBarEx(RectangleD bounds, MemoryPointer<RPointer<RChar>> text, int count, MemoryPointer<RInt> hscroll, MemoryPointer<RInt> active, MemoryPointer<RInt> focus) → int
GuiTextBox(RectangleD bounds, MemoryPointer<RChar> text, int textSize, bool editMode) → int
GuiTextInputBox(RectangleD bounds, MemoryPointer<RChar> title, MemoryPointer<RChar> message, MemoryPointer<RChar> text, int textSize, MemoryPointer<RChar> btnText, MemoryPointer<RInt> btnActive, MemoryPointer<RBool> secretViewActive) → int
GuiToggle(RectangleD bounds, MemoryPointer<RChar> text, MemoryPointer<RBool> active) → int
GuiToggleGroup(RectangleD bounds, MemoryPointer<RChar> text, MemoryPointer<RInt> active) → int
GuiToggleSlider(RectangleD bounds, MemoryPointer<RChar> text, MemoryPointer<RInt> active) → int
GuiUnlock() → void
GuiValueBox(RectangleD bounds, MemoryPointer<RChar> text, MemoryPointer<RInt> value, int minValue, int maxValue, bool editMode) → int
GuiValueBoxFloat(RectangleD bounds, MemoryPointer<RChar> text, MemoryPointer<RChar> textValue, MemoryPointer<RFloat> value, bool editMode) → int
GuiWindowBox(RectangleD bounds, MemoryPointer<RChar> title) → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited