QuaternionFromVector3ToVector3 method
Calculate quaternion based on the rotation from one vector to another
Implementation
QuaternionC QuaternionFromVector3ToVector3(Vector3C from, Vector3C to)
=> _QuaternionFromVector3ToVector3(from, to);
Calculate quaternion based on the rotation from one vector to another
QuaternionC QuaternionFromVector3ToVector3(Vector3C from, Vector3C to)
=> _QuaternionFromVector3ToVector3(from, to);