rlSetTexture method
Set current texture for render batch and check buffers limits
Implementation
void rlSetTexture(int id)
=> _rlSetTexture(id);
Set current texture for render batch and check buffers limits
void rlSetTexture(int id)
=> _rlSetTexture(id);