RaylibVector2Ext class

Inheritance

Constructors

RaylibVector2Ext(Raylib rl)

Properties

$ → RaylibTemp<RaylibBase>
See RaylibTemp.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
rl → Raylib
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

debug(bool v) → void
Enables or disables debug logging for this module.
inherited
debugError(String message) → void
Logs message at error level if debug is enabled and message passes all filters.
inherited
debugFilter(bool filter(String)) → void
Adds a predicate that gates debug output. Only messages satisfying at least one filter are logged.
inherited
debugInfo(String message) → void
Logs message at info level if debug is enabled and message passes all filters.
inherited
debugTime(bool v) → void
Enables or disables per-call timing output alongside debug logs.
inherited
debugWarn(String message) → void
Logs message at warn level if debug is enabled and message passes all filters.
inherited
disableSync<T>(T f()) → T
Executes f with RaylibTemp syncing temporarily disabled, restoring the previous sync state afterward.
inherited
dispose() → void
Calls all registered onDispose callbacks and clears them.
inherited
disposeStructWithOpFreed<D extends RaylibStruct<D>>(D struct, void fn(StructPointer<D> ptr)) → void
Disposes struct, invokes fn with its underlying pointer, and then frees the temporary allocation backing the pointer, if any.
inherited
disposeStructWithOpUnslotted<D extends RaylibStruct<D>>(D struct, void fn(StructPointer<D> ptr)) → void
Disposes struct, invokes fn with its underlying pointer, and then unslots the temporary allocation backing the pointer, if any.
inherited
load() → void
Override to perform one-time module initialization.
inherited
logError(Object? message) → void
inherited
logInfo(Object? message) → void
inherited
logWarn(Object? message) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose(void fn()) → void
Registers fn to be called when this module is disposed.
inherited
run<T>(String name(), T f()) → T
Executes f, logging its label (and optionally timing it) when debug is enabled and the label passes all filters.
inherited
toString() → String
A string representation of this object.
inherited
Vector2Add(Vector2C v1, Vector2C v2) → Vector2C
Add two vectors (v1 + v2)
Vector2AddValue(Vector2C v, double add) → Vector2C
Add vector and double value
Vector2Angle(Vector2C v1, Vector2C v2) → double
Calculate the signed angle from v1 to v2, relative to the origin (0, 0)
Vector2Clamp(Vector2C v, Vector2C min, Vector2C max) → Vector2C
Clamp the components of the vector between min and max values specified by the given vectors
Vector2ClampValue(Vector2C v, double min, double max) → Vector2C
Clamp the magnitude of the vector between two min and max values
Vector2CrossProduct(Vector2C v1, Vector2C v2) → double
Calculate two vectors cross product
Vector2Distance(Vector2C v1, Vector2C v2) → double
Calculate distance between two vectors
Vector2DistanceSqr(Vector2C v1, Vector2C v2) → double
Calculate square distance between two vectors
Vector2Divide(Vector2C v1, Vector2C v2) → Vector2C
Divide vector by vector
Vector2DotProduct(Vector2C v1, Vector2C v2) → double
Calculate two vectors dot product
Vector2Equals(Vector2C p, Vector2C q) → bool
Check whether two given vectors are almost equal
Vector2Invert(Vector2C v) → Vector2C
Invert the given vector
Vector2Length(Vector2C v) → double
Calculate vector length
Vector2LengthSqr(Vector2C v) → double
Calculate vector square length
Vector2Lerp(Vector2C v1, Vector2C v2, double amount) → Vector2C
Calculate linear interpolation between two vectors
Vector2LineAngle(Vector2C start, Vector2C end) → double
Calculate angle defined by a two vectors line
Vector2Max(Vector2C v1, Vector2C v2) → Vector2C
Get max value for each pair of components
Vector2Min(Vector2C v1, Vector2C v2) → Vector2C
Get min value for each pair of components
Vector2MoveTowards(Vector2C v, Vector2C target, double maxDistance) → Vector2C
Move Vector towards target
Vector2Multiply(Vector2C v1, Vector2C v2) → Vector2C
Multiply vector by vector
Vector2Negate(Vector2C v) → Vector2C
Negate vector
Vector2Normalize(Vector2C v) → Vector2C
Normalize provided vector
Vector2One() → Vector2C
Vector with components value 1.0f
Vector2Reflect(Vector2C v, Vector2C normal) → Vector2C
Calculate reflected vector to normal
Vector2Refract(Vector2C v, Vector2C n, double r) → Vector2C
Compute the direction of a refracted ray v: normalized direction of the incoming ray n: normalized normal vector of the interface of two optical media r: ratio of the refractive index of the medium from where the ray comes to the refractive index of the medium on the other side of the surface
Vector2Rotate(Vector2C v, double angle) → Vector2C
Rotate vector by angle
Vector2Scale(Vector2C v, double scale) → Vector2C
Scale vector (multiply by value)
Vector2Subtract(Vector2C v1, Vector2C v2) → Vector2C
Subtract two vectors (v1 - v2)
Vector2SubtractValue(Vector2C v, double sub) → Vector2C
Subtract vector by double value
Vector2Transform(Vector2C v, MatrixC mat) → Vector2C
Transforms a Vector2 by a given Matrix
Vector2Zero() → Vector2C
Vector with components value 0.0f

Operators

operator ==(Object other) → bool
The equality operator.
inherited