Vector3Refract method

Vector3C Vector3Refract(
  1. Vector3C v,
  2. Vector3C n,
  3. double r
)

Compute the direction of a refracted ray v: normalized direction of the incoming ray n: normalized normal vector of the interface of two optical media r: ratio of the refractive index of the medium from where the ray comes to the refractive index of the medium on the other side of the surface

Implementation

Vector3C Vector3Refract(Vector3C v, Vector3C n, double r)
  => _Vector3Refract(v, n, r);