clone method
Returns a deep copy of this instance, preserving RaylibStructBase.originalPointer if present.
Implementation
@override
RectangleD clone() => .new(
originalPointer: originalPointer,
x: x,
y: y,
width: width,
height: height,
);
Returns a deep copy of this instance, preserving RaylibStructBase.originalPointer if present.
@override
RectangleD clone() => .new(
originalPointer: originalPointer,
x: x,
y: y,
width: width,
height: height,
);