setD method
Copies the fields of o into this instance and returns this.
Implementation
@override
RenderTextureD setD(RenderTextureD o) {
id = o.id;
texture = o.texture;
depth = o.texture;
return this;
}
Copies the fields of o into this instance and returns this.
@override
RenderTextureD setD(RenderTextureD o) {
id = o.id;
texture = o.texture;
depth = o.texture;
return this;
}