nativeWriteInto abstract method
void
nativeWriteInto(
- C p
Writes all fields directly into the native struct reference p.
For nested structs, use writeInto as well.
Implementation
void nativeWriteInto(C p);
Writes all fields directly into the native struct reference p.
For nested structs, use writeInto as well.
void nativeWriteInto(C p);