setD method
Copies the fields of o into this instance and returns this.
Implementation
@override
@nonVirtual
D setD(D o) => throw UnsupportedError('$runtimeType: is just a view; cannot write to it.');
Copies the fields of o into this instance and returns this.
@override
@nonVirtual
D setD(D o) => throw UnsupportedError('$runtimeType: is just a view; cannot write to it.');