setD method
Copies the fields of o into this instance and returns this.
Implementation
@override
TransformD setD(TransformD o) {
translation.setD(o.translation);
rotation.setD(o.rotation);
scale.setD(o.scale);
return this;
}
Copies the fields of o into this instance and returns this.
@override
TransformD setD(TransformD o) {
translation.setD(o.translation);
rotation.setD(o.rotation);
scale.setD(o.scale);
return this;
}