Vector2C class final
- Inheritance
- Implemented types
- Available extensions
Constructors
- Vector2C()
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- x ↔ double
-
getter/setter pair
- y ↔ double
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
set(
num x, num y) → Vector2C -
Available on Vector2C, provided by the Vector2CEx extension
-
setC(
Vector2C o) → Vector2C -
Available on Vector2C, provided by the Vector2CEx extension
-
setD(
Vector2D o) → Vector2C -
Available on Vector2C, provided by the Vector2CEx extension
-
toD(
[Pointer< Vector2C> ? ptr]) → Vector2D -
Available on Vector2C, provided by the Vector2CEx extension
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited