Vector3C class final

Inheritance
Implemented types
Available extensions

Constructors

Vector3C()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
getter/setter pair
y double
getter/setter pair
z double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(num x, num y, num z) Vector3C

Available on Vector3C, provided by the Vector3CEx extension

setC(Vector3C o) Vector3C

Available on Vector3C, provided by the Vector3CEx extension

setD(Vector3D o) Vector3C

Available on Vector3C, provided by the Vector3CEx extension

toD([Pointer<Vector3C>? ptr]) Vector3D

Available on Vector3C, provided by the Vector3CEx extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited