Vector4C class final
- Inheritance
- Implemented types
- Available extensions
Constructors
- Vector4C()
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- w ↔ double
-
getter/setter pair
- x ↔ double
-
getter/setter pair
- y ↔ double
-
getter/setter pair
- z ↔ double
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
set(
num x, num y, num z, num w) → Vector4C -
Available on Vector4C, provided by the Vector4CEx extension
-
setC(
Vector4C o) → Vector4C -
Available on Vector4C, provided by the Vector4CEx extension
-
setD(
Vector4D o) → Vector4C -
Available on Vector4C, provided by the Vector4CEx extension
-
toD(
[Pointer< Vector4C> ? ptr]) → Vector4D -
Available on Vector4C, provided by the Vector4CEx extension
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited