BASE_nameLength property
int
get
BASE_nameLength
Size of the native name buffer in bytes (C ABI layout constant).
Implementation
static int get BASE_nameLength => 32;
Size of the native name buffer in bytes (C ABI layout constant).
static int get BASE_nameLength => 32;