Compile-time ABI constant describing the capacity of the native name buffer.
name
This is not related to the Dart String length of name.
Exists only for memory layout / FFI compatibility.
int get nameLength => BASE_nameLength;