fovy property
Camera field-of-view aperture in Y (degrees) in perspective, used as near plane width in orthographic
Implementation
abstract double fovy;
Camera field-of-view aperture in Y (degrees) in perspective, used as near plane width in orthographic
abstract double fovy;