$state property
Per-instance allocation state tracking slot keys, disposal, and identity.
Implementation
final RaylibTempStructState $state = RaylibTempStructState();
Per-instance allocation state tracking slot keys, disposal, and identity.
final RaylibTempStructState $state = RaylibTempStructState();