FontType enum

Raylib FontType enum.

Inheritance
Available extensions

Values

FONT_DEFAULT → const FontType

FONT_DEFAULT

const FontType(0)
FONT_BITMAP → const FontType

FONT_BITMAP

const FontType(1)
FONT_SDF → const FontType

FONT_SDF

const FontType(2)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
The underlying native integer value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) FontType
Returns the FontType for the given native value.

Constants

values → const List<FontType>
A constant List of the values in this enum, in order of their declaration.