GuiColorPickerProperty enum

raygui GuiColorPickerProperty enum.

Inheritance
Mixed-in types
Available extensions

Values

COLOR_SELECTOR_SIZE → const GuiColorPickerProperty

COLOR_SELECTOR_SIZE

const GuiColorPickerProperty(16)
HUEBAR_WIDTH → const GuiColorPickerProperty

HUEBAR_WIDTH

const GuiColorPickerProperty(17)
HUEBAR_PADDING → const GuiColorPickerProperty

HUEBAR_PADDING

const GuiColorPickerProperty(18)
HUEBAR_SELECTOR_HEIGHT → const GuiColorPickerProperty

HUEBAR_SELECTOR_HEIGHT

const GuiColorPickerProperty(19)
HUEBAR_SELECTOR_OVERFLOW → const GuiColorPickerProperty

HUEBAR_SELECTOR_OVERFLOW

const GuiColorPickerProperty(20)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
The underlying native integer value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GuiColorPickerProperty
Returns the GuiColorPickerProperty for the given native value.

Constants

values → const List<GuiColorPickerProperty>
A constant List of the values in this enum, in order of their declaration.