DetachAudioMixedProcessor abstract method
Detach audio stream processor from the entire audio pipeline
Implementation
void DetachAudioMixedProcessor(
AudioCallbackType callback,
{bool keepAlive = false}
);
Detach audio stream processor from the entire audio pipeline
void DetachAudioMixedProcessor(
AudioCallbackType callback,
{bool keepAlive = false}
);