RaylibCaptureIds property
Capture ID generator for pointer slots allocated by this module.
Implementation
final RaylibCaptureIds = RaylibAudioModuleCaptureIds();
Capture ID generator for pointer slots allocated by this module.
final RaylibCaptureIds = RaylibAudioModuleCaptureIds();