RaylibAudioModuleCaptureIds class
Produces stable slot key strings identifying the allocation origin of each Audio module function's captured Struct.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
LoadAudioStream(
num sampleRate, num sampleSize, num channels) → String -
LoadMusicStream(
String fileName) → String -
LoadMusicStreamFromMemory(
String fileType, Uint8List data) → String -
LoadSound(
String fileName) → String -
LoadSoundAlias(
SoundBase< SoundBase< source) → Stringdynamic, AudioStreamBase> , AudioStreamBase> -
LoadSoundFromWave(
WaveBase< WaveBase> wave) → String -
LoadWave(
String fileName) → String -
LoadWaveFromMemory(
String fileType, Uint8List fileData) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
WaveCopy(
WaveBase< WaveBase> wave) → String
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited