DrawPixel abstract method
Draw a pixel using geometry Can be slow, use with care
Implementation
void DrawPixel(
num posX,
num posY,
ColorStructType color,
);
Draw a pixel using geometry Can be slow, use with care
void DrawPixel(
num posX,
num posY,
ColorStructType color,
);