ExportFontAsCode abstract method
Export font as code file, returns true on success
Implementation
bool ExportFontAsCode(
FontStructType font,
String fileName,
);
Export font as code file, returns true on success
bool ExportFontAsCode(
FontStructType font,
String fileName,
);