ExportImage abstract method
Export image data to file, returns true on success
Implementation
bool ExportImage(
ImageStructType image,
String fileName,
);
Export image data to file, returns true on success
bool ExportImage(
ImageStructType image,
String fileName,
);