ExportImageAsCode abstract method
Export image as code file defining an array of bytes, returns true on success
Implementation
bool ExportImageAsCode(
ImageStructType image,
String fileName,
);
Export image as code file defining an array of bytes, returns true on success
bool ExportImageAsCode(
ImageStructType image,
String fileName,
);