ExportMesh abstract method
Export mesh data to file, returns true on success
Implementation
bool ExportMesh(
MeshStructType mesh,
String fileName,
);
Export mesh data to file, returns true on success
bool ExportMesh(
MeshStructType mesh,
String fileName,
);