GetGlyphAtlasRec abstract method
Get glyph rectangle in font atlas for a codepoint (unicode character), fallback to '?' if not found
Implementation
RectangleStructType GetGlyphAtlasRec(
FontStructType font,
num codepoint,
);
Get glyph rectangle in font atlas for a codepoint (unicode character), fallback to '?' if not found
RectangleStructType GetGlyphAtlasRec(
FontStructType font,
num codepoint,
);