GetGlyphIndex abstract method
Get glyph index position in font for a codepoint (unicode character), fallback to '?' if not found
Implementation
int GetGlyphIndex(
FontStructType font,
num codepoint,
);
Get glyph index position in font for a codepoint (unicode character), fallback to '?' if not found
int GetGlyphIndex(
FontStructType font,
num codepoint,
);