GetGlyphInfo abstract method
Get glyph font info data for a codepoint (unicode character), fallback to '?' if not found
Implementation
GlyphInfoStructType GetGlyphInfo(
FontStructType font,
num codepoint,
);
Get glyph font info data for a codepoint (unicode character), fallback to '?' if not found
GlyphInfoStructType GetGlyphInfo(
FontStructType font,
num codepoint,
);