GetShapesTextureRectangle abstract method
RectangleStructType
GetShapesTextureRectangle()
Get texture source rectangle that is used for shapes drawing
Implementation
RectangleStructType GetShapesTextureRectangle();
Get texture source rectangle that is used for shapes drawing
RectangleStructType GetShapesTextureRectangle();