ImageFromChannel abstract method
Create an image from a selected channel of another image (GRAYSCALE)
Implementation
ImageStructType ImageFromChannel(
ImageStructType image,
num selectedChannel,
);
Create an image from a selected channel of another image (GRAYSCALE)
ImageStructType ImageFromChannel(
ImageStructType image,
num selectedChannel,
);