LoadDirectoryFilesEx abstract method

FilePathListStructType LoadDirectoryFilesEx(
  1. String basePath,
  2. String filter,
  3. bool scanSubdirs
)

Load directory filepaths with extension filtering and recursive directory scan. Use 'DIR' in the filter string to include directories in the result

Implementation

FilePathListStructType LoadDirectoryFilesEx(
  String basePath,
  String filter,
  bool scanSubdirs,
);