LoadFontEx abstract method

FontStructType LoadFontEx(
  1. String fileName,
  2. num fontSize, [
  3. Int32List? codepoints,
  4. num? codePointCount,
])

Load font from file with extended parameters, use NULL for codepoints and 0 for codepointCount to load the default character set, font size is provided in pixels height

Implementation

FontStructType LoadFontEx(
  String fileName,
  num fontSize, [
    Int32List? codepoints,
    num? codePointCount
  ]
);