LoadImagePalette abstract method
Load colors palette from image as a Color array (RGBA - 32bit)
Implementation
List<ColorStructType> LoadImagePalette(
ImageStructType image,
num maxPaletteSize,
);
Load colors palette from image as a Color array (RGBA - 32bit)
List<ColorStructType> LoadImagePalette(
ImageStructType image,
num maxPaletteSize,
);