RaylibFunctions class

Pure Dart implementations of Raylib's inline/math utility functions, shared across backends to avoid duplicating logic that doesn't touch native memory.

Constructors

RaylibFunctions()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

Clamp(num value, num min, num max) double
FloatEquals(double x, double y) bool
Lerp(num start, num end, num amount) double
Normalize(num value, num start, num end) double
Remap(num value, num inputStart, num inputEnd, num outputStart, num outputEnd) double
Wrap(num value, num min, num max) double