RaylibGuiModuleBase<R extends RaylibBase, ColorStructType extends ColorBase<ColorStructType>, FontStructType extends FontBase<FontStructType, TextureStructType, RectangleStructType, GlyphInfoStructType, ImageStructType>, GlyphInfoStructType extends GlyphInfoBase<GlyphInfoStructType, ImageStructType>, ImageStructType extends ImageBase<ImageStructType>, MatrixStructType extends MatrixBase<MatrixStructType, Vector3StructType, QuaternionStructType, Vector4StructType>, QuaternionStructType extends QuaternionBase<QuaternionStructType, MatrixStructType, Vector3StructType, Vector4StructType>, RectangleStructType extends RectangleBase<RectangleStructType>, TextureStructType extends TextureBase<TextureStructType>, Vector2StructType extends Vector2Base<Vector2StructType, MatrixStructType, Vector3StructType, QuaternionStructType, Vector4StructType>, Vector3StructType extends Vector3Base<Vector3StructType, MatrixStructType, QuaternionStructType, Vector4StructType>, Vector4StructType extends Vector4Base<Vector4StructType, QuaternionStructType, MatrixStructType, Vector3StructType>> class abstract

Backend-agnostic contract for the Raylib Gui module.

Concrete platform implementations mix in or extend this to provide the full Core API surface across different backends.

Inheritance
Mixed-in types
Implementers

Constructors

RaylibGuiModuleBase(R rl)

Properties

hashCode int
The hash code for this object.
no setterinherited
RAYGUI_COLORBARALPHA_CHECKED_SIZE int
no setterinherited
RAYGUI_GRID_ALPHA double
no setterinherited
RAYGUI_GROUPBOX_LINE_THICK int
no setterinherited
RAYGUI_ICON_DATA_ELEMENTS int
no setterinherited
RAYGUI_ICON_MAX_ICONS int
no setterinherited
RAYGUI_ICON_MAX_NAME_LENGTH int
no setterinherited
RAYGUI_ICON_SIZE int
no setterinherited
RAYGUI_ICON_TEXT_PADDING int
no setterinherited
RAYGUI_ICONS List<int>
no setterinherited
RAYGUI_LINE_MARGIN_TEXT int
no setterinherited
RAYGUI_LINE_TEXT_PADDING int
no setterinherited
RAYGUI_MAX_CONTROLS int
no setterinherited
RAYGUI_MAX_LINE_BUFFER_SIZE int
no setterinherited
RAYGUI_MAX_PROPS_BASE int
no setterinherited
RAYGUI_MAX_PROPS_EXTENDED int
no setterinherited
RAYGUI_MAX_TEXT_LINES int
no setterinherited
RAYGUI_MESSAGEBOX_BUTTON_HEIGHT int
no setterinherited
RAYGUI_MESSAGEBOX_BUTTON_PADDING int
no setterinherited
RAYGUI_MIN_MOUSE_WHEEL_SPEED int
no setterinherited
RAYGUI_MIN_SCROLLBAR_HEIGHT int
no setterinherited
RAYGUI_MIN_SCROLLBAR_WIDTH int
no setterinherited
RAYGUI_PANEL_BORDER_WIDTH int
no setterinherited
RAYGUI_SCROLLBAR_LEFT_SIDE int
no setterinherited
RAYGUI_SCROLLBAR_RIGHT_SIDE int
no setterinherited
RAYGUI_TABBAR_ITEM_WIDTH int
no setterinherited
RAYGUI_TEXTBOX_AUTO_CURSOR_COOLDOWN int
no setterinherited
RAYGUI_TEXTBOX_AUTO_CURSOR_DELAY int
no setterinherited
RAYGUI_TEXTFORMAT_MAX_SIZE int
no setterinherited
RAYGUI_TEXTINPUTBOX_BUTTON_HEIGHT int
no setterinherited
RAYGUI_TEXTINPUTBOX_BUTTON_PADDING int
no setterinherited
RAYGUI_TEXTINPUTBOX_HEIGHT int
no setterinherited
RAYGUI_TEXTSPLIT_MAX_ITEMS int
no setterinherited
RAYGUI_TEXTSPLIT_MAX_TEXT_SIZE int
no setterinherited
RAYGUI_TOGGLEGROUP_MAX_ITEMS int
no setterinherited
RAYGUI_VALUEBOX_MAX_CHARS int
no setterinherited
RAYGUI_VERSION String
no setterinherited
RAYGUI_VERSION_MAJOR int
no setterinherited
RAYGUI_VERSION_MINOR int
no setterinherited
RAYGUI_VERSION_PATCH int
no setterinherited
RAYGUI_WINDOWBOX_STATUSBAR_HEIGHT int
no setterinherited
RaylibCaptureIds RaylibGuiModuleCaptureIds
Capture ID generator for pointer slots allocated by this module.
final
RaylibDebugLabels RaylibGuiModuleDebugLabels
Debug label generator for this module's function calls.
final
rl → R
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

debug(bool v) → void
Enables or disables debug logging for this module.
inherited
debugError(String message) → void
Logs message at error level if debug is enabled and message passes all filters.
inherited
debugFilter(bool filter(String)) → void
Adds a predicate that gates debug output. Only messages satisfying at least one filter are logged.
inherited
debugInfo(String message) → void
Logs message at info level if debug is enabled and message passes all filters.
inherited
debugTime(bool v) → void
Enables or disables per-call timing output alongside debug logs.
inherited
debugWarn(String message) → void
Logs message at warn level if debug is enabled and message passes all filters.
inherited
disableSync<T>(T f()) → T
Executes f with RaylibTempBase syncing temporarily disabled, restoring the previous sync state afterward.
inherited
dispose() → void
Calls all registered onDispose callbacks and clears them.
inherited
doLoad() → void
Ensures load is called exactly once, regardless of how many times doLoad is invoked.
inherited
GuiButton(RectangleStructType bounds, String? text) int
GuiCheckBox(RectangleStructType bounds, String? text, bool checked) → (int, bool)
GuiColorBarAlpha(RectangleStructType bounds, num alpha) → (int, double)
GuiColorBarHue(RectangleStructType bounds, num value) → (int, double)
GuiColorPanel(RectangleStructType bounds, ColorStructType color) → (int, ColorStructType)
GuiColorPanelHSV(RectangleStructType bounds, [Vector3StructType? colorHsv]) → (int, Vector3StructType)
GuiColorPicker(RectangleStructType bounds, ColorStructType? color) → (int, ColorStructType)
GuiColorPickerHSV(RectangleStructType bounds, [Vector3StructType? colorHsv]) → (int, Vector3StructType)
GuiComboBox(RectangleStructType bounds, String? text, num active) → (int, int)
GuiDisable() → void
GuiDisableTooltip() → void
GuiDrawIcon(GuiIconName iconId, num posX, num posY, num pixelSize, ColorStructType color) → void
GuiDropdownBox(RectangleStructType bounds, String? text, num active, bool editMode) → (int, int)
GuiDummyRec(RectangleStructType bounds, String? text) int
GuiEnable() → void
GuiEnableTooltip() → void
GuiGetFont() → FontStructType
GuiGetIcons() List<int>
GuiGetState() int
GuiGetStyle(GuiControl control, GuiProperty property) int
GuiGetTextWidth(String? text) int
GuiGrid(RectangleStructType bounds, num spacing, num subdivs, [Vector2StructType? mouseCell]) int
GuiGroupBox(RectangleStructType bounds, String? text) int
GuiIconText(GuiIconName iconId, String? text) String
GuiIsLocked() bool
GuiLabel(RectangleStructType bounds, String? text) int
GuiLabelButton(RectangleStructType bounds, String? text) int
GuiLine(RectangleStructType bounds, String? text) int
GuiListView(RectangleStructType bounds, String? text, {int? scrollIndex, int? active}) → (int, int, int)
GuiListViewEx(RectangleStructType bounds, List<String> text, {int? scrollIndex, int? active, int? focus}) → (int, int, int, int)
GuiLoadIcons(String fileName, bool loadIconsName) List<String>
GuiLoadStyle(String fileName) → void
GuiLoadStyleDefault() → void
GuiLock() → void
GuiMessageBox(RectangleStructType bounds, String? title, String message, String buttons) int
GuiPanel(RectangleStructType bounds, String? text) int
GuiProgressBar(RectangleStructType bounds, String? textLeft, String? textRight, num value, num minValue, num maxValue) → (int, double)
GuiScrollPanel(RectangleStructType bounds, String? text, RectangleStructType content, Vector2StructType scroll, [RectangleStructType? view]) int
GuiSetAlpha(num alpha) → void
GuiSetFont(FontStructType font) → void
GuiSetIconScale(num scale) → void
GuiSetState(GuiState state) → void
GuiSetStyle(GuiControl control, GuiProperty property, num value) → void
GuiSetTooltip(String? tooltip) → void
GuiSlider(RectangleStructType bounds, String? textLeft, String? textRight, num value, num minValue, num maxValue) → (int, double)
GuiSliderBar(RectangleStructType bounds, String? textLeft, String? textRight, num value, num minValue, num maxValue) → (int, double)
GuiSpinner(RectangleStructType bounds, String? text, num value, num minValue, num maxValue, bool editMode) → (int, int)
GuiStatusBar(RectangleStructType bounds, String? text) int
GuiTabBar(RectangleStructType bounds, List<String> text) → (int, int)
GuiTextBox(RectangleStructType bounds, String? text, num textSize, bool editMode) → (int, String)
GuiTextInputBox(RectangleStructType bounds, String? title, String? message, String buttons, String? text, num textMaxSize, bool? secretViewActive) → (int, String, bool?)
GuiToggle(RectangleStructType bounds, String? text, bool active) → (int, bool)
GuiToggleGroup(RectangleStructType bounds, String? text, num active) → (int, int)
GuiToggleSlider(RectangleStructType bounds, String? text, num active) → (int, int)
GuiUnlock() → void
GuiValueBox(RectangleStructType bounds, String? text, num value, num minValue, num maxValue, bool editMode) → (int, int)
GuiValueBoxFloat(RectangleStructType bounds, String? text, String textValue, num value, bool editMode) → (int, double)
GuiWindowBox(RectangleStructType bounds, String? title) int
load() → void
Override to perform one-time module initialization. Called by doLoad.
inherited
logError(Object? message) → void
inherited
logInfo(Object? message) → void
inherited
logWarn(Object? message) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose(void fn()) → void
Registers fn to be called when this module is disposed.
inherited
run<T>(String name(), T f()) → T
Executes f, logging its label (and optionally timing it) when debug is enabled and the label passes all filters.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited