RaylibGuiModuleDebugLabels class
Produces human-readable debug strings for each Gui module function call, logged to the console when debug output is enabled.
- Inheritance
-
- Object
- RaylibDebugLabelsBase
- RaylibGuiModuleDebugLabels
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
EnumsAsFlagsOr(
Iterable< RaylibEnum> flags) → String -
Formats
flagsas a|-separated string of enum names, mirroring C bitflag notation.inherited -
GuiButton(
RectangleBase< RectangleBase> bounds, String? text) → String -
GuiCheckBox(
RectangleBase< RectangleBase> bounds, String? text, bool checked) → String -
GuiColorBarAlpha(
RectangleBase< RectangleBase> bounds, num alpha) → String -
GuiColorBarHue(
RectangleBase< RectangleBase> bounds, num value) → String -
GuiColorPanel(
RectangleBase< RectangleBase> bounds, ColorBase<ColorBase> color) → String -
GuiColorPanelHSV(
RectangleBase< RectangleBase> bounds, [Vector3Base<Vector3Base, MatrixBase, QuaternionBase, Vector4Base> ? colorHsv]) → String -
GuiColorPicker(
RectangleBase< RectangleBase> bounds, ColorBase<ColorBase> ? color) → String -
GuiColorPickerHSV(
RectangleBase< RectangleBase> bounds, [Vector3Base<Vector3Base, MatrixBase, QuaternionBase, Vector4Base> ? colorHsv]) → String -
GuiComboBox(
RectangleBase< RectangleBase> bounds, String? text, num active) → String -
GuiDisable(
) → String -
GuiDisableTooltip(
) → String -
GuiDrawIcon(
GuiIconName iconId, num posX, num posY, num pixelSize, ColorBase< ColorBase> color) → String -
GuiDropdownBox(
RectangleBase< RectangleBase> bounds, String? text, num active, bool editMode) → String -
GuiDummyRec(
RectangleBase< RectangleBase> bounds, String? text) → String -
GuiEnable(
) → String -
GuiEnableTooltip(
) → String -
GuiGetFont(
) → String -
GuiGetIcons(
) → String -
GuiGetState(
) → String -
GuiGetStyle(
GuiControl control, GuiProperty property) → String -
GuiGetTextWidth(
String? text) → String -
GuiGrid(
RectangleBase< RectangleBase> bounds, num spacing, num subdivs, [Vector2Base<Vector2Base< ? mouseCell]) → Stringdynamic, MatrixBase, Vector3Base, QuaternionBase, Vector4Base> , MatrixBase, Vector3Base, QuaternionBase, Vector4Base> -
GuiGroupBox(
RectangleBase< RectangleBase> bounds, String? text) → String -
GuiIconText(
GuiIconName iconId, String? text) → String -
GuiIsLocked(
) → String -
GuiLabel(
RectangleBase< RectangleBase> bounds, String? text) → String -
GuiLabelButton(
RectangleBase< RectangleBase> bounds, String? text) → String -
GuiLine(
RectangleBase< RectangleBase> bounds, String? text) → String -
GuiListView(
RectangleBase< RectangleBase> bounds, String? text, {int? scrollIndex, int? active}) → String -
GuiListViewEx(
RectangleBase< RectangleBase> bounds, List<String> text, {int? scrollIndex, int? active, int? focus}) → String -
GuiLoadIcons(
String fileName, bool loadIconsName) → String -
GuiLoadStyle(
String fileName) → String -
GuiLoadStyleDefault(
) → String -
GuiLock(
) → String -
GuiMessageBox(
RectangleBase< RectangleBase> bounds, String? title, String message, String buttons) → String -
GuiPanel(
RectangleBase< RectangleBase> bounds, String? text) → String -
GuiProgressBar(
RectangleBase< RectangleBase> bounds, String? textLeft, String? textRight, num value, num minValue, num maxValue) → String -
GuiScrollPanel(
RectangleBase< RectangleBase> bounds, String? text, RectangleBase<RectangleBase> content, Vector2Base<Vector2Base< scroll, [RectangleBase<dynamic, MatrixBase, Vector3Base, QuaternionBase, Vector4Base> , MatrixBase, Vector3Base, QuaternionBase, Vector4Base>RectangleBase> ? view]) → String -
GuiSetAlpha(
num alpha) → String -
GuiSetFont(
FontBase< FontBase< font) → Stringdynamic, TextureBase, RectangleBase, GlyphInfoBase< , TextureBase, RectangleBase, GlyphInfoBase<dynamic, ImageBase> , ImageBase>dynamic, ImageBase> , ImageBase> -
GuiSetIconScale(
num scale) → String -
GuiSetState(
GuiState state) → String -
GuiSetStyle(
GuiControl control, GuiProperty property, num value) → String -
GuiSetTooltip(
String? tooltip) → String -
GuiSlider(
RectangleBase< RectangleBase> bounds, String? textLeft, String? textRight, num value, num minValue, num maxValue) → String -
GuiSliderBar(
RectangleBase< RectangleBase> bounds, String? textLeft, String? textRight, num value, num minValue, num maxValue) → String -
GuiSpinner(
RectangleBase< RectangleBase> bounds, String? text, num value, num minValue, num maxValue, bool editMode) → String -
GuiStatusBar(
RectangleBase< RectangleBase> bounds, String? text) → String -
GuiTabBar(
RectangleBase< RectangleBase> bounds, List<String> text) → String -
GuiTextBox(
RectangleBase< RectangleBase> bounds, String? text, num textSize, bool editMode) → String -
GuiTextInputBox(
RectangleBase< RectangleBase> bounds, String? title, String? message, String buttons, String? text, num textMaxSize, bool? secretViewActive) → String -
GuiToggle(
RectangleBase< RectangleBase> bounds, String? text, bool active) → String -
GuiToggleGroup(
RectangleBase< RectangleBase> bounds, String? text, num active) → String -
GuiToggleSlider(
RectangleBase< RectangleBase> bounds, String? text, num active) → String -
GuiUnlock(
) → String -
GuiValueBox(
RectangleBase< RectangleBase> bounds, String? text, num value, num minValue, num maxValue, bool editMode) → String -
GuiValueBoxFloat(
RectangleBase< RectangleBase> bounds, String? text, String textValue, num value, bool editMode) → String -
GuiWindowBox(
RectangleBase< RectangleBase> bounds, String? title) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited