operator []= method
Sets the value at the given index in the list to value.
The index must be a valid index of this list,
which means that index must be non-negative and
less than length.
Implementation
@override
operator []=(int index, E value) {
_inner[index] = value;
onElementSet(index, value);
}