scale static method
Returns a scaling matrix for the given x, y, z factors.
Implementation
static MatrixBase scale(double x, double y, double z) => createFactory(
x, 0, 0, 0,
0, y, 0, 0,
0, 0, z, 0,
0, 0, 0, 1,
);
Returns a scaling matrix for the given x, y, z factors.
static MatrixBase scale(double x, double y, double z) => createFactory(
x, 0, 0, 0,
0, y, 0, 0,
0, 0, z, 0,
0, 0, 0, 1,
);