RaylibRlglModuleBase<R extends RaylibBase, MatrixStructType extends MatrixBase<MatrixStructType, Vector3StructType, QuaternionStructType, Vector4StructType>, QuaternionStructType extends QuaternionBase<QuaternionStructType, MatrixStructType, Vector3StructType, Vector4StructType>, RlDrawCallStructType extends RlDrawCallBase<RlDrawCallStructType>, RlRenderBatchStructType extends RlRenderBatchBase<RlRenderBatchStructType, RlVertexBufferStructType, RlDrawCallStructType>, RlVertexBufferStructType extends RlVertexBufferBase<RlVertexBufferStructType>, Vector3StructType extends Vector3Base<Vector3StructType, MatrixStructType, QuaternionStructType, Vector4StructType>, Vector4StructType extends Vector4Base<Vector4StructType, QuaternionStructType, MatrixStructType, Vector3StructType>> class abstract

Backend-agnostic contract for the Raylib Rlgl module.

Concrete platform implementations mix in or extend this to provide the full Core API surface across different backends.

Inheritance
Mixed-in types
Implementers

Constructors

RaylibRlglModuleBase(R rl)

Properties

hashCode int
The hash code for this object.
no setterinherited
RaylibCaptureIds RaylibRlglModuleCaptureIds
Capture ID generator for pointer slots allocated by this module.
final
RaylibDebugLabels RaylibRlglModuleDebugLabels
Debug label generator for this module's function calls.
final
rl → R
finalinherited
RL_BLEND_COLOR int
no setterinherited
RL_BLEND_DST_ALPHA int
no setterinherited
RL_BLEND_DST_RGB int
no setterinherited
RL_BLEND_EQUATION int
no setterinherited
RL_BLEND_EQUATION_ALPHA int
no setterinherited
RL_BLEND_EQUATION_RGB int
no setterinherited
RL_BLEND_SRC_ALPHA int
no setterinherited
RL_BLEND_SRC_RGB int
no setterinherited
RL_COMPUTE_SHADER int
no setterinherited
RL_CONSTANT_ALPHA int
no setterinherited
RL_CONSTANT_COLOR int
no setterinherited
RL_CULL_DISTANCE_FAR double
no setterinherited
RL_CULL_DISTANCE_NEAR double
no setterinherited
RL_DEFAULT_BATCH_BUFFER_ELEMENTS int
no setterinherited
RL_DEFAULT_BATCH_BUFFERS int
no setterinherited
RL_DEFAULT_BATCH_DRAWCALLS int
no setterinherited
RL_DEFAULT_BATCH_MAX_TEXTURE_UNITS int
no setterinherited
RL_DEFAULT_SHADER_ATTRIB_LOCATION_BONEIDS int
no setterinherited
RL_DEFAULT_SHADER_ATTRIB_LOCATION_BONEWEIGHTS int
no setterinherited
RL_DEFAULT_SHADER_ATTRIB_LOCATION_COLOR int
no setterinherited
RL_DEFAULT_SHADER_ATTRIB_LOCATION_INDICES int
no setterinherited
RL_DEFAULT_SHADER_ATTRIB_LOCATION_NORMAL int
no setterinherited
RL_DEFAULT_SHADER_ATTRIB_LOCATION_POSITION int
no setterinherited
RL_DEFAULT_SHADER_ATTRIB_LOCATION_TANGENT int
no setterinherited
RL_DEFAULT_SHADER_ATTRIB_LOCATION_TEXCOORD int
no setterinherited
RL_DEFAULT_SHADER_ATTRIB_LOCATION_TEXCOORD2 int
no setterinherited
RL_DRAW_FRAMEBUFFER int
no setterinherited
RL_DST_ALPHA int
no setterinherited
RL_DST_COLOR int
no setterinherited
RL_DYNAMIC_COPY int
no setterinherited
RL_DYNAMIC_DRAW int
no setterinherited
RL_DYNAMIC_READ int
no setterinherited
RL_FLOAT int
no setterinherited
RL_FRAGMENT_SHADER int
no setterinherited
RL_FUNC_ADD int
no setterinherited
RL_FUNC_REVERSE_SUBTRACT int
no setterinherited
RL_FUNC_SUBTRACT int
no setterinherited
RL_LINES int
no setterinherited
RL_MAX int
no setterinherited
RL_MAX_MATRIX_STACK_SIZE int
no setterinherited
RL_MAX_SHADER_LOCATIONS int
no setterinherited
RL_MIN int
no setterinherited
RL_MODELVIEW int
no setterinherited
RL_ONE int
no setterinherited
RL_ONE_MINUS_CONSTANT_ALPHA int
no setterinherited
RL_ONE_MINUS_CONSTANT_COLOR int
no setterinherited
RL_ONE_MINUS_DST_ALPHA int
no setterinherited
RL_ONE_MINUS_DST_COLOR int
no setterinherited
RL_ONE_MINUS_SRC_ALPHA int
no setterinherited
RL_ONE_MINUS_SRC_COLOR int
no setterinherited
RL_PROJECTION int
no setterinherited
RL_QUADS int
no setterinherited
RL_READ_FRAMEBUFFER int
no setterinherited
RL_SHADER_LOC_MAP_DIFFUSE int
no setterinherited
RL_SHADER_LOC_MAP_SPECULAR int
no setterinherited
RL_SRC_ALPHA int
no setterinherited
RL_SRC_ALPHA_SATURATE int
no setterinherited
RL_SRC_COLOR int
no setterinherited
RL_STATIC_COPY int
no setterinherited
RL_STATIC_DRAW int
no setterinherited
RL_STATIC_READ int
no setterinherited
RL_STREAM_COPY int
no setterinherited
RL_STREAM_DRAW int
no setterinherited
RL_STREAM_READ int
no setterinherited
RL_TEXTURE int
no setterinherited
RL_TEXTURE_FILTER_ANISOTROPIC int
no setterinherited
RL_TEXTURE_FILTER_LINEAR int
no setterinherited
RL_TEXTURE_FILTER_LINEAR_MIP_NEAREST int
no setterinherited
RL_TEXTURE_FILTER_MIP_LINEAR int
no setterinherited
RL_TEXTURE_FILTER_MIP_NEAREST int
no setterinherited
RL_TEXTURE_FILTER_NEAREST int
no setterinherited
RL_TEXTURE_FILTER_NEAREST_MIP_LINEAR int
no setterinherited
RL_TEXTURE_MAG_FILTER int
no setterinherited
RL_TEXTURE_MIN_FILTER int
no setterinherited
RL_TEXTURE_MIPMAP_BIAS_RATIO int
no setterinherited
RL_TEXTURE_WRAP_CLAMP int
no setterinherited
RL_TEXTURE_WRAP_MIRROR_CLAMP int
no setterinherited
RL_TEXTURE_WRAP_MIRROR_REPEAT int
no setterinherited
RL_TEXTURE_WRAP_REPEAT int
no setterinherited
RL_TEXTURE_WRAP_S int
no setterinherited
RL_TEXTURE_WRAP_T int
no setterinherited
RL_TRIANGLES int
no setterinherited
RL_UNSIGNED_BYTE int
no setterinherited
RL_VERTEX_SHADER int
no setterinherited
RL_ZERO int
no setterinherited
RLGL_VERSION String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

debug(bool v) → void
Enables or disables debug logging for this module.
inherited
debugError(String message) → void
Logs message at error level if debug is enabled and message passes all filters.
inherited
debugFilter(bool filter(String)) → void
Adds a predicate that gates debug output. Only messages satisfying at least one filter are logged.
inherited
debugInfo(String message) → void
Logs message at info level if debug is enabled and message passes all filters.
inherited
debugTime(bool v) → void
Enables or disables per-call timing output alongside debug logs.
inherited
debugWarn(String message) → void
Logs message at warn level if debug is enabled and message passes all filters.
inherited
disableSync<T>(T f()) → T
Executes f with RaylibTempBase syncing temporarily disabled, restoring the previous sync state afterward.
inherited
dispose() → void
Calls all registered onDispose callbacks and clears them.
inherited
doLoad() → void
Ensures load is called exactly once, regardless of how many times doLoad is invoked.
inherited
load() → void
Override to perform one-time module initialization. Called by doLoad.
inherited
logError(Object? message) → void
inherited
logInfo(Object? message) → void
inherited
logWarn(Object? message) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose(void fn()) → void
Registers fn to be called when this module is disposed.
inherited
rlActiveDrawBuffers(num count) → void
rlActiveTextureSlot(num slot) → void
rlBegin(RlDrawMode mode) → void
rlBindFramebuffer(num target, num framebuffer) → void
rlBindImageTexture(num id, num index, PixelFormat format, bool readonly) → void
rlBindShaderBuffer(num id, num index) → void
rlBlitFramebuffer(num srcX, num srcY, num srcWidth, num srcHeight, num dstX, num dstY, num dstWidth, num dstHeight, num bufferMask) → void
rlCheckErrors() → void
rlCheckRenderBatchLimit(num vCount) bool
rlClearColor(num r, num g, num b, num a) → void
rlClearScreenBuffers() → void
rlColor3f(num x, num y, num z) → void
rlColor4f(num x, num y, num z, num w) → void
rlColor4ub(num r, num g, num b, num a) → void
rlColorMask(bool r, bool g, bool b, bool a) → void
rlCompileShader(String shaderCode, RlShaderType type) int
rlComputeShaderDispatch(num groupX, num groupY, num groupZ) → void
rlCopyShaderBuffer(num destId, num srcId, num destOffset, num srcOffset, num count) → void
rlCubemapParameters(num id, num param, num value) → void
rlDisableBackfaceCulling() → void
rlDisableColorBlend() → void
rlDisableDepthMask() → void
rlDisableDepthTest() → void
rlDisableFramebuffer() → void
rlDisableScissorTest() → void
rlDisableShader() → void
rlDisableSmoothLines() → void
rlDisableStereoRender() → void
rlDisableTexture() → void
rlDisableTextureCubemap() → void
rlDisableVertexArray() → void
rlDisableVertexAttribute(num index) → void
rlDisableVertexBuffer() → void
rlDisableVertexBufferElement() → void
rlDisableWireMode() → void
rlDrawRenderBatch(RlRenderBatchStructType batch) → void
rlDrawRenderBatchActive() → void
rlDrawVertexArray(num offset, num count) → void
rlDrawVertexArrayElements(num offset, num count, Uint16List buffer) → void
rlDrawVertexArrayElementsInstanced(num offset, num count, Uint16List buffer, num instances) → void
rlDrawVertexArrayInstanced(num offset, num count, num instances) → void
rlEnableBackfaceCulling() → void
rlEnableColorBlend() → void
rlEnableDepthMask() → void
rlEnableDepthTest() → void
rlEnableFramebuffer(num id) → void
rlEnablePointMode() → void
rlEnableScissorTest() → void
rlEnableShader(num id) → void
rlEnableSmoothLines() → void
rlEnableStereoRender() → void
rlEnableTexture(num id) → void
rlEnableTextureCubemap(num id) → void
rlEnableVertexArray(num vaoId) bool
rlEnableVertexAttribute(num index) → void
rlEnableVertexBuffer(num id) → void
rlEnableVertexBufferElement(num id) → void
rlEnableWireMode() → void
rlEnd() → void
rlFramebufferAttach(num fboId, num texId, RlFramebufferAttachType attachType, RlFramebufferAttachTextureType texType, num mipLevel) → void
rlFramebufferComplete(num id) bool
rlFrustum(num left, num right, num bottom, num top, num znear, num zfar) → void
rlGenTextureMipmaps(num id, num width, num height, PixelFormat format) int
rlGetActiveFramebuffer() int
rlGetCullDistanceFar() double
rlGetCullDistanceNear() double
rlGetFramebufferHeight() int
rlGetFramebufferWidth() int
rlGetGlTextureFormats(PixelFormat format) → (int, int, int)
rlGetLineWidth() double
rlGetLocationAttrib(num shaderId, String attribName) int
rlGetLocationUniform(num shaderId, String uniformName) int
rlGetMatrixModelview() → MatrixStructType
rlGetMatrixProjection() → MatrixStructType
rlGetMatrixProjectionStereo(num eye) → MatrixStructType
rlGetMatrixTransform() → MatrixStructType
rlGetMatrixViewOffsetStereo(num eye) → MatrixStructType
rlGetPixelFormatName(PixelFormat format) String
rlGetShaderBufferSize(num id) int
rlGetShaderIdDefault() int
rlGetShaderLocsDefault() List<int>
rlGetTextureIdDefault() int
rlGetVersion() int
rlglClose() → void
rlglInit(num width, num height) → void
rlIsStereoRenderEnabled() bool
rlLoadComputeShaderProgram(num shaderId) int
rlLoadDrawCube() → void
rlLoadDrawQuad() → void
rlLoadFramebuffer() int
rlLoadIdentity() → void
rlLoadRenderBatch(num numBuffers, num bufferElements) → RlRenderBatchStructType
rlLoadShaderBuffer(num size, TypedDataList? data, RlUsageHint? usageHint) int
rlLoadShaderCode(String? vsCode, String? fsCode) int
rlLoadShaderProgram(num vShaderId, num fShaderId) int
rlLoadTexture(Uint8List? data, num width, num height, PixelFormat format, num mipmapCount) int
rlLoadTextureCubemap(Uint8List? data, num size, PixelFormat format, num mipmapCount) int
rlLoadTextureDepth(num width, num height, bool useRenderBuffer) int
rlLoadVertexArray() int
rlLoadVertexBuffer(TypedDataList buffer, bool dynamic) int
rlLoadVertexBufferElement(TypedDataList buffer, bool dynamic) int
rlMatrixMode(RlMatrixMode mode) → void
rlMultMatrixf(List<double> matf) → void
rlNormal3f(num x, num y, num z) → void
rlOrtho(num left, num right, num bottom, num top, num znear, num zfar) → void
rlPopMatrix() → void
rlPushMatrix() → void
rlReadScreenPixels(num width, num height) Uint8List
rlReadShaderBuffer(num id, num count, num offset) Uint8List
rlReadTexturePixels(num id, num width, num height, PixelFormat format) Uint8List
rlRotatef(num angle, num x, num y, num z) → void
rlScalef(num x, num y, num z) → void
rlScissor(num x, num y, num width, num height) → void
rlSetBlendFactors(num glSrcFactor, num glDstFactor, num glEquation) → void
rlSetBlendFactorsSeparate(num glSrcRGB, num glDstRGB, num glSrcAlpha, num glDstAlpha, num glEqRGB, num glEqAlpha) → void
rlSetBlendMode(BlendMode mode) → void
rlSetClipPlanes(num nearPlane, num farPlane) → void
rlSetCullFace(RlCullMode mode) → void
rlSetFramebufferHeight(num height) → void
rlSetFramebufferWidth(num width) → void
rlSetLineWidth(num width) → void
rlSetMatrixModelview(MatrixStructType view) → void
rlSetMatrixProjection(MatrixStructType proj) → void
rlSetMatrixProjectionStereo(MatrixStructType right, MatrixStructType left) → void
rlSetMatrixViewOffsetStereo(MatrixStructType right, MatrixStructType left) → void
rlSetRenderBatchActive(RlRenderBatchStructType batch) → void
rlSetShader(num id, List<int> locs) → void
rlSetTexture(num id) → void
rlSetUniform(num locIndex, TypedDataList value, RlShaderUniformDataType uniformType, num count) → void
rlSetUniformMatrices(num locIndex, List<MatrixStructType> mat) → void
rlSetUniformMatrix(num locIndex, MatrixStructType mat) → void
rlSetUniformSampler(num locIndex, num textureId) → void
rlSetVertexAttribute(num index, num compSize, num type, bool normalized, num stride, num offset) → void
rlSetVertexAttributeDefault(num locIndex, Float32List value, RlShaderAttributeDataType attribType) → void
rlSetVertexAttributeDivisor(num index, num divisor) → void
rlTexCoord2f(num x, num y) → void
rlTextureParameters(num id, num param, num value) → void
rlTranslatef(num x, num y, num z) → void
rlUnloadFramebuffer(num id) → void
rlUnloadRenderBatch(RlRenderBatchStructType batch) → void
rlUnloadShaderBuffer(num ssboId) → void
rlUnloadShaderProgram(num id) → void
rlUnloadTexture(num id) → void
rlUnloadVertexArray(num vaoId) → void
rlUnloadVertexBuffer(num vboId) → void
rlUpdateShaderBuffer(num id, TypedDataList data, num offset) → void
rlUpdateTexture(num id, num offsetX, num offsetY, num width, num height, PixelFormat format, Uint8List data) → void
rlUpdateVertexBuffer(num bufferId, TypedDataList data, num offset) → void
rlUpdateVertexBufferElements(num id, TypedDataList data, num offset) → void
rlVertex2f(num x, num y) → void
rlVertex2i(num x, num y) → void
rlVertex3f(num x, num y, num z) → void
rlViewport(num x, num y, num width, num height) → void
run<T>(String name(), T f()) → T
Executes f, logging its label (and optionally timing it) when debug is enabled and the label passes all filters.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited