structAllocateInto abstract method
Allocates nested pointers into temp under key as needed.
Implementation
void structAllocateInto(T temp, P p, String key);
Allocates nested pointers into temp under key as needed.
void structAllocateInto(T temp, P p, String key);