clone abstract method
T
clone()
Returns a deep copy of this instance, preserving RaylibStructBase.originalPointer if present.
Implementation
T clone();
Returns a deep copy of this instance, preserving RaylibStructBase.originalPointer if present.
T clone();