stringCount property
The number of string slots to pre-allocate.
Defaults to 4. Increase this if your frame logic needs to pass
more than 4 temporary strings to Raylib in a single tick.
Implementation
final int stringCount;
The number of string slots to pre-allocate.
Defaults to 4. Increase this if your frame logic needs to pass
more than 4 temporary strings to Raylib in a single tick.
final int stringCount;