RawArray method
Allocates an unslotted array.
The caller is responsible for freeing the returned pointer.
Implementation
P RawArray(List<X> array) => Raw(array.length);
Allocates an unslotted array.
The caller is responsible for freeing the returned pointer.
P RawArray(List<X> array) => Raw(array.length);