Unslot method

void Unslot(
  1. String key
)
inherited

Removes the slot entry for key from the table without freeing the underlying memory.

Use when ownership of the pointer has been transferred elsewhere.

Implementation

void Unslot(String key) => slots.remove(slotKey(key));