asView property
Wraps ptr as a Dart TypedDataList of length elements.
The list is a view into native memory, so mutations are reflected immediately in the native buffer.
Implementation
L Function(S ptr, int length) get asView;
Wraps ptr as a Dart TypedDataList of length elements.
The list is a view into native memory, so mutations are reflected immediately in the native buffer.
L Function(S ptr, int length) get asView;