Array method

P Array(
  1. List<num> array, {
  2. String? key,
})
inherited

Writes array into a slot of sufficient capacity and returns the pointer.

key defaults to 'struct'. The slot is grown automatically if the current capacity is smaller than array.length.

Implementation

P Array(List<X> array, {String? key}) {
  final p = At(slotKey(key), array.length);
  for (int i = 0; i < array.length; i++) indexSetterFunc(p, i, array[i]);
  return p;
}