asDartList property

List<num> Function(S ptr, int length) get asDartList
inherited

Returns a Dart List<X> view over length elements starting at ptr, backed directly by the underlying memory, no copy is made.

Implementation

List<X> Function(S ptr, int length) get asDartList;