asView property

L Function(S ptr, int length) get asView
inherited

Wraps ptr as a Dart TypedDataList of length elements.

The list is a view into native memory, so mutations are reflected immediately in the native buffer.

Implementation

L Function(S ptr, int length) get asView;