uniqueSlotKey method

String uniqueSlotKey(
  1. String key
)
inherited

Returns a slot key guaranteed to be unique within this temp context, by prefixing key with the next available ID.

Implementation

String uniqueSlotKey(String key) => '${temp.nextId()}_$key';