Slot method
Returns the pointer stored under key, or null if the slot does not
exist. Does not allocate.
Implementation
P? Slot(String key) => slots[slotKey(key)]?.$1;
Returns the pointer stored under key, or null if the slot does not
exist. Does not allocate.
P? Slot(String key) => slots[slotKey(key)]?.$1;