reset method

void reset()

Resets all slot bookkeeping structures to their initial state.

Called during construction and at the end of dispose.

Implementation

void reset() {
  // NOTE: needs to be growable
  stringSlots = .filled(slotCount, nullptrFactory(), growable: true);
  stringCapacities = .filled(slotCount, 0, growable: true);
  stringAnonIndex = 0;
}