signature method
Returns a string that identifies the concrete type of this allocator, including its type parameters.
Implementation
String signature() => runtimeType.toString();
Returns a string that identifies the concrete type of this allocator, including its type parameters.
String signature() => runtimeType.toString();