Raw method
Allocates count raw elements and returns the wrapped pointer.
Implementation
P Raw([int count = 1]) => pointerFactory(allocatorFunc(count));
Allocates count raw elements and returns the wrapped pointer.
P Raw([int count = 1]) => pointerFactory(allocatorFunc(count));