indexerFunc property
V Function(P ptr, int i)
get
indexerFunc
Returns the C struct at index i of the array at ptr.
Implementation
V Function(P ptr, int i) get indexerFunc;
Returns the C struct at index i of the array at ptr.
V Function(P ptr, int i) get indexerFunc;