pointerToStruct property
X Function(P ptr)
get
pointerToStruct
Converts a P to its Dart-side X wrapper, referencing the memory at that pointer.
Implementation
X Function(P ptr) get pointerToStruct;
Converts a P to its Dart-side X wrapper, referencing the memory at that pointer.
X Function(P ptr) get pointerToStruct;