updateFunc property
void Function(P ptr, X source)
get
updateFunc
Copies the fields of source into the native memory at ptr.
Implementation
void Function(P ptr, X source) get updateFunc;
Copies the fields of source into the native memory at ptr.
void Function(P ptr, X source) get updateFunc;