writeIntoFunc property
void Function(P ptr, X value)
get
writeIntoFunc
Writes the Dart value value into the struct at ptr.
Implementation
void Function(P ptr, X value) get writeIntoFunc;
Writes the Dart value value into the struct at ptr.
void Function(P ptr, X value) get writeIntoFunc;