RawArray method
Allocates an unslotted array.
The caller is responsible for freeing the returned pointer.
Implementation
PP RawArray(List<X> array) => Raw(array.length);
Allocates an unslotted array.
The caller is responsible for freeing the returned pointer.
PP RawArray(List<X> array) => Raw(array.length);