allocatorFunc property
Allocates count elements and returns the raw source pointer.
Implementation
final S Function([int count]) allocatorFunc;
Allocates count elements and returns the raw source pointer.
final S Function([int count]) allocatorFunc;