pointerToSource property
S Function(PP ptr)
pointerToSource
finalinherited
Unwraps a platform pointer ptr back to its source type S.
Implementation
final S Function(P ptr) pointerToSource;
Unwraps a platform pointer ptr back to its source type S.
final S Function(P ptr) pointerToSource;