rawArrayFunc property
P Function(List<X> array)
get
rawArrayFunc
Converts a List<D> of Dart struct wrappers into an allocated P array.
Implementation
P Function(List<X> array) get rawArrayFunc;
Converts a List<D> of Dart struct wrappers into an allocated P array.
P Function(List<X> array) get rawArrayFunc;