isFirstSync property

bool isFirstSync
getter/setter pair

Whether RaylibTempStructAllocatorBase.PointerTo has never been called for this instance.

Used to skip the sync step on the first RaylibTempStructAllocatorBase.PointerTo allocation, since there is no prior native state to read back yet.

Implementation

bool isFirstSync = true;