RaylibVector2Factories class

Backend-agnostic factory hub for Vector2Base construction.

zeroFactory and createFactory are injected by the concrete backend package before use (e.g. RaylibVector2Factories.createFactory = Vector2D.vec2).

Constructors

RaylibVector2Factories()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

createFactory Vector2Base<Vector2Base<dynamic, MatrixBase, Vector3Base, QuaternionBase, Vector4Base>, MatrixBase, Vector3Base, QuaternionBase, Vector4Base> Function(num x, num y)
Creates a vector from x, y components. Injected by the backend package.
getter/setter pair
zeroFactory Vector2Base<Vector2Base<dynamic, MatrixBase, Vector3Base, QuaternionBase, Vector4Base>, MatrixBase, Vector3Base, QuaternionBase, Vector4Base> Function()
Creates a zero vector (0, 0). Injected by the backend package.
getter/setter pair