RlShaderType enum
Rlgl ShaderType enum.
Values
- RL_FRAGMENT_SHADER → const RlShaderType
-
RL_FRAGMENT_SHADERconst RlShaderType(0x8B30) - RL_VERTEX_SHADER → const RlShaderType
-
RL_VERTEX_SHADERconst RlShaderType(0x8B31) - RL_COMPUTE_SHADER → const RlShaderType
-
RL_COMPUTE_SHADERconst RlShaderType(0x91B9)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
The underlying native integer value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → RlShaderType -
Returns the RlShaderType for the given native
value.
Constants
-
values
→ const List<
RlShaderType> - A constant List of the values in this enum, in order of their declaration.