RlShaderUniformDataType enum

Rlgl ShaderUniformDataType enum.

Inheritance
Available extensions

Values

RL_SHADER_UNIFORM_FLOAT → const RlShaderUniformDataType

RL_SHADER_UNIFORM_FLOAT

const RlShaderUniformDataType(0)
RL_SHADER_UNIFORM_VEC2 → const RlShaderUniformDataType

RL_SHADER_UNIFORM_VEC2

const RlShaderUniformDataType(1)
RL_SHADER_UNIFORM_VEC3 → const RlShaderUniformDataType

RL_SHADER_UNIFORM_VEC3

const RlShaderUniformDataType(2)
RL_SHADER_UNIFORM_VEC4 → const RlShaderUniformDataType

RL_SHADER_UNIFORM_VEC4

const RlShaderUniformDataType(3)
RL_SHADER_UNIFORM_INT → const RlShaderUniformDataType

RL_SHADER_UNIFORM_INT

const RlShaderUniformDataType(4)
RL_SHADER_UNIFORM_IVEC2 → const RlShaderUniformDataType

RL_SHADER_UNIFORM_IVEC2

const RlShaderUniformDataType(5)
RL_SHADER_UNIFORM_IVEC3 → const RlShaderUniformDataType

RL_SHADER_UNIFORM_IVEC3

const RlShaderUniformDataType(6)
RL_SHADER_UNIFORM_IVEC4 → const RlShaderUniformDataType

RL_SHADER_UNIFORM_IVEC4

const RlShaderUniformDataType(7)
RL_SHADER_UNIFORM_UINT → const RlShaderUniformDataType

RL_SHADER_UNIFORM_UINT

const RlShaderUniformDataType(8)
RL_SHADER_UNIFORM_UIVEC2 → const RlShaderUniformDataType

RL_SHADER_UNIFORM_UIVEC2

const RlShaderUniformDataType(9)
RL_SHADER_UNIFORM_UIVEC3 → const RlShaderUniformDataType

RL_SHADER_UNIFORM_UIVEC3

const RlShaderUniformDataType(10)
RL_SHADER_UNIFORM_UIVEC4 → const RlShaderUniformDataType

RL_SHADER_UNIFORM_UIVEC4

const RlShaderUniformDataType(11)
RL_SHADER_UNIFORM_SAMPLER2D → const RlShaderUniformDataType

RL_SHADER_UNIFORM_SAMPLER2D

const RlShaderUniformDataType(12)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
The underlying native integer value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) RlShaderUniformDataType
Returns the RlShaderUniformDataType for the given native value.

Constants

values → const List<RlShaderUniformDataType>
A constant List of the values in this enum, in order of their declaration.