TextureFilter enum
Raylib TextureFilter enum.
Values
- TEXTURE_FILTER_POINT → const TextureFilter
-
TEXTURE_FILTER_POINTconst TextureFilter(0) - TEXTURE_FILTER_BILINEAR → const TextureFilter
-
TEXTURE_FILTER_BILINEARconst TextureFilter(1) - TEXTURE_FILTER_TRILINEAR → const TextureFilter
-
TEXTURE_FILTER_TRILINEARconst TextureFilter(2) - TEXTURE_FILTER_ANISOTROPIC_4X → const TextureFilter
-
TEXTURE_FILTER_ANISOTROPIC_4Xconst TextureFilter(3) - TEXTURE_FILTER_ANISOTROPIC_8X → const TextureFilter
-
TEXTURE_FILTER_ANISOTROPIC_8Xconst TextureFilter(4) - TEXTURE_FILTER_ANISOTROPIC_16X → const TextureFilter
-
TEXTURE_FILTER_ANISOTROPIC_16Xconst TextureFilter(5)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
The underlying native integer value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → TextureFilter -
Returns the TextureFilter for the given native
value.
Constants
-
values
→ const List<
TextureFilter> - A constant List of the values in this enum, in order of their declaration.