equals method

bool equals(
  1. V2 o
)

Returns true if this vector is approximately equal to o.

Uses epsilon-based per-component comparison scaled to the magnitude of the compared values.

Implementation

bool equals(V2 o) =>
  (((x - o.x).abs()) <= (RaylibConstants.EPSILON*math.max(1.0, math.max((x).abs(), (o.x).abs())))) &&
  (((y - o.y).abs()) <= (RaylibConstants.EPSILON*math.max(1.0, math.max((y).abs(), (o.y).abs()))));