invert method
V2
invert()
Returns a new vector with each component replaced by its reciprocal (1/x, 1/y).
Implementation
V2 invert() => _v2(1.0/x, 1.0/y);
Returns a new vector with each component replaced by its reciprocal (1/x, 1/y).
V2 invert() => _v2(1.0/x, 1.0/y);