max method
V2
max(
- V2 o
Returns a new vector with each component being the component-wise maximum of this and o.
Implementation
V2 max(V2 o) => _v2(
math.max(x, o.x),
math.max(y, o.y),
);
Returns a new vector with each component being the component-wise maximum of this and o.
V2 max(V2 o) => _v2(
math.max(x, o.x),
math.max(y, o.y),
);