min method
V2
min(
- V2 o
Returns a new vector with each component being the component-wise minimum of this and o.
Implementation
V2 min(V2 o) => _v2(
math.min(x, o.x),
math.min(y, o.y),
);
Returns a new vector with each component being the component-wise minimum of this and o.
V2 min(V2 o) => _v2(
math.min(x, o.x),
math.min(y, o.y),
);