setD abstract method
V2
setD(
- V2 o
inherited
Copies the fields of o into this instance and returns this.
Implementation
T setD(T o);
Copies the fields of o into this instance and returns this.
T setD(T o);