subValue method
Returns a new vector with value subtracted from each component.
Implementation
V2 subValue(num value) => _v2(x - value, y - value);
Returns a new vector with value subtracted from each component.
V2 subValue(num value) => _v2(x - value, y - value);