orthoNormalize method

V3 orthoNormalize(
  1. V3 o
)

Orthonormalizes this vector against o using the Gram-Schmidt process.

Normalizes this in place via setD, then returns a vector perpendicular to the normalized this in the plane of this and o.

Implementation

V3 orthoNormalize(V3 o) {
  final n1 = normalize();
  final vn1 = n1.crossProduct(o).normalize();
  setD(n1);
  return vn1.crossProduct(n1);
}