subValue method
Returns a new vector with value subtracted from each component.
Implementation
V3 subValue(num value) => _v3(x - value, y - value, z - value);
Returns a new vector with value subtracted from each component.
V3 subValue(num value) => _v3(x - value, y - value, z - value);