subValue method
Returns a new vector with value subtracted from each component.
Implementation
V4 subValue(num value) => _v4(x - value, y - value, z - value, w - value);
Returns a new vector with value subtracted from each component.
V4 subValue(num value) => _v4(x - value, y - value, z - value, w - value);