CubemapLayout enum

CubemapLayout

Inheritance
Mixed-in types
Available extensions

Values

CUBEMAP_LAYOUT_AUTO_DETECT → const CubemapLayout

CUBEMAP_LAYOUT_AUTO_DETECT

const CubemapLayout(0)
CUBEMAP_LAYOUT_LINE_VERTICAL → const CubemapLayout

CUBEMAP_LAYOUT_LINE_VERTICAL

const CubemapLayout(1)
CUBEMAP_LAYOUT_LINE_HORIZONTAL → const CubemapLayout

CUBEMAP_LAYOUT_LINE_HORIZONTAL

const CubemapLayout(2)
CUBEMAP_LAYOUT_CROSS_THREE_BY_FOUR → const CubemapLayout

CUBEMAP_LAYOUT_CROSS_THREE_BY_FOUR

const CubemapLayout(3)
CUBEMAP_LAYOUT_CROSS_FOUR_BY_THREE → const CubemapLayout

CUBEMAP_LAYOUT_CROSS_FOUR_BY_THREE

const CubemapLayout(4)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
The underlying native integer value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator <(RaylibEnum other) → bool
inherited
operator <=(RaylibEnum other) → bool
inherited
operator ==(Object other) → bool
The equality operator.
inherited
operator >(RaylibEnum other) → bool
inherited
operator >=(RaylibEnum other) → bool
inherited

Static Methods

fromValue(int value) → CubemapLayout
Returns the CubemapLayout for the given native value.

Constants

values → const List<CubemapLayout>
A constant List of the values in this enum, in order of their declaration.