GuiState enum

GuiState

Gui control state

Inheritance
Mixed-in types
Available extensions

Values

STATE_NORMAL → const GuiState

STATE_NORMAL

const GuiState(0)
STATE_FOCUSED → const GuiState

STATE_FOCUSED

const GuiState(1)
STATE_PRESSED → const GuiState

STATE_PRESSED

const GuiState(2)
STATE_DISABLED → const GuiState

STATE_DISABLED

const GuiState(3)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
The underlying native integer value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator <(RaylibEnum other) → bool
inherited
operator <=(RaylibEnum other) → bool
inherited
operator ==(Object other) → bool
The equality operator.
inherited
operator >(RaylibEnum other) → bool
inherited
operator >=(RaylibEnum other) → bool
inherited

Static Methods

fromValue(int value) → GuiState
Returns the GuiState for the given native value.

Constants

values → const List<GuiState>
A constant List of the values in this enum, in order of their declaration.