LightD class
Light
- Inheritance
-
- Object
- RaylibStruct<
LightD> - LightD
Constructors
-
LightD({StructPointer<
LightD> ? op, LightType type = .LIGHT_POINT, bool enabled = false, Vector3D? position, Vector3D? target, ColorD? color, double attenuation = 0, int enabledLoc = 0, int typeLoc = 0, int positionLoc = 0, int targetLoc = 0, int colorLoc = 0, int attenuationLoc = 0}) - LightD.zero()
-
factory
Properties
- $state → RaylibTempStructState
-
Per-instance allocation state tracking slot keys, disposal, and identity.
finalinherited
- attenuation ↔ double
-
Light attenuation factor (falloff over distance)
getter/setter pair
- attenuationLoc ↔ int
-
Shader location for attenuation
getter/setter pair
- color ↔ ColorD
-
Light color
getter/setter pair
- colorLoc ↔ int
-
Shader location for color
getter/setter pair
- enabled ↔ bool
-
Whether the light is currently active
getter/setter pair
- enabledLoc ↔ int
-
Shader location for enabled
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
op
↔ StructPointer<
LightD> ? -
The C-owned or RaylibTemp-owned typed pointer for this struct, if any.
getter/setter pairinherited
- position ↔ Vector3D
-
Light position in world space
getter/setter pair
- positionLoc ↔ int
-
Shader location for position
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- structIsDisposed → bool
-
Whether structMarkDisposed has been called on this instance.
no setterinherited
- structName → String
-
The Dart-side type name of this struct
no setterinherited
- target ↔ Vector3D
-
Light target direction (used for directional lights)
getter/setter pair
- targetLoc ↔ int
-
Shader location for target
getter/setter pair
- type ↔ LightType
-
Light type (directional or point)
getter/setter pair
- typeLoc ↔ int
-
Shader location for type
getter/setter pair
Methods
-
clone(
) → LightD -
Returns a deep copy of this instance, preserving op if present.
override
-
copy(
) → LightD -
Returns a deep copy of this instance without op.
inherited
-
getOp(
) → StructPointer< LightD> -
Returns op, throwing a descriptive StateError if unavailable or this instance RaylibTempStructState.isDisposed.
inherited
-
getOpAndDispose(
) → StructPointer< LightD> -
Returns op and immediately disposes this struct.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setDart(
LightD o) → LightD -
Copies the fields of
ointo this instance.override -
signature(
) → String -
Returns a human-readable representation of this struct.
override
-
structAllocateInto(
RaylibTemp< RaylibBase> temp, MemoryPointer<RType> p, String key) → void -
Allocates nested pointers into
tempunderkeyas needed.inherited -
structMarkDisposed(
) → void -
Marks this instance as disposed and clears op.
inherited
-
structOnOp(
void callback(StructPointer< LightD> p)) → void -
Calls
callbackwith op if it is set, otherwise no-ops.inherited -
structReadFrom(
MemoryPointer< RType> p) → void -
override
-
structSetTag(
String newTag) → LightD -
Sets RaylibTempStructState.tag to
newTag.inherited -
structSyncFromMemory(
) → void -
Syncs all fields from the memory. Requires op.
inherited
-
structSyncToMemory(
) → void -
Syncs all fields to the memory. Requires op.
inherited
-
structWriteInto(
MemoryPointer< RType> p) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
field_attenuation
→ StructValueField<
double, RFloat> -
Field descriptor for attenuation.
final
-
field_attenuationLoc
→ StructValueField<
int, RInt> -
Field descriptor for attenuationLoc.
final
-
field_color
→ StructValueField<
ColorD, RStruct> -
Field descriptor for color.
final
-
field_colorLoc
→ StructValueField<
int, RInt> -
Field descriptor for colorLoc.
final
-
field_enabled
→ StructValueField<
bool, RBool> -
Field descriptor for enabled.
final
-
field_enabledLoc
→ StructValueField<
int, RInt> -
Field descriptor for enabledLoc.
final
-
field_position
→ StructValueField<
Vector3D, RStruct> -
Field descriptor for position.
final
-
field_positionLoc
→ StructValueField<
int, RInt> -
Field descriptor for positionLoc.
final
-
field_target
→ StructValueField<
Vector3D, RStruct> -
Field descriptor for target.
final
-
field_targetLoc
→ StructValueField<
int, RInt> -
Field descriptor for targetLoc.
final
-
field_type
→ StructValueField<
int, RInt> -
Field descriptor for type.
final
-
field_typeLoc
→ StructValueField<
int, RInt> -
Field descriptor for typeLoc.
final
-
struct
→ StructType<
LightD> -
Describes the raw memory layout, construction, and pointer representation
of this struct type.
final
-
structLayout
→ StructLayout<
LightField> -
Raw memory layout of this object.
final