RFloat32 class final

IEEE-754 single-precision float. Maps to C float.

Inheritance

Constructors

RFloat32()
const

Properties

alignment → int
Natural alignment for this field, per C rules, arrays align to their element size, not their total size.
no setterinherited
byteSize → int
Size of a single element.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read<V>(MemoryPointer<RType> p, int offset) → V?
Read this RType from a p at given offset.
override
toString() → String
A string representation of this object.
inherited
write<V>(MemoryPointer<RType> p, int offset, V? value) → void
Write a value of RType into a p at given offset.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

scalarByteSize → int
final