RType class sealed
Properties
- alignment → int
-
Natural alignment for this field, per C rules,
arrays align to their element size, not their total size.
no setter
- byteSize → int
-
Size of a single element.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read<
V> (MemoryPointer< RType> p, int offset) → V? -
Read this RType from a
pat givenoffset. -
toString(
) → String -
A string representation of this object.
inherited
-
write<
V> (MemoryPointer< RType> p, int offset, V? value) → void -
Write a
valueof RType into apat givenoffset.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- isNative32Bit → bool
-
no setter
- nativeWordSize ↔ int
-
Must be set once by the concrete backend during initialization,
before any RType byteSize/elementByteSize is computed.
getter/setter pair