init abstract method
void
init(
- R rl
Called once before the app loop starts.
Use this to initialize app state and open the window via RaylibCoreDart.InitWindow.
Implementation
void init(R rl);
Called once before the app loop starts.
Use this to initialize app state and open the window via RaylibCoreDart.InitWindow.
void init(R rl);