RaylibAudioDart<R extends RaylibBase> class final

Backend-agnostic Raylib Audio module.

Inheritance

Constructors

RaylibAudioDart(R rl)

Properties

$ → RaylibTemp<RaylibBase>
See RaylibTemp.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
rl → R
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

AttachAudioMixedProcessor(covariant AudioCallbackBase processor) → void
Attach audio stream processor to the entire audio pipeline, receives the samples as 'float'
AttachAudioStreamProcessor(AudioStreamD stream, covariant AudioCallbackBase processor) → void
Attach audio stream processor to stream, receives the samples as 'float'
CloseAudioDevice() → void
Close the audio device and context
debug(bool v) → void
Enables or disables debug logging for this module.
inherited
debugError(String message) → void
Logs message at error level if debug is enabled and message passes all filters.
inherited
debugFilter(bool filter(String)) → void
Adds a predicate that gates debug output. Only messages satisfying at least one filter are logged.
inherited
debugInfo(String message) → void
Logs message at info level if debug is enabled and message passes all filters.
inherited
debugTime(bool v) → void
Enables or disables per-call timing output alongside debug logs.
inherited
debugWarn(String message) → void
Logs message at warn level if debug is enabled and message passes all filters.
inherited
DetachAudioMixedProcessor(covariant AudioCallbackBase processor, {bool keepAlive = false}) → void
Detach audio stream processor from the entire audio pipeline
DetachAudioStreamProcessor(AudioStreamD stream, covariant AudioCallbackBase processor, {bool keepAlive = false}) → void
Detach audio stream processor from stream
disableSync<T>(T f()) → T
Executes f with RaylibTemp syncing temporarily disabled, restoring the previous sync state afterward.
inherited
dispose() → void
Calls all registered onDispose callbacks and clears them.
inherited
disposeStructWithOpFreed<D extends RaylibStruct<D>>(D struct, void fn(StructPointer<D> ptr)) → void
Disposes struct, invokes fn with its underlying pointer, and then frees the temporary allocation backing the pointer, if any.
inherited
disposeStructWithOpUnslotted<D extends RaylibStruct<D>>(D struct, void fn(StructPointer<D> ptr)) → void
Disposes struct, invokes fn with its underlying pointer, and then unslots the temporary allocation backing the pointer, if any.
inherited
ExportWave(WaveD wave, String fileName) → bool
Export wave data to file, returns true on success
ExportWaveAsCode(WaveD wave, String fileName) → bool
Export wave sample data to code (.h), returns true on success
GetMasterVolume() → double
Get master volume (listener)
GetMusicTimeLength(MusicD music) → double
Get music time length (in seconds)
GetMusicTimePlayed(MusicD music) → double
Get current music time played (in seconds)
InitAudioDevice() → void
Initialize audio device and context
IsAudioDeviceReady() → bool
Check if audio device has been initialized successfully
IsAudioStreamPlaying(AudioStreamD stream) → bool
Check if audio stream is playing
IsAudioStreamProcessed(AudioStreamD stream) → bool
Check if any audio stream buffers requires refill
IsAudioStreamValid(AudioStreamD stream) → bool
Checks if an audio stream is valid (buffers initialized)
IsMusicStreamPlaying(MusicD music) → bool
Check if music is playing
IsMusicValid(MusicD music) → bool
Checks if a music stream is valid (context and buffers initialized)
IsSoundPlaying(SoundD sound) → bool
Check if a sound is currently playing
IsSoundValid(SoundD sound) → bool
Checks if a sound is valid (data loaded and buffers initialized)
IsWaveValid(WaveD wave) → bool
Checks if wave data is valid (data loaded and parameters)
load() → void
Override to perform one-time module initialization.
inherited
LoadAudioStream(int sampleRate, int sampleSize, int channels) → AudioStreamD
Load audio stream (to stream raw audio pcm data)
LoadMusicStream(String fileName) → MusicD
Load music stream from file
LoadMusicStreamFromMemory(String fileType, Uint8List data) → MusicD
Load music stream from data
LoadSound(String fileName) → SoundD
Load sound from file
LoadSoundAlias(SoundD source) → SoundD
Create a new sound that shares the same sample data as the source sound, does not own the sound data
LoadSoundFromWave(WaveD wave) → SoundD
Load sound from wave data
LoadWave(String fileName) → WaveD
Load wave data from file
LoadWaveFromMemory(String fileType, Uint8List fileData) → WaveD
Load wave from memory buffer, fileType refers to extension: i.e. '.wav'
LoadWaveSamples(WaveD wave) → List<double>
Load samples data from wave as a 32bit float data array
logError(Object? message) → void
inherited
logInfo(Object? message) → void
inherited
logWarn(Object? message) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose(void fn()) → void
Registers fn to be called when this module is disposed.
inherited
PauseAudioStream(AudioStreamD stream) → void
Pause audio stream
PauseMusicStream(MusicD music) → void
Pause music playing
PauseSound(SoundD sound) → void
Pause a sound
PlayAudioStream(AudioStreamD stream) → void
Play audio stream
PlayMusicStream(MusicD music) → void
Start music playing
PlaySound(SoundD sound) → void
Play a sound
ResumeAudioStream(AudioStreamD stream) → void
Resume audio stream
ResumeMusicStream(MusicD music) → void
Resume playing paused music
ResumeSound(SoundD sound) → void
Resume a paused sound
run<T>(String name(), T f()) → T
Executes f, logging its label (and optionally timing it) when debug is enabled and the label passes all filters.
inherited
SeekMusicStream(MusicD music, double position) → void
Seek music to a position (in seconds)
SetAudioStreamBufferSizeDefault(int size) → void
Default size for new audio streams
SetAudioStreamCallback(AudioStreamD stream, covariant AudioCallbackBase? callback) → void
Audio thread callback to request new data
SetAudioStreamPan(AudioStreamD stream, double pan) → void
Set pan for a sound (-1.0 left, 0.0 center, 1.0 right)
SetAudioStreamPitch(AudioStreamD stream, double pitch) → void
Set pitch for audio stream (1.0 is base level)
SetAudioStreamVolume(AudioStreamD stream, double volume) → void
Set volume for audio stream (1.0 is max level)
SetMasterVolume(double volume) → void
Set master volume (listener)
SetMusicPan(MusicD music, double pan) → void
Set pan for a music (0.5 is center)
SetMusicPitch(MusicD music, double pitch) → void
Set pitch for a music (1.0 is base level)
SetMusicVolume(MusicD music, double volume) → void
Set volume for music (1.0 is max level)
SetSoundPan(SoundD sound, double pan) → void
Set pan for a sound (0.5 is center)
SetSoundPitch(SoundD sound, double pitch) → void
Set pitch for a sound (1.0 is base level)
SetSoundVolume(SoundD sound, double volume) → void
Set volume for a sound (1.0 is max level)
StopAudioStream(AudioStreamD stream) → void
Stop audio stream
StopMusicStream(MusicD music) → void
Stop music playing
StopSound(SoundD sound) → void
Stop playing a sound
toString() → String
A string representation of this object.
inherited
UnloadAudioStream(AudioStreamD stream) → void
Unload audio stream and free memory
UnloadMusicStream(MusicD music) → void
Unload music stream
UnloadSound(SoundD sound) → void
Unload sound
UnloadSoundAlias(SoundD alias) → void
Unload a sound alias (does not deallocate sample data)
UnloadWave(WaveD wave) → void
Unload wave data
UpdateAudioStream(AudioStreamD stream, TypedDataList data) → void
Update audio stream buffers with data
UpdateMusicStream(MusicD music) → void
Updates buffers for music streaming
UpdateSound(SoundD sound, TypedDataList data, int sampleCount) → void
Update sound buffer with new data
WaveCopy(WaveD wave) → WaveD
Copy a wave to a new wave
WaveCrop(WaveD wave, int initFrame, int finalFrame) → void
Crop a wave to defined frames range
WaveFormat(WaveD wave, int sampleRate, int sampleSize, int channels) → void
Convert wave data to desired format

Operators

operator ==(Object other) → bool
The equality operator.
inherited