RaylibGuiModuleExtras<R extends RaylibBase> mixin

Re-exports RaylibGuiConstants values as instance members, so constants are accessible directly on the module without a class qualifier.

Superclass constraints
Mixin applications

Properties

$ → RaylibTemp<RaylibBase>
See RaylibTemp.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
RAYGUI_COLORBARALPHA_CHECKED_SIZE → int
See RaylibGuiConstants.RAYGUI_COLORBARALPHA_CHECKED_SIZE.
no setter
RAYGUI_GRID_ALPHA → double
See RaylibGuiConstants.RAYGUI_GRID_ALPHA.
no setter
RAYGUI_GROUPBOX_LINE_THICK → int
See RaylibGuiConstants.RAYGUI_GROUPBOX_LINE_THICK.
no setter
RAYGUI_ICON_DATA_ELEMENTS → int
See RaylibGuiConstants.RAYGUI_ICON_DATA_ELEMENTS.
no setter
RAYGUI_ICON_FONT_ATLAS_PADDING → int
See RaylibGuiConstants.RAYGUI_ICON_FONT_ATLAS_PADDING.
no setter
RAYGUI_ICON_MAX_FONT_BACKED → int
See RaylibGuiConstants.RAYGUI_ICON_MAX_FONT_BACKED.
no setter
RAYGUI_ICON_MAX_ICONS → int
See RaylibGuiConstants.RAYGUI_ICON_MAX_ICONS.
no setter
RAYGUI_ICON_MAX_NAME_LENGTH → int
See RaylibGuiConstants.RAYGUI_ICON_MAX_NAME_LENGTH.
no setter
RAYGUI_ICON_SIZE → int
See RaylibGuiConstants.RAYGUI_ICON_SIZE.
no setter
RAYGUI_ICON_TEXT_PADDING → int
See RaylibGuiConstants.RAYGUI_ICON_TEXT_PADDING.
no setter
RAYGUI_ICONS → List<int>
See RaylibGuiConstants.RAYGUI_ICONS.
no setter
RAYGUI_LINE_MARGIN_TEXT → int
See RaylibGuiConstants.RAYGUI_LINE_MARGIN_TEXT.
no setter
RAYGUI_LINE_TEXT_PADDING → int
See RaylibGuiConstants.RAYGUI_LINE_TEXT_PADDING.
no setter
RAYGUI_MAX_CONTROLS → int
See RaylibGuiConstants.RAYGUI_MAX_CONTROLS.
no setter
RAYGUI_MAX_PROPS_BASE → int
See RaylibGuiConstants.RAYGUI_MAX_PROPS_BASE.
no setter
RAYGUI_MAX_PROPS_EXTENDED → int
See RaylibGuiConstants.RAYGUI_MAX_PROPS_EXTENDED.
no setter
RAYGUI_MAX_TEXT_LINES → int
See RaylibGuiConstants.RAYGUI_MAX_TEXT_LINES.
no setter
RAYGUI_MESSAGEBOX_BUTTON_HEIGHT → int
See RaylibGuiConstants.RAYGUI_MESSAGEBOX_BUTTON_HEIGHT.
no setter
RAYGUI_MESSAGEBOX_BUTTON_PADDING → int
See RaylibGuiConstants.RAYGUI_MESSAGEBOX_BUTTON_PADDING.
no setter
RAYGUI_MIN_MOUSE_WHEEL_SPEED → int
See RaylibGuiConstants.RAYGUI_MIN_MOUSE_WHEEL_SPEED.
no setter
RAYGUI_MIN_SCROLLBAR_HEIGHT → int
See RaylibGuiConstants.RAYGUI_MIN_SCROLLBAR_HEIGHT.
no setter
RAYGUI_MIN_SCROLLBAR_WIDTH → int
See RaylibGuiConstants.RAYGUI_MIN_SCROLLBAR_WIDTH.
no setter
RAYGUI_PANEL_BORDER_WIDTH → int
See RaylibGuiConstants.RAYGUI_PANEL_BORDER_WIDTH.
no setter
RAYGUI_SCROLLBAR_LEFT_SIDE → int
See RaylibGuiConstants.RAYGUI_SCROLLBAR_LEFT_SIDE.
no setter
RAYGUI_SCROLLBAR_RIGHT_SIDE → int
See RaylibGuiConstants.RAYGUI_SCROLLBAR_RIGHT_SIDE.
no setter
RAYGUI_TEXTBOX_AUTO_CURSOR_COOLDOWN → int
See RaylibGuiConstants.RAYGUI_TEXTBOX_AUTO_CURSOR_COOLDOWN.
no setter
RAYGUI_TEXTBOX_AUTO_CURSOR_DELAY → int
See RaylibGuiConstants.RAYGUI_TEXTBOX_AUTO_CURSOR_DELAY.
no setter
RAYGUI_TEXTINPUTBOX_BUTTON_HEIGHT → int
See RaylibGuiConstants.RAYGUI_TEXTINPUTBOX_BUTTON_HEIGHT.
no setter
RAYGUI_TEXTINPUTBOX_BUTTON_PADDING → int
See RaylibGuiConstants.RAYGUI_TEXTINPUTBOX_BUTTON_PADDING.
no setter
RAYGUI_TEXTINPUTBOX_HEIGHT → int
See RaylibGuiConstants.RAYGUI_TEXTINPUTBOX_HEIGHT.
no setter
RAYGUI_TOGGLEGROUP_MAX_ITEM_TEXT_SIZE → int
See RaylibGuiConstants.RAYGUI_TOGGLEGROUP_MAX_ITEM_TEXT_SIZE.
no setter
RAYGUI_VALUEBOX_MAX_CHARS → int
See RaylibGuiConstants.RAYGUI_VALUEBOX_MAX_CHARS.
no setter
RAYGUI_VERSION → String
See RaylibGuiConstants.RAYGUI_VERSION.
no setter
RAYGUI_VERSION_MAJOR → int
See RaylibGuiConstants.RAYGUI_VERSION_MAJOR.
no setter
RAYGUI_VERSION_MINOR → int
See RaylibGuiConstants.RAYGUI_VERSION_MINOR.
no setter
RAYGUI_VERSION_PATCH → int
See RaylibGuiConstants.RAYGUI_VERSION_PATCH.
no setter
RAYGUI_WINDOWBOX_CLOSEBUTTON_HEIGHT → int
See RaylibGuiConstants.RAYGUI_WINDOWBOX_CLOSEBUTTON_HEIGHT.
no setter
RAYGUI_WINDOWBOX_STATUSBAR_HEIGHT → int
See RaylibGuiConstants.RAYGUI_WINDOWBOX_STATUSBAR_HEIGHT.
no setter
rl → R
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

debug(bool v) → void
Enables or disables debug logging for this module.
inherited
debugError(String message) → void
Logs message at error level if debug is enabled and message passes all filters.
inherited
debugFilter(bool filter(String)) → void
Adds a predicate that gates debug output. Only messages satisfying at least one filter are logged.
inherited
debugInfo(String message) → void
Logs message at info level if debug is enabled and message passes all filters.
inherited
debugTime(bool v) → void
Enables or disables per-call timing output alongside debug logs.
inherited
debugWarn(String message) → void
Logs message at warn level if debug is enabled and message passes all filters.
inherited
disableSync<T>(T f()) → T
Executes f with RaylibTemp syncing temporarily disabled, restoring the previous sync state afterward.
inherited
dispose() → void
Calls all registered onDispose callbacks and clears them.
inherited
disposeStructWithOpFreed<D extends RaylibStruct<D>>(D struct, void fn(StructPointer<D> ptr)) → void
Disposes struct, invokes fn with its underlying pointer, and then frees the temporary allocation backing the pointer, if any.
inherited
disposeStructWithOpUnslotted<D extends RaylibStruct<D>>(D struct, void fn(StructPointer<D> ptr)) → void
Disposes struct, invokes fn with its underlying pointer, and then unslots the temporary allocation backing the pointer, if any.
inherited
load() → void
Override to perform one-time module initialization.
inherited
logError(Object? message) → void
inherited
logInfo(Object? message) → void
inherited
logWarn(Object? message) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose(void fn()) → void
Registers fn to be called when this module is disposed.
inherited
run<T>(String name(), T f()) → T
Executes f, logging its label (and optionally timing it) when debug is enabled and the label passes all filters.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited