QuaternionFromVector3ToVector3 abstract method
Calculate quaternion based on the rotation from one vector to another
Implementation
QuaternionD QuaternionFromVector3ToVector3(
Vector3D from,
Vector3D to,
);
Calculate quaternion based on the rotation from one vector to another
QuaternionD QuaternionFromVector3ToVector3(
Vector3D from,
Vector3D to,
);