RlShaderAttributeDataType enum

ShaderAttributeDataType

Inheritance
Mixed-in types
Available extensions

Values

RL_SHADER_ATTRIB_FLOAT → const RlShaderAttributeDataType

RL_SHADER_ATTRIB_FLOAT

const RlShaderAttributeDataType(0)
RL_SHADER_ATTRIB_VEC2 → const RlShaderAttributeDataType

RL_SHADER_ATTRIB_VEC2

const RlShaderAttributeDataType(1)
RL_SHADER_ATTRIB_VEC3 → const RlShaderAttributeDataType

RL_SHADER_ATTRIB_VEC3

const RlShaderAttributeDataType(2)
RL_SHADER_ATTRIB_VEC4 → const RlShaderAttributeDataType

RL_SHADER_ATTRIB_VEC4

const RlShaderAttributeDataType(3)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
The underlying native integer value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator <(RaylibEnum other) → bool
inherited
operator <=(RaylibEnum other) → bool
inherited
operator ==(Object other) → bool
The equality operator.
inherited
operator >(RaylibEnum other) → bool
inherited
operator >=(RaylibEnum other) → bool
inherited

Static Methods

fromValue(int value) → RlShaderAttributeDataType
Returns the RlShaderAttributeDataType for the given native value.

Constants

values → const List<RlShaderAttributeDataType>
A constant List of the values in this enum, in order of their declaration.