StructTypes class final

Registry of StructTypes

Constructors

StructTypes()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

of<D extends RaylibStruct<D>>([D? value]) → StructType<D>
Gets the StructType either by type D directly or by infering type from value.
register<D extends RaylibStruct<D>>(StructType<D> type) → void
Registers a StructType under the key D.