Utf32StringPointer extension

on

Methods

toDartString([int? maxLength]) → String

Available on MemoryPointer<RInt32>, provided by the Utf32StringPointer extension

writeString(String text, [int? maxLength, int elementOffset = 0]) → void

Available on MemoryPointer<RInt32>, provided by the Utf32StringPointer extension

Writes text into a buffer field at address + elementOffset*4. If maxLength is null, it's derived from the UTF-32 code unit (rune) length of text (caller is responsible for the field actually being that size).