core/modules/ffi/core/abbr
library
Functions
-
BeginBlendMode(int mode)
→ void
-
See RaylibCore.BeginBlendMode.
-
BeginDrawing()
→ void
-
See RaylibCore.BeginDrawing.
-
BeginMode2D(Camera2DC camera)
→ void
-
See RaylibCore.BeginMode2D.
-
BeginMode3D(Camera3DC camera)
→ void
-
See RaylibCore.BeginMode3D.
-
BeginScissorMode(int x, int y, int width, int height)
→ void
-
See RaylibCore.BeginScissorMode.
-
BeginShaderMode(ShaderC shader)
→ void
-
See RaylibCore.BeginShaderMode.
-
BeginTextureMode(RenderTextureC target)
→ void
-
See RaylibCore.BeginTextureMode.
-
BeginVrStereoMode(VrStereoConfigC config)
→ void
-
See RaylibCore.BeginVrStereoMode.
-
ChangeDirectory(Pointer<Char> dir)
→ bool
-
See RaylibCore.ChangeDirectory.
-
CheckCollisionBoxes(BoundingBoxC box1, BoundingBoxC box2)
→ bool
-
See RaylibCore.CheckCollisionBoxes.
-
CheckCollisionBoxSphere(BoundingBoxC box, Vector3C center, double radius)
→ bool
-
See RaylibCore.CheckCollisionBoxSphere.
-
CheckCollisionCircleLine(Vector2C center, double radius, Vector2C p1, Vector2C p2)
→ bool
-
See RaylibCore.CheckCollisionCircleLine.
-
CheckCollisionCircleRec(Vector2C center, double radius, RectangleC rec)
→ bool
-
See RaylibCore.CheckCollisionCircleRec.
-
CheckCollisionCircles(Vector2C center1, double radius1, Vector2C center2, double radius2)
→ bool
-
See RaylibCore.CheckCollisionCircles.
-
CheckCollisionLines(Vector2C startPos1, Vector2C endPos1, Vector2C startPos2, Vector2C endPos2, Pointer<Vector2C> collisionPoint)
→ bool
-
See RaylibCore.CheckCollisionLines.
-
CheckCollisionPointCircle(Vector2C point, Vector2C center, double radius)
→ bool
-
See RaylibCore.CheckCollisionPointCircle.
-
CheckCollisionPointLine(Vector2C point, Vector2C p1, Vector2C p2, int threshold)
→ bool
-
See RaylibCore.CheckCollisionPointLine.
-
CheckCollisionPointPoly(Vector2C point, Pointer<Vector2C> points, int pointCount)
→ bool
-
See RaylibCore.CheckCollisionPointPoly.
-
CheckCollisionPointRec(Vector2C point, RectangleC rec)
→ bool
-
See RaylibCore.CheckCollisionPointRec.
-
CheckCollisionPointTriangle(Vector2C point, Vector2C p1, Vector2C p2, Vector2C p3)
→ bool
-
See RaylibCore.CheckCollisionPointTriangle.
-
CheckCollisionRecs(RectangleC rec1, RectangleC rec2)
→ bool
-
See RaylibCore.CheckCollisionRecs.
-
CheckCollisionSpheres(Vector3C center1, double radius1, Vector3C center2, double radius2)
→ bool
-
See RaylibCore.CheckCollisionSpheres.
-
ClearBackground(ColorC color)
→ void
-
See RaylibCore.ClearBackground.
-
ClearWindowState(int flags)
→ void
-
See RaylibCore.ClearWindowState.
-
CloseWindow()
→ void
-
See RaylibCore.CloseWindow.
-
CodepointToUTF8(int codepoint, Pointer<Int> utf8Size)
→ Pointer<Char>
-
See RaylibCore.CodepointToUTF8.
-
ColorAlpha(ColorC color, double alpha)
→ ColorC
-
See RaylibCore.ColorAlpha.
-
ColorAlphaBlend(ColorC dst, ColorC src, ColorC tint)
→ ColorC
-
See RaylibCore.ColorAlphaBlend.
-
ColorBrightness(ColorC color, double factor)
→ ColorC
-
See RaylibCore.ColorBrightness.
-
ColorContrast(ColorC color, double contrast)
→ ColorC
-
See RaylibCore.ColorContrast.
-
ColorFromHSV(double hue, double saturation, double value)
→ ColorC
-
See RaylibCore.ColorFromHSV.
-
ColorFromNormalized(Vector4C normalized)
→ ColorC
-
See RaylibCore.ColorFromNormalized.
-
ColorIsEqual(ColorC col1, ColorC col2)
→ bool
-
See RaylibCore.ColorIsEqual.
-
ColorLerp(ColorC color1, ColorC color2, double factor)
→ ColorC
-
See RaylibCore.ColorLerp.
-
ColorNormalize(ColorC color)
→ Vector4C
-
See RaylibCore.ColorNormalize.
-
ColorTint(ColorC color, ColorC tint)
→ ColorC
-
See RaylibCore.ColorTint.
-
ColorToHSV(ColorC color)
→ Vector3C
-
See RaylibCore.ColorToHSV.
-
ColorToInt(ColorC color)
→ int
-
See RaylibCore.ColorToInt.
-
CompressData(Pointer<UnsignedChar> data, int dataSize, Pointer<Int> compDataSize)
→ Pointer<UnsignedChar>
-
See RaylibCore.CompressData.
-
ComputeCRC32(Pointer<UnsignedChar> data, int dataSize)
→ int
-
See RaylibCore.ComputeCRC32.
-
ComputeMD5(Pointer<UnsignedChar> data, int dataSize)
→ Pointer<UnsignedInt>
-
See RaylibCore.ComputeMD5.
-
ComputeSHA1(Pointer<UnsignedChar> data, int dataSize)
→ Pointer<UnsignedInt>
-
See RaylibCore.ComputeSHA1.
-
ComputeSHA256(Pointer<UnsignedChar> data, int dataSize)
→ Pointer<UnsignedInt>
-
See RaylibCore.ComputeSHA256.
-
DecodeDataBase64(Pointer<Char> data, Pointer<Int> outputSize)
→ Pointer<UnsignedChar>
-
See RaylibCore.DecodeDataBase64.
-
DecompressData(Pointer<UnsignedChar> compData, int compDataSize, Pointer<Int> dataSize)
→ Pointer<UnsignedChar>
-
See RaylibCore.DecompressData.
-
DirectoryExists(Pointer<Char> dirPath)
→ bool
-
See RaylibCore.DirectoryExists.
-
DisableCursor()
→ void
-
See RaylibCore.DisableCursor.
-
DisableEventWaiting()
→ void
-
See RaylibCore.DisableEventWaiting.
-
DrawBillboard(Camera3DC camera, TextureC texture, Vector3C position, double scale, ColorC tint)
→ void
-
See RaylibCore.DrawBillboard.
-
DrawBillboardPro(Camera3DC camera, TextureC texture, RectangleC source, Vector3C position, Vector3C up, Vector2C size, Vector2C origin, double rotation, ColorC tint)
→ void
-
See RaylibCore.DrawBillboardPro.
-
DrawBillboardRec(Camera3DC camera, TextureC texture, RectangleC source, Vector3C position, Vector2C size, ColorC tint)
→ void
-
See RaylibCore.DrawBillboardRec.
-
DrawBoundingBox(BoundingBoxC box, ColorC color)
→ void
-
See RaylibCore.DrawBoundingBox.
-
DrawCapsule(Vector3C startPos, Vector3C endPos, double radius, int slices, int rings, ColorC color)
→ void
-
See RaylibCore.DrawCapsule.
-
DrawCapsuleWires(Vector3C startPos, Vector3C endPos, double radius, int slices, int rings, ColorC color)
→ void
-
See RaylibCore.DrawCapsuleWires.
-
DrawCircle(int centerX, int centerY, double radius, ColorC color)
→ void
-
See RaylibCore.DrawCircle.
-
DrawCircle3D(Vector3C center, double radius, Vector3C rotationAxis, double rotationAngle, ColorC color)
→ void
-
See RaylibCore.DrawCircle3D.
-
DrawCircleGradient(Vector2C center, double radius, ColorC inner, ColorC outer)
→ void
-
See RaylibCore.DrawCircleGradient.
-
DrawCircleLines(int centerX, int centerY, double radius, ColorC color)
→ void
-
See RaylibCore.DrawCircleLines.
-
DrawCircleLinesV(Vector2C center, double radius, ColorC color)
→ void
-
See RaylibCore.DrawCircleLinesV.
-
DrawCircleSector(Vector2C center, double radius, double startAngle, double endAngle, int segments, ColorC color)
→ void
-
See RaylibCore.DrawCircleSector.
-
DrawCircleSectorLines(Vector2C center, double radius, double startAngle, double endAngle, int segments, ColorC color)
→ void
-
See RaylibCore.DrawCircleSectorLines.
-
DrawCircleV(Vector2C center, double radius, ColorC color)
→ void
-
See RaylibCore.DrawCircleV.
-
DrawCube(Vector3C position, double width, double height, double length, ColorC color)
→ void
-
See RaylibCore.DrawCube.
-
DrawCubeV(Vector3C position, Vector3C size, ColorC color)
→ void
-
See RaylibCore.DrawCubeV.
-
DrawCubeWires(Vector3C position, double width, double height, double length, ColorC color)
→ void
-
See RaylibCore.DrawCubeWires.
-
DrawCubeWiresV(Vector3C position, Vector3C size, ColorC color)
→ void
-
See RaylibCore.DrawCubeWiresV.
-
DrawCylinder(Vector3C position, double radiusTop, double radiusBottom, double height, int slices, ColorC color)
→ void
-
See RaylibCore.DrawCylinder.
-
DrawCylinderEx(Vector3C startPos, Vector3C endPos, double startRadius, double endRadius, int sides, ColorC color)
→ void
-
See RaylibCore.DrawCylinderEx.
-
DrawCylinderWires(Vector3C position, double radiusTop, double radiusBottom, double height, int slices, ColorC color)
→ void
-
See RaylibCore.DrawCylinderWires.
-
DrawCylinderWiresEx(Vector3C startPos, Vector3C endPos, double startRadius, double endRadius, int sides, ColorC color)
→ void
-
See RaylibCore.DrawCylinderWiresEx.
-
DrawEllipse(int centerX, int centerY, double radiusH, double radiusV, ColorC color)
→ void
-
See RaylibCore.DrawEllipse.
-
DrawEllipseLines(int centerX, int centerY, double radiusH, double radiusV, ColorC color)
→ void
-
See RaylibCore.DrawEllipseLines.
-
DrawEllipseLinesV(Vector2C center, double radiusH, double radiusV, ColorC color)
→ void
-
See RaylibCore.DrawEllipseLinesV.
-
DrawEllipseV(Vector2C center, double radiusH, double radiusV, ColorC color)
→ void
-
See RaylibCore.DrawEllipseV.
-
DrawFPS(int posX, int posY)
→ void
-
See RaylibCore.DrawFPS.
-
DrawGrid(int slices, double spacing)
→ void
-
See RaylibCore.DrawGrid.
-
DrawLine(int startPosX, int startPosY, int endPosX, int endPosY, ColorC color)
→ void
-
See RaylibCore.DrawLine.
-
DrawLine3D(Vector3C startPos, Vector3C endPos, ColorC color)
→ void
-
See RaylibCore.DrawLine3D.
-
DrawLineBezier(Vector2C startPos, Vector2C endPos, double thick, ColorC color)
→ void
-
See RaylibCore.DrawLineBezier.
-
DrawLineDashed(Vector2C startPos, Vector2C endPos, int dashSize, int spaceSize, ColorC color)
→ void
-
See RaylibCore.DrawLineDashed.
-
DrawLineEx(Vector2C startPos, Vector2C endPos, double thick, ColorC color)
→ void
-
See RaylibCore.DrawLineEx.
-
DrawLineStrip(Pointer<Vector2C> points, int pointCount, ColorC color)
→ void
-
See RaylibCore.DrawLineStrip.
-
DrawLineV(Vector2C startPos, Vector2C endPos, ColorC color)
→ void
-
See RaylibCore.DrawLineV.
-
DrawMesh(MeshC mesh, MaterialC material, MatrixC transform)
→ void
-
See RaylibCore.DrawMesh.
-
DrawMeshInstanced(MeshC mesh, MaterialC material, Pointer<MatrixC> transforms, int instances)
→ void
-
See RaylibCore.DrawMeshInstanced.
-
DrawModel(ModelC model, Vector3C position, double scale, ColorC tint)
→ void
-
See RaylibCore.DrawModel.
-
DrawModelEx(ModelC model, Vector3C position, Vector3C rotationAxis, double rotationAngle, Vector3C scale, ColorC tint)
→ void
-
See RaylibCore.DrawModelEx.
-
DrawModelWires(ModelC model, Vector3C position, double scale, ColorC tint)
→ void
-
See RaylibCore.DrawModelWires.
-
DrawModelWiresEx(ModelC model, Vector3C position, Vector3C rotationAxis, double rotationAngle, Vector3C scale, ColorC tint)
→ void
-
See RaylibCore.DrawModelWiresEx.
-
DrawPixel(int posX, int posY, ColorC color)
→ void
-
See RaylibCore.DrawPixel.
-
DrawPixelV(Vector2C position, ColorC color)
→ void
-
See RaylibCore.DrawPixelV.
-
DrawPlane(Vector3C centerPos, Vector2C size, ColorC color)
→ void
-
See RaylibCore.DrawPlane.
-
DrawPoint3D(Vector3C position, ColorC color)
→ void
-
See RaylibCore.DrawPoint3D.
-
DrawPoly(Vector2C center, int sides, double radius, double rotation, ColorC color)
→ void
-
See RaylibCore.DrawPoly.
-
DrawPolyLines(Vector2C center, int sides, double radius, double rotation, ColorC color)
→ void
-
See RaylibCore.DrawPolyLines.
-
DrawPolyLinesEx(Vector2C center, int sides, double radius, double rotation, double lineThick, ColorC color)
→ void
-
See RaylibCore.DrawPolyLinesEx.
-
DrawRay(RayC ray, ColorC color)
→ void
-
See RaylibCore.DrawRay.
-
DrawRectangle(int posX, int posY, int width, int height, ColorC color)
→ void
-
See RaylibCore.DrawRectangle.
-
DrawRectangleGradientEx(RectangleC rec, ColorC topLeft, ColorC bottomLeft, ColorC topRight, ColorC bottomRight)
→ void
-
See RaylibCore.DrawRectangleGradientEx.
-
DrawRectangleGradientH(int posX, int posY, int width, int height, ColorC left, ColorC right)
→ void
-
See RaylibCore.DrawRectangleGradientH.
-
DrawRectangleGradientV(int posX, int posY, int width, int height, ColorC top, ColorC bottom)
→ void
-
See RaylibCore.DrawRectangleGradientV.
-
DrawRectangleLines(int posX, int posY, int width, int height, ColorC color)
→ void
-
See RaylibCore.DrawRectangleLines.
-
DrawRectangleLinesEx(RectangleC rec, double lineThick, ColorC color)
→ void
-
See RaylibCore.DrawRectangleLinesEx.
-
DrawRectanglePro(RectangleC rec, Vector2C origin, double rotation, ColorC color)
→ void
-
See RaylibCore.DrawRectanglePro.
-
DrawRectangleRec(RectangleC rec, ColorC color)
→ void
-
See RaylibCore.DrawRectangleRec.
-
DrawRectangleRounded(RectangleC rec, double roundness, int segments, ColorC color)
→ void
-
See RaylibCore.DrawRectangleRounded.
-
DrawRectangleRoundedLines(RectangleC rec, double roundness, int segments, ColorC color)
→ void
-
See RaylibCore.DrawRectangleRoundedLines.
-
DrawRectangleRoundedLinesEx(RectangleC rec, double roundness, int segments, double lineThick, ColorC color)
→ void
-
See RaylibCore.DrawRectangleRoundedLinesEx.
-
DrawRectangleV(Vector2C position, Vector2C size, ColorC color)
→ void
-
See RaylibCore.DrawRectangleV.
-
DrawRing(Vector2C center, double innerRadius, double outerRadius, double startAngle, double endAngle, int segments, ColorC color)
→ void
-
See RaylibCore.DrawRing.
-
DrawRingLines(Vector2C center, double innerRadius, double outerRadius, double startAngle, double endAngle, int segments, ColorC color)
→ void
-
See RaylibCore.DrawRingLines.
-
DrawSphere(Vector3C centerPos, double radius, ColorC color)
→ void
-
See RaylibCore.DrawSphere.
-
DrawSphereEx(Vector3C centerPos, double radius, int rings, int slices, ColorC color)
→ void
-
See RaylibCore.DrawSphereEx.
-
DrawSphereWires(Vector3C centerPos, double radius, int rings, int slices, ColorC color)
→ void
-
See RaylibCore.DrawSphereWires.
-
DrawSplineBasis(Pointer<Vector2C> points, int pointCount, double thick, ColorC color)
→ void
-
See RaylibCore.DrawSplineBasis.
-
DrawSplineBezierCubic(Pointer<Vector2C> points, int pointCount, double thick, ColorC color)
→ void
-
See RaylibCore.DrawSplineBezierCubic.
-
DrawSplineBezierQuadratic(Pointer<Vector2C> points, int pointCount, double thick, ColorC color)
→ void
-
See RaylibCore.DrawSplineBezierQuadratic.
-
DrawSplineCatmullRom(Pointer<Vector2C> points, int pointCount, double thick, ColorC color)
→ void
-
See RaylibCore.DrawSplineCatmullRom.
-
DrawSplineLinear(Pointer<Vector2C> points, int pointCount, double thick, ColorC color)
→ void
-
See RaylibCore.DrawSplineLinear.
-
DrawSplineSegmentBasis(Vector2C p1, Vector2C p2, Vector2C p3, Vector2C p4, double thick, ColorC color)
→ void
-
See RaylibCore.DrawSplineSegmentBasis.
-
DrawSplineSegmentBezierCubic(Vector2C p1, Vector2C c2, Vector2C c3, Vector2C p4, double thick, ColorC color)
→ void
-
See RaylibCore.DrawSplineSegmentBezierCubic.
-
DrawSplineSegmentBezierQuadratic(Vector2C p1, Vector2C c2, Vector2C p3, double thick, ColorC color)
→ void
-
See RaylibCore.DrawSplineSegmentBezierQuadratic.
-
DrawSplineSegmentCatmullRom(Vector2C p1, Vector2C p2, Vector2C p3, Vector2C p4, double thick, ColorC color)
→ void
-
See RaylibCore.DrawSplineSegmentCatmullRom.
-
DrawSplineSegmentLinear(Vector2C p1, Vector2C p2, double thick, ColorC color)
→ void
-
See RaylibCore.DrawSplineSegmentLinear.
-
DrawText(Pointer<Char> text, int posX, int posY, int fontSize, ColorC color)
→ void
-
See RaylibCore.DrawText.
-
DrawTextCodepoint(FontC font, int codepoint, Vector2C position, double fontSize, ColorC tint)
→ void
-
See RaylibCore.DrawTextCodepoint.
-
DrawTextCodepoints(FontC font, Pointer<Int> codepoints, int codepointCount, Vector2C position, double fontSize, double spacing, ColorC tint)
→ void
-
See RaylibCore.DrawTextCodepoints.
-
DrawTextEx(FontC font, Pointer<Char> text, Vector2C position, double fontSize, double spacing, ColorC tint)
→ void
-
See RaylibCore.DrawTextEx.
-
DrawTextPro(FontC font, Pointer<Char> text, Vector2C position, Vector2C origin, double rotation, double fontSize, double spacing, ColorC tint)
→ void
-
See RaylibCore.DrawTextPro.
-
DrawTexture(TextureC texture, int posX, int posY, ColorC tint)
→ void
-
See RaylibCore.DrawTexture.
-
DrawTextureEx(TextureC texture, Vector2C position, double rotation, double scale, ColorC tint)
→ void
-
See RaylibCore.DrawTextureEx.
-
DrawTextureNPatch(TextureC texture, NPatchInfoC nPatchInfo, RectangleC dest, Vector2C origin, double rotation, ColorC tint)
→ void
-
See RaylibCore.DrawTextureNPatch.
-
DrawTexturePro(TextureC texture, RectangleC source, RectangleC dest, Vector2C origin, double rotation, ColorC tint)
→ void
-
See RaylibCore.DrawTexturePro.
-
DrawTextureRec(TextureC texture, RectangleC source, Vector2C position, ColorC tint)
→ void
-
See RaylibCore.DrawTextureRec.
-
DrawTextureV(TextureC texture, Vector2C position, ColorC tint)
→ void
-
See RaylibCore.DrawTextureV.
-
DrawTriangle(Vector2C v1, Vector2C v2, Vector2C v3, ColorC color)
→ void
-
See RaylibCore.DrawTriangle.
-
DrawTriangle3D(Vector3C v1, Vector3C v2, Vector3C v3, ColorC color)
→ void
-
See RaylibCore.DrawTriangle3D.
-
DrawTriangleFan(Pointer<Vector2C> points, int pointCount, ColorC color)
→ void
-
See RaylibCore.DrawTriangleFan.
-
DrawTriangleLines(Vector2C v1, Vector2C v2, Vector2C v3, ColorC color)
→ void
-
See RaylibCore.DrawTriangleLines.
-
DrawTriangleStrip(Pointer<Vector2C> points, int pointCount, ColorC color)
→ void
-
See RaylibCore.DrawTriangleStrip.
-
DrawTriangleStrip3D(Pointer<Vector3C> points, int pointCount, ColorC color)
→ void
-
See RaylibCore.DrawTriangleStrip3D.
-
EnableCursor()
→ void
-
See RaylibCore.EnableCursor.
-
EnableEventWaiting()
→ void
-
See RaylibCore.EnableEventWaiting.
-
EncodeDataBase64(Pointer<UnsignedChar> data, int dataSize, Pointer<Int> outputSize)
→ Pointer<Char>
-
See RaylibCore.EncodeDataBase64.
-
EndBlendMode()
→ void
-
See RaylibCore.EndBlendMode.
-
EndDrawing()
→ void
-
See RaylibCore.EndDrawing.
-
EndMode2D()
→ void
-
See RaylibCore.EndMode2D.
-
EndMode3D()
→ void
-
See RaylibCore.EndMode3D.
-
EndScissorMode()
→ void
-
See RaylibCore.EndScissorMode.
-
EndShaderMode()
→ void
-
See RaylibCore.EndShaderMode.
-
EndTextureMode()
→ void
-
See RaylibCore.EndTextureMode.
-
EndVrStereoMode()
→ void
-
See RaylibCore.EndVrStereoMode.
-
ExportAutomationEventList(AutomationEventListC list, Pointer<Char> fileName)
→ bool
-
See RaylibCore.ExportAutomationEventList.
-
ExportDataAsCode(Pointer<UnsignedChar> data, int dataSize, Pointer<Char> fileName)
→ bool
-
See RaylibCore.ExportDataAsCode.
-
ExportFontAsCode(FontC font, Pointer<Char> fileName)
→ bool
-
See RaylibCore.ExportFontAsCode.
-
ExportImage(ImageC image, Pointer<Char> fileName)
→ bool
-
See RaylibCore.ExportImage.
-
ExportImageAsCode(ImageC image, Pointer<Char> fileName)
→ bool
-
See RaylibCore.ExportImageAsCode.
-
ExportImageToMemory(ImageC image, Pointer<Char> fileType, Pointer<Int> fileSize)
→ Pointer<UnsignedChar>
-
See RaylibCore.ExportImageToMemory.
-
ExportMesh(MeshC mesh, Pointer<Char> fileName)
→ bool
-
See RaylibCore.ExportMesh.
-
ExportMeshAsCode(MeshC mesh, Pointer<Char> fileName)
→ bool
-
See RaylibCore.ExportMeshAsCode.
-
Fade(ColorC color, double alpha)
→ ColorC
-
See RaylibCore.Fade.
-
FileCopy(Pointer<Char> srcPath, Pointer<Char> dstPath)
→ int
-
See RaylibCore.FileCopy.
-
FileExists(Pointer<Char> fileName)
→ bool
-
See RaylibCore.FileExists.
-
FileMove(Pointer<Char> srcPath, Pointer<Char> dstPath)
→ int
-
See RaylibCore.FileMove.
-
FileRemove(Pointer<Char> fileName)
→ int
-
See RaylibCore.FileRemove.
-
FileRename(Pointer<Char> fileName, Pointer<Char> fileRename)
→ int
-
See RaylibCore.FileRename.
-
FileTextFindIndex(Pointer<Char> fileName, Pointer<Char> search)
→ int
-
See RaylibCore.FileTextFindIndex.
-
FileTextReplace(Pointer<Char> fileName, Pointer<Char> search, Pointer<Char> replacement)
→ int
-
See RaylibCore.FileTextReplace.
-
GenImageCellular(int width, int height, int tileSize)
→ ImageC
-
See RaylibCore.GenImageCellular.
-
GenImageChecked(int width, int height, int checksX, int checksY, ColorC col1, ColorC col2)
→ ImageC
-
See RaylibCore.GenImageChecked.
-
GenImageColor(int width, int height, ColorC color)
→ ImageC
-
See RaylibCore.GenImageColor.
-
GenImageFontAtlas(Pointer<GlyphInfoC> glyphs, Pointer<Pointer<RectangleC>> glyphRecs, int glyphCount, int fontSize, int padding, int packMethod)
→ ImageC
-
See RaylibCore.GenImageFontAtlas.
-
GenImageGradientLinear(int width, int height, int direction, ColorC start, ColorC end)
→ ImageC
-
See RaylibCore.GenImageGradientLinear.
-
GenImageGradientRadial(int width, int height, double density, ColorC inner, ColorC outer)
→ ImageC
-
See RaylibCore.GenImageGradientRadial.
-
GenImageGradientSquare(int width, int height, double density, ColorC inner, ColorC outer)
→ ImageC
-
See RaylibCore.GenImageGradientSquare.
-
GenImagePerlinNoise(int width, int height, int offsetX, int offsetY, double scale)
→ ImageC
-
See RaylibCore.GenImagePerlinNoise.
-
GenImageText(int width, int height, Pointer<Char> text)
→ ImageC
-
See RaylibCore.GenImageText.
-
GenImageWhiteNoise(int width, int height, double factor)
→ ImageC
-
See RaylibCore.GenImageWhiteNoise.
-
GenMeshCone(double radius, double height, int slices)
→ MeshC
-
See RaylibCore.GenMeshCone.
-
GenMeshCube(double width, double height, double length)
→ MeshC
-
See RaylibCore.GenMeshCube.
-
GenMeshCubicmap(ImageC cubicmap, Vector3C cubeSize)
→ MeshC
-
See RaylibCore.GenMeshCubicmap.
-
GenMeshCylinder(double radius, double height, int slices)
→ MeshC
-
See RaylibCore.GenMeshCylinder.
-
GenMeshHeightmap(ImageC heightmap, Vector3C size)
→ MeshC
-
See RaylibCore.GenMeshHeightmap.
-
GenMeshHemiSphere(double radius, int rings, int slices)
→ MeshC
-
See RaylibCore.GenMeshHemiSphere.
-
GenMeshKnot(double radius, double size, int radSeg, int sides)
→ MeshC
-
See RaylibCore.GenMeshKnot.
-
GenMeshPlane(double width, double length, int resX, int resZ)
→ MeshC
-
See RaylibCore.GenMeshPlane.
-
GenMeshPoly(int sides, double radius)
→ MeshC
-
See RaylibCore.GenMeshPoly.
-
GenMeshSphere(double radius, int rings, int slices)
→ MeshC
-
See RaylibCore.GenMeshSphere.
-
GenMeshTangents(Pointer<MeshC> mesh)
→ void
-
See RaylibCore.GenMeshTangents.
-
GenMeshTorus(double radius, double size, int radSeg, int sides)
→ MeshC
-
See RaylibCore.GenMeshTorus.
-
GenTextureMipmaps(Pointer<TextureC> texture)
→ void
-
See RaylibCore.GenTextureMipmaps.
-
GetApplicationDirectory()
→ Pointer<Char>
-
See RaylibCore.GetApplicationDirectory.
-
GetCameraMatrix(Camera3DC camera)
→ MatrixC
-
See RaylibCore.GetCameraMatrix.
-
GetCameraMatrix2D(Camera2DC camera)
→ MatrixC
-
See RaylibCore.GetCameraMatrix2D.
-
GetCharPressed()
→ int
-
See RaylibCore.GetCharPressed.
-
GetClipboardImage()
→ ImageC
-
See RaylibCore.GetClipboardImage.
-
GetClipboardText()
→ Pointer<Char>
-
See RaylibCore.GetClipboardText.
-
GetCodepoint(Pointer<Char> text, Pointer<Int> codepointSize)
→ int
-
See RaylibCore.GetCodepoint.
-
GetCodepointCount(Pointer<Char> text)
→ int
-
See RaylibCore.GetCodepointCount.
-
GetCodepointNext(Pointer<Char> text, Pointer<Int> codepointSize)
→ int
-
See RaylibCore.GetCodepointNext.
-
GetCodepointPrevious(Pointer<Char> text, Pointer<Int> codepointSize)
→ int
-
See RaylibCore.GetCodepointPrevious.
-
GetCollisionRec(RectangleC rec1, RectangleC rec2)
→ RectangleC
-
See RaylibCore.GetCollisionRec.
-
GetColor(int hexValue)
→ ColorC
-
See RaylibCore.GetColor.
-
GetCurrentMonitor()
→ int
-
See RaylibCore.GetCurrentMonitor.
-
GetDirectoryFileCount(Pointer<Char> dirPath)
→ int
-
See RaylibCore.GetDirectoryFileCount.
-
GetDirectoryFileCountEx(Pointer<Char> basePath, Pointer<Char> filter, bool scanSubdirs)
→ int
-
See RaylibCore.GetDirectoryFileCountEx.
-
GetDirectoryPath(Pointer<Char> filePath)
→ Pointer<Char>
-
See RaylibCore.GetDirectoryPath.
-
GetFileExtension(Pointer<Char> fileName)
→ Pointer<Char>
-
See RaylibCore.GetFileExtension.
-
GetFileLength(Pointer<Char> fileName)
→ int
-
See RaylibCore.GetFileLength.
-
GetFileModTime(Pointer<Char> fileName)
→ int
-
See RaylibCore.GetFileModTime.
-
GetFileName(Pointer<Char> filePath)
→ Pointer<Char>
-
See RaylibCore.GetFileName.
-
GetFileNameWithoutExt(Pointer<Char> filePath)
→ Pointer<Char>
-
See RaylibCore.GetFileNameWithoutExt.
-
GetFontDefault()
→ FontC
-
See RaylibCore.GetFontDefault.
-
GetFPS()
→ int
-
See RaylibCore.GetFPS.
-
GetFrameTime()
→ double
-
See RaylibCore.GetFrameTime.
-
GetGamepadAxisCount(int gamepad)
→ int
-
See RaylibCore.GetGamepadAxisCount.
-
GetGamepadAxisMovement(int gamepad, int axis)
→ double
-
See RaylibCore.GetGamepadAxisMovement.
-
GetGamepadButtonPressed()
→ int
-
See RaylibCore.GetGamepadButtonPressed.
-
GetGamepadName(int gamepad)
→ Pointer<Char>
-
See RaylibCore.GetGamepadName.
-
GetGestureDetected()
→ int
-
See RaylibCore.GetGestureDetected.
-
GetGestureDragAngle()
→ double
-
See RaylibCore.GetGestureDragAngle.
-
GetGestureDragVector()
→ Vector2C
-
See RaylibCore.GetGestureDragVector.
-
GetGestureHoldDuration()
→ double
-
See RaylibCore.GetGestureHoldDuration.
-
GetGesturePinchAngle()
→ double
-
See RaylibCore.GetGesturePinchAngle.
-
GetGesturePinchVector()
→ Vector2C
-
See RaylibCore.GetGesturePinchVector.
-
GetGlyphAtlasRec(FontC font, int codepoint)
→ RectangleC
-
See RaylibCore.GetGlyphAtlasRec.
-
GetGlyphIndex(FontC font, int codepoint)
→ int
-
See RaylibCore.GetGlyphIndex.
-
GetGlyphInfo(FontC font, int codepoint)
→ GlyphInfoC
-
See RaylibCore.GetGlyphInfo.
-
GetImageAlphaBorder(ImageC image, double threshold)
→ RectangleC
-
See RaylibCore.GetImageAlphaBorder.
-
GetImageColor(ImageC image, int x, int y)
→ ColorC
-
See RaylibCore.GetImageColor.
-
GetKeyName(int key)
→ Pointer<Char>
-
See RaylibCore.GetKeyName.
-
GetKeyPressed()
→ int
-
See RaylibCore.GetKeyPressed.
-
GetMeshBoundingBox(MeshC mesh)
→ BoundingBoxC
-
See RaylibCore.GetMeshBoundingBox.
-
GetModelBoundingBox(ModelC model)
→ BoundingBoxC
-
See RaylibCore.GetModelBoundingBox.
-
GetMonitorCount()
→ int
-
See RaylibCore.GetMonitorCount.
-
GetMonitorHeight(int monitor)
→ int
-
See RaylibCore.GetMonitorHeight.
-
GetMonitorName(int monitor)
→ Pointer<Char>
-
See RaylibCore.GetMonitorName.
-
GetMonitorPhysicalHeight(int monitor)
→ int
-
See RaylibCore.GetMonitorPhysicalHeight.
-
GetMonitorPhysicalWidth(int monitor)
→ int
-
See RaylibCore.GetMonitorPhysicalWidth.
-
GetMonitorPosition(int monitor)
→ Vector2C
-
See RaylibCore.GetMonitorPosition.
-
GetMonitorRefreshRate(int monitor)
→ int
-
See RaylibCore.GetMonitorRefreshRate.
-
GetMonitorWidth(int monitor)
→ int
-
See RaylibCore.GetMonitorWidth.
-
GetMouseDelta()
→ Vector2C
-
See RaylibCore.GetMouseDelta.
-
GetMousePosition()
→ Vector2C
-
See RaylibCore.GetMousePosition.
-
GetMouseWheelMove()
→ double
-
See RaylibCore.GetMouseWheelMove.
-
GetMouseWheelMoveV()
→ Vector2C
-
See RaylibCore.GetMouseWheelMoveV.
-
GetMouseX()
→ int
-
See RaylibCore.GetMouseX.
-
GetMouseY()
→ int
-
See RaylibCore.GetMouseY.
-
GetPixelColor(Pointer<Void> srcPtr, int format)
→ ColorC
-
See RaylibCore.GetPixelColor.
-
GetPixelDataSize(int width, int height, int format)
→ int
-
See RaylibCore.GetPixelDataSize.
-
GetPrevDirectoryPath(Pointer<Char> dirPath)
→ Pointer<Char>
-
See RaylibCore.GetPrevDirectoryPath.
-
GetRandomValue(int min, int max)
→ int
-
See RaylibCore.GetRandomValue.
-
GetRayCollisionBox(RayC ray, BoundingBoxC box)
→ RayCollisionC
-
See RaylibCore.GetRayCollisionBox.
-
GetRayCollisionMesh(RayC ray, MeshC mesh, MatrixC transform)
→ RayCollisionC
-
See RaylibCore.GetRayCollisionMesh.
-
GetRayCollisionQuad(RayC ray, Vector3C p1, Vector3C p2, Vector3C p3, Vector3C p4)
→ RayCollisionC
-
See RaylibCore.GetRayCollisionQuad.
-
GetRayCollisionSphere(RayC ray, Vector3C center, double radius)
→ RayCollisionC
-
See RaylibCore.GetRayCollisionSphere.
-
GetRayCollisionTriangle(RayC ray, Vector3C p1, Vector3C p2, Vector3C p3)
→ RayCollisionC
-
See RaylibCore.GetRayCollisionTriangle.
-
GetRenderHeight()
→ int
-
See RaylibCore.GetRenderHeight.
-
GetRenderWidth()
→ int
-
See RaylibCore.GetRenderWidth.
-
GetScreenHeight()
→ int
-
See RaylibCore.GetScreenHeight.
-
GetScreenToWorld2D(Vector2C position, Camera2DC camera)
→ Vector2C
-
See RaylibCore.GetScreenToWorld2D.
-
GetScreenToWorldRay(Vector2C position, Camera3DC camera)
→ RayC
-
See RaylibCore.GetScreenToWorldRay.
-
GetScreenToWorldRayEx(Vector2C position, Camera3DC camera, int width, int height)
→ RayC
-
See RaylibCore.GetScreenToWorldRayEx.
-
GetScreenWidth()
→ int
-
See RaylibCore.GetScreenWidth.
-
GetShaderLocation(ShaderC shader, Pointer<Char> uniformName)
→ int
-
See RaylibCore.GetShaderLocation.
-
GetShaderLocationAttrib(ShaderC shader, Pointer<Char> attribName)
→ int
-
See RaylibCore.GetShaderLocationAttrib.
-
GetShapesTexture()
→ TextureC
-
See RaylibCore.GetShapesTexture.
-
GetShapesTextureRectangle()
→ RectangleC
-
See RaylibCore.GetShapesTextureRectangle.
-
GetSplinePointBasis(Vector2C p1, Vector2C p2, Vector2C p3, Vector2C p4, double t)
→ Vector2C
-
See RaylibCore.GetSplinePointBasis.
-
GetSplinePointBezierCubic(Vector2C p1, Vector2C c2, Vector2C c3, Vector2C p4, double t)
→ Vector2C
-
See RaylibCore.GetSplinePointBezierCubic.
-
GetSplinePointBezierQuad(Vector2C p1, Vector2C c2, Vector2C p3, double t)
→ Vector2C
-
See RaylibCore.GetSplinePointBezierQuad.
-
GetSplinePointCatmullRom(Vector2C p1, Vector2C p2, Vector2C p3, Vector2C p4, double t)
→ Vector2C
-
See RaylibCore.GetSplinePointCatmullRom.
-
GetSplinePointLinear(Vector2C startPos, Vector2C endPos, double t)
→ Vector2C
-
See RaylibCore.GetSplinePointLinear.
-
GetTextBetween(Pointer<Char> text, Pointer<Char> begin, Pointer<Char> end)
→ Pointer<Char>
-
See RaylibCore.GetTextBetween.
-
GetTime()
→ double
-
See RaylibCore.GetTime.
-
GetTouchPointCount()
→ int
-
See RaylibCore.GetTouchPointCount.
-
GetTouchPointId(int index)
→ int
-
See RaylibCore.GetTouchPointId.
-
GetTouchPosition(int index)
→ Vector2C
-
See RaylibCore.GetTouchPosition.
-
GetTouchX()
→ int
-
See RaylibCore.GetTouchX.
-
GetTouchY()
→ int
-
See RaylibCore.GetTouchY.
-
GetWindowHandle()
→ Pointer<Void>
-
See RaylibCore.GetWindowHandle.
-
GetWindowPosition()
→ Vector2C
-
See RaylibCore.GetWindowPosition.
-
GetWindowScaleDPI()
→ Vector2C
-
See RaylibCore.GetWindowScaleDPI.
-
GetWorkingDirectory()
→ Pointer<Char>
-
See RaylibCore.GetWorkingDirectory.
-
GetWorldToScreen(Vector3C position, Camera3DC camera)
→ Vector2C
-
See RaylibCore.GetWorldToScreen.
-
GetWorldToScreen2D(Vector2C position, Camera2DC camera)
→ Vector2C
-
See RaylibCore.GetWorldToScreen2D.
-
GetWorldToScreenEx(Vector3C position, Camera3DC camera, int width, int height)
→ Vector2C
-
See RaylibCore.GetWorldToScreenEx.
-
HideCursor()
→ void
-
See RaylibCore.HideCursor.
-
ImageAlphaClear(Pointer<ImageC> image, ColorC color, double threshold)
→ void
-
See RaylibCore.ImageAlphaClear.
-
ImageAlphaCrop(Pointer<ImageC> image, double threshold)
→ void
-
See RaylibCore.ImageAlphaCrop.
-
ImageAlphaMask(Pointer<ImageC> image, ImageC alphaMask)
→ void
-
See RaylibCore.ImageAlphaMask.
-
ImageAlphaPremultiply(Pointer<ImageC> image)
→ void
-
See RaylibCore.ImageAlphaPremultiply.
-
ImageBlurGaussian(Pointer<ImageC> image, int blurSize)
→ void
-
See RaylibCore.ImageBlurGaussian.
-
ImageClearBackground(Pointer<ImageC> dst, ColorC color)
→ void
-
See RaylibCore.ImageClearBackground.
-
ImageColorBrightness(Pointer<ImageC> image, int brightness)
→ void
-
See RaylibCore.ImageColorBrightness.
-
ImageColorContrast(Pointer<ImageC> image, double contrast)
→ void
-
See RaylibCore.ImageColorContrast.
-
ImageColorGrayscale(Pointer<ImageC> image)
→ void
-
See RaylibCore.ImageColorGrayscale.
-
ImageColorInvert(Pointer<ImageC> image)
→ void
-
See RaylibCore.ImageColorInvert.
-
ImageColorReplace(Pointer<ImageC> image, ColorC color, ColorC replace)
→ void
-
See RaylibCore.ImageColorReplace.
-
ImageColorTint(Pointer<ImageC> image, ColorC color)
→ void
-
See RaylibCore.ImageColorTint.
-
ImageCopy(ImageC image)
→ ImageC
-
See RaylibCore.ImageCopy.
-
ImageCrop(Pointer<ImageC> image, RectangleC crop)
→ void
-
See RaylibCore.ImageCrop.
-
ImageDither(Pointer<ImageC> image, int rBpp, int gBpp, int bBpp, int aBpp)
→ void
-
See RaylibCore.ImageDither.
-
ImageDraw(Pointer<ImageC> dst, ImageC src, RectangleC srcRec, RectangleC dstRec, ColorC tint)
→ void
-
See RaylibCore.ImageDraw.
-
ImageDrawCircle(Pointer<ImageC> dst, int centerX, int centerY, int radius, ColorC color)
→ void
-
See RaylibCore.ImageDrawCircle.
-
ImageDrawCircleLines(Pointer<ImageC> dst, int centerX, int centerY, int radius, ColorC color)
→ void
-
See RaylibCore.ImageDrawCircleLines.
-
ImageDrawCircleLinesV(Pointer<ImageC> dst, Vector2C center, int radius, ColorC color)
→ void
-
See RaylibCore.ImageDrawCircleLinesV.
-
ImageDrawCircleV(Pointer<ImageC> dst, Vector2C center, int radius, ColorC color)
→ void
-
See RaylibCore.ImageDrawCircleV.
-
ImageDrawLine(Pointer<ImageC> dst, int startPosX, int startPosY, int endPosX, int endPosY, ColorC color)
→ void
-
See RaylibCore.ImageDrawLine.
-
ImageDrawLineEx(Pointer<ImageC> dst, Vector2C start, Vector2C end, int thick, ColorC color)
→ void
-
See RaylibCore.ImageDrawLineEx.
-
ImageDrawLineV(Pointer<ImageC> dst, Vector2C start, Vector2C end, ColorC color)
→ void
-
See RaylibCore.ImageDrawLineV.
-
ImageDrawPixel(Pointer<ImageC> dst, int posX, int posY, ColorC color)
→ void
-
See RaylibCore.ImageDrawPixel.
-
ImageDrawPixelV(Pointer<ImageC> dst, Vector2C position, ColorC color)
→ void
-
See RaylibCore.ImageDrawPixelV.
-
ImageDrawRectangle(Pointer<ImageC> dst, int posX, int posY, int width, int height, ColorC color)
→ void
-
See RaylibCore.ImageDrawRectangle.
-
ImageDrawRectangleLines(Pointer<ImageC> dst, RectangleC rec, int thick, ColorC color)
→ void
-
See RaylibCore.ImageDrawRectangleLines.
-
ImageDrawRectangleRec(Pointer<ImageC> dst, RectangleC rec, ColorC color)
→ void
-
See RaylibCore.ImageDrawRectangleRec.
-
ImageDrawRectangleV(Pointer<ImageC> dst, Vector2C position, Vector2C size, ColorC color)
→ void
-
See RaylibCore.ImageDrawRectangleV.
-
ImageDrawText(Pointer<ImageC> dst, Pointer<Char> text, int posX, int posY, int fontSize, ColorC color)
→ void
-
See RaylibCore.ImageDrawText.
-
ImageDrawTextEx(Pointer<ImageC> dst, FontC font, Pointer<Char> text, Vector2C position, double fontSize, double spacing, ColorC tint)
→ void
-
See RaylibCore.ImageDrawTextEx.
-
ImageDrawTriangle(Pointer<ImageC> dst, Vector2C v1, Vector2C v2, Vector2C v3, ColorC color)
→ void
-
See RaylibCore.ImageDrawTriangle.
-
ImageDrawTriangleEx(Pointer<ImageC> dst, Vector2C v1, Vector2C v2, Vector2C v3, ColorC c1, ColorC c2, ColorC c3)
→ void
-
See RaylibCore.ImageDrawTriangleEx.
-
ImageDrawTriangleFan(Pointer<ImageC> dst, Pointer<Vector2C> points, int pointCount, ColorC color)
→ void
-
See RaylibCore.ImageDrawTriangleFan.
-
ImageDrawTriangleLines(Pointer<ImageC> dst, Vector2C v1, Vector2C v2, Vector2C v3, ColorC color)
→ void
-
See RaylibCore.ImageDrawTriangleLines.
-
ImageDrawTriangleStrip(Pointer<ImageC> dst, Pointer<Vector2C> points, int pointCount, ColorC color)
→ void
-
See RaylibCore.ImageDrawTriangleStrip.
-
ImageFlipHorizontal(Pointer<ImageC> image)
→ void
-
See RaylibCore.ImageFlipHorizontal.
-
ImageFlipVertical(Pointer<ImageC> image)
→ void
-
See RaylibCore.ImageFlipVertical.
-
ImageFormat(Pointer<ImageC> image, int newFormat)
→ void
-
See RaylibCore.ImageFormat.
-
ImageFromChannel(ImageC image, int selectedChannel)
→ ImageC
-
See RaylibCore.ImageFromChannel.
-
ImageFromImage(ImageC image, RectangleC rec)
→ ImageC
-
See RaylibCore.ImageFromImage.
-
ImageKernelConvolution(Pointer<ImageC> image, Pointer<Float> kernel, int kernelSize)
→ void
-
See RaylibCore.ImageKernelConvolution.
-
ImageMipmaps(Pointer<ImageC> image)
→ void
-
See RaylibCore.ImageMipmaps.
-
ImageResize(Pointer<ImageC> image, int newWidth, int newHeight)
→ void
-
See RaylibCore.ImageResize.
-
ImageResizeCanvas(Pointer<ImageC> image, int newWidth, int newHeight, int offsetX, int offsetY, ColorC fill)
→ void
-
See RaylibCore.ImageResizeCanvas.
-
ImageResizeNN(Pointer<ImageC> image, int newWidth, int newHeight)
→ void
-
See RaylibCore.ImageResizeNN.
-
ImageRotate(Pointer<ImageC> image, int degrees)
→ void
-
See RaylibCore.ImageRotate.
-
ImageRotateCCW(Pointer<ImageC> image)
→ void
-
See RaylibCore.ImageRotateCCW.
-
ImageRotateCW(Pointer<ImageC> image)
→ void
-
See RaylibCore.ImageRotateCW.
-
ImageText(Pointer<Char> text, int fontSize, ColorC color)
→ ImageC
-
See RaylibCore.ImageText.
-
ImageTextEx(FontC font, Pointer<Char> text, double fontSize, double spacing, ColorC tint)
→ ImageC
-
See RaylibCore.ImageTextEx.
-
ImageToPOT(Pointer<ImageC> image, ColorC fill)
→ void
-
See RaylibCore.ImageToPOT.
-
InitWindow(int width, int height, Pointer<Char> title)
→ void
-
See RaylibCore.InitWindow.
-
IsCursorHidden()
→ bool
-
See RaylibCore.IsCursorHidden.
-
IsCursorOnScreen()
→ bool
-
See RaylibCore.IsCursorOnScreen.
-
IsFileDropped()
→ bool
-
See RaylibCore.IsFileDropped.
-
IsFileExtension(Pointer<Char> fileName, Pointer<Char> ext)
→ bool
-
See RaylibCore.IsFileExtension.
-
IsFileNameValid(Pointer<Char> fileName)
→ bool
-
See RaylibCore.IsFileNameValid.
-
IsFontValid(FontC font)
→ bool
-
See RaylibCore.IsFontValid.
-
IsGamepadAvailable(int gamepad)
→ bool
-
See RaylibCore.IsGamepadAvailable.
-
IsGamepadButtonDown(int gamepad, int button)
→ bool
-
See RaylibCore.IsGamepadButtonDown.
-
IsGamepadButtonPressed(int gamepad, int button)
→ bool
-
See RaylibCore.IsGamepadButtonPressed.
-
IsGamepadButtonReleased(int gamepad, int button)
→ bool
-
See RaylibCore.IsGamepadButtonReleased.
-
IsGamepadButtonUp(int gamepad, int button)
→ bool
-
See RaylibCore.IsGamepadButtonUp.
-
IsGestureDetected(int gesture)
→ bool
-
See RaylibCore.IsGestureDetected.
-
IsImageValid(ImageC image)
→ bool
-
See RaylibCore.IsImageValid.
-
IsKeyDown(int key)
→ bool
-
See RaylibCore.IsKeyDown.
-
IsKeyPressed(int key)
→ bool
-
See RaylibCore.IsKeyPressed.
-
IsKeyPressedRepeat(int key)
→ bool
-
See RaylibCore.IsKeyPressedRepeat.
-
IsKeyReleased(int key)
→ bool
-
See RaylibCore.IsKeyReleased.
-
IsKeyUp(int key)
→ bool
-
See RaylibCore.IsKeyUp.
-
IsMaterialValid(MaterialC material)
→ bool
-
See RaylibCore.IsMaterialValid.
-
IsModelAnimationValid(ModelC model, ModelAnimationC anim)
→ bool
-
See RaylibCore.IsModelAnimationValid.
-
IsModelValid(ModelC model)
→ bool
-
See RaylibCore.IsModelValid.
-
IsMouseButtonDown(int button)
→ bool
-
See RaylibCore.IsMouseButtonDown.
-
IsMouseButtonPressed(int button)
→ bool
-
See RaylibCore.IsMouseButtonPressed.
-
IsMouseButtonReleased(int button)
→ bool
-
See RaylibCore.IsMouseButtonReleased.
-
IsMouseButtonUp(int button)
→ bool
-
See RaylibCore.IsMouseButtonUp.
-
IsPathFile(Pointer<Char> path)
→ bool
-
See RaylibCore.IsPathFile.
-
IsRenderTextureValid(RenderTextureC target)
→ bool
-
See RaylibCore.IsRenderTextureValid.
-
IsShaderValid(ShaderC shader)
→ bool
-
See RaylibCore.IsShaderValid.
-
IsTextureValid(TextureC texture)
→ bool
-
See RaylibCore.IsTextureValid.
-
IsWindowFocused()
→ bool
-
See RaylibCore.IsWindowFocused.
-
IsWindowFullscreen()
→ bool
-
See RaylibCore.IsWindowFullscreen.
-
IsWindowHidden()
→ bool
-
See RaylibCore.IsWindowHidden.
-
IsWindowMaximized()
→ bool
-
See RaylibCore.IsWindowMaximized.
-
IsWindowMinimized()
→ bool
-
See RaylibCore.IsWindowMinimized.
-
IsWindowReady()
→ bool
-
See RaylibCore.IsWindowReady.
-
IsWindowResized()
→ bool
-
See RaylibCore.IsWindowResized.
-
IsWindowState(int flag)
→ bool
-
See RaylibCore.IsWindowState.
-
LoadAutomationEventList(Pointer<Char> fileName)
→ AutomationEventListC
-
See RaylibCore.LoadAutomationEventList.
-
LoadCodepoints(Pointer<Char> text, Pointer<Int> count)
→ Pointer<Int>
-
See RaylibCore.LoadCodepoints.
-
LoadDirectoryFiles(Pointer<Char> dirPath)
→ FilePathListC
-
See RaylibCore.LoadDirectoryFiles.
-
LoadDirectoryFilesEx(Pointer<Char> basePath, Pointer<Char> filter, bool scanSubdirs)
→ FilePathListC
-
See RaylibCore.LoadDirectoryFilesEx.
-
LoadDroppedFiles()
→ FilePathListC
-
See RaylibCore.LoadDroppedFiles.
-
LoadFileData(Pointer<Char> fileName, Pointer<Int> dataSize)
→ Pointer<UnsignedChar>
-
See RaylibCore.LoadFileData.
-
LoadFileText(Pointer<Char> fileName)
→ Pointer<Char>
-
See RaylibCore.LoadFileText.
-
LoadFont(Pointer<Char> fileName)
→ FontC
-
See RaylibCore.LoadFont.
-
LoadFontData(Pointer<UnsignedChar> fileData, int dataSize, int fontSize, Pointer<Int> codepoints, int codepointCount, int type, Pointer<Int> glyphCount)
→ Pointer<GlyphInfoC>
-
See RaylibCore.LoadFontData.
-
LoadFontEx(Pointer<Char> fileName, int fontSize, Pointer<Int> codepoints, int codepointCount)
→ FontC
-
See RaylibCore.LoadFontEx.
-
LoadFontFromImage(ImageC image, ColorC key, int firstChar)
→ FontC
-
See RaylibCore.LoadFontFromImage.
-
LoadFontFromMemory(Pointer<Char> fileType, Pointer<UnsignedChar> fileData, int dataSize, int fontSize, Pointer<Int> codepoints, int codepointCount)
→ FontC
-
See RaylibCore.LoadFontFromMemory.
-
LoadImage(Pointer<Char> fileName)
→ ImageC
-
See RaylibCore.LoadImage.
-
LoadImageAnim(Pointer<Char> fileName, Pointer<Int> frames)
→ ImageC
-
See RaylibCore.LoadImageAnim.
-
LoadImageAnimFromMemory(Pointer<Char> fileType, Pointer<UnsignedChar> fileData, int dataSize, Pointer<Int> frames)
→ ImageC
-
See RaylibCore.LoadImageAnimFromMemory.
-
LoadImageColors(ImageC image)
→ Pointer<ColorC>
-
See RaylibCore.LoadImageColors.
-
LoadImageFromMemory(Pointer<Char> fileType, Pointer<UnsignedChar> fileData, int dataSize)
→ ImageC
-
See RaylibCore.LoadImageFromMemory.
-
LoadImageFromScreen()
→ ImageC
-
See RaylibCore.LoadImageFromScreen.
-
LoadImageFromTexture(TextureC texture)
→ ImageC
-
See RaylibCore.LoadImageFromTexture.
-
LoadImagePalette(ImageC image, int maxPaletteSize, Pointer<Int> colorCount)
→ Pointer<ColorC>
-
See RaylibCore.LoadImagePalette.
-
LoadImageRaw(Pointer<Char> fileName, int width, int height, int format, )
→ ImageC
-
See RaylibCore.LoadImageRaw.
-
LoadMaterialDefault()
→ MaterialC
-
See RaylibCore.LoadMaterialDefault.
-
LoadMaterials(Pointer<Char> fileName, Pointer<Int> materialCount)
→ Pointer<MaterialC>
-
See RaylibCore.LoadMaterials.
-
LoadModel(Pointer<Char> fileName)
→ ModelC
-
See RaylibCore.LoadModel.
-
LoadModelAnimations(Pointer<Char> fileName, Pointer<Int> animCount)
→ Pointer<ModelAnimationC>
-
See RaylibCore.LoadModelAnimations.
-
LoadModelFromMesh(MeshC mesh)
→ ModelC
-
See RaylibCore.LoadModelFromMesh.
-
LoadRandomSequence(int count, int min, int max)
→ Pointer<Int>
-
See RaylibCore.LoadRandomSequence.
-
LoadRenderTexture(int width, int height)
→ RenderTextureC
-
See RaylibCore.LoadRenderTexture.
-
LoadShader(Pointer<Char> vsFileName, Pointer<Char> fsFileName)
→ ShaderC
-
See RaylibCore.LoadShader.
-
LoadShaderFromMemory(Pointer<Char> vsCode, Pointer<Char> fsCode)
→ ShaderC
-
See RaylibCore.LoadShaderFromMemory.
-
LoadTextLines(Pointer<Char> text, Pointer<Int> count)
→ Pointer<Pointer<Char>>
-
See RaylibCore.LoadTextLines.
-
LoadTexture(Pointer<Char> fileName)
→ TextureC
-
See RaylibCore.LoadTexture.
-
LoadTextureCubemap(ImageC image, int layout)
→ TextureC
-
See RaylibCore.LoadTextureCubemap.
-
LoadTextureFromImage(ImageC image)
→ TextureC
-
See RaylibCore.LoadTextureFromImage.
-
LoadUTF8(Pointer<Int> codepoints, int length)
→ Pointer<Char>
-
See RaylibCore.LoadUTF8.
-
LoadVrStereoConfig(VrDeviceInfoC device)
→ VrStereoConfigC
-
See RaylibCore.LoadVrStereoConfig.
-
MakeDirectory(Pointer<Char> dirPath)
→ int
-
See RaylibCore.MakeDirectory.
-
MaximizeWindow()
→ void
-
See RaylibCore.MaximizeWindow.
-
MeasureText(Pointer<Char> text, int fontSize)
→ int
-
See RaylibCore.MeasureText.
-
MeasureTextCodepoints(FontC font, Pointer<Int> codepoints, int length, double fontSize, double spacing)
→ Vector2C
-
See RaylibCore.MeasureTextCodepoints.
-
MeasureTextEx(FontC font, Pointer<Char> text, double fontSize, double spacing)
→ Vector2C
-
See RaylibCore.MeasureTextEx.
-
MinimizeWindow()
→ void
-
See RaylibCore.MinimizeWindow.
-
OpenURL(Pointer<Char> url)
→ void
-
See RaylibCore.OpenURL.
-
PlayAutomationEvent(AutomationEventC event)
→ void
-
See RaylibCore.PlayAutomationEvent.
-
PollInputEvents()
→ void
-
See RaylibCore.PollInputEvents.
-
ProcessGestureEvent(GestureEventC event)
→ void
-
See RaylibCore.ProcessGestureEvent.
-
RestoreWindow()
→ void
-
See RaylibCore.RestoreWindow.
-
SaveFileData(Pointer<Char> fileName, Pointer<Void> data, int dataSize)
→ bool
-
See RaylibCore.SaveFileData.
-
SaveFileText(Pointer<Char> fileName, Pointer<Char> text)
→ bool
-
See RaylibCore.SaveFileText.
-
SetAutomationEventBaseFrame(int frame)
→ void
-
See RaylibCore.SetAutomationEventBaseFrame.
-
SetAutomationEventList(Pointer<AutomationEventListC> list)
→ void
-
See RaylibCore.SetAutomationEventList.
-
SetClipboardText(Pointer<Char> text)
→ void
-
See RaylibCore.SetClipboardText.
-
SetConfigFlags(int flags)
→ void
-
See RaylibCore.SetConfigFlags.
-
SetExitKey(int key)
→ void
-
See RaylibCore.SetExitKey.
-
SetGamepadMappings(Pointer<Char> mappings)
→ int
-
See RaylibCore.SetGamepadMappings.
-
SetGamepadVibration(int gamepad, double leftMotor, double rightMotor, double duration)
→ void
-
See RaylibCore.SetGamepadVibration.
-
SetGesturesEnabled(int flags)
→ void
-
See RaylibCore.SetGesturesEnabled.
-
SetLoadFileDataCallback(LoadFileDataCallbackC callback)
→ void
-
See RaylibCore.SetLoadFileDataCallback.
-
SetLoadFileTextCallback(LoadFileTextCallbackC callback)
→ void
-
See RaylibCore.SetLoadFileTextCallback.
-
SetMaterialTexture(Pointer<MaterialC> material, int mapType, TextureC texture)
→ void
-
See RaylibCore.SetMaterialTexture.
-
SetModelMeshMaterial(Pointer<ModelC> model, int meshId, int materialId)
→ void
-
See RaylibCore.SetModelMeshMaterial.
-
SetMouseCursor(int cursor)
→ void
-
See RaylibCore.SetMouseCursor.
-
SetMouseOffset(int offsetX, int offsetY)
→ void
-
See RaylibCore.SetMouseOffset.
-
SetMousePosition(int x, int y)
→ void
-
See RaylibCore.SetMousePosition.
-
SetMouseScale(double scaleX, double scaleY)
→ void
-
See RaylibCore.SetMouseScale.
-
SetPixelColor(Pointer<Void> dstPtr, ColorC color, int format)
→ void
-
See RaylibCore.SetPixelColor.
-
SetRandomSeed(int seed)
→ void
-
See RaylibCore.SetRandomSeed.
-
SetSaveFileDataCallback(SaveFileDataCallbackC callback)
→ void
-
See RaylibCore.SetSaveFileDataCallback.
-
SetSaveFileTextCallback(SaveFileTextCallbackC callback)
→ void
-
See RaylibCore.SetSaveFileTextCallback.
-
SetShaderValue(ShaderC shader, int locIndex, Pointer<Void> value, int uniformType)
→ void
-
See RaylibCore.SetShaderValue.
-
SetShaderValueMatrix(ShaderC shader, int locIndex, MatrixC mat)
→ void
-
See RaylibCore.SetShaderValueMatrix.
-
SetShaderValueTexture(ShaderC shader, int locIndex, TextureC texture)
→ void
-
See RaylibCore.SetShaderValueTexture.
-
SetShaderValueV(ShaderC shader, int locIndex, Pointer<Void> value, int uniformType, int count)
→ void
-
See RaylibCore.SetShaderValueV.
-
SetShapesTexture(TextureC texture, RectangleC source)
→ void
-
See RaylibCore.SetShapesTexture.
-
SetTargetFPS(int fps)
→ void
-
See RaylibCore.SetTargetFPS.
-
SetTextLineSpacing(int spacing)
→ void
-
See RaylibCore.SetTextLineSpacing.
-
SetTextureFilter(TextureC texture, int filter)
→ void
-
See RaylibCore.SetTextureFilter.
-
SetTextureWrap(TextureC texture, int wrap)
→ void
-
See RaylibCore.SetTextureWrap.
-
SetTraceLogCallback(TraceLogCallbackC callback)
→ void
-
See RaylibCore.SetTraceLogCallback.
-
SetTraceLogLevel(int logLevel)
→ void
-
See RaylibCore.SetTraceLogLevel.
-
SetWindowFocused()
→ void
-
See RaylibCore.SetWindowFocused.
-
SetWindowIcon(ImageC image)
→ void
-
See RaylibCore.SetWindowIcon.
-
SetWindowIcons(Pointer<ImageC> images, int count)
→ void
-
See RaylibCore.SetWindowIcons.
-
SetWindowMaxSize(int width, int height)
→ void
-
See RaylibCore.SetWindowMaxSize.
-
SetWindowMinSize(int width, int height)
→ void
-
See RaylibCore.SetWindowMinSize.
-
SetWindowMonitor(int monitor)
→ void
-
See RaylibCore.SetWindowMonitor.
-
SetWindowOpacity(double opacity)
→ void
-
See RaylibCore.SetWindowOpacity.
-
SetWindowPosition(int x, int y)
→ void
-
See RaylibCore.SetWindowPosition.
-
SetWindowSize(int width, int height)
→ void
-
See RaylibCore.SetWindowSize.
-
SetWindowState(int flags)
→ void
-
See RaylibCore.SetWindowState.
-
SetWindowTitle(Pointer<Char> title)
→ void
-
See RaylibCore.SetWindowTitle.
-
ShowCursor()
→ void
-
See RaylibCore.ShowCursor.
-
StartAutomationEventRecording()
→ void
-
See RaylibCore.StartAutomationEventRecording.
-
StopAutomationEventRecording()
→ void
-
See RaylibCore.StopAutomationEventRecording.
-
SwapScreenBuffer()
→ void
-
See RaylibCore.SwapScreenBuffer.
-
TakeScreenshot(Pointer<Char> fileName)
→ void
-
See RaylibCore.TakeScreenshot.
-
TextAppend(Pointer<Char> text, Pointer<Char> append, Pointer<Int> position)
→ void
-
See RaylibCore.TextAppend.
-
TextCopy(Pointer<Char> dst, Pointer<Char> src)
→ int
-
See RaylibCore.TextCopy.
-
TextFindIndex(Pointer<Char> text, Pointer<Char> find)
→ int
-
See RaylibCore.TextFindIndex.
-
TextFormat(Pointer<Char> text)
→ Pointer<Char>
-
See RaylibCore.TextFormat.
-
TextInsert(Pointer<Char> text, Pointer<Char> insert, int position)
→ Pointer<Char>
-
See RaylibCore.TextInsert.
-
TextInsertAlloc(Pointer<Char> text, Pointer<Char> insert, int position)
→ Pointer<Char>
-
See RaylibCore.TextInsertAlloc.
-
TextIsEqual(Pointer<Char> text1, Pointer<Char> text2)
→ bool
-
See RaylibCore.TextIsEqual.
-
TextJoin(Pointer<Pointer<Char>> textList, int count, Pointer<Char> delimiter)
→ Pointer<Char>
-
See RaylibCore.TextJoin.
-
TextLength(Pointer<Char> text)
→ int
-
See RaylibCore.TextLength.
-
TextRemoveSpaces(Pointer<Char> text)
→ Pointer<Char>
-
See RaylibCore.TextRemoveSpaces.
-
TextReplace(Pointer<Char> text, Pointer<Char> replace, Pointer<Char> by)
→ Pointer<Char>
-
See RaylibCore.TextReplace.
-
TextReplaceAlloc(Pointer<Char> text, Pointer<Char> replace, Pointer<Char> by)
→ Pointer<Char>
-
See RaylibCore.TextReplaceAlloc.
-
TextReplaceBetween(Pointer<Char> text, Pointer<Char> begin, Pointer<Char> end, Pointer<Char> replacement)
→ Pointer<Char>
-
See RaylibCore.TextReplaceBetween.
-
TextReplaceBetweenAlloc(Pointer<Char> text, Pointer<Char> begin, Pointer<Char> end, Pointer<Char> replacement)
→ Pointer<Char>
-
See RaylibCore.TextReplaceBetweenAlloc.
-
TextSplit(Pointer<Char> text, int delimiter, Pointer<Int> count)
→ Pointer<Pointer<Char>>
-
See RaylibCore.TextSplit.
-
TextSubtext(Pointer<Char> text, int position, int length)
→ Pointer<Char>
-
See RaylibCore.TextSubtext.
-
TextToCamel(Pointer<Char> text)
→ Pointer<Char>
-
See RaylibCore.TextToCamel.
-
TextToFloat(Pointer<Char> text)
→ double
-
See RaylibCore.TextToFloat.
-
TextToInteger(Pointer<Char> text)
→ int
-
See RaylibCore.TextToInteger.
-
TextToLower(Pointer<Char> text)
→ Pointer<Char>
-
See RaylibCore.TextToLower.
-
TextToPascal(Pointer<Char> text)
→ Pointer<Char>
-
See RaylibCore.TextToPascal.
-
TextToSnake(Pointer<Char> text)
→ Pointer<Char>
-
See RaylibCore.TextToSnake.
-
TextToUpper(Pointer<Char> text)
→ Pointer<Char>
-
See RaylibCore.TextToUpper.
-
ToggleBorderlessWindowed()
→ void
-
See RaylibCore.ToggleBorderlessWindowed.
-
ToggleFullscreen()
→ void
-
See RaylibCore.ToggleFullscreen.
-
TraceLog(int logLevel, Pointer<Char> text)
→ void
-
See RaylibCore.TraceLog.
-
UnloadAutomationEventList(AutomationEventListC list)
→ void
-
See RaylibCore.UnloadAutomationEventList.
-
UnloadCodepoints(Pointer<Int> codepoints)
→ void
-
See RaylibCore.UnloadCodepoints.
-
UnloadDirectoryFiles(FilePathListC files)
→ void
-
See RaylibCore.UnloadDirectoryFiles.
-
UnloadDroppedFiles(FilePathListC files)
→ void
-
See RaylibCore.UnloadDroppedFiles.
-
UnloadFileData(Pointer<UnsignedChar> data)
→ void
-
See RaylibCore.UnloadFileData.
-
UnloadFileText(Pointer<Char> text)
→ void
-
See RaylibCore.UnloadFileText.
-
UnloadFont(FontC font)
→ void
-
See RaylibCore.UnloadFont.
-
UnloadFontData(Pointer<GlyphInfoC> glyphs, int glyphCount)
→ void
-
See RaylibCore.UnloadFontData.
-
UnloadImage(ImageC image)
→ void
-
See RaylibCore.UnloadImage.
-
UnloadImageColors(Pointer<ColorC> colors)
→ void
-
See RaylibCore.UnloadImageColors.
-
UnloadImagePalette(Pointer<ColorC> colors)
→ void
-
See RaylibCore.UnloadImagePalette.
-
UnloadMaterial(MaterialC material)
→ void
-
See RaylibCore.UnloadMaterial.
-
UnloadMesh(MeshC mesh)
→ void
-
See RaylibCore.UnloadMesh.
-
UnloadModel(ModelC model)
→ void
-
See RaylibCore.UnloadModel.
-
UnloadModelAnimations(Pointer<ModelAnimationC> animations, int animCount)
→ void
-
See RaylibCore.UnloadModelAnimations.
-
UnloadRandomSequence(Pointer<Int> sequence)
→ void
-
See RaylibCore.UnloadRandomSequence.
-
UnloadRenderTexture(RenderTextureC target)
→ void
-
See RaylibCore.UnloadRenderTexture.
-
UnloadShader(ShaderC shader)
→ void
-
See RaylibCore.UnloadShader.
-
UnloadTextLines(Pointer<Pointer<Char>> text, int lineCount)
→ void
-
See RaylibCore.UnloadTextLines.
-
UnloadTexture(TextureC texture)
→ void
-
See RaylibCore.UnloadTexture.
-
UnloadUTF8(Pointer<Char> text)
→ void
-
See RaylibCore.UnloadUTF8.
-
UnloadVrStereoConfig(VrStereoConfigC config)
→ void
-
See RaylibCore.UnloadVrStereoConfig.
-
UpdateCamera(Pointer<Camera3DC> camera, int mode)
→ void
-
See RaylibCore.UpdateCamera.
-
UpdateCameraPro(Pointer<Camera3DC> camera, Vector3C movement, Vector3C rotation, double zoom)
→ void
-
See RaylibCore.UpdateCameraPro.
-
UpdateGestures()
→ void
-
See RaylibCore.UpdateGestures.
-
UpdateMeshBuffer(MeshC mesh, int index, Pointer<Void> data, int dataSize, int offset)
→ void
-
See RaylibCore.UpdateMeshBuffer.
-
UpdateModelAnimation(ModelC model, ModelAnimationC anim, double frame)
→ void
-
See RaylibCore.UpdateModelAnimation.
-
UpdateModelAnimationEx(ModelC model, ModelAnimationC animA, double frameA, ModelAnimationC animB, double frameB, double blend)
→ void
-
See RaylibCore.UpdateModelAnimationEx.
-
UpdateTexture(TextureC texture, Pointer<Void> pixels)
→ void
-
See RaylibCore.UpdateTexture.
-
UpdateTextureRec(TextureC texture, RectangleC rec, Pointer<Void> pixels)
→ void
-
See RaylibCore.UpdateTextureRec.
-
UploadMesh(Pointer<MeshC> mesh, bool dynamic)
→ void
-
See RaylibCore.UploadMesh.
-
WaitTime(double seconds)
→ void
-
See RaylibCore.WaitTime.
-
WindowShouldClose()
→ bool
-
See RaylibCore.WindowShouldClose.