AudioCallbackD class abstract

Inheritance

Constructors

AudioCallbackD([String? name])
AudioCallbackD.function(AudioCallbackFunctionD f, {String? name})
factory

Properties

function AudioCallbackFunctionD
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pairinherited
nativeFunction Pointer<NativeFunction<AudioCallbackFunctionC>>
no setterinherited
registry List<CallbackD<Function, Function>>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

attach() Pointer<NativeFunction<AudioCallbackFunctionC>>
inherited
detach([bool keepAlive = false]) → void
inherited
dispose() → void
inherited
initializer() NativeCallable<AudioCallbackFunctionC>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

disposeRegistry() → void
override