AudioStreamC class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter -
buffer
↔ Pointer<
rAudioBuffer> -
getter/setter pair
- channels ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
processor
↔ Pointer<
rAudioProcessor> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleRate ↔ int
-
getter/setter pair
- sampleSize ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setC(
AudioStreamC o) → AudioStreamC -
Available on AudioStreamC, provided by the AudioStreamCEx extension
-
setD(
AudioStreamD o) → AudioStreamC -
Available on AudioStreamC, provided by the AudioStreamCEx extension
-
toD(
[Pointer< AudioStreamC> ? ptr]) → AudioStreamD -
Available on AudioStreamC, provided by the AudioStreamCEx extension
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited