AutomationEventListD class
- Inheritance
-
- Object
- StructD<
AutomationEventListD, AutomationEventListC> - StructDView<
AutomationEventListD, AutomationEventListC> - AutomationEventListD
Constructors
-
AutomationEventListD(Pointer<
AutomationEventListC> originalPointer)
Properties
- allocKey → String
-
no setterinherited
- capacity → int
-
no setter
- count → int
-
no setter
- cStructName → String
-
no setterinherited
-
events
→ List<
AutomationEventD> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- internalId → int
-
no setterinherited
- isDisposed → bool
-
no setterinherited
-
originalPointer
↔ Pointer<
AutomationEventListC> ? -
getter/setter pairinherited
- ref → AutomationEventListC
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- structName → String
-
no setterinherited
- tag → String
-
no setterinherited
Methods
-
allocateInto(
RaylibTemp temp, Pointer< AutomationEventListC> p, String key) → void -
inherited
-
allocatePointer(
RaylibTemp temp, String key, [int count = 1]) → Pointer< AutomationEventListC> -
inherited
-
clone(
) → AutomationEventListD -
override
-
copy(
) → AutomationEventListD -
inherited
-
getOriginalPointer(
) → Pointer< AutomationEventListC> -
inherited
-
getOriginalPointerAndDispose(
) → Pointer< AutomationEventListC> -
inherited
-
markDisposed(
) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onOriginalPointer(
void callback(Pointer< AutomationEventListC> p)) → void -
inherited
-
setC(
AutomationEventListC o) → AutomationEventListD -
inherited
-
setD(
AutomationEventListD o) → AutomationEventListD -
inherited
-
setTag(
String newTag) → AutomationEventListD -
inherited
-
signature(
) → String -
override
-
syncInto(
RaylibTemp temp, Pointer< AutomationEventListC> p, String key) → void -
inherited
-
toC(
RaylibTemp temp, String key) → Pointer< AutomationEventListC> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
writeInto(
AutomationEventListC p) → void -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited