BoundingBoxD class
- Inheritance
-
- Object
- StructD<
BoundingBoxD, BoundingBoxC> - StructDLiteral<
BoundingBoxD, BoundingBoxC> - BoundingBoxD
Constructors
-
BoundingBoxD({Pointer<
BoundingBoxC> ? originalPointer, Vector3D? min, Vector3D? max}) - BoundingBoxD.bbox(Vector3D min, Vector3D max)
-
factory
- BoundingBoxD.zero()
-
factory
Properties
- allocKey → String
-
no setterinherited
- cStructName → String
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- internalId → int
-
no setterinherited
- isDisposed → bool
-
no setterinherited
- max ↔ Vector3D
-
getter/setter pair
- min ↔ Vector3D
-
getter/setter pair
-
originalPointer
↔ Pointer<
BoundingBoxC> ? -
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- structName → String
-
no setterinherited
- tag → String
-
no setterinherited
Methods
-
allocateInto(
RaylibTemp temp, Pointer< BoundingBoxC> p, String key) → void -
override
-
allocatePointer(
RaylibTemp temp, String key, [int count = 1]) → Pointer< BoundingBoxC> -
override
-
clone(
) → BoundingBoxD -
override
-
copy(
) → BoundingBoxD -
inherited
-
getOriginalPointer(
) → Pointer< BoundingBoxC> -
inherited
-
getOriginalPointerAndDispose(
) → Pointer< BoundingBoxC> -
inherited
-
markDisposed(
) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onOriginalPointer(
void callback(Pointer< BoundingBoxC> p)) → void -
inherited
-
setC(
BoundingBoxC o) → BoundingBoxD -
override
-
setD(
BoundingBoxD o) → BoundingBoxD -
override
-
setTag(
String newTag) → BoundingBoxD -
inherited
-
signature(
) → String -
override
-
syncInto(
RaylibTemp temp, Pointer< BoundingBoxC> p, String key) → void -
inherited
-
toC(
RaylibTemp temp, String key) → Pointer< BoundingBoxC> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
writeInto(
BoundingBoxC p) → void -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited