CallbackD<C extends Function, D extends Function> class
abstract
Properties
- function → D
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String
-
getter/setter pair
-
nativeFunction
→ Pointer<
NativeFunction< C> > -
no setter
-
registry
→ List<
CallbackD< Function, Function> > -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
attach(
) → Pointer< NativeFunction< C> > -
detach(
[bool keepAlive = false]) → void -
dispose(
) → void -
initializer(
) → NativeCallable< C> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
disposeRegistry(
List< CallbackD< registry) → voidFunction, Function> >