GuiControl enum
Values
- DEFAULT → const GuiControl
-
const GuiControl(0) - LABEL → const GuiControl
-
const GuiControl(1) - BUTTON → const GuiControl
-
const GuiControl(2) - TOGGLE → const GuiControl
-
const GuiControl(3) - SLIDER → const GuiControl
-
const GuiControl(4) - PROGRESSBAR → const GuiControl
-
const GuiControl(5) - CHECKBOX → const GuiControl
-
const GuiControl(6) - COMBOBOX → const GuiControl
-
const GuiControl(7) - DROPDOWNBOX → const GuiControl
-
const GuiControl(8) - TEXTBOX → const GuiControl
-
const GuiControl(9) - VALUEBOX → const GuiControl
-
const GuiControl(10) - CONTROL11 → const GuiControl
-
const GuiControl(11) - LISTVIEW → const GuiControl
-
const GuiControl(12) - COLORPICKER → const GuiControl
-
const GuiControl(13) - SCROLLBAR → const GuiControl
-
const GuiControl(14) - STATUSBAR → const GuiControl
-
const GuiControl(15)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → GuiControl
Constants
-
values
→ const List<
GuiControl> - A constant List of the values in this enum, in order of their declaration.