GuiDefaultProperty enum

Inheritance
Mixed-in types
Available extensions

Values

TEXT_SIZE → const GuiDefaultProperty
const GuiDefaultProperty(16)
TEXT_SPACING → const GuiDefaultProperty
const GuiDefaultProperty(17)
LINE_COLOR → const GuiDefaultProperty
const GuiDefaultProperty(18)
BACKGROUND_COLOR → const GuiDefaultProperty
const GuiDefaultProperty(19)
TEXT_LINE_SPACING → const GuiDefaultProperty
const GuiDefaultProperty(20)
TEXT_ALIGNMENT_VERTICAL → const GuiDefaultProperty
const GuiDefaultProperty(21)
TEXT_WRAP_MODE → const GuiDefaultProperty
const GuiDefaultProperty(22)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GuiDefaultProperty

Constants

values → const List<GuiDefaultProperty>
A constant List of the values in this enum, in order of their declaration.