GuiListViewProperty enum

Inheritance
Mixed-in types
Available extensions

Values

LIST_ITEMS_HEIGHT → const GuiListViewProperty
const GuiListViewProperty(16)
LIST_ITEMS_SPACING → const GuiListViewProperty
const GuiListViewProperty(17)
SCROLLBAR_WIDTH → const GuiListViewProperty
const GuiListViewProperty(18)
SCROLLBAR_SIDE → const GuiListViewProperty
const GuiListViewProperty(19)
LIST_ITEMS_BORDER_NORMAL → const GuiListViewProperty
const GuiListViewProperty(20)
LIST_ITEMS_BORDER_WIDTH → const GuiListViewProperty
const GuiListViewProperty(21)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) GuiListViewProperty

Constants

values → const List<GuiListViewProperty>
A constant List of the values in this enum, in order of their declaration.