HasTempHelpers mixin
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
rl
→ Raylib
-
no setter
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
refId(String x)
→ String
-
-
refLitSized<U extends NativeType, D>(int count, String? key, Pointer<U> alloc(String, [int]))
→ Pointer<U>
-
-
refPtrLitOrNull<U extends NativeType, D>(D? x, String key, Pointer<U> alloc([D, String]))
→ Pointer<U>
-
-
refPtrStructOrNull<U extends Struct, D extends StructD<D, U>>(D? x, String key, Pointer<U> alloc([D, String]))
→ Pointer<U>
-
-
refUpdateNullable$<T, C extends Struct, D extends StructD<D, C>>(D? o, T callback(Pointer<C> p), Pointer<C> alloc(D), void update(Pointer<C> p, D o))
→ T
-
-
toString()
→ String
-
A string representation of this object.
inherited