ImageD class

Inheritance
Available extensions

Constructors

ImageD({Pointer<ImageC>? originalPointer, int width = 0, int height = 0, int mipmaps = 0, PixelFormat format = .PIXELFORMAT_NONE, List<int>? data})
ImageD.zero()
factory

Properties

allocKey String
no setterinherited
bytesPerPixel int

Available on ImageD, provided by the ImageDLike extension

no setter
cStructName String
no setterinherited
data List<int>
getter/setter pair
format PixelFormat
getter/setter pair
frameSize int

Available on ImageD, provided by the ImageDLike extension

no setter
hashCode int
The hash code for this object.
no setterinherited
height int
getter/setter pair
internalId int
no setterinherited
isDisposed bool
no setterinherited
mipmaps int
getter/setter pair
originalPointer Pointer<ImageC>?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structName String
no setterinherited
tag String
no setterinherited
width int
getter/setter pair

Methods

allocateInto(RaylibTemp temp, Pointer<ImageC> p, String key) → void
override
allocatePointer(RaylibTemp temp, String key, [int count = 1]) Pointer<ImageC>
override
clone() ImageD
override
copy() ImageD
inherited
getOriginalPointer() Pointer<ImageC>
inherited
getOriginalPointerAndDispose() Pointer<ImageC>
inherited
markDisposed() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onOriginalPointer(void callback(Pointer<ImageC> p)) → void
inherited
setC(ImageC o) ImageD
override
setD(ImageD o) ImageD
override
setTag(String newTag) ImageD
inherited
signature() String
override
syncInto(RaylibTemp temp, Pointer<ImageC> p, String key) → void
inherited
toC(RaylibTemp temp, String key) Pointer<ImageC>
inherited
toString() String
A string representation of this object.
inherited
writeInto(ImageC p) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited