LightD class

Inheritance

Constructors

LightD({Pointer<LightC>? originalPointer, LightType type = .LIGHT_POINT, bool enabled = false, Vector3D? position, Vector3D? target, ColorD? color, double attenuation = 0, int enabledLoc = 0, int typeLoc = 0, int positionLoc = 0, int targetLoc = 0, int colorLoc = 0, int attenuationLoc = 0})
LightD.zero()
factory

Properties

allocKey String
no setterinherited
attenuation double
getter/setter pair
attenuationLoc int
getter/setter pair
color ColorD
getter/setter pair
colorLoc int
getter/setter pair
cStructName String
no setterinherited
enabled bool
getter/setter pair
enabledLoc int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
internalId int
no setterinherited
isDisposed bool
no setterinherited
originalPointer Pointer<LightC>?
getter/setter pairinherited
position Vector3D
getter/setter pair
positionLoc int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structName String
no setterinherited
tag String
no setterinherited
target Vector3D
getter/setter pair
targetLoc int
getter/setter pair
type LightType
getter/setter pair
typeLoc int
getter/setter pair

Methods

allocateInto(RaylibTemp temp, Pointer<LightC> p, String key) → void
override
allocatePointer(RaylibTemp temp, String key, [int count = 1]) Pointer<LightC>
override
clone() LightD
override
copy() LightD
inherited
getOriginalPointer() Pointer<LightC>
inherited
getOriginalPointerAndDispose() Pointer<LightC>
inherited
markDisposed() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onOriginalPointer(void callback(Pointer<LightC> p)) → void
inherited
setC(LightC o) LightD
override
setD(LightD o) LightD
override
setTag(String newTag) LightD
inherited
signature() String
override
syncInto(RaylibTemp temp, Pointer<LightC> p, String key) → void
inherited
toC(RaylibTemp temp, String key) Pointer<LightC>
inherited
toString() String
A string representation of this object.
inherited
writeInto(LightC p) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited