MaterialD class

Inheritance
Available extensions

Constructors

MaterialD({Pointer<MaterialC>? originalPointer, ShaderD? shader, List<MaterialMapD>? maps, List<double>? params})
MaterialD.zero()
factory

Properties

allocKey String
no setterinherited
cStructName String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
internalId int
no setterinherited
isDisposed bool
no setterinherited
mapCount int

Available on MaterialD, provided by the MaterialDLike extension

no setter
maps List<MaterialMapD>
getter/setter pair
originalPointer Pointer<MaterialC>?
getter/setter pairinherited
paramCount int

Available on MaterialD, provided by the MaterialDLike extension

no setter
params List<double>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shader ShaderD
getter/setter pair
structName String
no setterinherited
tag String
no setterinherited

Methods

allocateInto(RaylibTemp temp, Pointer<MaterialC> p, String key) → void
override
allocatePointer(RaylibTemp temp, String key, [int count = 1]) Pointer<MaterialC>
override
clone() MaterialD
override
copy() MaterialD
inherited
getOriginalPointer() Pointer<MaterialC>
inherited
getOriginalPointerAndDispose() Pointer<MaterialC>
inherited
markDisposed() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onOriginalPointer(void callback(Pointer<MaterialC> p)) → void
inherited
setC(MaterialC o) MaterialD
override
setD(MaterialD o) MaterialD
override
setTag(String newTag) MaterialD
inherited
signature() String
override
syncInto(RaylibTemp temp, Pointer<MaterialC> p, String key) → void
override
toC(RaylibTemp temp, String key) Pointer<MaterialC>
inherited
toString() String
A string representation of this object.
inherited
writeInto(MaterialC p) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited