MaterialMapC class final

Inheritance
Implemented types
Available extensions

Constructors

MaterialMapC()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
color ColorC
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
texture Texture2DC
getter/setter pair
value double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setC(MaterialMapC o) MaterialMapC

Available on MaterialMapC, provided by the MaterialMapCEx extension

setD(MaterialMapD o) MaterialMapC

Available on MaterialMapC, provided by the MaterialMapCEx extension

toD([Pointer<MaterialMapC>? ptr]) MaterialMapD

Available on MaterialMapC, provided by the MaterialMapCEx extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited