MaterialMapD class

Inheritance

Constructors

MaterialMapD({Pointer<MaterialMapC>? originalPointer, TextureD? texture, ColorD? color, double value = 0})
MaterialMapD.zero()
factory

Properties

allocKey String
no setterinherited
color ColorD
getter/setter pair
cStructName String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
internalId int
no setterinherited
isDisposed bool
no setterinherited
originalPointer Pointer<MaterialMapC>?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structName String
no setterinherited
tag String
no setterinherited
texture TextureD
getter/setter pair
value double
getter/setter pair

Methods

allocateInto(RaylibTemp temp, Pointer<MaterialMapC> p, String key) → void
override
allocatePointer(RaylibTemp temp, String key, [int count = 1]) Pointer<MaterialMapC>
override
clone() MaterialMapD
override
copy() MaterialMapD
inherited
getOriginalPointer() Pointer<MaterialMapC>
inherited
getOriginalPointerAndDispose() Pointer<MaterialMapC>
inherited
markDisposed() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onOriginalPointer(void callback(Pointer<MaterialMapC> p)) → void
inherited
setC(MaterialMapC o) MaterialMapD
override
setD(MaterialMapD o) MaterialMapD
override
setTag(String newTag) MaterialMapD
inherited
signature() String
override
syncInto(RaylibTemp temp, Pointer<MaterialMapC> p, String key) → void
inherited
toC(RaylibTemp temp, String key) Pointer<MaterialMapC>
inherited
toString() String
A string representation of this object.
inherited
writeInto(MaterialMapC p) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited