MeshD class
Constructors
-
MeshD({Pointer<
MeshC> ? originalPointer, int vertexCount = 0, int triangleCount = 0, int boneCount = 0, List<double> ? vertices, List<double> ? texcoords, List<double> ? texcoords2, List<double> ? normals, List<double> ? tangents, List<int> ? colors, List<int> ? indices, List<double> ? animVertices, List<double> ? animNormals, List<int> ? boneIds, List<double> ? boneWeights, List<MatrixD> ? boneMatrices, int vaoId = 0, List<int> ? vboId}) - MeshD.zero()
-
factory
Properties
- allocKey → String?
-
The RaylibTemp slot key used during the most recent toC allocation.
no setterinherited
-
animNormals
↔ List<
double> -
getter/setter pair
- animNormalsCount → int
-
Available on MeshD, provided by the MeshDLike extension
no setter -
animVertices
↔ List<
double> -
getter/setter pair
- animVerticesCount → int
-
Available on MeshD, provided by the MeshDLike extension
no setter - boneCount ↔ int
-
getter/setter pair
-
boneIds
↔ List<
int> -
getter/setter pair
- boneIdsCount → int
-
Available on MeshD, provided by the MeshDLike extension
no setter -
boneMatrices
↔ List<
MatrixD> -
getter/setter pair
- boneMatricesCount → int
-
Available on MeshD, provided by the MeshDLike extension
no setter -
boneWeights
↔ List<
double> -
getter/setter pair
- boneWeightsCount → int
-
Available on MeshD, provided by the MeshDLike extension
no setter -
colors
↔ List<
int> -
getter/setter pair
- colorsCount → int
-
Available on MeshD, provided by the MeshDLike extension
no setter - hashCode → int
-
The hash code for this object.
no setterinherited
-
indices
↔ List<
int> -
getter/setter pair
- indicesCount → int
-
Available on MeshD, provided by the MeshDLike extension
no setter - internalId → int
-
A stable numeric ID assigned on first toC call for pointer-owning structs.
no setterinherited
- isDisposed → bool
-
Whether markDisposed has been called on this instance.
no setterinherited
-
normals
↔ List<
double> -
getter/setter pair
- normalsCount → int
-
Available on MeshD, provided by the MeshDLike extension
no setter -
originalPointer
↔ Pointer<
MeshC> ? -
The C-owned or RaylibTemp-owned native pointer for this struct, if any.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- structName → String
-
The Dart-side type name of this struct
no setterinherited
- tag → String
-
The slot tag used to disambiguate RaylibTemp keys for this instance.
no setterinherited
-
tangents
↔ List<
double> -
getter/setter pair
- tangentsCount → int
-
Available on MeshD, provided by the MeshDLike extension
no setter -
texcoords
↔ List<
double> -
getter/setter pair
-
texcoords2
↔ List<
double> -
getter/setter pair
- texcoords2Count → int
-
Available on MeshD, provided by the MeshDLike extension
no setter - texcoordsCount → int
-
Available on MeshD, provided by the MeshDLike extension
no setter - triangleCount ↔ int
-
getter/setter pair
- vaoId ↔ int
-
getter/setter pair
-
vboId
↔ List<
int> -
getter/setter pair
- vertexCount ↔ int
-
getter/setter pair
-
vertices
↔ List<
double> -
getter/setter pair
- verticesCount → int
-
Available on MeshD, provided by the MeshDLike extension
no setter
Methods
-
allocateInto(
RaylibTemp temp, Pointer< MeshC> p, String key) → void -
Writes all fields into the native struct at
p, allocating nested pointers intotempunderkeyas needed.override -
allocatePointer(
RaylibTemp temp, String key, [int count = 1]) → Pointer< MeshC> -
Allocates a native slot of
countelements intempunderkeyand returns the resulting pointer.override -
clone(
) → MeshD -
Returns a deep copy of this instance, preserving originalPointer.
override
-
copy(
) → MeshD -
Returns a deep copy of this instance without originalPointer.
inherited
-
getOriginalPointer(
) → Pointer< MeshC> -
Returns originalPointer, throwing a descriptive StateError if unavailable or this instance isDisposed.
inherited
-
getOriginalPointerAndDispose(
) → Pointer< MeshC> -
Returns originalPointer and immediately calls markDisposed.
inherited
-
markDisposed(
) → void -
Marks this instance as disposed and clears originalPointer.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onOriginalPointer(
void callback(Pointer< MeshC> p)) → void -
Calls
callbackwith originalPointer if it is set, otherwise no-ops.inherited -
setC(
MeshC o) → MeshD -
Copies the fields of the native struct
ointo this instance.override -
setD(
MeshD o) → MeshD -
Copies the fields of the Dart struct
ointo this instance.override -
setTag(
String newTag) → MeshD -
Sets tag to
newTagand returnsthisfor chaining.inherited -
signature(
) → String -
Returns a human-readable description of this struct's current field values.
override
-
syncInto(
RaylibTemp temp, Pointer< MeshC> p, String key) → void -
Syncs Dart-side fields into the already-allocated native pointer
p.override -
toC(
RaylibTemp temp, String key) → Pointer< MeshC> -
Returns a native pointer for this struct, allocating or syncing as needed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
writeInto(
MeshC p) → void -
Writes all fields directly into the native struct reference
p. For nested structs, usewriteIntoas well.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited