ModelAnimationC class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - boneCount ↔ int
-
getter/setter pair
-
bones
↔ Pointer<
BoneInfoC> -
getter/setter pair
- frameCount ↔ int
-
getter/setter pair
-
framePoses
↔ Pointer<
Pointer< TransformC> > -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
name
↔ Array<
Char> -
getter/setter pair
- nameLength → int
-
Available on ModelAnimationC, provided by the ModelAnimationCLike extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setC(
ModelAnimationC o) → ModelAnimationC -
Available on ModelAnimationC, provided by the ModelAnimationCEx extension
-
setD(
ModelAnimationD o) → ModelAnimationC -
Available on ModelAnimationC, provided by the ModelAnimationCEx extension
-
toD(
[Pointer< ModelAnimationC> ? ptr]) → ModelAnimationD -
Available on ModelAnimationC, provided by the ModelAnimationCEx extension
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited