NPatchInfoCEx extension
- on
Methods
-
set(
num x, num y, num width, num height, num left, num top, num right, num bottom, int layout) → NPatchInfoC -
Available on NPatchInfoC, provided by the NPatchInfoCEx extension
-
setC(
NPatchInfoC o) → NPatchInfoC -
Available on NPatchInfoC, provided by the NPatchInfoCEx extension
-
setD(
NPatchInfoD o) → NPatchInfoC -
Available on NPatchInfoC, provided by the NPatchInfoCEx extension
-
toD(
[Pointer< NPatchInfoC> ? ptr]) → NPatchInfoD -
Available on NPatchInfoC, provided by the NPatchInfoCEx extension