NPatchInfoD class
- Inheritance
-
- Object
- StructD<
NPatchInfoD, NPatchInfoC> - NPatchInfoD
Constructors
-
NPatchInfoD({Pointer<
NPatchInfoC> ? originalPointer, RectangleD? source, int left = 0, int top = 0, int right = 0, int bottom = 0, NPatchLayout layout = .NPATCH_NINE_PATCH}) - NPatchInfoD.nPatchInfo(RectangleD source, num left, num top, num right, num bottom, NPatchLayout layout)
-
factory
- NPatchInfoD.zero()
-
factory
Properties
- allocKey → String
-
no setterinherited
- bottom ↔ int
-
getter/setter pair
- cStructName → String
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- internalId → int
-
no setterinherited
- isDisposed → bool
-
no setterinherited
- layout ↔ NPatchLayout
-
getter/setter pair
- left ↔ int
-
getter/setter pair
-
originalPointer
↔ Pointer<
NPatchInfoC> ? -
getter/setter pairinherited
- right ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source ↔ RectangleD
-
getter/setter pair
- structName → String
-
no setterinherited
- tag → String
-
no setterinherited
- top ↔ int
-
getter/setter pair
Methods
-
allocateInto(
RaylibTemp temp, Pointer< NPatchInfoC> p, String key) → void -
override
-
allocatePointer(
RaylibTemp temp, String key, [int count = 1]) → Pointer< NPatchInfoC> -
override
-
clone(
) → NPatchInfoD -
override
-
copy(
) → NPatchInfoD -
inherited
-
getOriginalPointer(
) → Pointer< NPatchInfoC> -
inherited
-
getOriginalPointerAndDispose(
) → Pointer< NPatchInfoC> -
inherited
-
markDisposed(
) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onOriginalPointer(
void callback(Pointer< NPatchInfoC> p)) → void -
inherited
-
set(
RectangleD source, num left, num top, num right, num bottom, NPatchLayout layout) → NPatchInfoD -
setC(
NPatchInfoC o) → NPatchInfoD -
override
-
setD(
NPatchInfoD o) → NPatchInfoD -
override
-
setTag(
String newTag) → NPatchInfoD -
inherited
-
signature(
) → String -
override
-
syncInto(
RaylibTemp temp, Pointer< NPatchInfoC> p, String key) → void -
inherited
-
toC(
RaylibTemp temp, String key) → Pointer< NPatchInfoC> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
writeInto(
NPatchInfoC p) → void -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited