Unslot method
Removes the slot entry for key from the table without freeing the
underlying memory.
Use when ownership of the pointer has been transferred elsewhere.
Implementation
void Unslot(String key) => _Slots.remove(_slotKey(key));
Removes the slot entry for key from the table without freeing the
underlying memory.
Use when ownership of the pointer has been transferred elsewhere.
void Unslot(String key) => _Slots.remove(_slotKey(key));