Allocates and returns an unslotted array of count Pointer<Char> pointers.
count
Pointer<Char>
The caller is responsible for freeing the returned pointer.
Pointer<Pointer<Char>> Raw([int count = 1]) => allocatorFunc(count);