RaylibCore class

Inheritance

Constructors

RaylibCore(Raylib lib)

Properties

hashCode int
The hash code for this object.
no setterinherited
logger → Logger
no setterinherited
rl Raylib
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

BeginBlendMode(int mode) → void
BeginDrawing() → void
BeginMode2D(Camera2DC camera) → void
BeginMode3D(Camera3DC camera) → void
BeginScissorMode(int x, int y, int width, int height) → void
BeginShaderMode(ShaderC shader) → void
BeginTextureMode(RenderTexture2DC target) → void
BeginVrStereoMode(VrStereoConfigC config) → void
ChangeDirectory(Pointer<Char> dir) bool
CheckCollisionBoxes(BoundingBoxC box1, BoundingBoxC box2) bool
CheckCollisionBoxSphere(BoundingBoxC box, Vector3C center, double radius) bool
CheckCollisionCircleLine(Vector2C center, double radius, Vector2C p1, Vector2C p2) bool
CheckCollisionCircleRec(Vector2C center, double radius, RectangleC rec) bool
CheckCollisionCircles(Vector2C center1, double radius1, Vector2C center2, double radius2) bool
CheckCollisionLines(Vector2C startPos1, Vector2C endPos1, Vector2C startPos2, Vector2C endPos2, Pointer<Vector2C> collisionPoint) bool
CheckCollisionPointCircle(Vector2C point, Vector2C center, double radius) bool
CheckCollisionPointLine(Vector2C point, Vector2C p1, Vector2C p2, int threshold) bool
CheckCollisionPointPoly(Vector2C point, Pointer<Vector2C> points, int pointCount) bool
CheckCollisionPointRec(Vector2C point, RectangleC rec) bool
CheckCollisionPointTriangle(Vector2C point, Vector2C p1, Vector2C p2, Vector2C p3) bool
CheckCollisionRecs(RectangleC rec1, RectangleC rec2) bool
CheckCollisionSpheres(Vector3C center1, double radius1, Vector3C center2, double radius2) bool
ClearBackground(ColorC color) → void
ClearWindowState(int flags) → void
CloseWindow() → void
CodepointToUTF8(int codepoint, Pointer<Int> utf8Size) Pointer<Char>
ColorAlpha(ColorC color, double alpha) ColorC
ColorAlphaBlend(ColorC dst, ColorC src, ColorC tint) ColorC
ColorBrightness(ColorC color, double factor) ColorC
ColorContrast(ColorC color, double contrast) ColorC
ColorFromHSV(double hue, double saturation, double value) ColorC
ColorFromNormalized(Vector4C normalized) ColorC
ColorIsEqual(ColorC col1, ColorC col2) bool
ColorLerp(ColorC color1, ColorC color2, double factor) ColorC
ColorNormalize(ColorC color) Vector4C
ColorTint(ColorC color, ColorC tint) ColorC
ColorToHSV(ColorC color) Vector3C
ColorToInt(ColorC color) int
CompressData(Pointer<UnsignedChar> data, int dataSize, Pointer<Int> compDataSize) Pointer<UnsignedChar>
ComputeCRC32(Pointer<UnsignedChar> data, int dataSize) int
ComputeMD5(Pointer<UnsignedChar> data, int dataSize) Pointer<UnsignedInt>
ComputeSHA1(Pointer<UnsignedChar> data, int dataSize) Pointer<UnsignedInt>
debug(bool v) → void
inherited
debugFilter(bool filter(String)) → void
inherited
debugInfo(String message) → void
inherited
debugTime(bool v) → void
inherited
debugWarn(String message) → void
inherited
DecodeDataBase64(Pointer<UnsignedChar> data, Pointer<Int> outputSize) Pointer<UnsignedChar>
DecompressData(Pointer<UnsignedChar> compData, int compDataSize, Pointer<Int> dataSize) Pointer<UnsignedChar>
DirectoryExists(Pointer<Char> dirPath) bool
DisableCursor() → void
DisableEventWaiting() → void
disableSync<T>(T f()) → T
inherited
dispose() → void
inherited
DrawBillboard(CameraC camera, Texture2DC texture, Vector3C position, double scale, ColorC tint) → void
DrawBillboardPro(CameraC camera, Texture2DC texture, RectangleC source, Vector3C position, Vector3C up, Vector2C size, Vector2C origin, double rotation, ColorC tint) → void
DrawBillboardRec(CameraC camera, Texture2DC texture, RectangleC source, Vector3C position, Vector2C size, ColorC tint) → void
DrawBoundingBox(BoundingBoxC box, ColorC color) → void
DrawCapsule(Vector3C startPos, Vector3C endPos, double radius, int slices, int rings, ColorC color) → void
DrawCapsuleWires(Vector3C startPos, Vector3C endPos, double radius, int slices, int rings, ColorC color) → void
DrawCircle(int centerX, int centerY, double radius, ColorC color) → void
DrawCircle3D(Vector3C center, double radius, Vector3C rotationAxis, double rotationAngle, ColorC color) → void
DrawCircleGradient(int centerX, int centerY, double radius, ColorC inner, ColorC outer) → void
DrawCircleLines(int centerX, int centerY, double radius, ColorC color) → void
DrawCircleLinesV(Vector2C center, double radius, ColorC color) → void
DrawCircleSector(Vector2C center, double radius, double startAngle, double endAngle, int segments, ColorC color) → void
DrawCircleSectorLines(Vector2C center, double radius, double startAngle, double endAngle, int segments, ColorC color) → void
DrawCircleV(Vector2C center, double radius, ColorC color) → void
DrawCube(Vector3C position, double width, double height, double length, ColorC color) → void
DrawCubeV(Vector3C position, Vector3C size, ColorC color) → void
DrawCubeWires(Vector3C position, double width, double height, double length, ColorC color) → void
DrawCubeWiresV(Vector3C position, Vector3C size, ColorC color) → void
DrawCylinder(Vector3C position, double radiusTop, double radiusBottom, double height, int slices, ColorC color) → void
DrawCylinderEx(Vector3C startPos, Vector3C endPos, double startRadius, double endRadius, int sides, ColorC color) → void
DrawCylinderWires(Vector3C position, double radiusTop, double radiusBottom, double height, int slices, ColorC color) → void
DrawCylinderWiresEx(Vector3C startPos, Vector3C endPos, double startRadius, double endRadius, int sides, ColorC color) → void
DrawEllipse(int centerX, int centerY, double radiusH, double radiusV, ColorC color) → void
DrawEllipseLines(int centerX, int centerY, double radiusH, double radiusV, ColorC color) → void
DrawFPS(int posX, int posY) → void
DrawGrid(int slices, double spacing) → void
DrawLine(int startPosX, int startPosY, int endPosX, int endPosY, ColorC color) → void
DrawLine3D(Vector3C startPos, Vector3C endPos, ColorC color) → void
DrawLineBezier(Vector2C startPos, Vector2C endPos, double thick, ColorC color) → void
DrawLineEx(Vector2C startPos, Vector2C endPos, double thick, ColorC color) → void
DrawLineStrip(Pointer<Vector2C> points, int pointCount, ColorC color) → void
DrawLineV(Vector2C startPos, Vector2C endPos, ColorC color) → void
DrawMesh(MeshC mesh, MaterialC material, MatrixC transform) → void
DrawMeshInstanced(MeshC mesh, MaterialC material, Pointer<MatrixC> transforms, int instances) → void
DrawModel(ModelC model, Vector3C position, double scale, ColorC tint) → void
DrawModelEx(ModelC model, Vector3C position, Vector3C rotationAxis, double rotationAngle, Vector3C scale, ColorC tint) → void
DrawModelPoints(ModelC model, Vector3C position, double scale, ColorC tint) → void
DrawModelPointsEx(ModelC model, Vector3C position, Vector3C rotationAxis, double rotationAngle, Vector3C scale, ColorC tint) → void
DrawModelWires(ModelC model, Vector3C position, double scale, ColorC tint) → void
DrawModelWiresEx(ModelC model, Vector3C position, Vector3C rotationAxis, double rotationAngle, Vector3C scale, ColorC tint) → void
DrawPixel(int posX, int posY, ColorC color) → void
DrawPixelV(Vector2C position, ColorC color) → void
DrawPlane(Vector3C centerPos, Vector2C size, ColorC color) → void
DrawPoint3D(Vector3C position, ColorC color) → void
DrawPoly(Vector2C center, int sides, double radius, double rotation, ColorC color) → void
DrawPolyLines(Vector2C center, int sides, double radius, double rotation, ColorC color) → void
DrawPolyLinesEx(Vector2C center, int sides, double radius, double rotation, double lineThick, ColorC color) → void
DrawRay(RayC ray, ColorC color) → void
DrawRectangle(int posX, int posY, int width, int height, ColorC color) → void
DrawRectangleGradientEx(RectangleC rec, ColorC topLeft, ColorC bottomLeft, ColorC topRight, ColorC bottomRight) → void
DrawRectangleGradientH(int posX, int posY, int width, int height, ColorC left, ColorC right) → void
DrawRectangleGradientV(int posX, int posY, int width, int height, ColorC top, ColorC bottom) → void
DrawRectangleLines(int posX, int posY, int width, int height, ColorC color) → void
DrawRectangleLinesEx(RectangleC rec, double lineThick, ColorC color) → void
DrawRectanglePro(RectangleC rec, Vector2C origin, double rotation, ColorC color) → void
DrawRectangleRec(RectangleC rec, ColorC color) → void
DrawRectangleRounded(RectangleC rec, double roundness, int segments, ColorC color) → void
DrawRectangleRoundedLines(RectangleC rec, double roundness, int segments, ColorC color) → void
DrawRectangleRoundedLinesEx(RectangleC rec, double roundness, int segments, double lineThick, ColorC color) → void
DrawRectangleV(Vector2C position, Vector2C size, ColorC color) → void
DrawRing(Vector2C center, double innerRadius, double outerRadius, double startAngle, double endAngle, int segments, ColorC color) → void
DrawRingLines(Vector2C center, double innerRadius, double outerRadius, double startAngle, double endAngle, int segments, ColorC color) → void
DrawSphere(Vector3C centerPos, double radius, ColorC color) → void
DrawSphereEx(Vector3C centerPos, double radius, int rings, int slices, ColorC color) → void
DrawSphereWires(Vector3C centerPos, double radius, int rings, int slices, ColorC color) → void
DrawSplineBasis(Pointer<Vector2C> points, int pointCount, double thick, ColorC color) → void
DrawSplineBezierCubic(Pointer<Vector2C> points, int pointCount, double thick, ColorC color) → void
DrawSplineBezierQuadratic(Pointer<Vector2C> points, int pointCount, double thick, ColorC color) → void
DrawSplineCatmullRom(Pointer<Vector2C> points, int pointCount, double thick, ColorC color) → void
DrawSplineLinear(Pointer<Vector2C> points, int pointCount, double thick, ColorC color) → void
DrawSplineSegmentBasis(Vector2C p1, Vector2C p2, Vector2C p3, Vector2C p4, double thick, ColorC color) → void
DrawSplineSegmentBezierCubic(Vector2C p1, Vector2C c2, Vector2C c3, Vector2C p4, double thick, ColorC color) → void
DrawSplineSegmentBezierQuadratic(Vector2C p1, Vector2C c2, Vector2C p3, double thick, ColorC color) → void
DrawSplineSegmentCatmullRom(Vector2C p1, Vector2C p2, Vector2C p3, Vector2C p4, double thick, ColorC color) → void
DrawSplineSegmentLinear(Vector2C p1, Vector2C p2, double thick, ColorC color) → void
DrawText(Pointer<Char> text, int posX, int posY, int fontSize, ColorC color) → void
DrawTextCodepoint(FontC font, int codepoint, Vector2C position, double fontSize, ColorC tint) → void
DrawTextCodepoints(FontC font, Pointer<Int> codepoints, int codepointCount, Vector2C position, double fontSize, double spacing, ColorC tint) → void
DrawTextEx(FontC font, Pointer<Char> text, Vector2C position, double fontSize, double spacing, ColorC tint) → void
DrawTextPro(FontC font, Pointer<Char> text, Vector2C position, Vector2C origin, double rotation, double fontSize, double spacing, ColorC tint) → void
DrawTexture(Texture2DC texture, int posX, int posY, ColorC tint) → void
DrawTextureEx(Texture2DC texture, Vector2C position, double rotation, double scale, ColorC tint) → void
DrawTextureNPatch(Texture2DC texture, NPatchInfoC nPatchInfo, RectangleC dest, Vector2C origin, double rotation, ColorC tint) → void
DrawTexturePro(Texture2DC texture, RectangleC source, RectangleC dest, Vector2C origin, double rotation, ColorC tint) → void
DrawTextureRec(Texture2DC texture, RectangleC source, Vector2C position, ColorC tint) → void
DrawTextureV(Texture2DC texture, Vector2C position, ColorC tint) → void
DrawTriangle(Vector2C v1, Vector2C v2, Vector2C v3, ColorC color) → void
DrawTriangle3D(Vector3C v1, Vector3C v2, Vector3C v3, ColorC color) → void
DrawTriangleFan(Pointer<Vector2C> points, int pointCount, ColorC color) → void
DrawTriangleLines(Vector2C v1, Vector2C v2, Vector2C v3, ColorC color) → void
DrawTriangleStrip(Pointer<Vector2C> points, int pointCount, ColorC color) → void
DrawTriangleStrip3D(Pointer<Vector3C> points, int pointCount, ColorC color) → void
EnableCursor() → void
EnableEventWaiting() → void
EncodeDataBase64(Pointer<UnsignedChar> data, int dataSize, Pointer<Int> outputSize) Pointer<Char>
EndBlendMode() → void
EndDrawing() → void
EndMode2D() → void
EndMode3D() → void
EndScissorMode() → void
EndShaderMode() → void
EndTextureMode() → void
EndVrStereoMode() → void
ExportAutomationEventList(AutomationEventListC list, Pointer<Char> fileName) bool
ExportDataAsCode(Pointer<UnsignedChar> data, int dataSize, Pointer<Char> fileName) bool
ExportFontAsCode(FontC font, Pointer<Char> fileName) bool
ExportImage(ImageC image, Pointer<Char> fileName) bool
ExportImageAsCode(ImageC image, Pointer<Char> fileName) bool
ExportImageToMemory(ImageC image, Pointer<Char> fileType, Pointer<Int> fileSize) Pointer<UnsignedChar>
ExportMesh(MeshC mesh, Pointer<Char> fileName) bool
ExportMeshAsCode(MeshC mesh, Pointer<Char> fileName) bool
Fade(ColorC color, double alpha) ColorC
FileExists(Pointer<Char> fileName) bool
GenImageCellular(int width, int height, int tileSize) ImageC
GenImageChecked(int width, int height, int checksX, int checksY, ColorC col1, ColorC col2) ImageC
GenImageColor(int width, int height, ColorC color) ImageC
GenImageFontAtlas(Pointer<GlyphInfoC> glyphs, Pointer<Pointer<RectangleC>> glyphRecs, int glyphCount, int fontSize, int padding, int packMethod) ImageC
GenImageGradientLinear(int width, int height, int direction, ColorC start, ColorC end) ImageC
GenImageGradientRadial(int width, int height, double density, ColorC inner, ColorC outer) ImageC
GenImageGradientSquare(int width, int height, double density, ColorC inner, ColorC outer) ImageC
GenImagePerlinNoise(int width, int height, int offsetX, int offsetY, double scale) ImageC
GenImageText(int width, int height, Pointer<Char> text) ImageC
GenImageWhiteNoise(int width, int height, double factor) ImageC
GenMeshCone(double radius, double height, int slices) MeshC
GenMeshCube(double width, double height, double length) MeshC
GenMeshCubicmap(ImageC cubicmap, Vector3C cubeSize) MeshC
GenMeshCylinder(double radius, double height, int slices) MeshC
GenMeshHeightmap(ImageC heightmap, Vector3C size) MeshC
GenMeshHemiSphere(double radius, int rings, int slices) MeshC
GenMeshKnot(double radius, double size, int radSeg, int sides) MeshC
GenMeshPlane(double width, double length, int resX, int resZ) MeshC
GenMeshPoly(int sides, double radius) MeshC
GenMeshSphere(double radius, int rings, int slices) MeshC
GenMeshTangents(Pointer<MeshC> mesh) → void
GenMeshTorus(double radius, double size, int radSeg, int sides) MeshC
GenTextureMipmaps(Pointer<Texture2DC> texture) → void
GetApplicationDirectory() Pointer<Char>
GetCameraMatrix(CameraC camera) MatrixC
GetCameraMatrix2D(Camera2DC camera) MatrixC
GetCharPressed() int
GetClipboardImage() ImageC
GetClipboardText() Pointer<Char>
GetCodepoint(Pointer<Char> text, Pointer<Int> codepointSize) int
GetCodepointCount(Pointer<Char> text) int
GetCodepointNext(Pointer<Char> text, Pointer<Int> codepointSize) int
GetCodepointPrevious(Pointer<Char> text, Pointer<Int> codepointSize) int
GetCollisionRec(RectangleC rec1, RectangleC rec2) RectangleC
GetColor(int hexValue) ColorC
GetCurrentMonitor() int
GetDirectoryPath(Pointer<Char> filePath) Pointer<Char>
GetFileExtension(Pointer<Char> fileName) Pointer<Char>
GetFileLength(Pointer<Char> fileName) int
GetFileModTime(Pointer<Char> fileName) int
GetFileName(Pointer<Char> filePath) Pointer<Char>
GetFileNameWithoutExt(Pointer<Char> filePath) Pointer<Char>
GetFontDefault() FontC
GetFPS() int
GetFrameTime() double
GetGamepadAxisCount(int gamepad) int
GetGamepadAxisMovement(int gamepad, int axis) double
GetGamepadButtonPressed() int
GetGamepadName(int gamepad) Pointer<Char>
GetGestureDetected() int
GetGestureDragAngle() double
GetGestureDragVector() Vector2C
GetGestureHoldDuration() double
GetGesturePinchAngle() double
GetGesturePinchVector() Vector2C
GetGlyphAtlasRec(FontC font, int codepoint) RectangleC
GetGlyphIndex(FontC font, int codepoint) int
GetGlyphInfo(FontC font, int codepoint) GlyphInfoC
GetImageAlphaBorder(ImageC image, double threshold) RectangleC
GetImageColor(ImageC image, int x, int y) ColorC
GetKeyPressed() int
GetMeshBoundingBox(MeshC mesh) BoundingBoxC
GetModelBoundingBox(ModelC model) BoundingBoxC
GetMonitorCount() int
GetMonitorHeight(int monitor) int
GetMonitorName(int monitor) Pointer<Char>
GetMonitorPhysicalHeight(int monitor) int
GetMonitorPhysicalWidth(int monitor) int
GetMonitorPosition(int monitor) Vector2C
GetMonitorRefreshRate(int monitor) int
GetMonitorWidth(int monitor) int
GetMouseDelta() Vector2C
GetMousePosition() Vector2C
GetMouseWheelMove() double
GetMouseWheelMoveV() Vector2C
GetMouseX() int
GetMouseY() int
GetPixelColor(Pointer<Void> srcPtr, int format) ColorC
GetPixelDataSize(int width, int height, int format) int
GetPrevDirectoryPath(Pointer<Char> dirPath) Pointer<Char>
GetRandomValue(int min, int max) int
GetRayCollisionBox(RayC ray, BoundingBoxC box) RayCollisionC
GetRayCollisionMesh(RayC ray, MeshC mesh, MatrixC transform) RayCollisionC
GetRayCollisionQuad(RayC ray, Vector3C p1, Vector3C p2, Vector3C p3, Vector3C p4) RayCollisionC
GetRayCollisionSphere(RayC ray, Vector3C center, double radius) RayCollisionC
GetRayCollisionTriangle(RayC ray, Vector3C p1, Vector3C p2, Vector3C p3) RayCollisionC
GetRenderHeight() int
GetRenderWidth() int
GetScreenHeight() int
GetScreenToWorld2D(Vector2C position, Camera2DC camera) Vector2C
GetScreenToWorldRay(Vector2C position, CameraC camera) RayC
GetScreenToWorldRayEx(Vector2C position, CameraC camera, int width, int height) RayC
GetScreenWidth() int
GetShaderLocation(ShaderC shader, Pointer<Char> uniformName) int
GetShaderLocationAttrib(ShaderC shader, Pointer<Char> attribName) int
GetShapesTexture() Texture2DC
GetShapesTextureRectangle() RectangleC
GetSplinePointBasis(Vector2C p1, Vector2C p2, Vector2C p3, Vector2C p4, double t) Vector2C
GetSplinePointBezierCubic(Vector2C p1, Vector2C c2, Vector2C c3, Vector2C p4, double t) Vector2C
GetSplinePointBezierQuad(Vector2C p1, Vector2C c2, Vector2C p3, double t) Vector2C
GetSplinePointCatmullRom(Vector2C p1, Vector2C p2, Vector2C p3, Vector2C p4, double t) Vector2C
GetSplinePointLinear(Vector2C startPos, Vector2C endPos, double t) Vector2C
GetTime() double
GetTouchPointCount() int
GetTouchPointId(int index) int
GetTouchPosition(int index) Vector2C
GetTouchX() int
GetTouchY() int
GetWindowHandle() Pointer<Void>
GetWindowPosition() Vector2C
GetWindowScaleDPI() Vector2C
GetWorkingDirectory() Pointer<Char>
GetWorldToScreen(Vector3C position, CameraC camera) Vector2C
GetWorldToScreen2D(Vector2C position, Camera2DC camera) Vector2C
GetWorldToScreenEx(Vector3C position, CameraC camera, int width, int height) Vector2C
HideCursor() → void
ImageAlphaClear(Pointer<ImageC> image, ColorC color, double threshold) → void
ImageAlphaCrop(Pointer<ImageC> image, double threshold) → void
ImageAlphaMask(Pointer<ImageC> image, ImageC alphaMask) → void
ImageAlphaPremultiply(Pointer<ImageC> image) → void
ImageBlurGaussian(Pointer<ImageC> image, int blurSize) → void
ImageClearBackground(Pointer<ImageC> dst, ColorC color) → void
ImageColorBrightness(Pointer<ImageC> image, int brightness) → void
ImageColorContrast(Pointer<ImageC> image, double contrast) → void
ImageColorGrayscale(Pointer<ImageC> image) → void
ImageColorInvert(Pointer<ImageC> image) → void
ImageColorReplace(Pointer<ImageC> image, ColorC color, ColorC replace) → void
ImageColorTint(Pointer<ImageC> image, ColorC color) → void
ImageCopy(ImageC image) ImageC
ImageCrop(Pointer<ImageC> image, RectangleC crop) → void
ImageDither(Pointer<ImageC> image, int rBpp, int gBpp, int bBpp, int aBpp) → void
ImageDraw(Pointer<ImageC> dst, ImageC src, RectangleC srcRec, RectangleC dstRec, ColorC tint) → void
ImageDrawCircle(Pointer<ImageC> dst, int centerX, int centerY, int radius, ColorC color) → void
ImageDrawCircleLines(Pointer<ImageC> dst, int centerX, int centerY, int radius, ColorC color) → void
ImageDrawCircleLinesV(Pointer<ImageC> dst, Vector2C center, int radius, ColorC color) → void
ImageDrawCircleV(Pointer<ImageC> dst, Vector2C center, int radius, ColorC color) → void
ImageDrawLine(Pointer<ImageC> dst, int startPosX, int startPosY, int endPosX, int endPosY, ColorC color) → void
ImageDrawLineEx(Pointer<ImageC> dst, Vector2C start, Vector2C end, int thick, ColorC color) → void
ImageDrawLineV(Pointer<ImageC> dst, Vector2C start, Vector2C end, ColorC color) → void
ImageDrawPixel(Pointer<ImageC> dst, int posX, int posY, ColorC color) → void
ImageDrawPixelV(Pointer<ImageC> dst, Vector2C position, ColorC color) → void
ImageDrawRectangle(Pointer<ImageC> dst, int posX, int posY, int width, int height, ColorC color) → void
ImageDrawRectangleLines(Pointer<ImageC> dst, RectangleC rec, int thick, ColorC color) → void
ImageDrawRectangleRec(Pointer<ImageC> dst, RectangleC rec, ColorC color) → void
ImageDrawRectangleV(Pointer<ImageC> dst, Vector2C position, Vector2C size, ColorC color) → void
ImageDrawText(Pointer<ImageC> dst, Pointer<Char> text, int posX, int posY, int fontSize, ColorC color) → void
ImageDrawTextEx(Pointer<ImageC> dst, FontC font, Pointer<Char> text, Vector2C position, double fontSize, double spacing, ColorC tint) → void
ImageDrawTriangle(Pointer<ImageC> dst, Vector2C v1, Vector2C v2, Vector2C v3, ColorC color) → void
ImageDrawTriangleEx(Pointer<ImageC> dst, Vector2C v1, Vector2C v2, Vector2C v3, ColorC c1, ColorC c2, ColorC c3) → void
ImageDrawTriangleFan(Pointer<ImageC> dst, Pointer<Vector2C> points, int pointCount, ColorC color) → void
ImageDrawTriangleLines(Pointer<ImageC> dst, Vector2C v1, Vector2C v2, Vector2C v3, ColorC color) → void
ImageDrawTriangleStrip(Pointer<ImageC> dst, Pointer<Vector2C> points, int pointCount, ColorC color) → void
ImageFlipHorizontal(Pointer<ImageC> image) → void
ImageFlipVertical(Pointer<ImageC> image) → void
ImageFormat(Pointer<ImageC> image, int newFormat) → void
ImageFromChannel(ImageC image, int selectedChannel) ImageC
ImageFromImage(ImageC image, RectangleC rec) ImageC
ImageKernelConvolution(Pointer<ImageC> image, Pointer<Float> kernel, int kernelSize) → void
ImageMipmaps(Pointer<ImageC> image) → void
ImageResize(Pointer<ImageC> image, int newWidth, int newHeight) → void
ImageResizeCanvas(Pointer<ImageC> image, int newWidth, int newHeight, int offsetX, int offsetY, ColorC fill) → void
ImageResizeNN(Pointer<ImageC> image, int newWidth, int newHeight) → void
ImageRotate(Pointer<ImageC> image, int degrees) → void
ImageRotateCCW(Pointer<ImageC> image) → void
ImageRotateCW(Pointer<ImageC> image) → void
ImageText(Pointer<Char> text, int fontSize, ColorC color) ImageC
ImageTextEx(FontC font, Pointer<Char> text, double fontSize, double spacing, ColorC tint) ImageC
ImageToPOT(Pointer<ImageC> image, ColorC fill) → void
InitWindow(int width, int height, Pointer<Char> title) → void
IsCursorHidden() bool
IsCursorOnScreen() bool
IsFileDropped() bool
IsFileExtension(Pointer<Char> fileName, Pointer<Char> ext) bool
IsFileNameValid(Pointer<Char> fileName) bool
IsFontValid(FontC font) bool
IsGamepadAvailable(int gamepad) bool
IsGamepadButtonDown(int gamepad, int button) bool
IsGamepadButtonPressed(int gamepad, int button) bool
IsGamepadButtonReleased(int gamepad, int button) bool
IsGamepadButtonUp(int gamepad, int button) bool
IsGestureDetected(int gesture) bool
IsImageValid(ImageC image) bool
IsKeyDown(int key) bool
IsKeyPressed(int key) bool
IsKeyPressedRepeat(int key) bool
IsKeyReleased(int key) bool
IsKeyUp(int key) bool
IsMaterialValid(MaterialC material) bool
IsModelAnimationValid(ModelC model, ModelAnimationC anim) bool
IsModelValid(ModelC model) bool
IsMouseButtonDown(int button) bool
IsMouseButtonPressed(int button) bool
IsMouseButtonReleased(int button) bool
IsMouseButtonUp(int button) bool
IsPathFile(Pointer<Char> path) bool
IsRenderTextureValid(RenderTexture2DC target) bool
IsShaderValid(ShaderC shader) bool
IsTextureValid(Texture2DC texture) bool
IsWindowFocused() bool
IsWindowFullscreen() bool
IsWindowHidden() bool
IsWindowMaximized() bool
IsWindowMinimized() bool
IsWindowReady() bool
IsWindowResized() bool
IsWindowState(int flag) bool
load() → void
inherited
LoadAutomationEventList(Pointer<Char> fileName) AutomationEventListC
LoadCodepoints(Pointer<Char> text, Pointer<Int> count) Pointer<Int>
LoadDirectoryFiles(Pointer<Char> dirPath) FilePathListC
LoadDirectoryFilesEx(Pointer<Char> basePath, Pointer<Char> filter, bool scanSubdirs) FilePathListC
LoadDroppedFiles() FilePathListC
LoadFileData(Pointer<Char> fileName, Pointer<Int> dataSize) Pointer<UnsignedChar>
LoadFileText(Pointer<Char> fileName) Pointer<Char>
LoadFont(Pointer<Char> fileName) FontC
LoadFontData(Pointer<UnsignedChar> fileData, int dataSize, int fontSize, Pointer<Int> codepoints, int codepointCount, int type) Pointer<GlyphInfoC>
LoadFontEx(Pointer<Char> fileName, int fontSize, Pointer<Int> codepoints, int codepointCount) FontC
LoadFontFromImage(ImageC image, ColorC key, int firstChar) FontC
LoadFontFromMemory(Pointer<Char> fileType, Pointer<UnsignedChar> fileData, int dataSize, int fontSize, Pointer<Int> codepoints, int codepointCount) FontC
LoadImage(Pointer<Char> fileName) ImageC
LoadImageAnim(Pointer<Char> fileName, Pointer<Int> frames) ImageC
LoadImageAnimFromMemory(Pointer<Char> fileType, Pointer<UnsignedChar> fileData, int dataSize, Pointer<Int> frames) ImageC
LoadImageColors(ImageC image) Pointer<ColorC>
LoadImageFromMemory(Pointer<Char> fileType, Pointer<UnsignedChar> fileData, int dataSize) ImageC
LoadImageFromScreen() ImageC
LoadImageFromTexture(Texture2DC texture) ImageC
LoadImagePalette(ImageC image, int maxPaletteSize, Pointer<Int> colorCount) Pointer<ColorC>
LoadImageRaw(Pointer<Char> fileName, int width, int height, int format, int headerSize) ImageC
LoadMaterialDefault() MaterialC
LoadMaterials(Pointer<Char> fileName, Pointer<Int> materialCount) Pointer<MaterialC>
LoadModel(Pointer<Char> fileName) ModelC
LoadModelAnimations(Pointer<Char> fileName, Pointer<Int> animCount) Pointer<ModelAnimationC>
LoadModelFromMesh(MeshC mesh) ModelC
LoadRandomSequence(int count, int min, int max) Pointer<Int>
LoadRenderTexture(int width, int height) RenderTexture2DC
LoadShader(Pointer<Char> vsFileName, Pointer<Char> fsFileName) ShaderC
LoadShaderFromMemory(Pointer<Char> vsCode, Pointer<Char> fsCode) ShaderC
LoadTexture(Pointer<Char> fileName) Texture2DC
LoadTextureCubemap(ImageC image, int layout) TextureCubemapC
LoadTextureFromImage(ImageC image) Texture2DC
LoadUTF8(Pointer<Int> codepoints, int length) Pointer<Char>
LoadVrStereoConfig(VrDeviceInfoC device) VrStereoConfigC
logInfo(String message) → void
inherited
logWarn(String message) → void
inherited
MakeDirectory(Pointer<Char> dirPath) int
MaximizeWindow() → void
MeasureText(Pointer<Char> text, int fontSize) int
MeasureTextEx(FontC font, Pointer<Char> text, double fontSize, double spacing) Vector2C
MinimizeWindow() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose(void fn()) → void
inherited
OpenURL(Pointer<Char> url) → void
PlayAutomationEvent(AutomationEventC event) → void
PollInputEvents() → void
RestoreWindow() → void
run<T>(String name(), T f()) → T
inherited
SaveFileData(Pointer<Char> fileName, Pointer<Void> data, int dataSize) bool
SaveFileText(Pointer<Char> fileName, Pointer<Char> text) bool
SetAutomationEventBaseFrame(int frame) → void
SetAutomationEventList(Pointer<AutomationEventListC> list) → void
SetClipboardText(Pointer<Char> text) → void
SetConfigFlags(int flags) → void
SetExitKey(int key) → void
SetGamepadMappings(Pointer<Char> mappings) int
SetGamepadVibration(int gamepad, double leftMotor, double rightMotor, double duration) → void
SetGesturesEnabled(int flags) → void
SetLoadFileDataCallback(LoadFileDataCallbackC callback) → void
SetLoadFileTextCallback(LoadFileTextCallbackC callback) → void
SetMaterialTexture(Pointer<MaterialC> material, int mapType, Texture2DC texture) → void
SetModelMeshMaterial(Pointer<ModelC> model, int meshId, int materialId) → void
SetMouseCursor(int cursor) → void
SetMouseOffset(int offsetX, int offsetY) → void
SetMousePosition(int x, int y) → void
SetMouseScale(double scaleX, double scaleY) → void
SetPixelColor(Pointer<Void> dstPtr, ColorC color, int format) → void
SetRandomSeed(int seed) → void
SetSaveFileDataCallback(SaveFileDataCallbackC callback) → void
SetSaveFileTextCallback(SaveFileTextCallbackC callback) → void
SetShaderValue(ShaderC shader, int locIndex, Pointer<Void> value, int uniformType) → void
SetShaderValueMatrix(ShaderC shader, int locIndex, MatrixC mat) → void
SetShaderValueTexture(ShaderC shader, int locIndex, Texture2DC texture) → void
SetShaderValueV(ShaderC shader, int locIndex, Pointer<Void> value, int uniformType, int count) → void
SetShapesTexture(Texture2DC texture, RectangleC source) → void
SetTargetFPS(int fps) → void
SetTextLineSpacing(int spacing) → void
SetTextureFilter(Texture2DC texture, int filter) → void
SetTextureWrap(Texture2DC texture, int wrap) → void
SetTraceLogLevel(int logLevel) → void
SetWindowFocused() → void
SetWindowIcon(ImageC image) → void
SetWindowIcons(Pointer<ImageC> images, int count) → void
SetWindowMaxSize(int width, int height) → void
SetWindowMinSize(int width, int height) → void
SetWindowMonitor(int monitor) → void
SetWindowOpacity(double opacity) → void
SetWindowPosition(int x, int y) → void
SetWindowSize(int width, int height) → void
SetWindowState(int flags) → void
SetWindowTitle(Pointer<Char> title) → void
ShowCursor() → void
StartAutomationEventRecording() → void
StopAutomationEventRecording() → void
SwapScreenBuffer() → void
TakeScreenshot(Pointer<Char> fileName) → void
TextAppend(Pointer<Char> text, Pointer<Char> append, Pointer<Int> position) → void
TextCopy(Pointer<Char> dst, Pointer<Char> src) int
TextFindIndex(Pointer<Char> text, Pointer<Char> find) int
TextFormat(Pointer<Char> text) Pointer<Char>
TextInsert(Pointer<Char> text, Pointer<Char> insert, int position) Pointer<Char>
TextIsEqual(Pointer<Char> text1, Pointer<Char> text2) bool
TextJoin(Pointer<Pointer<Char>> textList, int count, Pointer<Char> delimiter) Pointer<Char>
TextLength(Pointer<Char> text) int
TextReplace(Pointer<Char> text, Pointer<Char> replace, Pointer<Char> by) Pointer<Char>
TextSplit(Pointer<Char> text, int delimiter, Pointer<Int> count) Pointer<Pointer<Char>>
TextSubtext(Pointer<Char> text, int position, int length) Pointer<Char>
TextToCamel(Pointer<Char> text) Pointer<Char>
TextToFloat(Pointer<Char> text) double
TextToInteger(Pointer<Char> text) int
TextToLower(Pointer<Char> text) Pointer<Char>
TextToPascal(Pointer<Char> text) Pointer<Char>
TextToSnake(Pointer<Char> text) Pointer<Char>
TextToUpper(Pointer<Char> text) Pointer<Char>
ToggleBorderlessWindowed() → void
ToggleFullscreen() → void
toString() String
A string representation of this object.
inherited
TraceLog(int logLevel, Pointer<Char> text) → void
UnloadAutomationEventList(AutomationEventListC list) → void
UnloadCodepoints(Pointer<Int> codepoints) → void
UnloadDirectoryFiles(FilePathListC files) → void
UnloadDroppedFiles(FilePathListC files) → void
UnloadFileData(Pointer<UnsignedChar> data) → void
UnloadFileText(Pointer<Char> text) → void
UnloadFont(FontC font) → void
UnloadFontData(Pointer<GlyphInfoC> glyphs, int glyphCount) → void
UnloadImage(ImageC image) → void
UnloadImageColors(Pointer<ColorC> colors) → void
UnloadImagePalette(Pointer<ColorC> colors) → void
UnloadMaterial(MaterialC material) → void
UnloadMesh(MeshC mesh) → void
UnloadModel(ModelC model) → void
UnloadModelAnimation(ModelAnimationC anim) → void
UnloadModelAnimations(Pointer<ModelAnimationC> animations, int animCount) → void
UnloadRandomSequence(Pointer<Int> sequence) → void
UnloadRenderTexture(RenderTexture2DC target) → void
UnloadShader(ShaderC shader) → void
UnloadTexture(Texture2DC texture) → void
UnloadUTF8(Pointer<Char> text) → void
UnloadVrStereoConfig(VrStereoConfigC config) → void
UpdateCamera(Pointer<CameraC> camera, int mode) → void
UpdateCameraPro(Pointer<CameraC> camera, Vector3C movement, Vector3C rotation, double zoom) → void
UpdateMeshBuffer(MeshC mesh, int index, Pointer<Void> data, int dataSize, int offset) → void
UpdateModelAnimation(ModelC model, ModelAnimationC anim, int frame) → void
UpdateModelAnimationBones(ModelC model, ModelAnimationC anim, int frame) → void
UpdateTexture(Texture2DC texture, Pointer<Void> pixels) → void
UpdateTextureRec(Texture2DC texture, RectangleC rec, Pointer<Void> pixels) → void
UploadMesh(Pointer<MeshC> mesh, bool dynamic) → void
WaitTime(double seconds) → void
WindowShouldClose() bool

Operators

operator ==(Object other) bool
The equality operator.
inherited