RaylibGuiD class

Inheritance
Mixed-in types

Constructors

RaylibGuiD(Raylib lib)

Properties

guiIcons List<int>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
ICON_TEXT_PADDING int
no setterinherited
logger → Logger
no setterinherited
MAX_LINE_BUFFER_SIZE int
no setterinherited
RAYGUI_COLORBARALPHA_CHECKED_SIZE int
no setterinherited
RAYGUI_GRID_ALPHA double
no setterinherited
RAYGUI_GROUPBOX_LINE_THICK int
no setterinherited
RAYGUI_ICON_DATA_ELEMENTS int
no setterinherited
RAYGUI_ICON_MAX_ICONS int
no setterinherited
RAYGUI_ICON_MAX_NAME_LENGTH int
no setterinherited
RAYGUI_ICON_SIZE int
no setterinherited
RAYGUI_LINE_MARGIN_TEXT int
no setterinherited
RAYGUI_LINE_TEXT_PADDING int
no setterinherited
RAYGUI_MAX_CONTROLS int
no setterinherited
RAYGUI_MAX_PROPS_BASE int
no setterinherited
RAYGUI_MAX_PROPS_EXTENDED int
no setterinherited
RAYGUI_MAX_TEXT_LINES int
no setterinherited
RAYGUI_MESSAGEBOX_BUTTON_HEIGHT int
no setterinherited
RAYGUI_MESSAGEBOX_BUTTON_PADDING int
no setterinherited
RAYGUI_MIN_MOUSE_WHEEL_SPEED int
no setterinherited
RAYGUI_MIN_SCROLLBAR_HEIGHT int
no setterinherited
RAYGUI_MIN_SCROLLBAR_WIDTH int
no setterinherited
RAYGUI_PANEL_BORDER_WIDTH int
no setterinherited
RAYGUI_TABBAR_ITEM_WIDTH int
no setterinherited
RAYGUI_TEXTBOX_AUTO_CURSOR_COOLDOWN int
no setterinherited
RAYGUI_TEXTBOX_AUTO_CURSOR_DELAY int
no setterinherited
RAYGUI_TEXTFORMAT_MAX_SIZE int
no setterinherited
RAYGUI_TEXTINPUTBOX_BUTTON_HEIGHT int
no setterinherited
RAYGUI_TEXTINPUTBOX_BUTTON_PADDING int
no setterinherited
RAYGUI_TEXTINPUTBOX_HEIGHT int
no setterinherited
RAYGUI_TEXTSPLIT_MAX_ITEMS int
no setterinherited
RAYGUI_TEXTSPLIT_MAX_TEXT_SIZE int
no setterinherited
RAYGUI_TOGGLEGROUP_MAX_ITEMS int
no setterinherited
RAYGUI_VALUEBOX_MAX_CHARS int
no setterinherited
RAYGUI_VERSION String
no setterinherited
RAYGUI_VERSION_MAJOR int
no setterinherited
RAYGUI_VERSION_MINOR int
no setterinherited
RAYGUI_VERSION_PATCH int
no setterinherited
RAYGUI_WINDOWBOX_STATUSBAR_HEIGHT int
no setterinherited
rl Raylib
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
SCROLLBAR_LEFT_SIDE int
no setterinherited
SCROLLBAR_RIGHT_SIDE int
no setterinherited

Methods

debug(bool v) → void
inherited
debugFilter(bool filter(String)) → void
inherited
debugInfo(String message) → void
inherited
debugTime(bool v) → void
inherited
debugWarn(String message) → void
inherited
disableSync<T>(T f()) → T
inherited
dispose() → void
inherited
GuiButton(RectangleD bounds, String? text) int
GuiCheckBox(RectangleD bounds, String? text, bool checked) → (int, bool)
GuiColorBarAlpha(RectangleD bounds, num alpha) → (int, double)
GuiColorBarHue(RectangleD bounds, num value) → (int, double)
GuiColorPanel(RectangleD bounds, ColorD color) → (int, ColorD)
GuiColorPanelHSV(RectangleD bounds, [Vector3D? colorHsv]) → (int, Vector3D)
GuiColorPicker(RectangleD bounds, ColorD? color) → (int, ColorD)
GuiColorPickerHSV(RectangleD bounds, [Vector3D? colorHsv]) → (int, Vector3D)
GuiComboBox(RectangleD bounds, String? text, num active) → (int, int)
GuiDisable() → void
GuiDisableTooltip() → void
GuiDrawIcon(GuiIconName iconId, num posX, num posY, num pixelSize, ColorD color) → void
GuiDropdownBox(RectangleD bounds, String? text, num active, bool editMode) → (int, int)
GuiDummyRec(RectangleD bounds, String? text) int
GuiEnable() → void
GuiEnableTooltip() → void
GuiGetFont() FontD
GuiGetIcons() List<int>
GuiGetState() int
GuiGetStyle(GuiControl control, GuiProperty property) int
GuiGetTextWidth(String? text) int
GuiGrid(RectangleD bounds, num spacing, num subdivs, [Vector2D? mouseCell]) int
GuiGroupBox(RectangleD bounds, String? text) int
GuiIconText(GuiIconName iconId, String? text) String
GuiIsLocked() bool
GuiLabel(RectangleD bounds, String? text) int
GuiLabelButton(RectangleD bounds, String? text) int
GuiLine(RectangleD bounds, String? text) int
GuiListView(RectangleD bounds, String? text, {int? scrollIndex, int? active}) → (int, int, int)
GuiListViewEx(RectangleD bounds, List<String> text, {int? scrollIndex, int? active, int? focus}) → (int, int, int, int)
GuiLoadIcons(String fileName, bool loadIconsName) List<String>
GuiLoadStyle(String fileName) → void
GuiLoadStyleDefault() → void
GuiLock() → void
GuiMessageBox(RectangleD bounds, String? title, String message, String buttons) int
GuiPanel(RectangleD bounds, String? text) int
GuiProgressBar(RectangleD bounds, String? textLeft, String? textRight, num value, num minValue, num maxValue) → (int, double)
GuiScrollPanel(RectangleD bounds, String? text, RectangleD content, Vector2D scroll, [RectangleD? view]) int
GuiSetAlpha(num alpha) → void
GuiSetFont(FontD font) → void
GuiSetIconScale(num scale) → void
GuiSetState(GuiState state) → void
GuiSetStyle(GuiControl control, GuiProperty property, num value) → void
GuiSetTooltip(String? tooltip) → void
GuiSlider(RectangleD bounds, String? textLeft, String? textRight, num value, num minValue, num maxValue) → (int, double)
GuiSliderBar(RectangleD bounds, String? textLeft, String? textRight, num value, num minValue, num maxValue) → (int, double)
GuiSpinner(RectangleD bounds, String? text, num value, num minValue, num maxValue, bool editMode) → (int, int)
GuiStatusBar(RectangleD bounds, String? text) int
GuiTabBar(RectangleD bounds, List<String> text) → (int, int)
GuiTextBox(RectangleD bounds, String? text, num textSize, bool editMode) → (int, String)
GuiTextInputBox(RectangleD bounds, String? title, String? message, String buttons, String? text, num textMaxSize, bool? secretViewActive) → (int, String)
GuiToggle(RectangleD bounds, String? text, bool active) → (int, bool)
GuiToggleGroup(RectangleD bounds, String? text, num active) → (int, int)
GuiToggleSlider(RectangleD bounds, String? text, num active) → (int, int)
GuiUnlock() → void
GuiValueBox(RectangleD bounds, String? text, num value, num minValue, num maxValue, bool editMode) → (int, int)
GuiValueBoxFloat(RectangleD bounds, String? text, String textValue, num value, bool editMode) → (int, double)
GuiWindowBox(RectangleD bounds, String? title) int
load() → void
inherited
logInfo(String message) → void
inherited
logWarn(String message) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose(void fn()) → void
inherited
refBool1([bool? y, String? x]) Pointer<Bool>
inherited
refBool1OrNull([bool? y]) Pointer<Bool>
inherited
refBool2([bool? y, String? x]) Pointer<Bool>
inherited
refBool2OrNull([bool? y]) Pointer<Bool>
inherited
refBool3([bool? y, String? x]) Pointer<Bool>
inherited
refBool3OrNull([bool? y]) Pointer<Bool>
inherited
refBool4([bool? y, String? x]) Pointer<Bool>
inherited
refBool4OrNull([bool? y]) Pointer<Bool>
inherited
refChar1([int? y]) Pointer<Char>
inherited
refChar1OrNull([int? y]) Pointer<Char>
inherited
refChar2([int? y]) Pointer<Char>
inherited
refChar2OrNull([int? y]) Pointer<Char>
inherited
refChar3([int? y]) Pointer<Char>
inherited
refChar3OrNull([int? y]) Pointer<Char>
inherited
refChar4([int? y]) Pointer<Char>
inherited
refChar4OrNull([int? y]) Pointer<Char>
inherited
refFloat1([double? y, String? x]) Pointer<Float>
inherited
refFloat1OrNull([double? y]) Pointer<Float>
inherited
refFloat2([double? y, String? x]) Pointer<Float>
inherited
refFloat2OrNull([double? y]) Pointer<Float>
inherited
refFloat3([double? y, String? x]) Pointer<Float>
inherited
refFloat3OrNull([double? y]) Pointer<Float>
inherited
refFloat4([double? y, String? x]) Pointer<Float>
inherited
refFloat4OrNull([double? y]) Pointer<Float>
inherited
refId(String x) String
inherited
refInt1([int? y]) Pointer<Int>
inherited
refInt1OrNull([int? y]) Pointer<Int>
inherited
refInt2([int? y]) Pointer<Int>
inherited
refInt2OrNull([int? y]) Pointer<Int>
inherited
refInt3([int? y]) Pointer<Int>
inherited
refInt3OrNull([int? y]) Pointer<Int>
inherited
refInt4([int? y]) Pointer<Int>
inherited
refInt4OrNull([int? y]) Pointer<Int>
inherited
refListBool(List<bool> y, [String? x]) Pointer<Bool>
inherited
refListChar(List<num> y, [String? x]) Pointer<Char>
inherited
refListFloat(List<num> y, [String? x]) Pointer<Float>
inherited
refListInt(List<num> y, [String? x]) Pointer<Int>
inherited
refListShort(List<num> y, [String? x]) Pointer<Short>
inherited
refListString(List<String> y, [String? x]) Pointer<Pointer<Char>>
inherited
refListUChars(List<num> y, [String? x]) Pointer<UnsignedChar>
inherited
refListUInt(List<num> y, [String? x]) Pointer<UnsignedInt>
inherited
refListUInt8(List<num> y, [String? x]) Pointer<Uint8>
inherited
refLitSized<U extends NativeType, D>(int count, String? key, Pointer<U> alloc(String, [int])) Pointer<U>
inherited
refPtrLitOrNull<U extends NativeType, D>(D? x, String key, Pointer<U> alloc([D, String])) Pointer<U>
inherited
refPtrStructOrNull<U extends Struct, D extends StructD<D, U>>(D? x, String key, Pointer<U> alloc([D, String])) Pointer<U>
inherited
refShort1([int? y]) Pointer<Short>
inherited
refShort1OrNull([int? y]) Pointer<Short>
inherited
refShort2([int? y]) Pointer<Short>
inherited
refShort2OrNull([int? y]) Pointer<Short>
inherited
refShort3([int? y]) Pointer<Short>
inherited
refShort3OrNull([int? y]) Pointer<Short>
inherited
refShort4([int? y]) Pointer<Short>
inherited
refShort4OrNull([int? y]) Pointer<Short>
inherited
refSizedUInt8(int count, [String? x]) Pointer<Uint8>
inherited
refStr(String? s) Pointer<Char>
inherited
refString1([String? y]) Pointer<Char>
inherited
refString2([String? y]) Pointer<Char>
inherited
refString3([String? y]) Pointer<Char>
inherited
refString4([String? y]) Pointer<Char>
inherited
refTypedDataUInt8(TypedData y, [String? x]) Pointer<Uint8>
inherited
refTypedListFloat(Float32List y, [String? x]) Pointer<Float>
inherited
refTypedListInt32(Int32List y, [String? x]) Pointer<Int32>
inherited
refTypedListUInt16(Uint16List y, [String? x]) Pointer<Uint16>
inherited
refTypedListUInt32(Uint32List y, [String? x]) Pointer<Uint32>
inherited
refTypedListUInt8(Uint8List y, [String? x]) Pointer<Uint8>
inherited
refUInt1([int? y]) Pointer<UnsignedInt>
inherited
refUInt1OrNull([int? y]) Pointer<UnsignedInt>
inherited
refUInt2([int? y]) Pointer<UnsignedInt>
inherited
refUInt2OrNull([int? y]) Pointer<UnsignedInt>
inherited
refUInt3([int? y]) Pointer<UnsignedInt>
inherited
refUInt3OrNull([int? y]) Pointer<UnsignedInt>
inherited
refUInt4([int? y]) Pointer<UnsignedInt>
inherited
refUInt4OrNull([int? y]) Pointer<UnsignedInt>
inherited
refUpdateNullable$<T, C extends Struct, D extends StructD<D, C>>(D? o, T callback(Pointer<C> p), Pointer<C> alloc(D), void update(Pointer<C> p, D o)) → T
inherited
run<T>(String name(), T f()) → T
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited