RaylibMatrices class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
logger
→ Logger
-
no setterinherited
-
rl
→ Raylib
-
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
debug(bool v)
→ void
-
inherited
-
debugFilter(bool filter(String))
→ void
-
inherited
-
debugInfo(String message)
→ void
-
inherited
-
debugTime(bool v)
→ void
-
inherited
-
debugWarn(String message)
→ void
-
inherited
-
disableSync<T>(T f())
→ T
-
inherited
-
dispose()
→ void
-
inherited
-
load()
→ void
-
inherited
-
logInfo(String message)
→ void
-
inherited
-
logWarn(String message)
→ void
-
inherited
-
MatrixAdd(MatrixD left, MatrixD right)
→ MatrixD
-
-
MatrixDecompose(MatrixD mat)
→ (Vector3D, QuaternionD, Vector3D)
-
-
MatrixDeterminant(MatrixD mat)
→ double
-
-
MatrixFrustum(double left, double right, double bottom, double top, double nearPlane, double farPlane)
→ MatrixD
-
-
MatrixIdentity()
→ MatrixD
-
-
MatrixInvert(MatrixD mat)
→ MatrixD
-
-
MatrixLookAt(Vector3D eye, Vector3D target, Vector3D up)
→ MatrixD
-
-
MatrixMultiply(MatrixD left, MatrixD right)
→ MatrixD
-
-
MatrixOrtho(double left, double right, double bottom, double top, double nearPlane, double farPlane)
→ MatrixD
-
-
MatrixPerspective(double fovY, double aspect, double nearPlane, double farPlane)
→ MatrixD
-
-
MatrixRotate(Vector3D axis, double angle)
→ MatrixD
-
-
MatrixRotateX(double angle)
→ MatrixD
-
-
MatrixRotateXYZ(Vector3D angle)
→ MatrixD
-
-
MatrixRotateY(double angle)
→ MatrixD
-
-
MatrixRotateZ(double angle)
→ MatrixD
-
-
MatrixRotateZYX(Vector3D angle)
→ MatrixD
-
-
MatrixScale(double x, double y, double z)
→ MatrixD
-
-
MatrixSubtract(MatrixD left, MatrixD right)
→ MatrixD
-
-
MatrixTrace(MatrixD mat)
→ double
-
-
MatrixTranslate(double x, double y, double z)
→ MatrixD
-
-
MatrixTranspose(MatrixD mat)
→ MatrixD
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
onDispose(void fn())
→ void
-
inherited
-
run<T>(String name(), T f())
→ T
-
inherited
-
toString()
→ String
-
A string representation of this object.
inherited