RaylibRlglD class
- Inheritance
-
- Mixed-in types
-
Methods
-
debug(bool v)
→ void
-
inherited
-
debugFilter(bool filter(String))
→ void
-
inherited
-
debugInfo(String message)
→ void
-
inherited
-
debugTime(bool v)
→ void
-
inherited
-
debugWarn(String message)
→ void
-
inherited
-
disableSync<T>(T f())
→ T
-
inherited
-
dispose()
→ void
-
inherited
-
load()
→ void
-
inherited
-
logInfo(String message)
→ void
-
inherited
-
logWarn(String message)
→ void
-
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
onDispose(void fn())
→ void
-
inherited
-
refBool1([bool? y, String? x])
→ Pointer<Bool>
-
inherited
-
refBool1OrNull([bool? y])
→ Pointer<Bool>
-
inherited
-
refBool2([bool? y, String? x])
→ Pointer<Bool>
-
inherited
-
refBool2OrNull([bool? y])
→ Pointer<Bool>
-
inherited
-
refBool3([bool? y, String? x])
→ Pointer<Bool>
-
inherited
-
refBool3OrNull([bool? y])
→ Pointer<Bool>
-
inherited
-
refBool4([bool? y, String? x])
→ Pointer<Bool>
-
inherited
-
refBool4OrNull([bool? y])
→ Pointer<Bool>
-
inherited
-
refChar1([int? y])
→ Pointer<Char>
-
inherited
-
refChar1OrNull([int? y])
→ Pointer<Char>
-
inherited
-
refChar2([int? y])
→ Pointer<Char>
-
inherited
-
refChar2OrNull([int? y])
→ Pointer<Char>
-
inherited
-
refChar3([int? y])
→ Pointer<Char>
-
inherited
-
refChar3OrNull([int? y])
→ Pointer<Char>
-
inherited
-
refChar4([int? y])
→ Pointer<Char>
-
inherited
-
refChar4OrNull([int? y])
→ Pointer<Char>
-
inherited
-
refFloat1([double? y, String? x])
→ Pointer<Float>
-
inherited
-
refFloat1OrNull([double? y])
→ Pointer<Float>
-
inherited
-
refFloat2([double? y, String? x])
→ Pointer<Float>
-
inherited
-
refFloat2OrNull([double? y])
→ Pointer<Float>
-
inherited
-
refFloat3([double? y, String? x])
→ Pointer<Float>
-
inherited
-
refFloat3OrNull([double? y])
→ Pointer<Float>
-
inherited
-
refFloat4([double? y, String? x])
→ Pointer<Float>
-
inherited
-
refFloat4OrNull([double? y])
→ Pointer<Float>
-
inherited
-
refId(String x)
→ String
-
inherited
-
refInt1([int? y])
→ Pointer<Int>
-
inherited
-
refInt1OrNull([int? y])
→ Pointer<Int>
-
inherited
-
refInt2([int? y])
→ Pointer<Int>
-
inherited
-
refInt2OrNull([int? y])
→ Pointer<Int>
-
inherited
-
refInt3([int? y])
→ Pointer<Int>
-
inherited
-
refInt3OrNull([int? y])
→ Pointer<Int>
-
inherited
-
refInt4([int? y])
→ Pointer<Int>
-
inherited
-
refInt4OrNull([int? y])
→ Pointer<Int>
-
inherited
-
refListBool(List<bool> y, [String? x])
→ Pointer<Bool>
-
inherited
-
refListChar(List<num> y, [String? x])
→ Pointer<Char>
-
inherited
-
refListFloat(List<num> y, [String? x])
→ Pointer<Float>
-
inherited
-
refListInt(List<num> y, [String? x])
→ Pointer<Int>
-
inherited
-
refListShort(List<num> y, [String? x])
→ Pointer<Short>
-
inherited
-
refListString(List<String> y, [String? x])
→ Pointer<Pointer<Char>>
-
inherited
-
refListUChars(List<num> y, [String? x])
→ Pointer<UnsignedChar>
-
inherited
-
refListUInt(List<num> y, [String? x])
→ Pointer<UnsignedInt>
-
inherited
-
refListUInt8(List<num> y, [String? x])
→ Pointer<Uint8>
-
inherited
-
refLitSized<U extends NativeType, D>(int count, String? key, Pointer<U> alloc(String, [int]))
→ Pointer<U>
-
inherited
-
refPtrLitOrNull<U extends NativeType, D>(D? x, String key, Pointer<U> alloc([D, String]))
→ Pointer<U>
-
inherited
-
refPtrStructOrNull<U extends Struct, D extends StructD<D, U>>(D? x, String key, Pointer<U> alloc([D, String]))
→ Pointer<U>
-
inherited
-
refShort1([int? y])
→ Pointer<Short>
-
inherited
-
refShort1OrNull([int? y])
→ Pointer<Short>
-
inherited
-
refShort2([int? y])
→ Pointer<Short>
-
inherited
-
refShort2OrNull([int? y])
→ Pointer<Short>
-
inherited
-
refShort3([int? y])
→ Pointer<Short>
-
inherited
-
refShort3OrNull([int? y])
→ Pointer<Short>
-
inherited
-
refShort4([int? y])
→ Pointer<Short>
-
inherited
-
refShort4OrNull([int? y])
→ Pointer<Short>
-
inherited
-
refSizedUInt8(int count, [String? x])
→ Pointer<Uint8>
-
inherited
-
refStr(String? s)
→ Pointer<Char>
-
inherited
-
refString1([String? y])
→ Pointer<Char>
-
inherited
-
refString2([String? y])
→ Pointer<Char>
-
inherited
-
refString3([String? y])
→ Pointer<Char>
-
inherited
-
refString4([String? y])
→ Pointer<Char>
-
inherited
-
refTypedDataUInt8(TypedData y, [String? x])
→ Pointer<Uint8>
-
inherited
-
refTypedListFloat(Float32List y, [String? x])
→ Pointer<Float>
-
inherited
-
refTypedListInt32(Int32List y, [String? x])
→ Pointer<Int32>
-
inherited
-
refTypedListUInt16(Uint16List y, [String? x])
→ Pointer<Uint16>
-
inherited
-
refTypedListUInt32(Uint32List y, [String? x])
→ Pointer<Uint32>
-
inherited
-
refTypedListUInt8(Uint8List y, [String? x])
→ Pointer<Uint8>
-
inherited
-
refUInt1([int? y])
→ Pointer<UnsignedInt>
-
inherited
-
refUInt1OrNull([int? y])
→ Pointer<UnsignedInt>
-
inherited
-
refUInt2([int? y])
→ Pointer<UnsignedInt>
-
inherited
-
refUInt2OrNull([int? y])
→ Pointer<UnsignedInt>
-
inherited
-
refUInt3([int? y])
→ Pointer<UnsignedInt>
-
inherited
-
refUInt3OrNull([int? y])
→ Pointer<UnsignedInt>
-
inherited
-
refUInt4([int? y])
→ Pointer<UnsignedInt>
-
inherited
-
refUInt4OrNull([int? y])
→ Pointer<UnsignedInt>
-
inherited
-
refUpdateNullable$<T, C extends Struct, D extends StructD<D, C>>(D? o, T callback(Pointer<C> p), Pointer<C> alloc(D), void update(Pointer<C> p, D o))
→ T
-
inherited
-
rlActiveDrawBuffers(num count)
→ void
-
-
rlActiveTextureSlot(num slot)
→ void
-
-
rlBegin(RlDrawMode mode)
→ void
-
-
rlBindFramebuffer(num target, num framebuffer)
→ void
-
-
rlBindImageTexture(num id, num index, RlPixelFormat format, bool readonly)
→ void
-
-
rlBindShaderBuffer(num id, num index)
→ void
-
-
rlBlitFramebuffer(num srcX, num srcY, num srcWidth, num srcHeight, num dstX, num dstY, num dstWidth, num dstHeight, num bufferMask)
→ void
-
-
rlCheckErrors()
→ void
-
-
rlCheckRenderBatchLimit(num vCount)
→ bool
-
-
rlClearColor(num r, num g, num b, num a)
→ void
-
-
rlClearScreenBuffers()
→ void
-
-
rlColor(ColorD color)
→ void
-
-
rlColor3f(num x, num y, num z)
→ void
-
-
rlColor4f(num x, num y, num z, num w)
→ void
-
-
rlColor4ub(num r, num g, num b, num a)
→ void
-
-
rlColorMask(bool r, bool g, bool b, bool a)
→ void
-
-
rlCompileShader(String shaderCode, RlShaderType type)
→ int
-
-
rlComputeShaderDispatch(num groupX, num groupY, num groupZ)
→ void
-
-
rlCopyShaderBuffer(num destId, num srcId, num destOffset, num srcOffset, num count)
→ void
-
-
rlCubemapParameters(num id, num param, num value)
→ void
-
-
rlDisableBackfaceCulling()
→ void
-
-
rlDisableColorBlend()
→ void
-
-
rlDisableDepthMask()
→ void
-
-
rlDisableDepthTest()
→ void
-
-
rlDisableFramebuffer()
→ void
-
-
rlDisableScissorTest()
→ void
-
-
rlDisableShader()
→ void
-
-
rlDisableSmoothLines()
→ void
-
-
rlDisableStereoRender()
→ void
-
-
rlDisableTexture()
→ void
-
-
rlDisableTextureCubemap()
→ void
-
-
rlDisableVertexArray()
→ void
-
-
rlDisableVertexAttribute(num index)
→ void
-
-
rlDisableVertexBuffer()
→ void
-
-
rlDisableVertexBufferElement()
→ void
-
-
rlDisableWireMode()
→ void
-
-
rlDrawRenderBatch(RlRenderBatchD batch)
→ void
-
-
rlDrawRenderBatchActive()
→ void
-
-
rlDrawVertexArray(num offset, num count)
→ void
-
-
rlDrawVertexArrayElements(num offset, num count, Uint16List buffer)
→ void
-
-
rlDrawVertexArrayElementsInstanced(num offset, num count, Uint16List buffer, num instances)
→ void
-
-
rlDrawVertexArrayInstanced(num offset, num count, num instances)
→ void
-
-
rlEnableBackfaceCulling()
→ void
-
-
rlEnableColorBlend()
→ void
-
-
rlEnableDepthMask()
→ void
-
-
rlEnableDepthTest()
→ void
-
-
rlEnableFramebuffer(num id)
→ void
-
-
rlEnablePointMode()
→ void
-
-
rlEnableScissorTest()
→ void
-
-
rlEnableShader(num id)
→ void
-
-
rlEnableSmoothLines()
→ void
-
-
rlEnableStereoRender()
→ void
-
-
rlEnableTexture(num id)
→ void
-
-
rlEnableTextureCubemap(num id)
→ void
-
-
rlEnableVertexArray(num vaoId)
→ bool
-
-
rlEnableVertexAttribute(num index)
→ void
-
-
rlEnableVertexBuffer(num id)
→ void
-
-
rlEnableVertexBufferElement(num id)
→ void
-
-
rlEnableWireMode()
→ void
-
-
rlEnd()
→ void
-
-
rlFramebufferAttach(num fboId, num texId, RlFramebufferAttachType attachType, RlFramebufferAttachTextureType texType, num mipLevel)
→ void
-
-
rlFramebufferComplete(num id)
→ bool
-
-
rlFrustum(num left, num right, num bottom, num top, num znear, num zfar)
→ void
-
-
rlGenTextureMipmaps(num id, num width, num height, RlPixelFormat format)
→ int
-
-
rlGetActiveFramebuffer()
→ int
-
-
rlGetCullDistanceFar()
→ double
-
-
rlGetCullDistanceNear()
→ double
-
-
rlGetFramebufferHeight()
→ int
-
-
rlGetFramebufferWidth()
→ int
-
-
rlGetGlTextureFormats(RlPixelFormat format)
→ (int, int, int)
-
-
rlGetLineWidth()
→ double
-
-
rlGetLocationAttrib(num shaderId, String attribName)
→ int
-
-
rlGetLocationUniform(num shaderId, String uniformName)
→ int
-
-
rlGetMatrixModelview()
→ MatrixD
-
-
rlGetMatrixProjection()
→ MatrixD
-
-
rlGetMatrixProjectionStereo(num eye)
→ MatrixD
-
-
rlGetMatrixTransform()
→ MatrixD
-
-
rlGetMatrixViewOffsetStereo(num eye)
→ MatrixD
-
-
rlGetPixelDataSize(int width, int height, RlPixelFormat format)
→ int
-
-
rlGetPixelFormatName(RlPixelFormat format)
→ String
-
-
rlGetShaderBufferSize(num id)
→ int
-
-
rlGetShaderIdDefault()
→ int
-
-
rlGetShaderLocsDefault()
→ List<int>
-
-
rlGetTextureIdDefault()
→ int
-
-
rlGetVersion()
→ int
-
-
rlglClose()
→ void
-
-
rlglInit(num width, num height)
→ void
-
-
rlIsStereoRenderEnabled()
→ bool
-
-
rlLoadComputeShaderProgram(num shaderId)
→ int
-
-
rlLoadDrawCube()
→ void
-
-
rlLoadDrawQuad()
→ void
-
-
rlLoadFramebuffer()
→ int
-
-
rlLoadIdentity()
→ void
-
-
rlLoadRenderBatch(num numBuffers, num bufferElements)
→ RlRenderBatchD
-
-
rlLoadShaderBuffer(num size, TypedData? data, RlUsageHint? usageHint)
→ int
-
-
rlLoadShaderCode(String? vsCode, String? fsCode)
→ int
-
-
rlLoadShaderProgram(num vShaderId, num fShaderId)
→ int
-
-
rlLoadTexture(Uint8List? data, num width, num height, RlPixelFormat format, num mipmapCount)
→ int
-
-
rlLoadTextureCubemap(Uint8List? data, num size, RlPixelFormat format, num mipmapCount)
→ int
-
-
rlLoadTextureDepth(num width, num height, bool useRenderBuffer)
→ int
-
-
rlLoadVertexArray()
→ int
-
-
rlLoadVertexBuffer(TypedData buffer, bool dynamic)
→ int
-
-
rlLoadVertexBufferElement(TypedData buffer, bool dynamic)
→ int
-
-
rlMatrixMode(RlMatrixMode mode)
→ void
-
-
rlMultMatrixf(List<double> matf)
→ void
-
-
rlNormal3f(num x, num y, num z)
→ void
-
-
rlOrtho(num left, num right, num bottom, num top, num znear, num zfar)
→ void
-
-
rlPopMatrix()
→ void
-
-
rlPushMatrix()
→ void
-
-
rlReadScreenPixels(num width, num height)
→ List<int>
-
-
rlReadShaderBuffer(num id, num count, num offset)
→ Uint8List
-
-
rlReadTexturePixels(num id, num width, num height, RlPixelFormat format)
→ Uint8List
-
-
rlRotatef(num angle, num x, num y, num z)
→ void
-
-
rlScalef(num x, num y, num z)
→ void
-
-
rlScissor(num x, num y, num width, num height)
→ void
-
-
rlSetBlendFactors(num glSrcFactor, num glDstFactor, num glEquation)
→ void
-
-
-
rlSetBlendMode(RlBlendMode mode)
→ void
-
-
rlSetClipPlanes(num nearPlane, num farPlane)
→ void
-
-
rlSetCullFace(RlCullMode mode)
→ void
-
-
rlSetFramebufferHeight(num height)
→ void
-
-
rlSetFramebufferWidth(num width)
→ void
-
-
rlSetLineWidth(num width)
→ void
-
-
rlSetMatrixModelview(MatrixD view)
→ void
-
-
rlSetMatrixProjection(MatrixD proj)
→ void
-
-
rlSetMatrixProjectionStereo(MatrixD right, MatrixD left)
→ void
-
-
rlSetMatrixViewOffsetStereo(MatrixD right, MatrixD left)
→ void
-
-
rlSetRenderBatchActive(RlRenderBatchD batch)
→ void
-
-
rlSetShader(num id, List<int> locs)
→ void
-
-
rlSetTexture(num id)
→ void
-
-
rlSetUniform(num locIndex, TypedData value, RlShaderUniformDataType uniformType, num count)
→ void
-
-
rlSetUniformMatrices(num locIndex, List<MatrixD> mat)
→ void
-
-
rlSetUniformMatrix(num locIndex, MatrixD mat)
→ void
-
-
rlSetUniformSampler(num locIndex, num textureId)
→ void
-
-
rlSetVertexAttribute(num index, num compSize, num type, bool normalized, num stride, num offset)
→ void
-
-
rlSetVertexAttributeDefault(num locIndex, Float32List value, RlShaderAttributeDataType attribType)
→ void
-
-
rlSetVertexAttributeDivisor(num index, num divisor)
→ void
-
-
rlTexCoord2f(num x, num y)
→ void
-
-
rlTextureParameters(num id, num param, num value)
→ void
-
-
rlTranslatef(num x, num y, num z)
→ void
-
-
rlUnloadFramebuffer(num id)
→ void
-
-
rlUnloadRenderBatch(RlRenderBatchD batch)
→ void
-
-
rlUnloadShaderBuffer(num ssboId)
→ void
-
-
rlUnloadShaderProgram(num id)
→ void
-
-
rlUnloadTexture(num id)
→ void
-
-
rlUnloadVertexArray(num vaoId)
→ void
-
-
rlUnloadVertexBuffer(num vboId)
→ void
-
-
rlUpdateShaderBuffer(num id, TypedData data, num offset)
→ void
-
-
rlUpdateTexture(num id, num offsetX, num offsetY, num width, num height, RlPixelFormat format, Uint8List data)
→ void
-
-
rlUpdateVertexBuffer(num bufferId, TypedData data, num offset)
→ void
-
-
rlUpdateVertexBufferElements(num id, TypedData data, num offset)
→ void
-
-
rlVertex2f(num x, num y)
→ void
-
-
rlVertex2i(num x, num y)
→ void
-
-
rlVertex3f(num x, num y, num z)
→ void
-
-
rlViewport(num x, num y, num width, num height)
→ void
-
-
run<T>(String name(), T f())
→ T
-
inherited
-
toString()
→ String
-
A string representation of this object.
inherited