RectangleD class

Inheritance
Available extensions

Constructors

RectangleD({Pointer<RectangleC>? originalPointer, double x = 0, double y = 0, double width = 0, double height = 0})
RectangleD.rect(num x, num y, num width, num height)
factory
RectangleD.zero()
factory

Properties

allocKey String
no setterinherited
cStructName String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
height double
getter/setter pair
internalId int
no setterinherited
isDisposed bool
no setterinherited
originalPointer Pointer<RectangleC>?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structName String
no setterinherited
tag String
no setterinherited
width double
getter/setter pair
x double
getter/setter pair
y double
getter/setter pair

Methods

allocateInto(RaylibTemp temp, Pointer<RectangleC> p, String key) → void
override
allocatePointer(RaylibTemp temp, String key, [int count = 1]) Pointer<RectangleC>
override
clone() RectangleD
override
copy() RectangleD
inherited
format([int x0 = 0, int? y0, int? w0, int? h0]) String

Available on RectangleD, provided by the RectangleDLike extension

getOriginalPointer() Pointer<RectangleC>
inherited
getOriginalPointerAndDispose() Pointer<RectangleC>
inherited
markDisposed() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onOriginalPointer(void callback(Pointer<RectangleC> p)) → void
inherited
set(num x, num y, num width, num height) RectangleD
setC(RectangleC o) RectangleD
override
setD(RectangleD o) RectangleD
override
setTag(String newTag) RectangleD
inherited
signature() String
override
syncInto(RaylibTemp temp, Pointer<RectangleC> p, String key) → void
inherited
toArray() List<double>
toC(RaylibTemp temp, String key) Pointer<RectangleC>
inherited
toString() String
A string representation of this object.
inherited
writeInto(RectangleC p) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited