RlShaderLocationIndex enum
Values
- RL_SHADER_LOC_VERTEX_POSITION → const RlShaderLocationIndex
-
const RlShaderLocationIndex(0) - RL_SHADER_LOC_VERTEX_TEXCOORD01 → const RlShaderLocationIndex
-
const RlShaderLocationIndex(1) - RL_SHADER_LOC_VERTEX_TEXCOORD02 → const RlShaderLocationIndex
-
const RlShaderLocationIndex(2) - RL_SHADER_LOC_VERTEX_NORMAL → const RlShaderLocationIndex
-
const RlShaderLocationIndex(3) - RL_SHADER_LOC_VERTEX_TANGENT → const RlShaderLocationIndex
-
const RlShaderLocationIndex(4) - RL_SHADER_LOC_VERTEX_COLOR → const RlShaderLocationIndex
-
const RlShaderLocationIndex(5) - RL_SHADER_LOC_MATRIX_MVP → const RlShaderLocationIndex
-
const RlShaderLocationIndex(6) - RL_SHADER_LOC_MATRIX_VIEW → const RlShaderLocationIndex
-
const RlShaderLocationIndex(7) - RL_SHADER_LOC_MATRIX_PROJECTION → const RlShaderLocationIndex
-
const RlShaderLocationIndex(8) - RL_SHADER_LOC_MATRIX_MODEL → const RlShaderLocationIndex
-
const RlShaderLocationIndex(9) - RL_SHADER_LOC_MATRIX_NORMAL → const RlShaderLocationIndex
-
const RlShaderLocationIndex(10) - RL_SHADER_LOC_VECTOR_VIEW → const RlShaderLocationIndex
-
const RlShaderLocationIndex(11) - RL_SHADER_LOC_COLOR_DIFFUSE → const RlShaderLocationIndex
-
const RlShaderLocationIndex(12) - RL_SHADER_LOC_COLOR_SPECULAR → const RlShaderLocationIndex
-
const RlShaderLocationIndex(13) - RL_SHADER_LOC_COLOR_AMBIENT → const RlShaderLocationIndex
-
const RlShaderLocationIndex(14) - RL_SHADER_LOC_MAP_ALBEDO → const RlShaderLocationIndex
-
const RlShaderLocationIndex(15) - RL_SHADER_LOC_MAP_METALNESS → const RlShaderLocationIndex
-
const RlShaderLocationIndex(16) - RL_SHADER_LOC_MAP_NORMAL → const RlShaderLocationIndex
-
const RlShaderLocationIndex(17) - RL_SHADER_LOC_MAP_ROUGHNESS → const RlShaderLocationIndex
-
const RlShaderLocationIndex(18) - RL_SHADER_LOC_MAP_OCCLUSION → const RlShaderLocationIndex
-
const RlShaderLocationIndex(19) - RL_SHADER_LOC_MAP_EMISSION → const RlShaderLocationIndex
-
const RlShaderLocationIndex(20) - RL_SHADER_LOC_MAP_HEIGHT → const RlShaderLocationIndex
-
const RlShaderLocationIndex(21) - RL_SHADER_LOC_MAP_CUBEMAP → const RlShaderLocationIndex
-
const RlShaderLocationIndex(22) - RL_SHADER_LOC_MAP_IRRADIANCE → const RlShaderLocationIndex
-
const RlShaderLocationIndex(23) - RL_SHADER_LOC_MAP_PREFILTER → const RlShaderLocationIndex
-
const RlShaderLocationIndex(24) - RL_SHADER_LOC_MAP_BRDF → const RlShaderLocationIndex
-
const RlShaderLocationIndex(25)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → RlShaderLocationIndex
Constants
-
values
→ const List<
RlShaderLocationIndex> - A constant List of the values in this enum, in order of their declaration.