RlUsageHint enum
Values
- RL_STREAM_DRAW → const RlUsageHint
-
const RlUsageHint(0x88E0) - RL_STREAM_READ → const RlUsageHint
-
const RlUsageHint(0x88E1) - RL_STREAM_COPY → const RlUsageHint
-
const RlUsageHint(0x88E2) - RL_STATIC_DRAW → const RlUsageHint
-
const RlUsageHint(0x88E4) - RL_STATIC_READ → const RlUsageHint
-
const RlUsageHint(0x88E5) - RL_STATIC_COPY → const RlUsageHint
-
const RlUsageHint(0x88E6) - RL_DYNAMIC_DRAW → const RlUsageHint
-
const RlUsageHint(0x88E8) - RL_DYNAMIC_READ → const RlUsageHint
-
const RlUsageHint(0x88E9) - RL_DYNAMIC_COPY → const RlUsageHint
-
const RlUsageHint(0x88EA)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → RlUsageHint
Constants
-
values
→ const List<
RlUsageHint> - A constant List of the values in this enum, in order of their declaration.