StructD<D extends StructD<D, C> , C extends NativeType> class
abstract
Properties
- allocKey → String
-
no setter
- cStructName → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- internalId → int
-
no setter
- isDisposed → bool
-
no setter
-
originalPointer
↔ Pointer<
C> ? -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- structName → String
-
no setter
- tag → String
-
no setter
Methods
-
allocateInto(
RaylibTemp temp, Pointer< C> p, String key) → void -
allocatePointer(
RaylibTemp temp, String key, [int count = 1]) → Pointer< C> -
clone(
) → D -
copy(
) → D -
getOriginalPointer(
) → Pointer< C> -
getOriginalPointerAndDispose(
) → Pointer< C> -
markDisposed(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onOriginalPointer(
void callback(Pointer< C> p)) → void -
setC(
C o) → D -
setD(
D o) → D -
setTag(
String newTag) → D -
signature(
) → String -
syncInto(
RaylibTemp temp, Pointer< C> p, String key) → void -
toC(
RaylibTemp temp, String key) → Pointer< C> -
toString(
) → String -
A string representation of this object.
override
-
writeInto(
C p) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited