copy method
D
copy()
Returns a deep copy of this instance without originalPointer.
Useful when you need an independent value that should not accidentally sync back into raylib-owned memory.
Implementation
D copy() {
final clone = this.clone();
clone.originalPointer = null;
return clone;
}