A stable numeric ID assigned on first toC call for pointer-owning structs.
Incorporated into slot keys to prevent collisions between distinct instances of the same struct type sharing the same tag.
int get internalId => _internalId;