StructDLiteral<D extends StructD<D, C>, C extends NativeType> class abstract

Inheritance
Implementers

Constructors

StructDLiteral({Pointer<C>? originalPointer})

Properties

allocKey String
no setterinherited
cStructName String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
internalId int
no setterinherited
isDisposed bool
no setterinherited
originalPointer Pointer<C>?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structName String
no setterinherited
tag String
no setterinherited

Methods

allocateInto(RaylibTemp temp, Pointer<C> p, String key) → void
inherited
allocatePointer(RaylibTemp temp, String key, [int count = 1]) Pointer<C>
inherited
clone() → D
inherited
copy() → D
inherited
getOriginalPointer() Pointer<C>
inherited
getOriginalPointerAndDispose() Pointer<C>
inherited
markDisposed() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onOriginalPointer(void callback(Pointer<C> p)) → void
inherited
setC(C o) → D
inherited
setD(D o) → D
inherited
setTag(String newTag) → D
inherited
signature() String
inherited
syncInto(RaylibTemp temp, Pointer<C> p, String key) → void
inherited
toC(RaylibTemp temp, String key) Pointer<C>
inherited
toString() String
A string representation of this object.
inherited
writeInto(C p) → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited