Vector2D class
- Inheritance
- Available extensions
Constructors
-
Vector2D({Pointer<
Vector2C> ? originalPointer, double x = 0, double y = 0}) - Vector2D.one()
-
factory
- Vector2D.vec2(num x, num y)
-
factory
- Vector2D.zero()
-
factory
Properties
- allocKey → String
-
no setterinherited
- cStructName → String
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- internalId → int
-
no setterinherited
- isDisposed → bool
-
no setterinherited
- length → double
-
Available on Vector2D, provided by the Vector2DLike extension
no setter - lengthSqr → double
-
Available on Vector2D, provided by the Vector2DLike extension
no setter -
originalPointer
↔ Pointer<
Vector2C> ? -
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- structName → String
-
no setterinherited
- tag → String
-
no setterinherited
- x ↔ double
-
getter/setter pair
- y ↔ double
-
getter/setter pair
Methods
-
add(
Vector2D o) → Vector2D -
addValue(
num value) → Vector2D -
allocateInto(
RaylibTemp temp, Pointer< Vector2C> p, String key) → void -
override
-
allocatePointer(
RaylibTemp temp, String key, [int count = 1]) → Pointer< Vector2C> -
override
-
angle(
Vector2D o) → double -
Available on Vector2D, provided by the Vector2DLike extension
-
clamp(
Vector2D min, Vector2D max) → Vector2D -
clampValue(
double min, double max) → Vector2D -
clone(
) → Vector2D -
override
-
copy(
) → Vector2D -
inherited
-
distance(
Vector2D o) → double -
Available on Vector2D, provided by the Vector2DLike extension
-
distanceSqr(
Vector2D o) → double -
Available on Vector2D, provided by the Vector2DLike extension
-
div(
Vector2D o) → Vector2D -
divideBy(
num o) → Vector2D -
dotProduct(
Vector2D o) → double -
Available on Vector2D, provided by the Vector2DLike extension
-
equals(
Vector2D o) → bool -
format(
[int x0 = 0, int? y0]) → String -
Available on Vector2D, provided by the Vector2DLike extension
-
getOriginalPointer(
) → Pointer< Vector2C> -
inherited
-
getOriginalPointerAndDispose(
) → Pointer< Vector2C> -
inherited
-
invert(
) → Vector2D -
lerp(
Vector2D o, double amount) → Vector2D -
lineAngle(
Vector2D o) → double -
Available on Vector2D, provided by the Vector2DLike extension
-
markDisposed(
) → void -
inherited
-
max(
Vector2D o) → Vector2D -
min(
Vector2D o) → Vector2D -
moveTowards(
Vector2D target, double maxDistance) → Vector2D -
mul(
Vector2D o) → Vector2D -
negate(
) → Vector2D -
normalize(
) → Vector2D -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onOriginalPointer(
void callback(Pointer< Vector2C> p)) → void -
inherited
-
reflect(
Vector2D normal) → Vector2D -
refract(
Vector2D n, double r) → Vector2D -
rotate(
double angle) → Vector2D -
scale(
num o) → Vector2D -
set(
num x, num y) → Vector2D -
setC(
Vector2C o) → Vector2D -
override
-
setD(
Vector2D o) → Vector2D -
override
-
setTag(
String newTag) → Vector2D -
inherited
-
signature(
) → String -
override
-
sub(
Vector2D o) → Vector2D -
subValue(
num value) → Vector2D -
syncInto(
RaylibTemp temp, Pointer< Vector2C> p, String key) → void -
inherited
-
toArray(
) → List< double> -
toC(
RaylibTemp temp, String key) → Pointer< Vector2C> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
transform(
MatrixD o) → Vector2D -
writeInto(
Vector2C p) → void -
override
Operators
-
operator *(
Vector2D other) → Vector2D -
operator +(
Vector2D other) → Vector2D -
operator -(
Vector2D other) → Vector2D -
operator /(
Vector2D other) → Vector2D -
operator ==(
Object other) → bool -
The equality operator.
inherited