Vector3C class final

Inheritance
Implemented types
Available extensions

Constructors

Vector3C()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
hashCode int
The hash code for this object.
no setterinherited
length double

Available on Vector3C, provided by the Vector3CLike extension

no setter
lengthSqr double

Available on Vector3C, provided by the Vector3CLike extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
getter/setter pair
y double
getter/setter pair
z double
getter/setter pair

Methods

add(Vector3C o) Vector3C

Available on Vector3C, provided by the Vector3CEx extension

angle(Vector3C o) double

Available on Vector3C, provided by the Vector3CLike extension

crossProduct(Vector3C o) Vector3C

Available on Vector3C, provided by the Vector3CEx extension

distance(Vector3C o) double

Available on Vector3C, provided by the Vector3CLike extension

distanceSqr(Vector3C o) double

Available on Vector3C, provided by the Vector3CLike extension

div(Vector3C o) Vector3C

Available on Vector3C, provided by the Vector3CEx extension

divideBy(num o) Vector3C

Available on Vector3C, provided by the Vector3CEx extension

dotProduct(Vector3C o) double

Available on Vector3C, provided by the Vector3CLike extension

format([int x0 = 0, int? y0, int? z0]) String

Available on Vector3C, provided by the Vector3CLike extension

lerp(Vector3C o, double amount) Vector3C

Available on Vector3C, provided by the Vector3CEx extension

mul(Vector3C o) Vector3C

Available on Vector3C, provided by the Vector3CEx extension

negate() Vector3C

Available on Vector3C, provided by the Vector3CEx extension

normalize() Vector3C

Available on Vector3C, provided by the Vector3CEx extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rotateByAxisAngle(Vector3C axis, double angle) Vector3C

Available on Vector3C, provided by the Vector3CEx extension

scale(num o) Vector3C

Available on Vector3C, provided by the Vector3CEx extension

set(num x, num y, num z) Vector3C

Available on Vector3C, provided by the Vector3CEx extension

setC(Vector3C o) Vector3C

Available on Vector3C, provided by the Vector3CEx extension

setD(Vector3D o) Vector3C

Available on Vector3C, provided by the Vector3CEx extension

sub(Vector3C o) Vector3C

Available on Vector3C, provided by the Vector3CEx extension

toD([Pointer<Vector3C>? ptr]) Vector3D

Available on Vector3C, provided by the Vector3CEx extension

toString() String
A string representation of this object.
inherited
transform(MatrixC o) Vector3C

Available on Vector3C, provided by the Vector3CEx extension

Operators

operator ==(Object other) bool
The equality operator.
inherited