Vector3D class
- Inheritance
- Available extensions
Constructors
-
Vector3D({Pointer<
Vector3C> ? originalPointer, double x = 0, double y = 0, double z = 0}) - Vector3D.barycenter(Vector3D p, Vector3D a, Vector3D b, Vector3D c)
-
factory
- Vector3D.one()
-
factory
- Vector3D.perpendicular(Vector3D o)
-
factory
- Vector3D.vec3(num x, num y, num z)
-
factory
- Vector3D.vec3Normalized(num x, num y, num z)
-
factory
- Vector3D.zero()
-
factory
Properties
- allocKey → String?
-
The RaylibTemp slot key used during the most recent toC allocation.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- internalId → int
-
A stable numeric ID assigned on first toC call for pointer-owning structs.
no setterinherited
- isDisposed → bool
-
Whether markDisposed has been called on this instance.
no setterinherited
- length → double
-
Available on Vector3D, provided by the Vector3DLike extension
no setter - lengthSqr → double
-
Available on Vector3D, provided by the Vector3DLike extension
no setter -
originalPointer
↔ Pointer<
Vector3C> ? -
The C-owned or RaylibTemp-owned native pointer for this struct, if any.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- structName → String
-
The Dart-side type name of this struct
no setterinherited
- tag → String
-
The slot tag used to disambiguate RaylibTemp keys for this instance.
no setterinherited
- x ↔ double
-
getter/setter pair
- y ↔ double
-
getter/setter pair
- z ↔ double
-
getter/setter pair
Methods
-
add(
Vector3D o) → Vector3D -
addValue(
num value) → Vector3D -
allocateInto(
RaylibTemp temp, Pointer< Vector3C> p, String key) → void -
Writes all fields into the native struct at
p, allocating nested pointers intotempunderkeyas needed.override -
allocatePointer(
RaylibTemp temp, String key, [int count = 1]) → Pointer< Vector3C> -
Allocates a native slot of
countelements intempunderkeyand returns the resulting pointer.override -
angle(
Vector3D o) → double -
Available on Vector3D, provided by the Vector3DLike extension
-
clamp(
Vector3D min, Vector3D max) → Vector3D -
clampValue(
double min, double max) → Vector3D -
clone(
) → Vector3D -
Returns a deep copy of this instance, preserving originalPointer.
override
-
copy(
) → Vector3D -
Returns a deep copy of this instance without originalPointer.
inherited
-
crossProduct(
Vector3D o) → Vector3D -
cubicHermite(
Vector3D tangent1, Vector3D v2, Vector3D tangent2, double amount) → Vector3D -
distance(
Vector3D o) → double -
Available on Vector3D, provided by the Vector3DLike extension
-
distanceSqr(
Vector3D o) → double -
Available on Vector3D, provided by the Vector3DLike extension
-
div(
Vector3D o) → Vector3D -
divideBy(
num o) → Vector3D -
dotProduct(
Vector3D o) → double -
Available on Vector3D, provided by the Vector3DLike extension
-
equals(
Vector3D o) → bool -
format(
[int x0 = 0, int? y0, int? z0]) → String -
Available on Vector3D, provided by the Vector3DLike extension
-
getOriginalPointer(
) → Pointer< Vector3C> -
Returns originalPointer, throwing a descriptive StateError if unavailable or this instance isDisposed.
inherited
-
getOriginalPointerAndDispose(
) → Pointer< Vector3C> -
Returns originalPointer and immediately calls markDisposed.
inherited
-
invert(
) → Vector3D -
lerp(
Vector3D o, double amount) → Vector3D -
markDisposed(
) → void -
Marks this instance as disposed and clears originalPointer.
inherited
-
max(
Vector3D o) → Vector3D -
min(
Vector3D o) → Vector3D -
moveTowards(
Vector3D target, double maxDistance) → Vector3D -
mul(
Vector3D o) → Vector3D -
negate(
) → Vector3D -
normalize(
) → Vector3D -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onOriginalPointer(
void callback(Pointer< Vector3C> p)) → void -
Calls
callbackwith originalPointer if it is set, otherwise no-ops.inherited -
orthoNormalize(
Vector3D o) → Vector3D -
project(
Vector3D o) → Vector3D -
reflect(
Vector3D normal) → Vector3D -
refract(
Vector3D n, double r) → Vector3D -
reject(
Vector3D o) → Vector3D -
rotateByAxisAngle(
Vector3D axis, double angle) → Vector3D -
rotateByQuaternion(
QuaternionD q) → Vector3D -
scale(
num o) → Vector3D -
set(
num x, num y, num z) → Vector3D -
setC(
Vector3C o) → Vector3D -
Copies the fields of the native struct
ointo this instance.override -
setD(
Vector3D o) → Vector3D -
Copies the fields of the Dart struct
ointo this instance.override -
setTag(
String newTag) → Vector3D -
Sets tag to
newTagand returnsthisfor chaining.inherited -
signature(
) → String -
Returns a human-readable description of this struct's current field values.
override
-
sub(
Vector3D o) → Vector3D -
subValue(
num value) → Vector3D -
syncInto(
RaylibTemp temp, Pointer< Vector3C> p, String key) → void -
Syncs Dart-side fields into the already-allocated native pointer
p.inherited -
toArray(
) → List< double> -
toC(
RaylibTemp temp, String key) → Pointer< Vector3C> -
Returns a native pointer for this struct, allocating or syncing as needed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
transform(
MatrixD o) → Vector3D -
unproject(
MatrixD projection, MatrixD view) → Vector3D -
writeInto(
Vector3C p) → void -
Writes all fields directly into the native struct reference
p. For nested structs, usewriteIntoas well.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited