Vector3D class

Inheritance
Available extensions

Constructors

Vector3D({Pointer<Vector3C>? originalPointer, double x = 0, double y = 0, double z = 0})
Vector3D.barycenter(Vector3D p, Vector3D a, Vector3D b, Vector3D c)
factory
Vector3D.one()
factory
Vector3D.perpendicular(Vector3D o)
factory
Vector3D.vec3(num x, num y, num z)
factory
Vector3D.vec3Normalized(num x, num y, num z)
factory
Vector3D.zero()
factory

Properties

allocKey String
no setterinherited
cStructName String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
internalId int
no setterinherited
isDisposed bool
no setterinherited
length double

Available on Vector3D, provided by the Vector3DLike extension

no setter
lengthSqr double

Available on Vector3D, provided by the Vector3DLike extension

no setter
originalPointer Pointer<Vector3C>?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structName String
no setterinherited
tag String
no setterinherited
x double
getter/setter pair
y double
getter/setter pair
z double
getter/setter pair

Methods

add(Vector3D o) Vector3D
addValue(num value) Vector3D
allocateInto(RaylibTemp temp, Pointer<Vector3C> p, String key) → void
override
allocatePointer(RaylibTemp temp, String key, [int count = 1]) Pointer<Vector3C>
override
angle(Vector3D o) double

Available on Vector3D, provided by the Vector3DLike extension

clamp(Vector3D min, Vector3D max) Vector3D
clampValue(double min, double max) Vector3D
clone() Vector3D
override
copy() Vector3D
inherited
crossProduct(Vector3D o) Vector3D
cubicHermite(Vector3D tangent1, Vector3D v2, Vector3D tangent2, double amount) Vector3D
distance(Vector3D o) double

Available on Vector3D, provided by the Vector3DLike extension

distanceSqr(Vector3D o) double

Available on Vector3D, provided by the Vector3DLike extension

div(Vector3D o) Vector3D
divideBy(num o) Vector3D
dotProduct(Vector3D o) double

Available on Vector3D, provided by the Vector3DLike extension

equals(Vector3D o) bool
format([int x0 = 0, int? y0, int? z0]) String

Available on Vector3D, provided by the Vector3DLike extension

getOriginalPointer() Pointer<Vector3C>
inherited
getOriginalPointerAndDispose() Pointer<Vector3C>
inherited
invert() Vector3D
lerp(Vector3D o, double amount) Vector3D
markDisposed() → void
inherited
max(Vector3D o) Vector3D
min(Vector3D o) Vector3D
moveTowards(Vector3D target, double maxDistance) Vector3D
mul(Vector3D o) Vector3D
negate() Vector3D
normalize() Vector3D
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onOriginalPointer(void callback(Pointer<Vector3C> p)) → void
inherited
orthoNormalize(Vector3D o) Vector3D
project(Vector3D o) Vector3D
reflect(Vector3D normal) Vector3D
refract(Vector3D n, double r) Vector3D
reject(Vector3D o) Vector3D
rotateByAxisAngle(Vector3D axis, double angle) Vector3D
rotateByQuaternion(QuaternionD q) Vector3D
scale(num o) Vector3D
set(num x, num y, num z) Vector3D
setC(Vector3C o) Vector3D
override
setD(Vector3D o) Vector3D
override
setTag(String newTag) Vector3D
inherited
signature() String
override
sub(Vector3D o) Vector3D
subValue(num value) Vector3D
syncInto(RaylibTemp temp, Pointer<Vector3C> p, String key) → void
inherited
toArray() List<double>
toC(RaylibTemp temp, String key) Pointer<Vector3C>
inherited
toString() String
A string representation of this object.
inherited
transform(MatrixD o) Vector3D
unproject(MatrixD projection, MatrixD view) Vector3D
writeInto(Vector3C p) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited