Vector4D class
- Inheritance
- Available extensions
Constructors
-
Vector4D({Pointer<
Vector4C> ? originalPointer, double x = 0, double y = 0, double z = 0, double w = 0}) - Vector4D.colorNormalize(ColorD color)
-
factory
- Vector4D.fromAxisAngle(Vector3D axis, double angle)
-
factory
- Vector4D.one()
-
factory
- Vector4D.qFromEuler(double pitch, double yaw, double roll)
-
factory
- Vector4D.qFromMatrix(MatrixD mat)
-
factory
- Vector4D.qFromVector3ToVector3(Vector3D from, Vector3D to)
-
factory
- Vector4D.qIdentity()
-
factory
- Vector4D.quat(num x, num y, num z, num w)
-
factory
- Vector4D.vec4(num x, num y, num z, num w)
-
factory
- Vector4D.zero()
-
factory
Properties
- allocKey → String?
-
The RaylibTemp slot key used during the most recent toC allocation.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- internalId → int
-
A stable numeric ID assigned on first toC call for pointer-owning structs.
no setterinherited
- isDisposed → bool
-
Whether markDisposed has been called on this instance.
no setterinherited
- length → double
-
Available on Vector4D, provided by the Vector4DLike extension
no setter - lengthSqr → double
-
Available on Vector4D, provided by the Vector4DLike extension
no setter -
originalPointer
↔ Pointer<
Vector4C> ? -
The C-owned or RaylibTemp-owned native pointer for this struct, if any.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- structName → String
-
The Dart-side type name of this struct
no setterinherited
- tag → String
-
The slot tag used to disambiguate RaylibTemp keys for this instance.
no setterinherited
- w ↔ double
-
getter/setter pair
- x ↔ double
-
getter/setter pair
- y ↔ double
-
getter/setter pair
- z ↔ double
-
getter/setter pair
Methods
-
add(
Vector4D o) → Vector4D -
addValue(
num value) → Vector4D -
allocateInto(
RaylibTemp temp, Pointer< Vector4C> p, String key) → void -
Writes all fields into the native struct at
p, allocating nested pointers intotempunderkeyas needed.override -
allocatePointer(
RaylibTemp temp, String key, [int count = 1]) → Pointer< Vector4C> -
Allocates a native slot of
countelements intempunderkeyand returns the resulting pointer.override -
clone(
) → Vector4D -
Returns a deep copy of this instance, preserving originalPointer.
override
-
copy(
) → Vector4D -
Returns a deep copy of this instance without originalPointer.
inherited
-
distance(
Vector4D o) → double -
Available on Vector4D, provided by the Vector4DLike extension
-
distanceSqr(
Vector4D o) → double -
Available on Vector4D, provided by the Vector4DLike extension
-
div(
Vector4D o) → Vector4D -
divideBy(
num o) → Vector4D -
dotProduct(
Vector4D o) → double -
Available on Vector4D, provided by the Vector4DLike extension
-
equals(
Vector4D o) → bool -
format(
[int x0 = 0, int? y0, int? z0, int? w0]) → String -
Available on Vector4D, provided by the Vector4DLike extension
-
getOriginalPointer(
) → Pointer< Vector4C> -
Returns originalPointer, throwing a descriptive StateError if unavailable or this instance isDisposed.
inherited
-
getOriginalPointerAndDispose(
) → Pointer< Vector4C> -
Returns originalPointer and immediately calls markDisposed.
inherited
-
invert(
) → Vector4D -
lerp(
Vector4D o, double amount) → Vector4D -
markDisposed(
) → void -
Marks this instance as disposed and clears originalPointer.
inherited
-
max(
Vector4D o) → Vector4D -
min(
Vector4D o) → Vector4D -
moveTowards(
Vector4D target, double maxDistance) → Vector4D -
mul(
Vector4D o) → Vector4D -
negate(
) → Vector4D -
normalize(
) → Vector4D -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onOriginalPointer(
void callback(Pointer< Vector4C> p)) → void -
Calls
callbackwith originalPointer if it is set, otherwise no-ops.inherited -
qCubicHermiteSpline(
QuaternionD outTangent1, QuaternionD q2, QuaternionD inTangent2, double t) → QuaternionD -
Available on Vector4D, provided by the Vector4DAsQuaternion extension
-
qEquals(
QuaternionD o) → bool -
Available on Vector4D, provided by the Vector4DAsQuaternion extension
-
qInvert(
) → QuaternionD -
Available on Vector4D, provided by the Vector4DAsQuaternion extension
-
qMul(
QuaternionD o) → QuaternionD -
Available on Vector4D, provided by the Vector4DAsQuaternion extension
-
qNlerp(
QuaternionD o, double amount) → QuaternionD -
Available on Vector4D, provided by the Vector4DAsQuaternion extension
-
qSlerp(
QuaternionD o, double amount) → QuaternionD -
Available on Vector4D, provided by the Vector4DAsQuaternion extension
-
qToAxisAngle(
) → (Vector3D, double) -
Available on Vector4D, provided by the Vector4DAsQuaternion extension
-
qToEuler(
) → Vector3D -
Available on Vector4D, provided by the Vector4DAsQuaternion extension
-
qToMatrix(
) → MatrixD -
Available on Vector4D, provided by the Vector4DAsQuaternion extension
-
qTransform(
MatrixD mat) → QuaternionD -
Available on Vector4D, provided by the Vector4DAsQuaternion extension
-
scale(
num o) → Vector4D -
set(
num x, num y, num z, num w) → Vector4D -
setC(
Vector4C o) → Vector4D -
Copies the fields of the native struct
ointo this instance.override -
setD(
Vector4D o) → Vector4D -
Copies the fields of the Dart struct
ointo this instance.override -
setTag(
String newTag) → Vector4D -
Sets tag to
newTagand returnsthisfor chaining.inherited -
signature(
) → String -
Returns a human-readable description of this struct's current field values.
override
-
sub(
Vector4D o) → Vector4D -
subValue(
num value) → Vector4D -
syncInto(
RaylibTemp temp, Pointer< Vector4C> p, String key) → void -
Syncs Dart-side fields into the already-allocated native pointer
p.inherited -
toArray(
) → List< double> -
toC(
RaylibTemp temp, String key) → Pointer< Vector4C> -
Returns a native pointer for this struct, allocating or syncing as needed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
writeInto(
Vector4C p) → void -
Writes all fields directly into the native struct reference
p. For nested structs, usewriteIntoas well.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited