Vector4D class

Inheritance
Available extensions

Constructors

Vector4D({Pointer<Vector4C>? originalPointer, double x = 0, double y = 0, double z = 0, double w = 0})
Vector4D.colorNormalize(ColorD color)
factory
Vector4D.fromAxisAngle(Vector3D axis, double angle)
factory
Vector4D.one()
factory
Vector4D.qFromEuler(double pitch, double yaw, double roll)
factory
Vector4D.qFromMatrix(MatrixD mat)
factory
Vector4D.qFromVector3ToVector3(Vector3D from, Vector3D to)
factory
Vector4D.qIdentity()
factory
Vector4D.quat(num x, num y, num z, num w)
factory
Vector4D.vec4(num x, num y, num z, num w)
factory
Vector4D.zero()
factory

Properties

allocKey String
no setterinherited
cStructName String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
internalId int
no setterinherited
isDisposed bool
no setterinherited
length double

Available on Vector4D, provided by the Vector4DLike extension

no setter
lengthSqr double

Available on Vector4D, provided by the Vector4DLike extension

no setter
originalPointer Pointer<Vector4C>?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structName String
no setterinherited
tag String
no setterinherited
w double
getter/setter pair
x double
getter/setter pair
y double
getter/setter pair
z double
getter/setter pair

Methods

add(Vector4D o) Vector4D
addValue(num value) Vector4D
allocateInto(RaylibTemp temp, Pointer<Vector4C> p, String key) → void
override
allocatePointer(RaylibTemp temp, String key, [int count = 1]) Pointer<Vector4C>
override
clone() Vector4D
override
copy() Vector4D
inherited
distance(Vector4D o) double

Available on Vector4D, provided by the Vector4DLike extension

distanceSqr(Vector4D o) double

Available on Vector4D, provided by the Vector4DLike extension

div(Vector4D o) Vector4D
divideBy(num o) Vector4D
dotProduct(Vector4D o) double

Available on Vector4D, provided by the Vector4DLike extension

equals(Vector4D o) bool
format([int x0 = 0, int? y0, int? z0, int? w0]) String

Available on Vector4D, provided by the Vector4DLike extension

getOriginalPointer() Pointer<Vector4C>
inherited
getOriginalPointerAndDispose() Pointer<Vector4C>
inherited
invert() Vector4D
lerp(Vector4D o, double amount) Vector4D
markDisposed() → void
inherited
max(Vector4D o) Vector4D
min(Vector4D o) Vector4D
moveTowards(Vector4D target, double maxDistance) Vector4D
mul(Vector4D o) Vector4D
negate() Vector4D
normalize() Vector4D
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onOriginalPointer(void callback(Pointer<Vector4C> p)) → void
inherited
qCubicHermiteSpline(QuaternionD outTangent1, QuaternionD q2, QuaternionD inTangent2, double t) QuaternionD

Available on Vector4D, provided by the Vector4DAsQuaternion extension

qEquals(QuaternionD o) bool

Available on Vector4D, provided by the Vector4DAsQuaternion extension

qInvert() QuaternionD

Available on Vector4D, provided by the Vector4DAsQuaternion extension

qMul(QuaternionD o) QuaternionD

Available on Vector4D, provided by the Vector4DAsQuaternion extension

qNlerp(QuaternionD o, double amount) QuaternionD

Available on Vector4D, provided by the Vector4DAsQuaternion extension

qSlerp(QuaternionD o, double amount) QuaternionD

Available on Vector4D, provided by the Vector4DAsQuaternion extension

qToAxisAngle() → (Vector3D, double)

Available on Vector4D, provided by the Vector4DAsQuaternion extension

qToEuler() Vector3D

Available on Vector4D, provided by the Vector4DAsQuaternion extension

qToMatrix() MatrixD

Available on Vector4D, provided by the Vector4DAsQuaternion extension

qTransform(MatrixD mat) QuaternionD

Available on Vector4D, provided by the Vector4DAsQuaternion extension

scale(num o) Vector4D
set(num x, num y, num z, num w) Vector4D
setC(Vector4C o) Vector4D
override
setD(Vector4D o) Vector4D
override
setTag(String newTag) Vector4D
inherited
signature() String
override
sub(Vector4D o) Vector4D
subValue(num value) Vector4D
syncInto(RaylibTemp temp, Pointer<Vector4C> p, String key) → void
inherited
toArray() List<double>
toC(RaylibTemp temp, String key) Pointer<Vector4C>
inherited
toString() String
A string representation of this object.
inherited
writeInto(Vector4C p) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited