VrDeviceInfoC class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter -
chromaAbCorrection
↔ Array<
Float> -
getter/setter pair
- eyeToScreenDistance ↔ double
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hResolution ↔ int
-
getter/setter pair
- hScreenSize ↔ double
-
getter/setter pair
- interpupillaryDistance ↔ double
-
getter/setter pair
-
lensDistortionValues
↔ Array<
Float> -
getter/setter pair
- lensSeparationDistance ↔ double
-
getter/setter pair
- paramCount → int
-
Available on VrDeviceInfoC, provided by the VrDeviceInfoCLike extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- vResolution ↔ int
-
getter/setter pair
- vScreenSize ↔ double
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setC(
VrDeviceInfoC o) → VrDeviceInfoC -
Available on VrDeviceInfoC, provided by the VrDeviceInfoCEx extension
-
setD(
VrDeviceInfoD o) → VrDeviceInfoC -
Available on VrDeviceInfoC, provided by the VrDeviceInfoCEx extension
-
toD(
[Pointer< VrDeviceInfoC> ? ptr]) → VrDeviceInfoD -
Available on VrDeviceInfoC, provided by the VrDeviceInfoCEx extension
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited