VrDeviceInfoD class

Inheritance
Available extensions

Constructors

VrDeviceInfoD({Pointer<VrDeviceInfoC>? originalPointer, int hResolution = 0, int vResolution = 0, double hScreenSize = 0, double vScreenSize = 0, double eyeToScreenDistance = 0, double lensSeparationDistance = 0, double interpupillaryDistance = 0, List<double>? lensDistortionValues, List<double>? chromaAbCorrection})
VrDeviceInfoD.zero()
factory

Properties

allocKey String
no setterinherited
chromaAbCorrection List<double>
getter/setter pair
cStructName String
no setterinherited
eyeToScreenDistance double
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hResolution int
getter/setter pair
hScreenSize double
getter/setter pair
internalId int
no setterinherited
interpupillaryDistance double
getter/setter pair
isDisposed bool
no setterinherited
lensDistortionValues List<double>
getter/setter pair
lensSeparationDistance double
getter/setter pair
originalPointer Pointer<VrDeviceInfoC>?
getter/setter pairinherited
paramCount int

Available on VrDeviceInfoD, provided by the VrDeviceInfoDLike extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structName String
no setterinherited
tag String
no setterinherited
vResolution int
getter/setter pair
vScreenSize double
getter/setter pair

Methods

allocateInto(RaylibTemp temp, Pointer<VrDeviceInfoC> p, String key) → void
override
allocatePointer(RaylibTemp temp, String key, [int count = 1]) Pointer<VrDeviceInfoC>
override
clone() VrDeviceInfoD
override
copy() VrDeviceInfoD
inherited
getOriginalPointer() Pointer<VrDeviceInfoC>
inherited
getOriginalPointerAndDispose() Pointer<VrDeviceInfoC>
inherited
markDisposed() → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onOriginalPointer(void callback(Pointer<VrDeviceInfoC> p)) → void
inherited
setC(VrDeviceInfoC o) VrDeviceInfoD
override
setD(VrDeviceInfoD o) VrDeviceInfoD
override
setTag(String newTag) VrDeviceInfoD
inherited
signature() String
override
syncInto(RaylibTemp temp, Pointer<VrDeviceInfoC> p, String key) → void
override
toC(RaylibTemp temp, String key) Pointer<VrDeviceInfoC>
inherited
toString() String
A string representation of this object.
inherited
writeInto(VrDeviceInfoC p) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited