core/raylib_dartified library

Classes

AudioCallbackD
AudioStreamC
AudioStreamD
AutomationEventC
AutomationEventD
AutomationEventListC
AutomationEventListD
BoneInfoC
BoneInfoD
BoundingBoxC
BoundingBoxD
CallbackD<C extends Function, D extends Function>
A Dart-side wrapper around a NativeCallable<C>, bridging a Dart function of type D to a native callback of type C.
Camera2DC
Camera2DD
Camera3DC
Camera3DD
ColorC
ColorD
DoNotValidate
FilePathListC
FilePathListD
FontC
FontD
GlyphInfoC
GlyphInfoD
ImageC
ImageD
LightC
LightD
LoadFileDataCallbackD
LoadFileTextCallbackD
MaterialC
MaterialD
MaterialMapC
MaterialMapD
MatrixC
MatrixD
MeshC
MeshD
ModelAnimationC
ModelAnimationD
ModelC
ModelD
MusicC
MusicD
NativeAlloc<C extends NativeType>
A slot-based temporary memory allocator for a single native type C.
NativeLitAlloc<X, C extends NativeType>
A NativeAlloc that also knows how to write Dart values of type X into native C memory, and supports typed-list array operations.
NativeLitFloatAlloc<C extends NativeType, L extends TypedDataList>
A typed-list allocator for floating-point native types (e.g. Float, Double).
NativeLitIntAlloc<C extends NativeType, L extends TypedDataList>
A typed-list allocator for integer native types (e.g. Int32, Uint8).
NativeLitPtrAlloc<X, C extends NativeType>
A slot-based allocator for arrays of pointers to literal elements.
NativeLitTypedListAlloc<X, C extends NativeType, L extends TypedDataList>
Extends NativeLitAlloc with typed-list bulk copy support.
NativeLiveListArray<C extends NativeType, E>
NativeLiveListArrayFloat
NativeLiveListArrayInt
NativeLiveListArrayStruct<C extends Struct, D extends StructD<C, D>>
NativeLiveListArrayUnsignedChar
NativeLiveListArrayUnsignedInt
NativeLiveListArrayUnsignedShort
NativeLiveListPointer<C extends NativeType, E>
NativeLiveListPointerFloat
NativeLiveListPointerInt
NativeLiveListPointerPointerStruct<C extends Struct, D extends StructD<C, D>>
NativeLiveListPointerStruct<C extends Struct, D extends StructD<C, D>>
NativeLiveListPointerUnsignedChar
NativeLiveListPointerUnsignedInt
NativeLiveListPointerUnsignedShort
NativeStringAlloc
A specialised slot-based allocator for C strings (Pointer\<Char>).
NativeStructAlloc<C extends Struct, D extends StructD<C, D>>
A slot-based allocator for native structs of type C, accepting Dart-side StructD wrappers of type D.
NativeStructPtrAlloc<C extends Struct, D extends StructD<C, D>>
A slot-based allocator for arrays of pointers to native structs of type C.
NativeTypedDataListAlloc
NPatchInfoC
NPatchInfoD
QuaternionC
QuaternionD
rAudioBuffer
rAudioProcessor
RayC
RayCollisionC
RayCollisionD
RayD
Raylib
RaylibAudio
RaylibAudioD
RaylibCamera
RaylibCameraD
RaylibColors
RaylibCore
RaylibCoreD
RaylibEasings
RaylibGame
RaylibGui
RaylibGuiD
RaylibLight
RaylibLightD
RaylibMatrices
RaylibQuaternions
RaylibRlgl
RaylibRlglD
RaylibTemp
RaylibUtils
RaylibVectors
RectangleC
RectangleD
RenderTextureC
RenderTextureD
RlDrawCallC
RlDrawCallD
RlRenderBatchC
RlRenderBatchD
RlVertexBufferC
RlVertexBufferD
SaveFileDataCallbackD
SaveFileTextCallbackD
ShaderC
ShaderD
SoundC
SoundD
StructD<C extends Struct, D extends StructD<C, D>>
Abstract Dart-side mirror of a native struct of type C.
StructDLiteral<C extends Struct, D extends StructD<C, D>>
A StructD for value-type structs that are always passed by value.
StructDView<C extends Struct, D extends StructD<C, D>>
A read-only StructD that wraps an existing native pointer without owning it.
TextureC
TextureD
TransformC
TransformD
Vector2C
Vector2D
Vector3C
Vector3D
Vector4C
Vector4D
VrDeviceInfoC
VrDeviceInfoD
VrStereoConfigC
VrStereoConfigD
WaveC
WaveD

Mixins

FEnum

Extensions

AudioStreamCEx on AudioStreamC
AudioStreamCPEx on Pointer<AudioStreamC>
AutomationEventCEx on AutomationEventC
AutomationEventCPEx on Pointer<AutomationEventC>
AutomationEventListCEx on AutomationEventListC
AutomationEventListCPEx on Pointer<AutomationEventListC>
BoneInfoCEx on BoneInfoC
BoneInfoCPEx on Pointer<BoneInfoC>
BoolAsInt on bool
BoundingBoxCEx on BoundingBoxC
BoundingBoxCPEx on Pointer<BoundingBoxC>
Camera2DCEx on Camera2DC
Camera2DCPEx on Pointer<Camera2DC>
Camera3DCEx on Camera3DC
Camera3DCPEx on Pointer<Camera3DC>
CharCodeString on String
CharPointerEx on Pointer<Char>
ColorCEx on ColorC
ColorCPEx on Pointer<ColorC>
CString on String
FilePathListCEx on FilePathListC
FilePathListCPEx on Pointer<FilePathListC>
FontCEx on FontC
FontCPEx on Pointer<FontC>
GetStringFromArrayChar on Array<Char>
GlyphInfoCEx on GlyphInfoC
GlyphInfoCPEx on Pointer<GlyphInfoC>
ImageCEx on ImageC
ImageCPEx on Pointer<ImageC>
IntAsBool on int
IntHex on int
IterableFEnumEx on Iterable<FEnum>
IterableIntEx on Iterable<int>
LightCEx on LightC
LightCPEx on Pointer<LightC>
MaterialCEx on MaterialC
MaterialCPEx on Pointer<MaterialC>
MaterialMapCEx on MaterialMapC
MaterialMapCPEx on Pointer<MaterialMapC>
MatrixCEx on MatrixC
MatrixCPEx on Pointer<MatrixC>
MeshCEx on MeshC
MeshCPEx on Pointer<MeshC>
ModelAnimationCEx on ModelAnimationC
ModelAnimationCPEx on Pointer<ModelAnimationC>
ModelCEx on ModelC
ModelCPEx on Pointer<ModelC>
MusicCEx on MusicC
MusicCPEx on Pointer<MusicC>
NPatchInfoCEx on NPatchInfoC
NPatchInfoCPEx on Pointer<NPatchInfoC>
QuaternionCEx on QuaternionC
QuaternionCPEx on Pointer<QuaternionC>
RayCEx on RayC
RayCollisionCEx on RayCollisionC
RayCollisionCPEx on Pointer<RayCollisionC>
RayCPEx on Pointer<RayC>
RectangleCEx on RectangleC
RectangleCPEx on Pointer<RectangleC>
RenderTextureCEx on RenderTextureC
RenderTextureCPEx on Pointer<RenderTextureC>
RlDrawCallCEx on RlDrawCallC
RlDrawCallCPEx on Pointer<RlDrawCallC>
RlRenderBatchCEx on RlRenderBatchC
RlRenderBatchCPEx on Pointer<RlRenderBatchC>
RlVertexBufferCEx on RlVertexBufferC
RlVertexBufferCPEx on Pointer<RlVertexBufferC>
ShaderCEx on ShaderC
ShaderCPEx on Pointer<ShaderC>
SoundCEx on SoundC
SoundCPEx on Pointer<SoundC>
TextureCEx on TextureC
TextureCPEx on Pointer<TextureC>
TransformCEx on TransformC
TransformCPEx on Pointer<TransformC>
Vector2CEx on Vector2C
Vector2CPEx on Pointer<Vector2C>
Vector3CEx on Vector3C
Vector3CPEx on Pointer<Vector3C>
Vector4CEx on Vector4C
Vector4CPEx on Pointer<Vector4C>
VrDeviceInfoCEx on VrDeviceInfoC
VrDeviceInfoCPEx on Pointer<VrDeviceInfoC>
VrStereoConfigCEx on VrStereoConfigC
VrStereoConfigCPEx on Pointer<VrStereoConfigC>
WaveCEx on WaveC
WaveCPEx on Pointer<WaveC>

Functions

findRaylib(String folder, [RaylibTempBaseOptions? tempOptions]) Raylib
runRaylib(RaylibGame game, {String? nativeLibPath}) → void

Typedefs

AudioCallbackC = Pointer<NativeFunction<AudioCallbackFunctionC>>
AudioCallbackFunctionC = Void Function(Pointer<Void> bufferData, UnsignedInt frames)
AudioCallbackFunctionD = void Function(Pointer<Void> bufferData, int frames)
LoadFileDataCallbackC = Pointer<NativeFunction<LoadFileDataCallbackFunctionC>>
LoadFileDataCallbackFriendlyFunctionD = Pointer<UnsignedChar> Function(String fileName, Pointer<Int> dataSize)
LoadFileDataCallbackFunctionC = Pointer<UnsignedChar> Function(Pointer<Char> fileName, Pointer<Int> dataSize)
LoadFileDataCallbackFunctionD = Pointer<UnsignedChar> Function(Pointer<Char> fileName, Pointer<Int> dataSize)
LoadFileTextCallbackC = Pointer<NativeFunction<LoadFileTextCallbackFunctionC>>
LoadFileTextCallbackFriendlyFunctionD = String Function(String fileName)
LoadFileTextCallbackFunctionC = Pointer<Char> Function(Pointer<Char> fileName)
LoadFileTextCallbackFunctionD = Pointer<Char> Function(Pointer<Char> fileName)
RaylibLookup = Pointer<T> Function<T extends NativeType>(String symbolName)
SaveFileDataCallbackC = Pointer<NativeFunction<SaveFileDataCallbackFunctionC>>
SaveFileDataCallbackFriendlyFunctionD = bool Function(String fileName, Pointer<Void> data, int dataSize)
SaveFileDataCallbackFunctionC = Bool Function(Pointer<Char> fileName, Pointer<Void> data, Int dataSize)
SaveFileDataCallbackFunctionD = bool Function(Pointer<Char> fileName, Pointer<Void> data, int dataSize)
SaveFileTextCallbackC = Pointer<NativeFunction<SaveFileTextCallbackFunctionC>>
SaveFileTextCallbackFriendlyFunctionD = bool Function(String fileName, String text)
SaveFileTextCallbackFunctionC = Bool Function(Pointer<Char> fileName, Pointer<Char> text)
SaveFileTextCallbackFunctionD = bool Function(Pointer<Char> fileName, Pointer<Char> text)