ModelC class final
- Inheritance
- Implemented types
- Available extensions
Constructors
- ModelC()
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter -
boneMatrices
↔ Pointer<
MatrixC> -
getter/setter pair
-
currentPose
↔ Pointer<
TransformC> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- materialCount ↔ int
-
getter/setter pair
-
materials
↔ Pointer<
MaterialC> -
getter/setter pair
- meshCount ↔ int
-
getter/setter pair
-
meshes
↔ Pointer<
MeshC> -
getter/setter pair
-
meshMaterial
↔ Pointer<
Int> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skeleton ↔ ModelSkeletonC
-
getter/setter pair
- transform ↔ MatrixC
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDart(
[Pointer< ModelC> ? ptr]) → ModelD -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited