MsfGifStateC class final
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - currentFrame ↔ MsfCookedFrameC
-
getter/setter pair
-
customAllocatorContext
↔ Pointer<
Void> -
getter/setter pair
-
fileWriteData
↔ Pointer<
Void> -
getter/setter pair
- fileWriteFunc ↔ MsfGifFileWriteFuncC
-
getter/setter pair
- framesSubmitted ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- height ↔ int
-
getter/setter pair
-
listHead
↔ Pointer<
MsfGifBufferC> -
getter/setter pair
-
listTail
↔ Pointer<
MsfGifBufferC> -
getter/setter pair
-
lzwMem
↔ Pointer<
Uint16> -
getter/setter pair
- previousFrame ↔ MsfCookedFrameC
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width ↔ int
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDart(
[Pointer< MsfGifStateC> ? ptr]) → MsfGifStateD -
Available on MsfGifStateC, provided by the MsfGifStateCEx extension
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited