DrawPolyLinesEx method

void DrawPolyLinesEx(
  1. Vector2C center,
  2. int sides,
  3. double radius,
  4. double rotation,
  5. double lineThick,
  6. ColorC color,
)

Draw a polygon outline of n sides with extended parameters

Implementation

void DrawPolyLinesEx(Vector2C center, int sides, double radius, double rotation, double lineThick, ColorC color)
  => _DrawPolyLinesEx(center, sides, radius, rotation, lineThick, color);