LoadFontEx method
Load font from file with extended parameters, use NULL for codepoints and 0 for codepointCount to load the default character set, font size is provided in pixels height
Implementation
FontC LoadFontEx(Pointer<Char> fileName, int fontSize, Pointer<Int> codepoints, int codepointCount)
=> _LoadFontEx(fileName, fontSize, codepoints, codepointCount);