RaylibGuiFlatNative class
Methods
-
debug(bool v)
→ void
-
Enables or disables debug logging for this module.
inherited
-
debugError(String message)
→ void
-
Logs
message at error level if debug is enabled and message passes all filters.
inherited
-
debugFilter(bool filter(String))
→ void
-
Adds a predicate that gates debug output. Only messages satisfying at least one filter are logged.
inherited
-
debugInfo(String message)
→ void
-
Logs
message at info level if debug is enabled and message passes all filters.
inherited
-
debugTime(bool v)
→ void
-
Enables or disables per-call timing output alongside debug logs.
inherited
-
debugWarn(String message)
→ void
-
Logs
message at warn level if debug is enabled and message passes all filters.
inherited
-
disableSync<T>(T f())
→ T
-
Executes
f with RaylibTemp syncing temporarily disabled,
restoring the previous sync state afterward.
inherited
-
dispose()
→ void
-
Calls all registered onDispose callbacks and clears them.
inherited
-
disposeStructWithOpFreed<D extends RaylibStruct<D>>(D struct, void fn(StructPointer<D> ptr))
→ void
-
Disposes
struct, invokes fn with its underlying pointer, and then frees
the temporary allocation backing the pointer, if any.
inherited
-
disposeStructWithOpUnslotted<D extends RaylibStruct<D>>(D struct, void fn(StructPointer<D> ptr))
→ void
-
Disposes
struct, invokes fn with its underlying pointer, and then
unslots the temporary allocation backing the pointer, if any.
inherited
-
GuiButton(RectangleD bounds, MemoryPointer<RChar> text)
→ int
-
Button control, returns true when clicked
override
-
GuiCheckBox(RectangleD bounds, MemoryPointer<RChar> text, MemoryPointer<RBool> checked)
→ int
-
Check Box control, returns true when active
override
-
GuiColorBarAlpha(RectangleD bounds, MemoryPointer<RChar> text, MemoryPointer<RFloat> alpha)
→ int
-
Color Bar Alpha control
override
-
GuiColorBarHue(RectangleD bounds, MemoryPointer<RChar> text, MemoryPointer<RFloat> value)
→ int
-
Color Bar Hue control
override
-
GuiColorPanel(RectangleD bounds, MemoryPointer<RChar> text, StructPointer<ColorD> color)
→ int
-
Color Panel control
override
-
GuiColorPanelHSV(RectangleD bounds, MemoryPointer<RChar> text, StructPointer<Vector3D> colorHsv)
→ int
-
Color Panel control, using Hue-Saturation-Value color data
override
-
GuiColorPicker(RectangleD bounds, MemoryPointer<RChar> text, StructPointer<ColorD> color)
→ int
-
Color Picker control, includes Color bar controls
override
-
GuiColorPickerHSV(RectangleD bounds, MemoryPointer<RChar> text, StructPointer<Vector3D> colorHsv)
→ int
-
Color Picker control, using Hue-Saturation-Value color data, includes Color bar controls
override
-
GuiComboBox(RectangleD bounds, MemoryPointer<RChar> text, MemoryPointer<RInt> active)
→ int
-
Combo Box control
override
-
GuiDisable()
→ void
-
Disable gui controls (global state)
override
-
GuiDisableTooltip()
→ void
-
Disable gui tooltips (global state)
override
-
GuiDrawIcon(int iconId, int posX, int posY, int pixelSize, ColorD color)
→ void
-
Draw icon using pixel size at specified position
override
-
GuiDropdownBox(RectangleD bounds, MemoryPointer<RChar> text, MemoryPointer<RInt> active, bool editMode)
→ int
-
Dropdown Box control
override
-
GuiDummyRec(RectangleD bounds, MemoryPointer<RChar> text)
→ int
-
Dummy control for placeholders
override
-
GuiEnable()
→ void
-
Enable gui controls (global state)
override
-
GuiEnableTooltip()
→ void
-
Enable gui tooltips (global state)
override
-
GuiGetFont()
→ FontD
-
Get gui custom font (global state)
override
-
GuiGetIcons()
→ NativeMemoryPointer<RUnsignedInt>
-
Get raygui icons data
override
-
GuiGetState()
→ int
-
Get gui state (global state)
override
-
GuiGetStyle(int control, int property)
→ int
-
Get one style property
override
-
GuiGetTextWidth(MemoryPointer<RChar> text)
→ int
-
Get text width considering gui style and icon size (if required)
override
-
GuiGrid(RectangleD bounds, MemoryPointer<RChar> text, double spacing, int subdivs, StructPointer<Vector2D> mouseCell)
→ int
-
Grid control
override
-
GuiGroupBox(RectangleD bounds, MemoryPointer<RChar> text)
→ int
-
Group Box control with text name
override
-
GuiIconText(int iconId, MemoryPointer<RChar> text)
→ NativeMemoryPointer<RChar>
-
Get text with icon id prepended (if supported)
override
-
GuiIsLocked()
→ bool
-
Check if gui is locked (global state)
override
-
GuiLabel(RectangleD bounds, MemoryPointer<RChar> text)
→ int
-
Label control
override
-
GuiLabelButton(RectangleD bounds, MemoryPointer<RChar> text)
→ int
-
Label button control, returns true when clicked
override
-
GuiLine(RectangleD bounds, MemoryPointer<RChar> text)
→ int
-
Line separator control, could contain text
override
-
GuiListView(RectangleD bounds, MemoryPointer<RChar> text, MemoryPointer<RInt> scrollIndex, MemoryPointer<RInt> active)
→ int
-
List View control
override
-
GuiListViewEx(RectangleD bounds, MemoryPointer<RPointer<RChar>> text, int count, MemoryPointer<RInt> scrollIndex, MemoryPointer<RInt> active, MemoryPointer<RInt> focus)
→ int
-
List View control, using text entries list and returning focus entry
override
-
GuiLoadIcons(MemoryPointer<RChar> fileName, bool loadIconsName)
→ NativeMemoryPointer<RPointer<RChar>>
-
Load raygui icons file (.rgi) into internal icons data
override
-
GuiLoadIconsFromMemory(MemoryPointer<RUnsignedChar> fileData, int dataSize, bool loadIconsName)
→ NativeMemoryPointer<RPointer<RChar>>
-
Load raygui icons file (.rgi) from memory into internal icons data
override
-
GuiLoadStyle(MemoryPointer<RChar> fileName)
→ void
-
Load style file over global style variable (.rgs)
override
-
GuiLoadStyleDefault()
→ void
-
Load style default over global style
override
-
GuiLoadStyleFromMemory(MemoryPointer<RUnsignedChar> fileData, int dataSize)
→ void
-
Load style from memory (binary only)
override
-
GuiLock()
→ void
-
Lock gui controls (global state)
override
-
GuiMessageBox(RectangleD bounds, MemoryPointer<RChar> title, MemoryPointer<RChar> message, MemoryPointer<RChar> btnText, MemoryPointer<RInt> btnActive)
→ int
-
Message Box control, displays a message
override
-
GuiPanel(RectangleD bounds, MemoryPointer<RChar> text)
→ int
-
Panel control, useful to group controls
override
-
GuiProgressBar(RectangleD bounds, MemoryPointer<RChar> textLeft, MemoryPointer<RChar> textRight, MemoryPointer<RFloat> value, double minValue, double maxValue)
→ int
-
Progress Bar control
override
-
GuiScrollPanel(RectangleD bounds, MemoryPointer<RChar> text, RectangleD content, StructPointer<Vector2D> scroll, StructPointer<RectangleD> view)
→ int
-
Scroll Panel control
override
-
GuiSetAlpha(double alpha)
→ void
-
Set gui controls alpha (global state), alpha goes from 0.0 to 1.0
override
-
GuiSetFont(FontD font)
→ void
-
Set gui custom font (global state)
override
-
GuiSetIconScale(int scale)
→ void
-
Set default icon drawing size
override
-
GuiSetState(int state)
→ void
-
Set gui state (global state)
override
-
GuiSetStyle(int control, int property, int value)
→ void
-
Set one style property
override
-
GuiSetTooltip(MemoryPointer<RChar> tooltip)
→ void
-
Set tooltip string
override
-
GuiSlider(RectangleD bounds, MemoryPointer<RChar> textLeft, MemoryPointer<RChar> textRight, MemoryPointer<RFloat> value, double minValue, double maxValue)
→ int
-
Slider control
override
-
GuiSliderBar(RectangleD bounds, MemoryPointer<RChar> textLeft, MemoryPointer<RChar> textRight, MemoryPointer<RFloat> value, double minValue, double maxValue)
→ int
-
Slider Bar control
override
-
GuiSpinner(RectangleD bounds, MemoryPointer<RChar> text, MemoryPointer<RInt> value, int minValue, int maxValue, bool editMode)
→ int
-
Spinner control
override
-
GuiStatusBar(RectangleD bounds, MemoryPointer<RChar> text)
→ int
-
Status Bar control, shows info text
override
-
GuiTabBar(RectangleD bounds, MemoryPointer<RChar> text, MemoryPointer<RInt> hscroll, MemoryPointer<RInt> active)
→ int
-
Tab Bar control
override
-
GuiTabBarEx(RectangleD bounds, MemoryPointer<RPointer<RChar>> text, int count, MemoryPointer<RInt> hscroll, MemoryPointer<RInt> active, MemoryPointer<RInt> focus)
→ int
-
Tab Bar control, using text entries list and returning focus entry
override
-
GuiTextBox(RectangleD bounds, MemoryPointer<RChar> text, int textSize, bool editMode)
→ int
-
Text Box control, updates input text
override
-
GuiTextInputBox(RectangleD bounds, MemoryPointer<RChar> title, MemoryPointer<RChar> message, MemoryPointer<RChar> text, int textSize, MemoryPointer<RChar> btnText, MemoryPointer<RInt> btnActive, MemoryPointer<RBool> secretViewActive)
→ int
-
Text Input Box control, ask for text, supports secret
override
-
GuiToggle(RectangleD bounds, MemoryPointer<RChar> text, MemoryPointer<RBool> active)
→ int
-
Toggle Button control
override
-
GuiToggleGroup(RectangleD bounds, MemoryPointer<RChar> text, MemoryPointer<RInt> active)
→ int
-
Toggle Group control
override
-
GuiToggleSlider(RectangleD bounds, MemoryPointer<RChar> text, MemoryPointer<RInt> active)
→ int
-
Toggle Slider control
override
-
GuiUnlock()
→ void
-
Unlock gui controls (global state)
override
-
GuiValueBox(RectangleD bounds, MemoryPointer<RChar> text, MemoryPointer<RInt> value, int minValue, int maxValue, bool editMode)
→ int
-
Value Box control, updates input text with numbers
override
-
GuiValueBoxFloat(RectangleD bounds, MemoryPointer<RChar> text, MemoryPointer<RChar> textValue, MemoryPointer<RFloat> value, bool editMode)
→ int
-
Value box control for float values
override
-
GuiWindowBox(RectangleD bounds, MemoryPointer<RChar> title)
→ int
-
Window Box control, shows a window that can be closed
override
-
load()
→ void
-
Override to perform one-time module initialization.
inherited
-
logError(Object? message)
→ void
-
inherited
-
logInfo(Object? message)
→ void
-
inherited
-
logWarn(Object? message)
→ void
-
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
onDispose(void fn())
→ void
-
Registers
fn to be called when this module is disposed.
inherited
-
run<T>(String name(), T f())
→ T
-
Executes
f, logging its label (and optionally timing it) when debug is enabled
and the label passes all filters.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited