RaylibVector3Ext class
Methods
debug (bool v )
→ void
Enables or disables debug logging for this module.
inherited
debugError (String message )
→ void
Logs message at error level if debug is enabled and message passes all filters.
inherited
debugFilter (bool filter (String ) )
→ void
Adds a predicate that gates debug output. Only messages satisfying at least one filter are logged.
inherited
debugInfo (String message )
→ void
Logs message at info level if debug is enabled and message passes all filters.
inherited
debugTime (bool v )
→ void
Enables or disables per-call timing output alongside debug logs.
inherited
debugWarn (String message )
→ void
Logs message at warn level if debug is enabled and message passes all filters.
inherited
disableSync <T > (T f () )
→ T
Executes f with RaylibTemp syncing temporarily disabled,
restoring the previous sync state afterward.
inherited
dispose ()
→ void
Calls all registered onDispose callbacks and clears them.
inherited
disposeStructWithOpFreed <D extends RaylibStruct <D > > (D struct , void fn (StructPointer <D > ptr ) )
→ void
Disposes struct, invokes fn with its underlying pointer, and then frees
the temporary allocation backing the pointer, if any.
inherited
disposeStructWithOpUnslotted <D extends RaylibStruct <D > > (D struct , void fn (StructPointer <D > ptr ) )
→ void
Disposes struct, invokes fn with its underlying pointer, and then
unslots the temporary allocation backing the pointer, if any.
inherited
load ()
→ void
Override to perform one-time module initialization.
inherited
logError (Object ? message )
→ void
inherited
logInfo (Object ? message )
→ void
inherited
logWarn (Object ? message )
→ void
inherited
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose (void fn () )
→ void
Registers fn to be called when this module is disposed.
inherited
run <T > (String name (), T f () )
→ T
Executes f, logging its label (and optionally timing it) when debug is enabled
and the label passes all filters.
inherited
toString ()
→ String
A string representation of this object.
inherited
Vector3Add (Vector3C v1 , Vector3C v2 )
→ Vector3C
Add two vectors
Vector3AddValue (Vector3C v , double add )
→ Vector3C
Add vector and double value
Vector3Angle (Vector3C v1 , Vector3C v2 )
→ double
Calculate angle between two vectors
Vector3Barycenter (Vector3C p , Vector3C a , Vector3C b , Vector3C c )
→ Vector3C
Compute barycenter coordinates (u, v, w) for point p with respect to triangle (a, b, c)
Vector3Clamp (Vector3C v , Vector3C min , Vector3C max )
→ Vector3C
Clamp the components of the vector between
min and max values specified by the given vectors
Vector3ClampValue (Vector3C v , double min , double max )
→ Vector3C
Clamp the magnitude of the vector between two values
Vector3CrossProduct (Vector3C v1 , Vector3C v2 )
→ Vector3C
Calculate two vectors cross product
Vector3CubicHermite (Vector3C v1 , Vector3C tangent1 , Vector3C v2 , Vector3C tangent2 , double amount )
→ Vector3C
Calculate cubic hermite interpolation between two vectors and their tangents
as described in the GLTF 2.0 specification: https://registry.khronos.org/glTF/specs/2.0/glTF-2.0.html#interpolation-cubic
Vector3Distance (Vector3C v1 , Vector3C v2 )
→ double
Calculate distance between two vectors
Vector3DistanceSqr (Vector3C v1 , Vector3C v2 )
→ double
Calculate square distance between two vectors
Vector3Divide (Vector3C v1 , Vector3C v2 )
→ Vector3C
Divide vector by vector
Vector3DotProduct (Vector3C v1 , Vector3C v2 )
→ double
Calculate two vectors dot product
Vector3Equals (Vector3C p , Vector3C q )
→ bool
Check whether two given vectors are almost equal
Vector3Invert (Vector3C v )
→ Vector3C
Invert the given vector
Vector3Length (Vector3C v )
→ double
Calculate vector length
Vector3LengthSqr (Vector3C v )
→ double
Calculate vector square length
Vector3Lerp (Vector3C v1 , Vector3C v2 , double amount )
→ Vector3C
Calculate linear interpolation between two vectors
Vector3Max (Vector3C v1 , Vector3C v2 )
→ Vector3C
Get max value for each pair of components
Vector3Min (Vector3C v1 , Vector3C v2 )
→ Vector3C
Get min value for each pair of components
Vector3MoveTowards (Vector3C v , Vector3C target , double maxDistance )
→ Vector3C
Move Vector towards target
Vector3Multiply (Vector3C v1 , Vector3C v2 )
→ Vector3C
Multiply vector by vector
Vector3Negate (Vector3C v )
→ Vector3C
Negate provided vector (invert direction)
Vector3Normalize (Vector3C v )
→ Vector3C
Normalize provided vector
Vector3One ()
→ Vector3C
Vector with components value 1.0f
Vector3OrthoNormalize (Pointer <Vector3C > v1 , Pointer <Vector3C > v2 )
→ void
Orthonormalize provided vectors
Makes vectors normalized and orthogonal to each other
Gram-Schmidt function implementation
Vector3Perpendicular (Vector3C v )
→ Vector3C
Calculate one vector perpendicular vector
Vector3Project (Vector3C v1 , Vector3C v2 )
→ Vector3C
Calculate the projection of the vector v1 on to v2
Vector3Reflect (Vector3C v , Vector3C normal )
→ Vector3C
Calculate reflected vector to normal
Vector3Refract (Vector3C v , Vector3C n , double r )
→ Vector3C
Compute the direction of a refracted ray
v: normalized direction of the incoming ray
n: normalized normal vector of the interface of two optical media
r: ratio of the refractive index of the medium from where the ray comes
to the refractive index of the medium on the other side of the surface
Vector3Reject (Vector3C v1 , Vector3C v2 )
→ Vector3C
Calculate the rejection of the vector v1 on to v2
Vector3RotateByAxisAngle (Vector3C v , Vector3C axis , double angle )
→ Vector3C
Rotates a vector around an axis
Vector3RotateByQuaternion (Vector3C v , QuaternionC q )
→ Vector3C
Transform a vector by quaternion rotation
Vector3Scale (Vector3C v , double scalar )
→ Vector3C
Multiply vector by scalar
Vector3Subtract (Vector3C v1 , Vector3C v2 )
→ Vector3C
Subtract two vectors
Vector3SubtractValue (Vector3C v , double sub )
→ Vector3C
Subtract vector by double value
Vector3ToFloatV (Vector3C v )
→ float3C
Get Vector3 as float array
Vector3Transform (Vector3C v , MatrixC mat )
→ Vector3C
Transforms a Vector3 by a given Matrix
Vector3Unproject (Vector3C source , MatrixC projection , MatrixC view )
→ Vector3C
Projects a Vector3 from screen space into object space
Vector3Zero ()
→ Vector3C
Vector with components value 0.0f