raylib library

Classes

AudioCallbackD
AudioStreamC
AudioStreamD
AutomationEventC
AutomationEventD
AutomationEventListC
AutomationEventListD
BaseRaylibModule
BoneInfoC
BoneInfoD
BoundingBoxC
BoundingBoxD
CallbackD<C extends Function, D extends Function>
Camera2DC
Camera2DD
Camera3DC
Camera3DD
ColorC
ColorD
DoNotValidate
FilePathListC
FilePathListD
FMouseButtonInfoD
FMouseInfoD
FontC
FontD
GlyphInfoC
GlyphInfoD
ImageC
ImageD
LightC
LightD
LoadFileDataCallbackD
LoadFileTextCallbackD
MaterialC
MaterialD
MaterialMapC
MaterialMapD
MatrixC
MatrixD
MeshC
MeshD
ModelAnimationC
ModelAnimationD
ModelC
ModelD
MusicC
MusicD
NPatchInfoC
NPatchInfoD
rAudioBuffer
rAudioProcessor
RayC
RayCollisionC
RayCollisionD
RayD
Raylib
RaylibAudio
RaylibAudioD
RaylibCamera
RaylibCameraD
RaylibColors
RaylibCore
RaylibCoreD
RaylibEasings
RaylibGui
RaylibGuiD
RaylibLight
RaylibLightD
RaylibMatrices
RaylibModule
RaylibModuleD
RaylibQuaternions
RaylibRlgl
RaylibRlglD
RaylibTemp
RaylibTempOptions
RaylibVectors
RectangleC
RectangleD
RenderTextureC
RenderTextureD
RlDrawCallC
RlDrawCallD
RlRenderBatchC
RlRenderBatchD
RlVertexBufferC
RlVertexBufferD
RTempAlloc<T extends NativeType>
A slot-based temporary memory allocator for a single native type T.
RTempLitAlloc<X, T extends NativeType>
A RTempAlloc that also knows how to write Dart values of type X into native T memory, and supports typed-list array operations.
RTempLitPtrAlloc<X, T extends NativeType>
A slot-based allocator for arrays of pointers to literal elements.
RTempLitTypedFloatListAlloc<X, T extends NativeType>
A typed-list allocator for floating-point native types (e.g. Float, Double).
RTempLitTypedIntListAlloc<X, T extends NativeType>
A typed-list allocator for integer native types (e.g. Int32, Uint8).
RTempLitTypedListAlloc<X, T extends NativeType>
Extends RTempLitAlloc with typed-list bulk copy support.
RTempStringAlloc
A specialised slot-based allocator for C strings (Pointer\<Char>).
RTempStructAlloc<T extends Struct, X extends StructD<X, T>>
A slot-based allocator for native structs of type T, accepting Dart-side StructD wrappers of type X.
RTempStructPtrAlloc<T extends Struct, X extends StructD<X, T>>
A slot-based allocator for arrays of pointers to native structs of type T.
SaveFileDataCallbackD
SaveFileTextCallbackD
ShaderC
ShaderD
SoundC
SoundD
StructD<D extends StructD<D, C>, C extends NativeType>
StructDLiteral<D extends StructD<D, C>, C extends NativeType>
StructDView<D extends StructD<D, C>, C extends NativeType>
TextureC
TextureD
TransformC
TransformD
Vector2C
Vector2D
Vector3C
Vector3D
Vector4C
Vector4D
VrDeviceInfoC
VrDeviceInfoD
VrStereoConfigC
VrStereoConfigD
WaveC
WaveD

Extensions

AudioStreamCEx on AudioStreamC
AudioStreamCPEx on Pointer<AudioStreamC>
AutomationEventCEx on AutomationEventC
AutomationEventCLike on AutomationEventC
AutomationEventCPEx on Pointer<AutomationEventC>
AutomationEventDLike on AutomationEventD
AutomationEventListCEx on AutomationEventListC
AutomationEventListCPEx on Pointer<AutomationEventListC>
BoneInfoCEx on BoneInfoC
BoneInfoCLike on BoneInfoC
BoneInfoCPEx on Pointer<BoneInfoC>
BoneInfoDLike on BoneInfoD
BoolAsInt on bool
BoundingBoxCEx on BoundingBoxC
BoundingBoxCPEx on Pointer<BoundingBoxC>
Camera2DCEx on Camera2DC
Camera2DCPEx on Pointer<Camera2DC>
Camera3DCEx on Camera3DC
Camera3DCPEx on Pointer<Camera3DC>
CharCodeString on String
CharPointerEx on Pointer<Char>
ColorCEx on ColorC
ColorCLike on ColorC
ColorCPEx on Pointer<ColorC>
ColorDLike on ColorD
CString on String
DoubleFormatting on double
FilePathListCEx on FilePathListC
FilePathListCPEx on Pointer<FilePathListC>
FontCEx on FontC
FontCPEx on Pointer<FontC>
GetStringFromArrayChar on Array<Char>
GlyphInfoCEx on GlyphInfoC
GlyphInfoCPEx on Pointer<GlyphInfoC>
ImageCEx on ImageC
ImageCLike on ImageC
ImageCPEx on Pointer<ImageC>
ImageDLike on ImageD
IntAsBool on int
IntHex on int
IterableFEnumEx on Iterable<FEnum>
IterableIntEx on Iterable<int>
LightCEx on LightC
LightCPEx on Pointer<LightC>
MaterialCEx on MaterialC
MaterialCLike on MaterialC
MaterialCPEx on Pointer<MaterialC>
MaterialDLike on MaterialD
MaterialMapCEx on MaterialMapC
MaterialMapCPEx on Pointer<MaterialMapC>
MatrixCEx on MatrixC
MatrixCLike on MatrixC
MatrixCPEx on Pointer<MatrixC>
MatrixDLike on MatrixD
MeshCEx on MeshC
MeshCLike on MeshC
MeshCPEx on Pointer<MeshC>
MeshDLike on MeshD
ModelAnimationCEx on ModelAnimationC
ModelAnimationCLike on ModelAnimationC
ModelAnimationCPEx on Pointer<ModelAnimationC>
ModelAnimationDLike on ModelAnimationD
ModelCEx on ModelC
ModelCPEx on Pointer<ModelC>
MusicCEx on MusicC
MusicCPEx on Pointer<MusicC>
NPatchInfoCEx on NPatchInfoC
NPatchInfoCPEx on Pointer<NPatchInfoC>
RayCEx on RayC
RayCollisionCEx on RayCollisionC
RayCollisionCPEx on Pointer<RayCollisionC>
RayCPEx on Pointer<RayC>
RaylibCoreDExtra on RaylibCoreD
RaylibVector2 on RaylibVectors
RaylibVector3 on RaylibVectors
RaylibVector4 on RaylibVectors
RectangleCEx on RectangleC
RectangleCLike on RectangleC
RectangleCPEx on Pointer<RectangleC>
RectangleDLike on RectangleD
RenderTextureCEx on RenderTextureC
RenderTextureCPEx on Pointer<RenderTextureC>
RlDrawCallCEx on RlDrawCallC
RlDrawCallCPEx on Pointer<RlDrawCallC>
RlRenderBatchCEx on RlRenderBatchC
RlRenderBatchCPEx on Pointer<RlRenderBatchC>
RlVertexBufferCEx on RlVertexBufferC
RlVertexBufferCLike on RlVertexBufferC
RlVertexBufferCPEx on Pointer<RlVertexBufferC>
RlVertexBufferDLike on RlVertexBufferD
ShaderCEx on ShaderC
ShaderCPEx on Pointer<ShaderC>
SoundCEx on SoundC
SoundCPEx on Pointer<SoundC>
TextureCEx on TextureC
TextureCPEx on Pointer<TextureC>
TransformCEx on TransformC
TransformCPEx on Pointer<TransformC>
Vector2CEx on Vector2C
Vector2CLike on Vector2C
Vector2CPEx on Pointer<Vector2C>
Vector2DLike on Vector2D
Vector3CEx on Vector3C
Vector3CLike on Vector3C
Vector3CPEx on Pointer<Vector3C>
Vector3DLike on Vector3D
Vector4CEx on Vector4C
Vector4CLike on Vector4C
Vector4CPEx on Pointer<Vector4C>
Vector4DAsQuaternion on Vector4D
Vector4DLike on Vector4D
VrDeviceInfoCEx on VrDeviceInfoC
VrDeviceInfoCLike on VrDeviceInfoC
VrDeviceInfoCPEx on Pointer<VrDeviceInfoC>
VrDeviceInfoDLike on VrDeviceInfoD
VrStereoConfigCEx on VrStereoConfigC
VrStereoConfigCLike on VrStereoConfigC
VrStereoConfigCPEx on Pointer<VrStereoConfigC>
VrStereoConfigDLike on VrStereoConfigD
WaveCEx on WaveC
WaveCLike on WaveC
WaveCPEx on Pointer<WaveC>
WaveDLike on WaveD

Functions

findDirectory(String folder) Directory?
findRaylib(String folder, [RaylibTempOptions? tempOptions]) Raylib

Typedefs

AudioCallbackC = Pointer<NativeFunction<AudioCallbackFunctionC>>
AudioCallbackFunctionC = Void Function(Pointer<Void> bufferData, UnsignedInt frames)
AudioCallbackFunctionD = void Function(Pointer<Void> bufferData, int frames)
CameraC = Camera3DC
CameraD = Camera3DD
LoadFileDataCallbackC = Pointer<NativeFunction<LoadFileDataCallbackFunctionC>>
LoadFileDataCallbackFunctionC = Pointer<UnsignedChar> Function(Pointer<Char> fileName, Pointer<Int> dataSize)
LoadFileDataCallbackFunctionD = Pointer<UnsignedChar> Function(Pointer<Char> fileName, Pointer<Int> dataSize)
LoadFileTextCallbackC = Pointer<NativeFunction<LoadFileTextCallbackFunctionC>>
LoadFileTextCallbackFunctionC = Pointer<Char> Function(Pointer<Char> fileName)
LoadFileTextCallbackFunctionD = Pointer<Char> Function(Pointer<Char> fileName)
QuaternionC = Vector4C
QuaternionD = Vector4D
RaylibLookup = Pointer<T> Function<T extends NativeType>(String symbolName)
RaylibModuleConstructor<T> = T Function(Raylib)
RenderTexture2DC = RenderTextureC
RenderTexture2DD = RenderTextureD
SaveFileDataCallbackC = Pointer<NativeFunction<SaveFileDataCallbackFunctionC>>
SaveFileDataCallbackFunctionC = Bool Function(Pointer<Char> fileName, Pointer<Void> data, Int dataSize)
SaveFileDataCallbackFunctionD = bool Function(Pointer<Char> fileName, Pointer<Void> data, int dataSize)
SaveFileTextCallbackC = Pointer<NativeFunction<SaveFileTextCallbackFunctionC>>
SaveFileTextCallbackFunctionC = Bool Function(Pointer<Char> fileName, Pointer<Char> text)
SaveFileTextCallbackFunctionD = bool Function(Pointer<Char> fileName, Pointer<Char> text)
Texture2DC = TextureC
Texture2DD = TextureD
TextureCubemapC = TextureC
TextureCubemapD = TextureD