AutomationEventType enum
Raylib AutomationEventType enum.
Values
- EVENT_NONE → const AutomationEventType
-
EVENT_NONEconst AutomationEventType(0) - INPUT_KEY_UP → const AutomationEventType
-
INPUT_KEY_UP, param0: keyconst AutomationEventType(1) - INPUT_KEY_DOWN → const AutomationEventType
-
INPUT_KEY_DOWN, param0: keyconst AutomationEventType(2) - INPUT_KEY_PRESSED → const AutomationEventType
-
INPUT_KEY_PRESSED, param0: keyconst AutomationEventType(3) - INPUT_KEY_RELEASED → const AutomationEventType
-
INPUT_KEY_RELEASED, param0: keyconst AutomationEventType(4) - INPUT_MOUSE_BUTTON_UP → const AutomationEventType
-
INPUT_MOUSE_BUTTON_UP, param0: buttonconst AutomationEventType(5) - INPUT_MOUSE_BUTTON_DOWN → const AutomationEventType
-
INPUT_MOUSE_BUTTON_DOWN, param0: buttonconst AutomationEventType(6) - INPUT_MOUSE_POSITION → const AutomationEventType
-
INPUT_MOUSE_POSITION, param0: x, param1: yconst AutomationEventType(7) - INPUT_MOUSE_WHEEL_MOTION → const AutomationEventType
-
INPUT_MOUSE_WHEEL_MOTION, param0: x delta, param1: y deltaconst AutomationEventType(8) - INPUT_GAMEPAD_CONNECT → const AutomationEventType
-
INPUT_GAMEPAD_CONNECT, param0: gamepadconst AutomationEventType(9) - INPUT_GAMEPAD_DISCONNECT → const AutomationEventType
-
INPUT_GAMEPAD_DISCONNECT, param0: gamepadconst AutomationEventType(10) - INPUT_GAMEPAD_BUTTON_UP → const AutomationEventType
-
INPUT_GAMEPAD_BUTTON_UP, param0: buttonconst AutomationEventType(11) - INPUT_GAMEPAD_BUTTON_DOWN → const AutomationEventType
-
INPUT_GAMEPAD_BUTTON_DOWN, param0: buttonconst AutomationEventType(12) - INPUT_GAMEPAD_AXIS_MOTION → const AutomationEventType
-
INPUT_GAMEPAD_AXIS_MOTION, param0: axis, param1: deltaconst AutomationEventType(13) - INPUT_TOUCH_UP → const AutomationEventType
-
INPUT_TOUCH_UP, param0: idconst AutomationEventType(14) - INPUT_TOUCH_DOWN → const AutomationEventType
-
INPUT_TOUCH_DOWN, param0: idconst AutomationEventType(15) - INPUT_TOUCH_POSITION → const AutomationEventType
-
INPUT_TOUCH_POSITION, param0: x, param1: yconst AutomationEventType(16) - INPUT_GESTURE → const AutomationEventType
-
INPUT_GESTURE, param0: gestureconst AutomationEventType(17) - WINDOW_CLOSE → const AutomationEventType
-
WINDOW_CLOSE, no paramsconst AutomationEventType(18) - WINDOW_MAXIMIZE → const AutomationEventType
-
WINDOW_MAXIMIZE, no paramsconst AutomationEventType(19) - WINDOW_MINIMIZE → const AutomationEventType
-
WINDOW_MINIMIZE, no paramsconst AutomationEventType(20) - WINDOW_RESIZE → const AutomationEventType
-
WINDOW_RESIZE, param0: width, param1: heightconst AutomationEventType(21) - ACTION_TAKE_SCREENSHOT → const AutomationEventType
-
ACTION_TAKE_SCREENSHOT, no paramsconst AutomationEventType(22) - ACTION_SETTARGETFPS → const AutomationEventType
-
ACTION_SETTARGETFPS, param0: fpsconst AutomationEventType(23)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
The underlying native integer value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → AutomationEventType -
Returns the AutomationEventType for the given native
value.
Constants
-
values
→ const List<
AutomationEventType> - A constant List of the values in this enum, in order of their declaration.