format property
Pixel format of the image data.
Must be set to a value other than PixelFormat.PIXELFORMAT_NONE before accessing any data layout properties such as bytesPerPixel, frameSize, or dataLength.
Implementation
abstract PixelFormat format;
Pixel format of the image data.
Must be set to a value other than PixelFormat.PIXELFORMAT_NONE before accessing any data layout properties such as bytesPerPixel, frameSize, or dataLength.
abstract PixelFormat format;