MusicContextType enum
Raylib MusicContextType enum.
Values
- MUSIC_AUDIO_NONE → const MusicContextType
-
MUSIC_AUDIO_NONE, no audio context loadedconst MusicContextType(0) - MUSIC_AUDIO_WAV → const MusicContextType
-
MUSIC_AUDIO_WAV, WAV audio contextconst MusicContextType(1) - MUSIC_AUDIO_OGG → const MusicContextType
-
MUSIC_AUDIO_OGG, OGG audio contextconst MusicContextType(2) - MUSIC_AUDIO_FLAC → const MusicContextType
-
MUSIC_AUDIO_FLAC, FLAC audio contextconst MusicContextType(3) - MUSIC_AUDIO_MP3 → const MusicContextType
-
MUSIC_AUDIO_MP3, MP3 audio contextconst MusicContextType(4) - MUSIC_AUDIO_QOA → const MusicContextType
-
MUSIC_AUDIO_QOA, QOA audio contextconst MusicContextType(5) - MUSIC_MODULE_XM → const MusicContextType
-
MUSIC_MODULE_XM, XM module audio contextconst MusicContextType(6) - MUSIC_MODULE_MOD → const MusicContextType
-
MUSIC_MODULE_MOD, MOD module audio contextconst MusicContextType(7)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
The underlying native integer value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → MusicContextType -
Returns the MusicContextType for the given native
value.
Constants
-
values
→ const List<
MusicContextType> - A constant List of the values in this enum, in order of their declaration.