MusicContextType enum

Raylib MusicContextType enum.

Inheritance
Available extensions

Values

MUSIC_AUDIO_NONE → const MusicContextType
const MusicContextType(0)
MUSIC_AUDIO_WAV → const MusicContextType
const MusicContextType(1)
MUSIC_AUDIO_OGG → const MusicContextType
const MusicContextType(2)
MUSIC_AUDIO_FLAC → const MusicContextType
const MusicContextType(3)
MUSIC_AUDIO_MP3 → const MusicContextType
const MusicContextType(4)
MUSIC_AUDIO_QOA → const MusicContextType
const MusicContextType(5)
MUSIC_MODULE_XM → const MusicContextType
const MusicContextType(6)
MUSIC_MODULE_MOD → const MusicContextType
const MusicContextType(7)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) MusicContextType

Constants

values → const List<MusicContextType>
A constant List of the values in this enum, in order of their declaration.