QuaternionBase<Q extends QuaternionBase<Q, M, V3, V4>, M extends MatrixBase<M, V3, Q, V4>, V3 extends Vector3Base<V3, M, Q, V4>, V4 extends Vector4Base<V4, Q, M, V3>> mixin

Backend-agnostic contract for QuaternionBase structs.

Must be mixed into every concrete platform implementation of a Raylib type to ensure a unified API surface across different backends.

Superclass constraints
Mixin applications

Properties

$state RaylibTempStructState
Per-instance allocation state tracking slot keys, disposal, and identity.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
length double
no setter
lengthSqr double
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structName String
The Dart-side type name of this struct
no setterinherited
w double
getter/setter pair
x double
getter/setter pair
y double
getter/setter pair
z double
getter/setter pair

Methods

add(Q o) → Q
addValue(num value) → Q
clone() → Q
Returns a deep copy of this instance, preserving RaylibStructBase.originalPointer if present.
inherited
copy() → Q
Returns a deep copy of this instance without RaylibStructBase.originalPointer.
inherited
cubicHermiteSpline(Q outTangent1, Q q2, Q inTangent2, double t) → Q
distance(Q o) double
distanceSqr(Q o) double
div(Q o) → Q
divideBy(num o) → Q
dotProduct(Q o) double
equals(Q o) bool
format([int x0 = 0, int? y0, int? z0, int? w0]) String
invert() → Q
lerp(Q o, double amount) → Q
max(Q o) → Q
min(Q o) → Q
mul(Q o) → Q
negate() → Q
nLerp(Q o, double amount) → Q
normalize() → Q
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scale(num o) → Q
set(num x, num y, num z, num w) → Q
setD(Q o) → Q
Copies the fields of o into this instance and returns this.
inherited
signature() String
Returns a human-readable representation of this struct's current field values.
override
sLerp(Q o, double amount) → Q
sub(Q o) → Q
subValue(num value) → Q
toArray() List<double>
toAxisAngle() → (V3, double)
toEuler() → V3
toMatrix() → M
toString() String
A string representation of this object.
inherited
toVector4() → V4
transform(M mat) → Q

Operators

operator ==(Object other) bool
The equality operator.
inherited