RlFramebufferAttachTextureType enum

Rlgl FramebufferAttachTextureType enum.

Inheritance
Available extensions

Values

RL_ATTACHMENT_CUBEMAP_POSITIVE_X → const RlFramebufferAttachTextureType
const RlFramebufferAttachTextureType(0)
RL_ATTACHMENT_CUBEMAP_NEGATIVE_X → const RlFramebufferAttachTextureType
const RlFramebufferAttachTextureType(1)
RL_ATTACHMENT_CUBEMAP_POSITIVE_Y → const RlFramebufferAttachTextureType
const RlFramebufferAttachTextureType(2)
RL_ATTACHMENT_CUBEMAP_NEGATIVE_Y → const RlFramebufferAttachTextureType
const RlFramebufferAttachTextureType(3)
RL_ATTACHMENT_CUBEMAP_POSITIVE_Z → const RlFramebufferAttachTextureType
const RlFramebufferAttachTextureType(4)
RL_ATTACHMENT_CUBEMAP_NEGATIVE_Z → const RlFramebufferAttachTextureType
const RlFramebufferAttachTextureType(5)
RL_ATTACHMENT_TEXTURE2D → const RlFramebufferAttachTextureType
const RlFramebufferAttachTextureType(100)
RL_ATTACHMENT_RENDERBUFFER → const RlFramebufferAttachTextureType
const RlFramebufferAttachTextureType(200)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) RlFramebufferAttachTextureType

Constants

values → const List<RlFramebufferAttachTextureType>
A constant List of the values in this enum, in order of their declaration.