RlFramebufferAttachType enum

Rlgl FramebufferAttachType enum.

Inheritance
Available extensions

Values

RL_ATTACHMENT_COLOR_CHANNEL0 → const RlFramebufferAttachType
const RlFramebufferAttachType(0)
RL_ATTACHMENT_COLOR_CHANNEL1 → const RlFramebufferAttachType
const RlFramebufferAttachType(1)
RL_ATTACHMENT_COLOR_CHANNEL2 → const RlFramebufferAttachType
const RlFramebufferAttachType(2)
RL_ATTACHMENT_COLOR_CHANNEL3 → const RlFramebufferAttachType
const RlFramebufferAttachType(3)
RL_ATTACHMENT_COLOR_CHANNEL4 → const RlFramebufferAttachType
const RlFramebufferAttachType(4)
RL_ATTACHMENT_COLOR_CHANNEL5 → const RlFramebufferAttachType
const RlFramebufferAttachType(5)
RL_ATTACHMENT_COLOR_CHANNEL6 → const RlFramebufferAttachType
const RlFramebufferAttachType(6)
RL_ATTACHMENT_COLOR_CHANNEL7 → const RlFramebufferAttachType
const RlFramebufferAttachType(7)
RL_ATTACHMENT_DEPTH → const RlFramebufferAttachType
const RlFramebufferAttachType(100)
RL_ATTACHMENT_STENCIL → const RlFramebufferAttachType
const RlFramebufferAttachType(200)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) RlFramebufferAttachType

Constants

values → const List<RlFramebufferAttachType>
A constant List of the values in this enum, in order of their declaration.