RlVertexBufferBase<X extends RlVertexBufferBase<X> > mixin
Backend-agnostic contract for RlVertexBufferBase structs.
Must be mixed into every concrete platform implementation of a Raylib type to ensure a unified API surface across different backends.
- Superclass constraints
- Mixin applications
Properties
- $state → RaylibTempStructState
-
Per-instance allocation state tracking slot keys, disposal, and identity.
finalinherited
-
colors
↔ RaylibLiveList<
int> -
Vertex colors (RGBA - 4 components per vertex) (shader-location = 3)
getter/setter pair
- colorsCount → int
-
Expected length of colors.
no setter
- elementCount ↔ int
-
Number of elements in the buffer (QUADS)
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
indices
↔ RaylibLiveList<
int> -
Vertex indices (in case vertex data comes indexed) (6 indices per quad)
getter/setter pair
- indicesCount → int
-
Expected length of indices.
no setter
-
normals
↔ RaylibLiveList<
double> -
Vertex normal (XYZ - 3 components per vertex) (shader-location = 2)
getter/setter pair
- normalsCount → int
-
Expected length of normals.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- structName → String
-
The Dart-side type name of this struct
no setterinherited
-
texcoords
↔ RaylibLiveList<
double> -
Vertex texture coordinates (UV - 2 components per vertex) (shader-location = 1)
getter/setter pair
- texcoordsCount → int
-
Expected length of texcoords.
no setter
- vaoId ↔ int
-
OpenGL Vertex Array Object id
getter/setter pair
-
vboId
↔ RaylibLiveList<
int> -
OpenGL Vertex Buffer Objects id (5 types of vertex data)
getter/setter pair
- vboIdCount → int
-
Expected length of vboId.
no setter
-
vertices
↔ RaylibLiveList<
double> -
Vertex position (XYZ - 3 components per vertex) (shader-location = 0)
getter/setter pair
- verticesCount → int
-
Expected length of vertices.
no setter
Methods
-
clone(
) → X -
Returns a deep copy of this instance, preserving RaylibStructBase.originalPointer if present.
inherited
-
copy(
) → X -
Returns a deep copy of this instance without RaylibStructBase.originalPointer.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setD(
X o) → X -
Copies the fields of
ointo this instance and returnsthis.inherited -
signature(
) → String -
Returns a human-readable representation of this struct.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- BASE_vboIdCount → int
-
Number of components in the
vboIdarray.no setter
Static Methods
-
BASE_colorsCount(
int elementCount) → int -
Number of components in the
colorsbuffer. -
BASE_indicesCount(
int elementCount) → int -
Number of components in the
indicesbuffer. -
BASE_normalsCount(
int elementCount) → int -
Number of components in the
normalsbuffer. -
BASE_texcoordsCount(
int elementCount) → int -
Number of components in the
texcoordsbuffer. -
BASE_verticesCount(
int elementCount) → int -
Number of components in the
verticesbuffer.