ShaderUniformDataType enum
Raylib ShaderUniformDataType enum.
Values
- SHADER_UNIFORM_FLOAT → const ShaderUniformDataType
-
const ShaderUniformDataType(0) - SHADER_UNIFORM_VEC2 → const ShaderUniformDataType
-
const ShaderUniformDataType(1) - SHADER_UNIFORM_VEC3 → const ShaderUniformDataType
-
const ShaderUniformDataType(2) - SHADER_UNIFORM_VEC4 → const ShaderUniformDataType
-
const ShaderUniformDataType(3) - SHADER_UNIFORM_INT → const ShaderUniformDataType
-
const ShaderUniformDataType(4) - SHADER_UNIFORM_IVEC2 → const ShaderUniformDataType
-
const ShaderUniformDataType(5) - SHADER_UNIFORM_IVEC3 → const ShaderUniformDataType
-
const ShaderUniformDataType(6) - SHADER_UNIFORM_IVEC4 → const ShaderUniformDataType
-
const ShaderUniformDataType(7) - SHADER_UNIFORM_SAMPLER2D → const ShaderUniformDataType
-
const ShaderUniformDataType(8)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → ShaderUniformDataType
Constants
-
values
→ const List<
ShaderUniformDataType> - A constant List of the values in this enum, in order of their declaration.