TextureFilter enum
Raylib TextureFilter enum.
Values
- TEXTURE_FILTER_POINT → const TextureFilter
-
const TextureFilter(0) - TEXTURE_FILTER_BILINEAR → const TextureFilter
-
const TextureFilter(1) - TEXTURE_FILTER_TRILINEAR → const TextureFilter
-
const TextureFilter(2) - TEXTURE_FILTER_ANISOTROPIC_4X → const TextureFilter
-
const TextureFilter(3) - TEXTURE_FILTER_ANISOTROPIC_8X → const TextureFilter
-
const TextureFilter(4) - TEXTURE_FILTER_ANISOTROPIC_16X → const TextureFilter
-
const TextureFilter(5)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → TextureFilter
Constants
-
values
→ const List<
TextureFilter> - A constant List of the values in this enum, in order of their declaration.