RaylibRlglDart<R extends RaylibBase> class
final
Backend-agnostic Raylib Rlgl module.
- Inheritance
-
- Object
- RaylibModule<
R> - RaylibRlglDart
- Mixed-in types
Constructors
- RaylibRlglDart(R rl)
Properties
-
$
→ RaylibTemp<
RaylibBase> -
See RaylibTemp.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- rl → R
-
finalinherited
- RL_BLEND_COLOR → int
-
See RaylibRlglConstants.RL_BLEND_COLOR.
no setterinherited
- RL_BLEND_DST_ALPHA → int
-
See RaylibRlglConstants.RL_BLEND_DST_ALPHA.
no setterinherited
- RL_BLEND_DST_RGB → int
-
See RaylibRlglConstants.RL_BLEND_DST_RGB.
no setterinherited
- RL_BLEND_EQUATION → int
-
See RaylibRlglConstants.RL_BLEND_EQUATION.
no setterinherited
- RL_BLEND_EQUATION_ALPHA → int
-
See RaylibRlglConstants.RL_BLEND_EQUATION_ALPHA.
no setterinherited
- RL_BLEND_EQUATION_RGB → int
-
See RaylibRlglConstants.RL_BLEND_EQUATION_RGB.
no setterinherited
- RL_BLEND_SRC_ALPHA → int
-
See RaylibRlglConstants.RL_BLEND_SRC_ALPHA.
no setterinherited
- RL_BLEND_SRC_RGB → int
-
See RaylibRlglConstants.RL_BLEND_SRC_RGB.
no setterinherited
- RL_COMPUTE_SHADER → int
-
See RaylibRlglConstants.RL_COMPUTE_SHADER.
no setterinherited
- RL_CONSTANT_ALPHA → int
-
See RaylibRlglConstants.RL_CONSTANT_ALPHA.
no setterinherited
- RL_CONSTANT_COLOR → int
-
See RaylibRlglConstants.RL_CONSTANT_COLOR.
no setterinherited
- RL_CULL_DISTANCE_FAR → double
-
See RaylibRlglConstants.RL_CULL_DISTANCE_FAR.
no setterinherited
- RL_CULL_DISTANCE_NEAR → double
-
See RaylibRlglConstants.RL_CULL_DISTANCE_NEAR.
no setterinherited
- RL_DEFAULT_BATCH_BUFFER_ELEMENTS → int
-
See RaylibRlglConstants.RL_DEFAULT_BATCH_BUFFER_ELEMENTS.
no setterinherited
- RL_DEFAULT_BATCH_BUFFERS → int
-
See RaylibRlglConstants.RL_DEFAULT_BATCH_BUFFERS.
no setterinherited
- RL_DEFAULT_BATCH_DRAWCALLS → int
-
See RaylibRlglConstants.RL_DEFAULT_BATCH_DRAWCALLS.
no setterinherited
- RL_DEFAULT_BATCH_MAX_TEXTURE_UNITS → int
-
See RaylibRlglConstants.RL_DEFAULT_BATCH_MAX_TEXTURE_UNITS.
no setterinherited
- RL_DRAW_FRAMEBUFFER → int
-
See RaylibRlglConstants.RL_DRAW_FRAMEBUFFER.
no setterinherited
- RL_DST_ALPHA → int
-
See RaylibRlglConstants.RL_DST_ALPHA.
no setterinherited
- RL_DST_COLOR → int
-
See RaylibRlglConstants.RL_DST_COLOR.
no setterinherited
- RL_DYNAMIC_COPY → int
-
See RaylibRlglConstants.RL_DYNAMIC_COPY.
no setterinherited
- RL_DYNAMIC_DRAW → int
-
See RaylibRlglConstants.RL_DYNAMIC_DRAW.
no setterinherited
- RL_DYNAMIC_READ → int
-
See RaylibRlglConstants.RL_DYNAMIC_READ.
no setterinherited
- RL_FLOAT → int
-
See RaylibRlglConstants.RL_FLOAT.
no setterinherited
- RL_FRAGMENT_SHADER → int
-
See RaylibRlglConstants.RL_FRAGMENT_SHADER.
no setterinherited
- RL_FUNC_ADD → int
-
See RaylibRlglConstants.RL_FUNC_ADD.
no setterinherited
- RL_FUNC_REVERSE_SUBTRACT → int
-
See RaylibRlglConstants.RL_FUNC_REVERSE_SUBTRACT.
no setterinherited
- RL_FUNC_SUBTRACT → int
-
See RaylibRlglConstants.RL_FUNC_SUBTRACT.
no setterinherited
- RL_LINES → int
-
See RaylibRlglConstants.RL_LINES.
no setterinherited
- RL_MAX → int
-
See RaylibRlglConstants.RL_MAX.
no setterinherited
- RL_MAX_MATRIX_STACK_SIZE → int
-
See RaylibRlglConstants.RL_MAX_MATRIX_STACK_SIZE.
no setterinherited
- RL_MAX_SHADER_LOCATIONS → int
-
See RaylibRlglConstants.RL_MAX_SHADER_LOCATIONS.
no setterinherited
- RL_MIN → int
-
See RaylibRlglConstants.RL_MIN.
no setterinherited
- RL_MODELVIEW → int
-
See RaylibRlglConstants.RL_MODELVIEW.
no setterinherited
- RL_ONE → int
-
See RaylibRlglConstants.RL_ONE.
no setterinherited
- RL_ONE_MINUS_CONSTANT_ALPHA → int
-
See RaylibRlglConstants.RL_ONE_MINUS_CONSTANT_ALPHA.
no setterinherited
- RL_ONE_MINUS_CONSTANT_COLOR → int
-
See RaylibRlglConstants.RL_ONE_MINUS_CONSTANT_COLOR.
no setterinherited
- RL_ONE_MINUS_DST_ALPHA → int
-
See RaylibRlglConstants.RL_ONE_MINUS_DST_ALPHA.
no setterinherited
- RL_ONE_MINUS_DST_COLOR → int
-
See RaylibRlglConstants.RL_ONE_MINUS_DST_COLOR.
no setterinherited
- RL_ONE_MINUS_SRC_ALPHA → int
-
See RaylibRlglConstants.RL_ONE_MINUS_SRC_ALPHA.
no setterinherited
- RL_ONE_MINUS_SRC_COLOR → int
-
See RaylibRlglConstants.RL_ONE_MINUS_SRC_COLOR.
no setterinherited
- RL_PROJECTION → int
-
See RaylibRlglConstants.RL_PROJECTION.
no setterinherited
- RL_QUADS → int
-
See RaylibRlglConstants.RL_QUADS.
no setterinherited
- RL_READ_FRAMEBUFFER → int
-
See RaylibRlglConstants.RL_READ_FRAMEBUFFER.
no setterinherited
- RL_SHADER_LOC_MAP_DIFFUSE → int
-
See RaylibRlglConstants.RL_SHADER_LOC_MAP_DIFFUSE.
no setterinherited
- RL_SHADER_LOC_MAP_SPECULAR → int
-
See RaylibRlglConstants.RL_SHADER_LOC_MAP_SPECULAR.
no setterinherited
- RL_SRC_ALPHA → int
-
See RaylibRlglConstants.RL_SRC_ALPHA.
no setterinherited
- RL_SRC_ALPHA_SATURATE → int
-
See RaylibRlglConstants.RL_SRC_ALPHA_SATURATE.
no setterinherited
- RL_SRC_COLOR → int
-
See RaylibRlglConstants.RL_SRC_COLOR.
no setterinherited
- RL_STATIC_COPY → int
-
See RaylibRlglConstants.RL_STATIC_COPY.
no setterinherited
- RL_STATIC_DRAW → int
-
See RaylibRlglConstants.RL_STATIC_DRAW.
no setterinherited
- RL_STATIC_READ → int
-
See RaylibRlglConstants.RL_STATIC_READ.
no setterinherited
- RL_STREAM_COPY → int
-
See RaylibRlglConstants.RL_STREAM_COPY.
no setterinherited
- RL_STREAM_DRAW → int
-
See RaylibRlglConstants.RL_STREAM_DRAW.
no setterinherited
- RL_STREAM_READ → int
-
See RaylibRlglConstants.RL_STREAM_READ.
no setterinherited
- RL_TEXTURE → int
-
See RaylibRlglConstants.RL_TEXTURE.
no setterinherited
- RL_TEXTURE_FILTER_ANISOTROPIC → int
-
See RaylibRlglConstants.RL_TEXTURE_FILTER_ANISOTROPIC.
no setterinherited
- RL_TEXTURE_FILTER_LINEAR → int
-
See RaylibRlglConstants.RL_TEXTURE_FILTER_LINEAR.
no setterinherited
- RL_TEXTURE_FILTER_LINEAR_MIP_NEAREST → int
-
See RaylibRlglConstants.RL_TEXTURE_FILTER_LINEAR_MIP_NEAREST.
no setterinherited
- RL_TEXTURE_FILTER_MIP_LINEAR → int
-
See RaylibRlglConstants.RL_TEXTURE_FILTER_MIP_LINEAR.
no setterinherited
- RL_TEXTURE_FILTER_MIP_NEAREST → int
-
See RaylibRlglConstants.RL_TEXTURE_FILTER_MIP_NEAREST.
no setterinherited
- RL_TEXTURE_FILTER_NEAREST → int
-
See RaylibRlglConstants.RL_TEXTURE_FILTER_NEAREST.
no setterinherited
- RL_TEXTURE_FILTER_NEAREST_MIP_LINEAR → int
-
See RaylibRlglConstants.RL_TEXTURE_FILTER_NEAREST_MIP_LINEAR.
no setterinherited
- RL_TEXTURE_MAG_FILTER → int
-
See RaylibRlglConstants.RL_TEXTURE_MAG_FILTER.
no setterinherited
- RL_TEXTURE_MIN_FILTER → int
-
See RaylibRlglConstants.RL_TEXTURE_MIN_FILTER.
no setterinherited
- RL_TEXTURE_MIPMAP_BIAS_RATIO → int
-
See RaylibRlglConstants.RL_TEXTURE_MIPMAP_BIAS_RATIO.
no setterinherited
- RL_TEXTURE_WRAP_CLAMP → int
-
See RaylibRlglConstants.RL_TEXTURE_WRAP_CLAMP.
no setterinherited
- RL_TEXTURE_WRAP_MIRROR_CLAMP → int
-
See RaylibRlglConstants.RL_TEXTURE_WRAP_MIRROR_CLAMP.
no setterinherited
- RL_TEXTURE_WRAP_MIRROR_REPEAT → int
-
See RaylibRlglConstants.RL_TEXTURE_WRAP_MIRROR_REPEAT.
no setterinherited
- RL_TEXTURE_WRAP_REPEAT → int
-
See RaylibRlglConstants.RL_TEXTURE_WRAP_REPEAT.
no setterinherited
- RL_TEXTURE_WRAP_S → int
-
See RaylibRlglConstants.RL_TEXTURE_WRAP_S.
no setterinherited
- RL_TEXTURE_WRAP_T → int
-
See RaylibRlglConstants.RL_TEXTURE_WRAP_T.
no setterinherited
- RL_TRIANGLES → int
-
See RaylibRlglConstants.RL_TRIANGLES.
no setterinherited
- RL_UNSIGNED_BYTE → int
-
See RaylibRlglConstants.RL_UNSIGNED_BYTE.
no setterinherited
- RL_VERTEX_SHADER → int
-
See RaylibRlglConstants.RL_VERTEX_SHADER.
no setterinherited
- RL_ZERO → int
-
See RaylibRlglConstants.RL_ZERO.
no setterinherited
- RLGL_VERSION → String
-
See RaylibRlglConstants.RLGL_VERSION.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
debug(
bool v) → void -
Enables or disables debug logging for this module.
inherited
-
debugError(
String message) → void -
Logs
messageat error level if debug is enabled andmessagepasses all filters.inherited -
debugFilter(
bool filter(String)) → void -
Adds a predicate that gates debug output. Only messages satisfying at least one filter are logged.
inherited
-
debugInfo(
String message) → void -
Logs
messageat info level if debug is enabled andmessagepasses all filters.inherited -
debugTime(
bool v) → void -
Enables or disables per-call timing output alongside debug logs.
inherited
-
debugWarn(
String message) → void -
Logs
messageat warn level if debug is enabled andmessagepasses all filters.inherited -
disableSync<
T> (T f()) → T -
Executes
fwith RaylibTemp syncing temporarily disabled, restoring the previous sync state afterward.inherited -
dispose(
) → void -
Calls all registered onDispose callbacks and clears them.
inherited
-
disposeStructWithOpFreed<
D extends RaylibStruct< (D> >D struct, void fn(StructPointer< D> ptr)) → void -
Disposes
struct, invokesfnwith its underlying pointer, and then frees the temporary allocation backing the pointer, if any.inherited -
disposeStructWithOpUnslotted<
D extends RaylibStruct< (D> >D struct, void fn(StructPointer< D> ptr)) → void -
Disposes
struct, invokesfnwith its underlying pointer, and then unslots the temporary allocation backing the pointer, if any.inherited -
load(
) → void -
Override to perform one-time module initialization.
inherited
-
logError(
Object? message) → void -
inherited
-
logInfo(
Object? message) → void -
inherited
-
logWarn(
Object? message) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onDispose(
void fn()) → void -
Registers
fnto be called when this module is disposed.inherited -
rlActiveDrawBuffers(
num count) → void - Activate multiple draw color buffers
-
rlActiveTextureSlot(
num slot) → void - Select and active a texture slot
-
rlBegin(
RlDrawMode mode) → void - Initialize drawing mode (how to organize vertex)
-
rlBindFramebuffer(
num target, num framebuffer) → void - Bind framebuffer (FBO)
-
rlBindImageTexture(
num id, num index, PixelFormat format, bool readonly) → void - Bind image texture
-
rlBindShaderBuffer(
num id, num index) → void - Bind SSBO buffer
-
rlBlitFramebuffer(
num srcX, num srcY, num srcWidth, num srcHeight, num dstX, num dstY, num dstWidth, num dstHeight, num bufferMask) → void - Blit active framebuffer to main framebuffer
-
rlCheckErrors(
) → void - Check and log OpenGL error codes
-
rlCheckRenderBatchLimit(
num vCount) → bool - Check internal buffer overflow for a given number of vertex
-
rlClearColor(
num r, num g, num b, num a) → void - Clear color buffer with color
-
rlClearScreenBuffers(
) → void - Clear used screen buffers (color and depth)
-
rlColor3f(
num x, num y, num z) → void - Define one vertex (color) - 3 float
-
rlColor4f(
num x, num y, num z, num w) → void - Define one vertex (color) - 4 float
-
rlColor4ub(
num r, num g, num b, num a) → void - Define one vertex (color) - 4 byte
-
rlColorMask(
bool r, bool g, bool b, bool a) → void - Color mask control
-
rlComputeShaderDispatch(
num groupX, num groupY, num groupZ) → void - Dispatch compute shader (equivalent to draw for graphics pipeline)
-
rlCopyFramebuffer(
num x, num y, num width, num height, PixelFormat format) → Uint8List - Copy framebuffer pixel data to internal buffer
-
rlCopyShaderBuffer(
num destId, num srcId, num destOffset, num srcOffset, num count) → void - Copy SSBO data between buffers
-
rlCubemapParameters(
num id, num param, num value) → void - Set cubemap parameters (filter, wrap)
-
rlDisableBackfaceCulling(
) → void - Disable backface culling
-
rlDisableColorBlend(
) → void - Disable color blending
-
rlDisableDepthMask(
) → void - Disable depth write
-
rlDisableDepthTest(
) → void - Disable depth test
-
rlDisableFramebuffer(
) → void - Disable render texture (fbo), return to default framebuffer
-
rlDisablePointMode(
) → void - Disable point mode
-
rlDisableScissorTest(
) → void - Disable scissor test
-
rlDisableShader(
) → void - Disable shader program
-
rlDisableSmoothLines(
) → void - Disable line aliasing
-
rlDisableStatePointer(
int vertexAttribType) → void - Disable attribute state pointer
-
rlDisableStereoRender(
) → void - Disable stereo rendering
-
rlDisableTexture(
) → void - Disable texture
-
rlDisableTextureCubemap(
) → void - Disable texture cubemap
-
rlDisableVertexArray(
) → void - Disable vertex array (VAO, if supported)
-
rlDisableVertexAttribute(
num index) → void - Disable vertex attribute index
-
rlDisableVertexBuffer(
) → void - Disable vertex buffer (VBO)
-
rlDisableVertexBufferElement(
) → void - Disable vertex buffer element (VBO element)
-
rlDisableWireMode(
) → void - Disable wire mode
-
rlDrawRenderBatch(
RlRenderBatchD batch) → void - Draw render batch data (Update->Draw->Reset)
-
rlDrawRenderBatchActive(
) → void - Update and draw internal render batch
-
rlDrawVertexArray(
num offset, num count) → void - Draw vertex array (currently active vao)
-
rlDrawVertexArrayElements(
num offset, num count, Uint16List buffer) → void - Draw vertex array elements
-
rlDrawVertexArrayElementsInstanced(
num offset, num count, Uint16List buffer, num instances) → void - Draw vertex array elements with instancing
-
rlDrawVertexArrayInstanced(
num offset, num count, num instances) → void - Draw vertex array (currently active vao) with instancing
-
rlEnableBackfaceCulling(
) → void - Enable backface culling
-
rlEnableColorBlend(
) → void - Enable color blending
-
rlEnableDepthMask(
) → void - Enable depth write
-
rlEnableDepthTest(
) → void - Enable depth test
-
rlEnableFramebuffer(
num id) → void - Enable render texture (fbo)
-
rlEnablePointMode(
) → void - Enable point mode
-
rlEnableScissorTest(
) → void - Enable scissor test
-
rlEnableShader(
num id) → void - Enable shader program
-
rlEnableSmoothLines(
) → void - Enable line aliasing
-
rlEnableStatePointer(
int vertexAttribType, TypedDataList buffer) → void - Enable attribute state pointer
-
rlEnableStereoRender(
) → void - Enable stereo rendering
-
rlEnableTexture(
num id) → void - Enable texture
-
rlEnableTextureCubemap(
num id) → void - Enable texture cubemap
-
rlEnableVertexArray(
num vaoId) → bool - Enable vertex array (VAO, if supported)
-
rlEnableVertexAttribute(
num index) → void - Enable vertex attribute index
-
rlEnableVertexBuffer(
num id) → void - Enable vertex buffer (VBO)
-
rlEnableVertexBufferElement(
num id) → void - Enable vertex buffer element (VBO element)
-
rlEnableWireMode(
) → void - Enable wire mode
-
rlEnd(
) → void - Finish vertex providing
-
rlFramebufferAttach(
num fboId, num texId, RlFramebufferAttachType attachType, RlFramebufferAttachTextureType texType, num mipLevel) → void - Attach texture/renderbuffer to a framebuffer
-
rlFramebufferComplete(
num id) → bool - Verify framebuffer is complete
-
rlFrustum(
num left, num right, num bottom, num top, num znear, num zfar) → void - Multiply the current matrix by a perspective matrix generated by parameters
-
rlGenTextureMipmaps(
num id, num width, num height, PixelFormat format) → int - Generate mipmap data for selected texture
-
rlGetActiveFramebuffer(
) → int - Get the currently active render texture (fbo), 0 for default framebuffer
-
rlGetCullDistanceFar(
) → double - Get cull plane distance far
-
rlGetCullDistanceNear(
) → double - Get cull plane distance near
-
rlGetFramebufferHeight(
) → int - Get default framebuffer height
-
rlGetFramebufferWidth(
) → int - Get default framebuffer width
-
rlGetGlTextureFormats(
PixelFormat format) → (int, int, int) - Get OpenGL internal formats
-
rlGetLineWidth(
) → double - Get the line drawing width
-
rlGetLocationAttrib(
num shaderId, String attribName) → int - Get shader location attribute, requires shader program id
-
rlGetLocationUniform(
num shaderId, String uniformName) → int - Get shader location uniform, requires shader program id
-
rlGetMatrixModelview(
) → MatrixD - Get internal modelview matrix
-
rlGetMatrixProjection(
) → MatrixD - Get internal projection matrix
-
rlGetMatrixProjectionStereo(
num eye) → MatrixD - Get internal projection matrix for stereo render (selected eye)
-
rlGetMatrixTransform(
) → MatrixD - Get internal accumulated transform matrix
-
rlGetMatrixViewOffsetStereo(
num eye) → MatrixD - Get internal view offset matrix for stereo render (selected eye)
-
rlGetPixelFormatName(
PixelFormat format) → String - Get name string for pixel format
-
rlGetPointSize(
) → double - Get the point drawing size
-
rlGetShaderBufferSize(
num id) → int - Get SSBO buffer size
-
rlGetShaderIdDefault(
) → int - Get default shader id
-
rlGetShaderLocsDefault(
) → List< int> - Get default shader locations
-
rlGetTextureIdDefault(
) → int - Get default texture id
-
rlGetVersion(
) → int - Get current OpenGL version
-
rlglClose(
) → void - De-initialize rlgl (buffers, shaders, textures)
-
rlglInit(
num width, num height) → void - Initialize rlgl (buffers, shaders, textures, states)
-
rlIsStereoRenderEnabled(
) → bool - Check if stereo render is enabled
-
rlLoadDrawCube(
) → void - Load and draw a cube
-
rlLoadDrawQuad(
) → void - Load and draw a quad
-
rlLoadFramebuffer(
) → int - Load an empty framebuffer
-
rlLoadIdentity(
) → void - Reset current matrix to identity matrix
-
rlLoadRenderBatch(
num numBuffers, num bufferElements) → RlRenderBatchD - Load a render batch system
-
rlLoadShader(
String code, RlShaderType type) → int - Load (compile) shader and return shader id
-
rlLoadShaderBuffer(
num size, TypedDataList? data, RlUsageHint? usageHint) → int - Load shader storage buffer object (SSBO)
-
rlLoadShaderProgram(
String vsCode, String fsCode) → int - Load shader from code strings
-
rlLoadShaderProgramCompute(
num csId) → int - Load compute shader program
-
rlLoadShaderProgramEx(
num vsId, num fsId) → int - Load shader program, using already loaded shader ids
-
rlLoadTexture(
Uint8List? data, num width, num height, PixelFormat format, num mipmapCount) → int - Load texture data
-
rlLoadTextureCubemap(
Uint8List? data, num size, PixelFormat format, num mipmapCount) → int - Load texture cubemap data
-
rlLoadTextureDepth(
num width, num height, bool useRenderBuffer) → int - Load depth texture/renderbuffer (to be attached to fbo)
-
rlLoadVertexArray(
) → int - Load vertex array (vao) if supported
-
rlLoadVertexBuffer(
TypedDataList buffer, bool dynamic) → int - Load a vertex buffer object
-
rlLoadVertexBufferElement(
TypedDataList buffer, bool dynamic) → int - Load vertex buffer elements object
-
rlMatrixMode(
RlMatrixMode mode) → void - Choose the current matrix to be transformed
-
rlMultMatrixf(
List< num> matf) → void - Multiply the current matrix by another matrix
-
rlNormal3f(
num x, num y, num z) → void - Define one vertex (normal) - 3 float
-
rlOrtho(
num left, num right, num bottom, num top, num znear, num zfar) → void - Multiply the current matrix by an orthographic matrix generated by parameters
-
rlPopMatrix(
) → void - Pop latest inserted matrix from stack
-
rlPushMatrix(
) → void - Push the current matrix to stack
-
rlReadScreenPixels(
num width, num height) → Uint8List - Read screen pixel data (color buffer)
-
rlReadShaderBuffer(
num id, num count, num offset) → Uint8List - Read SSBO buffer data (GPU->CPU)
-
rlReadTexturePixels(
num id, num width, num height, PixelFormat format) → Uint8List - Read texture pixel data
-
rlResizeFramebuffer(
num width, num height) → void - Resize internal framebuffer
-
rlRotatef(
num angle, num x, num y, num z) → void - Multiply the current matrix by a rotation matrix
-
rlScalef(
num x, num y, num z) → void - Multiply the current matrix by a scaling matrix
-
rlScissor(
num x, num y, num width, num height) → void - Scissor test
-
rlSetBlendFactors(
num glSrcFactor, num glDstFactor, num glEquation) → void - Set blending mode factor and equation (using OpenGL factors)
-
rlSetBlendFactorsSeparate(
num glSrcRGB, num glDstRGB, num glSrcAlpha, num glDstAlpha, num glEqRGB, num glEqAlpha) → void - Set blending mode factors and equations separately (using OpenGL factors)
-
rlSetBlendMode(
BlendMode mode) → void - Set blending mode
-
rlSetClipPlanes(
num nearPlane, num farPlane) → void - Set clip planes distances
-
rlSetCullFace(
RlCullMode mode) → void - Set face culling mode
-
rlSetFramebufferHeight(
num height) → void - Set current framebuffer height
-
rlSetFramebufferWidth(
num width) → void - Set current framebuffer width
-
rlSetLineWidth(
num width) → void - Set the line drawing width
-
rlSetMatrixModelview(
MatrixD view) → void - Set a custom modelview matrix (replaces internal modelview matrix)
-
rlSetMatrixProjection(
MatrixD proj) → void - Set a custom projection matrix (replaces internal projection matrix)
-
rlSetMatrixProjectionStereo(
MatrixD right, MatrixD left) → void - Set eyes projection matrices for stereo rendering
-
rlSetMatrixViewOffsetStereo(
MatrixD right, MatrixD left) → void - Set eyes view offsets matrices for stereo rendering
-
rlSetPointSize(
num size) → void - Set the point drawing size
-
rlSetRenderBatchActive(
[RlRenderBatchD? batch]) → void - Set the active render batch for rlgl (NULL for default internal)
-
rlSetShader(
num id, List< int> locs) → void - Set shader currently active (id and locations)
-
rlSetTexture(
num id) → void - Set current texture for render batch and check buffers limits
-
rlSetUniform(
num locIndex, TypedDataList value, RlShaderUniformDataType uniformType, num count) → void - Set shader value uniform
-
rlSetUniformMatrices(
num locIndex, List< MatrixD> mat) → void - Set shader value matrices
-
rlSetUniformMatrix(
num locIndex, MatrixD mat) → void - Set shader value matrix
-
rlSetUniformSampler(
num locIndex, num textureId) → void - Set shader value sampler
-
rlSetVertexAttribute(
num index, num compSize, num type, bool normalized, num stride, num offset) → void - Set vertex attribute data configuration
-
rlSetVertexAttributeDefault(
num locIndex, Float32List value, RlShaderAttributeDataType attribType) → void - Set vertex attribute default value, when attribute to provided
-
rlSetVertexAttributeDivisor(
num index, num divisor) → void - Set vertex attribute data divisor
-
rlTexCoord2f(
num x, num y) → void - Define one vertex (texture coordinate) - 2 float
-
rlTextureParameters(
num id, num param, num value) → void - Set texture parameters (filter, wrap)
-
rlTranslatef(
num x, num y, num z) → void - Multiply the current matrix by a translation matrix
-
rlUnloadFramebuffer(
num id) → void - Delete framebuffer from GPU
-
rlUnloadRenderBatch(
RlRenderBatchD batch) → void - Unload render batch system
-
rlUnloadShader(
num id) → void - Unload shader, loaded with rlLoadShader();
-
rlUnloadShaderBuffer(
num ssboId) → void - Unload shader storage buffer object (SSBO)
-
rlUnloadShaderProgram(
num id) → void - Unload shader program
-
rlUnloadTexture(
num id) → void - Unload texture from GPU memory
-
rlUnloadVertexArray(
num vaoId) → void - Unload vertex array (vao)
-
rlUnloadVertexBuffer(
num vboId) → void - Unload vertex buffer object
-
rlUpdateShaderBuffer(
num id, TypedDataList data, num offset) → void - Update SSBO buffer data
-
rlUpdateTexture(
num id, num offsetX, num offsetY, num width, num height, PixelFormat format, Uint8List data) → void - Update texture with new data on GPU
-
rlUpdateVertexBuffer(
num bufferId, TypedDataList data, num dataSize, num offset) → void - Update vertex buffer object data on GPU buffer
-
rlUpdateVertexBufferElements(
num id, TypedDataList data, num dataSize, num offset) → void - Update vertex buffer elements data on GPU buffer
-
rlVertex2f(
num x, num y) → void - Define one vertex (position) - 2 float
-
rlVertex2i(
num x, num y) → void - Define one vertex (position) - 2 int
-
rlVertex3f(
num x, num y, num z) → void - Define one vertex (position) - 3 float
-
rlViewport(
num x, num y, num width, num height) → void - Set the viewport area
-
run<
T> (String name(), T f()) → T -
Executes
f, logging its label (and optionally timing it) when debug is enabled and the label passes all filters.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited